**Randomized Regulation: The Impact of Minimum Quality Standards on Health Markets**
=====

When selecting the parts of the master dofile to run, set clean to 0 and construct, mainresults, appendix, and supplemental to 1 as below*:

|	Code to run	  |	Set to 0/1  |	Description                                                         |
|	------------	|	------------| --------------------------------------------------------------------|	  
|	clean		      |	0	          |	De-identify and clean raw data (requires access to encrypted files)	|
| construct	    |	1	          |	Construct indicators for baseline, endline and analysis	            |
| mainresults	  |	1	          |	Run main tables and figures	                                        |
| appendix	    |	1	          |	Run appendix tables and figures	                                    |   
| supplemental	|	1	          |	Run supplemental material tables and figures	                      |         

# README

This replication package generates the main tables and figures used in the working paper, starting from clean, deidentified versions of the study datasets and including the construction of indicators used in the analysis. One master file runs all of the code to generate the data and final tables and figures. The replicator should expect the analysis code to generate the tables and figures to run for about 45 mins, and if including the data preparation and variable construction code for an additional 15 minutes.

## Instructions
-------------------------------
This reproducibility package contains the code necessary to replicate the results shown in the paper. To do so, follow the instructions below.

1. **Download the replication folder**

1. **Use the main dofile to replicate the results** in the `do-files` folder. It is only necessary to add your computer's username and path to adjust the default path and set up the working environment to run the replication files. You can select which sections to run by editing the globals.

1. **Outputs will be generated when you run the master do-file** and saved in the `rep-package/outputs` folder.

## Data availability and license
-------------------------------------
The data used to support the findings of this will be deposited in the World Bank's [Microdata Catalog](https://microdata.worldbank.org/index.php/catalog). Primary data were collected by the authors, and are available under a Creative Commons Non-commercial license. See LICENSE for details.

## Computational requirements
-------------------------------

### Software requirements
The paper exhibits were generated with Stata version 17. Required packages are included in the ado path folder and should be loaded with the `ieboilstart` command included in the main dofile.

### Memory and runtime requirements
Approximate time needed to reproduce the analyses on a standard 2020 desktop machine: 20-30 minutes. The code was first run on a dual-core Intel-based laptop with MacOS version 13.1.

## Description of code
-------------------------------
- The code in `dofiles/analysis` generates all tables and figures used in the paper. The code file `main.do` will run them all. Each program called from `main.do` identifies the table or figure it creates (e.g., `table5.do`).  Output files are called appropriate names (`table5.tex`, `figure1.png`) and should be easy to correlate with the manuscript.
- The code in `dofiles/baseline` and `dofiles/endline` and the subfolders `clean` and `construct`, cleans the raw encrypted data and construct the final indicators for each survey round. The dofile `main.do` will run them all. Access to encrypted files are required to run cleaning and deidentification code in the `clean` subfolders, and without access the switch for *clean* should be set to zero in `master.do`.
- Ado files have been stored in `dofiles/ado` and the `master.do` files set the ADO directories appropriately.

## List of outputs and code
-------------------------------
All analysis code is stored in `dofiles/analysis`. All outputs are saved to `outputs`. All the code can be run from the `main.do` script, but the code to recreate each output can also be run independently, as long as the folder globals and custom programs are set using the master script.

### Main

|	Output	      |	Dofile	                  |	Output file	  |	Notes	                |
|	------------	|	-------------------	      |	-------------	|	--------------------- |
|	Table 1	      |	main/table_1.do	          |	table_1.tex	  |		                    |
|	Table 2	      |	main/table_2.do	          |	table_2.tex	  |		                    |
|	Table 3	      |	main/table_3.do	          |	table_3.tex	  |		                    |
|	Table 4	      |	main/table_4.do	          |	table_4.tex	  |		                    |
|	Table 5	      |	main/table_5.do	          |	table_5.tex	  |		                    |
|	Table 6	      |	main/table_6.do	          |	table_6.tex	  |		                    |
|	Table 7	      |	main/table_7.do	          |	table_7.tex	  |		                    |
|	Figure 1	    |	N/A	                      |	N/A	         	|	Generated externally	|
|	Figure 2	    |	main/figure_2.do	        |	figure_2.png	|		                    |
|	Figure 3	    |	main/figure_3.do	        |	figure_3.png	|		                    |
|	Figure 4	    |	main/figure_4.do	        |	figure_4.png	|		                    |

### Appendix

|	Output	      |	Dofile	                |	Output file	    |	Notes	                |
|	------------	|	-------------------	    | -------------	  |	--------------------- |
|	Table A1	    |	N/A	                    |	N/A	         	  |	Generated externally	|
|	Table A2	    |	appendix/table_A2.do	  |	table_A2.tex	  |		                    |
|	Table A3	    |	appendix/table_A3.do	  |	table_A3.tex	  |		                    |
|	Table A4	    |	appendix/table_A4.do	  |	table_A4.tex	  |		                    |
|	Table A5	    |	appendix/table_A5.do	  |	table_A5.tex	  |		                    |
|	Table A6	    |	appendix/table_A6.do	  |	table_A6.tex	  |		                    |
|	Table A7	    |	appendix/table_A7.do	  |	table_A7.tex	  |		                    |
|	Table A8	    |	appendix/table_A8.do	  |	table_A8.tex	  |		                    |
|	Table A9	    |	appendix/table_A9.do	  |	table_A9.tex	  |		                    |
|	Table A10	    |	appendix/table_A10.do	  |	table_A10.tex	  |		                    |
|	Table A11	    |	appendix/table_A11.do	  |	table_A11.tex	  |		                    |
|	Table A12	    |	appendix/table_A12.do	  |	table_A12.tex	  |		                    |
|	Figure A1	    |	N/A	                    |	N/A	         	  |	Generated externally	|
|	Figure A2	    |	N/A	                    |	N/A	         	  |	Generated externally	|
|	Figure A3	    |	N/A	                    |	N/A	         	  |	Generated externally	|
|	Figure A4	    |	N/A	                    |	N/A	         	  |	Generated externally	|
|	Figure A5	    |	appendix/figure_A5.do	  |	figure_A5.tex	  |		                    |
|	Figure A6	    |	appendix/figure_A6.do	  |	figure_A6.tex	  |		                    |
|	Figure A7	    |	appendix/figure_A7.do	  |	figure_A7.tex	  |		                    |
|	Figure A8	    |	appendix/figure_A8.do	  |	figure_A8.tex	  |		                    |
|	Figure A9	    |	appendix/figure_A9.do	  |	figure_A9.tex	  |		                    |

### Supplemental Material

|	Output	      |	Dofile	                    |	Output file	    |	Notes	                |
|	------------	|	-------------------	        | -------------	  |	--------------------- |
|	Table S1	    | supplemental/table_S1.do	  |	table_S1.tex	  |		                    |
|	Table S2	    |	N/A	                        |	N/A	         	  |	Generated externally	|
|	Table S3	    |	supplemental/table_S3.do	  |	table_S3.tex	  |		                    |
|	Table S4	    |	supplemental/table_S4.do	  |	table_S4.tex	  |		                    |
|	Table S5	    |	supplemental/table_S5.do	  |	table_S5.tex	  |		                    |
|	Table S6	    |	supplemental/table_S6.do	  |	table_S6.tex	  |		                    |
|	Table S7	    |	supplemental/table_S7.do	  |	table_S7.tex	  |		                    |
|	Table S8	    |	supplemental/table_S8.do	  |	table_S8.tex	  |		                    |
|	Table S9	    |	supplemental/table_S9.do	  |	table_S9.tex	  |		                    |
|	Table S10	    |	supplemental/table_S10.do	  |	table_S10.tex	  |		                    |
|	Table S11	    |	supplemental/table_S11.do	  |	table_S11.tex	  |		                    |
|	Table S12	    |	supplemental/table_S12.do	  |	table_S12.tex	  |		                    |
|	Table S13	    |	supplemental/table_S13.do	  |	table_S13.tex	  |		                    |
|	Table S14	    |	supplemental/table_S14.do	  |	table_S14.tex	  |		                    |
|	Table S15	    |	supplemental/table_S15.do	  |	table_S15.tex	  |		                    |
|	Table S16	    |	supplemental/table_S16.do	  |	table_S16.tex	  |	Some manual formatting required |
|	Table S17	    |	supplemental/table_S17.do	  |	table_S17.tex	  |		                    |
|	Table S18a	  |	supplemental/table_S18a.do	|	table_S18a.tex	|		                    |
|	Table S18b	  |	supplemental/table_S18b.do	|	table_S18b.tex	|		                    |
|	Figure S1	    |	N/A	                        |	N/A	         	  |	Generated externally	|
|	Figure S2	    |	N/A	                        |	N/A	         	  |	Generated externally	|
|	Figure S3	    |	supplemental/figure_S3.do	  |	figure_S3.tex	  |		                    |
|	Figure S4	    |	supplemental/figure_S4.do	  |	figure_S4.tex	  |		                    |

## References
-------------------------------
Bedoya, Guadalupe, Jishnu Das, and Amy Dolinger. “Randomized Regulation: The Impact of Minimum Quality Standards on Health Markets.” *Forthcoming*.

## Issues
-------------------------------
If you run into any troubles running this code or reproducing results, please [create an `Issue`](https://github.com/dime-worldbank/kepsie/issues) in this repository.
