/*******************************************************************************	

Project:  		KePSIE


Written by:  	Thomas Escande			

Revision: 		

********************************************************************************			

THIS DO FILE: 	 Figure presenting the robustness of main coefficients to three different specifications.  

CONTENT:		Part 0 - Create globals for directories and files 


INPUTS:     	"${KePSIE_DB}/IE_Main_Paper/DataSets/Final/Data_for_analysis.dta"
					
OUTPUTS:     	

*******************************************************************************/

********************************************************************************
	** Part 0: Create globals for directories and files 
********************************************************************************

clear all
set more off

* Input 
glo inputdata 				"${dt_final}/data_for_analysis.dta" 

* Output 
glo figure_loc 				"${out_appendix}" 	
		
	* Output files:

		
		global control_hfs level_3 level_4_5 						i.strata_expanded
		global control_mks per_level_2 per_level_3 per_level_4_5 	i.strata_expanded
		global control_bl_char oop_all_bl_m_mi oop_all_bl_m_mi_d jhic_all_bl_m_mi jhic_all_bl_m_mi_d outp_as_jan_bl_m_mi outp_as_jan_bl_m_mi_d
	
		global interaction		private private_t	
		
		global sample  s2
		
	*Options for graphs
	global graph_opts title(, justification(center) color(black) span pos(20)) graphregion(color(white)) ylab(,angle(0) nogrid noticks)  legend(region(lc(none) fc(none)))

********************************************************************************
** Part 1: Preparing dataset
********************************************************************************	

*Setting up controls for each situation:
global control_1 ${control_hfs}
global control_2 ""
global control_3 ${control_hfs} ${control_bl_char}


		use "${inputdata}", clear
		

*******************************To delete once corrected******************************
/*Correcting oop_all_bl_m_mi (should be corrected later on in the construction). Issue is, facilities with missing oop at baseline also have a 0 at the market level variable, instead of the market value*/
bys market_all_expanded: egen temp_oop_all_bl_m = max(oop_all_bl_m_mi)
replace oop_all_bl_m_mi = temp_oop_all_bl_m
drop temp_oop_all_bl_m

*For the dummy
bys market_all_expanded: egen temp_oop_all_bl_m_mi_d = max(oop_all_bl_m_mi_d)
replace oop_all_bl_m_mi_d = temp_oop_all_bl_m_mi_d
drop temp_oop_all_bl_m_mi_d
**********************************End delete*****************************************

	gen x_axis_1   = _n if _n < 4
	gen x_axis_2   = x_axis_1 + 0.1	
	gen x_axis_3   = x_axis_2 + 0.1	
	

*JHIC 
local outcome   jhic_all 	
forvalues spec = 1/3 	{	
	
	gen coeff_`spec' 	= .
    gen CIl_`spec' 		= .
    gen CIu_`spec' 		= .		
	
	foreach var in `outcome' `outcome'_w {
		
		if "`var'" == "`outcome'" {
		local i = 1
		
		reg `var' t ${control_`spec'}  			if $sample == 1 , vce(cluster market_all_expanded)	
	
		replace coeff_`spec'   =  _b[t]	    		if _n == `i'
		replace CIl_`spec'	 =  r(table)[5,1]		if _n == `i'
		replace CIu_`spec' 	 =  r(table)[6,1]	    if _n == `i'
	
		}
	
		if "`var'" == "`outcome'_w" {
		local var `outcome'	
		local i = 2
		
		reg `var' t ${control_`spec'}  	[aw = weight]		if $sample == 1 , vce(cluster market_all_expanded)	
	
		replace coeff_`spec'   =  _b[t]	    		if _n == `i'
		replace CIl_`spec'	 =  r(table)[5,1]		if _n == `i'
		replace CIu_`spec' 	 =  r(table)[6,1]	    if _n == `i'
	
		}
		
	}
}


gen zero = 0	

gen 	x_axis_zero = 0.5 	if _n == 1 
replace x_axis_zero = 2.8	if _n == 2 

		
twoway  (scatter coeff_1    x_axis_1   	,mcolor(dkgreen)) ///
		(scatter coeff_2   x_axis_2   	,mcolor(edkblue)) ///
		(scatter coeff_3   x_axis_3   	,mcolor(sienna)) ///
		(rcap CIl_1 	CIu_1   x_axis_1  , lcolor(dkgreen))  ///		
		(rcap CIl_2 	CIu_2   x_axis_2  , lcolor(edkblue))  ///
		(rcap CIl_3 	CIu_3   x_axis_3  , lcolor(sienna))  ///
		(line  zero x_axis_zero, lcolor(gs0) lwidth(vthin))  ///
		, ///
		$graph_opts legend(rows(3) pos(6) order(1 2 3) label(1 "Main Specification") label(2 "No imputation, No controls") label(3 "Main Specification + Market Baseline Controls") size(tiny)) ///
		 xlabel( 1.1 "Unweighted" 2.1 "Weighted"  , noticks labgap(3)) xscale(noline range(0.5 2.5) titlegap(3) ) yscale(noline) ///
		ytitle("JHIC Score") yscale(range(0 12)) ylab(0(4)12, noticks labgap(2)) scheme(cleanplots) title("JHIC Score") name(jhic)
		
	*graph export  "${figure_loc}/figure_A5_robust_`outcome'.pdf", replace as(pdf)		

	drop coeff* CI*

*JHIC : Public / Private 
local outcome   jhic_all 	
forvalues spec = 1/3 	{	
	
	gen coeff_`spec' 	= .
    gen CIl_`spec' 		= .
    gen CIu_`spec' 		= .		
	
	foreach var in `outcome' `outcome'_w {
		
		if "`var'" == "`outcome'" {
		local i = 1
		
		reg `var' t $interaction ${control_`spec'}  			if $sample == 1 , vce(cluster market_all_expanded)	
	
		replace coeff_`spec'   =  _b[t]	    		if _n == 1
		replace CIl_`spec'	 =  r(table)[5,1]		if _n == 1
		replace CIu_`spec' 	 =  r(table)[6,1]	    if _n == 1

		lincom  t +   private_t 				
	
		replace coeff_`spec' =  _b[t] + _b[private_t]	if _n == 2
		replace CIl_`spec'	 =  r(lb)					if _n == 2
		replace CIu_`spec' 	 =  r(ub)	    			if _n == 2	
		
		}
		
	}
}


		
twoway  (scatter coeff_1    x_axis_1   	,mcolor(dkgreen)) ///
		(scatter coeff_2   x_axis_2   	,mcolor(edkblue)) ///
		(scatter coeff_3   x_axis_3   	,mcolor(sienna)) ///
		(rcap CIl_1 	CIu_1   x_axis_1  , lcolor(dkgreen))  ///		
		(rcap CIl_2 	CIu_2   x_axis_2  , lcolor(edkblue))  ///
		(rcap CIl_3 	CIu_3   x_axis_3  , lcolor(sienna))  ///
		(line  zero x_axis_zero, lcolor(gs0) lwidth(vthin))  ///
		, ///
		$graph_opts legend(rows(3) pos(6) order(1 2 3) label(1 "Main Specification") label(2 "No imputation, No controls") label(3 "Main Specification + Market Baseline Controls") size(small)) ///
		 xlabel( 1.1 "Public" 2.1 "Private"  , noticks labgap(3)) xscale(noline range(0.5 2.5) titlegap(3) ) yscale(noline) ///
		ytitle("JHIC Score") yscale(range(0 12)) ylab(0(4)12, noticks labgap(2)) scheme(cleanplots) title("JHIC Score by Ownership" "Unweighted")	name(jhic_pri)
		
	*graph export  "${figure_loc}/figure_A5_robust_`outcome'_pub_pri.pdf", replace as(pdf)		

	drop coeff* CI*	

*OOP
local outcome   oop_all_imp 	
forvalues spec = 1/3 	{	
	
	gen coeff_`spec' 	= .
    gen CIl_`spec' 		= .
    gen CIu_`spec' 		= .		
	
	foreach var in `outcome' `outcome'_w {
		
		if "`var'" == "`outcome'" {
			if `spec' == 2 {
				local var oop_all
			}
		local i = 1
		
		reg `var' t ${control_`spec'}  			if $sample == 1 , vce(cluster market_all_expanded)	
	
		replace coeff_`spec'   =  _b[t]	    		if _n == `i'
		replace CIl_`spec'	 =  r(table)[5,1]		if _n == `i'
		replace CIu_`spec' 	 =  r(table)[6,1]	    if _n == `i'
	
		}
	
		if "`var'" == "`outcome'_w" {
		local var `outcome'	
			if `spec' == 2 {
				local var oop_all
			}		
		local i = 2
		
		reg `var' t ${control_`spec'}  	[aw = weight]		if $sample == 1 , vce(cluster market_all_expanded)	
	
		replace coeff_`spec'   =  _b[t]	    		if _n == `i'
		replace CIl_`spec'	 =  r(table)[5,1]		if _n == `i'
		replace CIu_`spec' 	 =  r(table)[6,1]	    if _n == `i'
	
		}
		
	}
}


		
twoway  (scatter coeff_1    x_axis_1   	,mcolor(dkgreen)) ///
		(scatter coeff_2   x_axis_2   	,mcolor(edkblue)) ///
		(scatter coeff_3   x_axis_3   	,mcolor(sienna)) ///
		(rcap CIl_1 	CIu_1   x_axis_1  , lcolor(dkgreen))  ///		
		(rcap CIl_2 	CIu_2   x_axis_2  , lcolor(edkblue))  ///
		(rcap CIl_3 	CIu_3   x_axis_3  , lcolor(sienna))  ///
		(line  zero x_axis_zero, lcolor(gs0) lwidth(vthin))  ///
		, ///
		$graph_opts legend(rows(3) pos(6) order(1 2 3) label(1 "Main Specification") label(2 "No imputation, No controls") label(3 "Main Specification + Market Baseline Controls") size(small)) ///
		 xlabel( 1.1 "Unweighted" 2.1 "Weighted"  , noticks labgap(3)) xscale(noline range(0.5 2.5) titlegap(3) ) yscale(noline) ///
		ytitle("OOP (USD PPP)") yscale(range(-2 4)) ylab(-2(1)4, noticks labgap(2)) scheme(cleanplots) title("OOP (USD PPP)")	name(oop)
		
	*graph export  "${figure_loc}/figure_A5_robust_`outcome'.pdf", replace as(pdf)		

	drop coeff* CI*	


*OOP : Public / Private 
local outcome   oop_all_imp 	
forvalues spec = 1/3 	{	
	
	gen coeff_`spec' 	= .
    gen CIl_`spec' 		= .
    gen CIu_`spec' 		= .		
	
	foreach var in `outcome' `outcome'_w {
		
		if "`var'" == "`outcome'" {
		local i = 1
		
			if `spec' == 2 {
				local var oop_all
			}			
			
		reg `var' t $interaction ${control_`spec'}  	[aw = weight]			if $sample == 1 , vce(cluster market_all_expanded)	
	
		replace coeff_`spec'   =  _b[t]	    		if _n == 1
		replace CIl_`spec'	 =  r(table)[5,1]		if _n == 1
		replace CIu_`spec' 	 =  r(table)[6,1]	    if _n == 1

		lincom  t +   private_t 				
	
		replace coeff_`spec' =  _b[t] + _b[private_t]	if _n == 2
		replace CIl_`spec'	 =  r(lb)					if _n == 2
		replace CIu_`spec' 	 =  r(ub)	    			if _n == 2	
		
		}
		
	}
}
		
twoway  (scatter coeff_1    x_axis_1   	,mcolor(dkgreen)) ///
		(scatter coeff_2   x_axis_2   	,mcolor(edkblue)) ///
		(scatter coeff_3   x_axis_3   	,mcolor(sienna)) ///
		(rcap CIl_1 	CIu_1   x_axis_1  , lcolor(dkgreen))  ///		
		(rcap CIl_2 	CIu_2   x_axis_2  , lcolor(edkblue))  ///
		(rcap CIl_3 	CIu_3   x_axis_3  , lcolor(sienna))  ///
		(line  zero x_axis_zero, lcolor(gs0) lwidth(vthin))  ///
		, ///
		$graph_opts legend(rows(3) pos(6) order(1 2 3) label(1 "Main Specification") label(2 "No imputation, No controls") label(3 "Main Specification + Market Baseline Controls") size(small)) ///
		 xlabel( 1.1 "Public" 2.1 "Private"  , noticks labgap(3)) xscale(noline range(0.5 2.5) titlegap(3) ) yscale(noline) ///
		ytitle("OOP (USD PPP)")  yscale(range(-2 4)) ylab(-2(1)4, noticks labgap(2)) scheme(cleanplots) title("OOP (USD PPP) by Ownership" "Weighted") name(oop_pri)
		
	*graph export  "${figure_loc}/figure_A5_robust_`outcome'_pub_pri.pdf", replace as(pdf)		

	drop coeff* CI*	




*OUtpatient
local outcome   outp_as_jan  	
forvalues spec = 1/3 	{	
	
	gen coeff_`spec' 	= .
    gen CIl_`spec' 		= .
    gen CIu_`spec' 		= .		
	
	foreach var in `outcome'  {
		
		if "`var'" == "`outcome'" {
		local i = 1
		
		reg `var' t ${control_`spec'}  			if $sample == 1 , vce(cluster market_all_expanded)	
	
		replace coeff_`spec'   =  _b[t]	    		if _n == `i'
		replace CIl_`spec'	 =  r(table)[5,1]		if _n == `i'
		replace CIu_`spec' 	 =  r(table)[6,1]	    if _n == `i'

		
		reg `var' t $interaction ${control_`spec'}  			if $sample == 1 , vce(cluster market_all_expanded)	
	
		replace coeff_`spec'   =  _b[t]	    		if _n == 2
		replace CIl_`spec'	 =  r(table)[5,1]		if _n == 2
		replace CIu_`spec' 	 =  r(table)[6,1]	    if _n == 2

		lincom  t +   private_t 				
	
		replace coeff_`spec' =  _b[t] + _b[private_t]	if _n == 3
		replace CIl_`spec'	 =  r(lb)					if _n == 3
		replace CIu_`spec' 	 =  r(ub)	    			if _n == 3	
		
		}		
	}
}

replace x_axis_zero = 3.8	if _n == 3 
		
twoway  (scatter coeff_1    x_axis_1   	,mcolor(dkgreen)) ///
		(scatter coeff_2   x_axis_2   	,mcolor(edkblue)) ///
		(scatter coeff_3   x_axis_3   	,mcolor(sienna)) ///
		(rcap CIl_1 	CIu_1   x_axis_1  , lcolor(dkgreen))  ///		
		(rcap CIl_2 	CIu_2   x_axis_2  , lcolor(edkblue))  ///
		(rcap CIl_3 	CIu_3   x_axis_3  , lcolor(sienna))  ///
		(line  zero x_axis_zero, lcolor(gs0) lwidth(vthin))  ///
		, ///
		$graph_opts legend(rows(3) pos(6) order(1 2 3) label(1 "Main Specification") label(2 "No imputation, No controls") label(3 "Main Specification + Market Baseline Controls") size(small)) ///
		 xlabel( 1.1 "All" 2.1 "Public" 3.1 "Private"  , noticks labgap(3)) xscale(noline range(0.5 2.8) titlegap(3) ) yscale(noline) ///
		ytitle("Daily Outpatient") yscale(range(-4 16)) ylab(-4(4)16, noticks labgap(2)) scheme(cleanplots) title("Daily Outpatient")	name(outp)
		

	*graph export  "${figure_loc}/figure_A5_robust_`outcome'.pdf", replace as(pdf)		

	drop coeff* CI*
	
grc1leg jhic jhic_pri oop oop_pri outp, row(3) iscale(.5) ysize(8) graphregion(color(white)) legendfrom(jhic) 
	
graph export  "${figure_loc}/figure_A5.png", replace 	





		
