/*******************************************************************************	

Project:  		KePSIE - Kenya
Created on:  	June 27, 2019
Last udpate on: June 27, 2019

Written by:  	Thomas Escande (tescande@worldbank.org)

Revision: 		

********************************************************************************			

THIS DO FILE: 	 Computes the Quantile Treatment Effect for the four main outcomes.   

CONTENT:		Part 0 - Create globals for directories and files
				Part 1 - Create the different graphs
				Part 2 - Combine the graphs on a single page

INPUTS:     	*dataset for analysis

OUTPUTS:		* Quantile Treatment Effect figures  

Note: This dofile requires two ado files to run which were taken from the paper "Distributional Impact Analysis", Bedoya et al.   	

*******************************************************************************/

********************************************************************************
	** Part 0: Create globals for directories and files 
********************************************************************************
	clear all
	set more off
	set maxvar 20000

  * Set the environment to make randomization replicable
    version 12.0 	
	
	*Running the adofiles which will be used in the dofile
		do "${program}/bscr.ado" 
		do "${program}/dte.ado"		

		global 	dataout_qte		"${dt_end_fin}"
		

	*Inputs
		global 	inputdata	 	"${dt_final}/data_for_analysis.dta" 
		global 	inputdata_oop_p	"${dt_final}/oop_p.dta"	

	* Outputs
		global 	output_gr 		"${out_appendix}"
		global 	output_gr2 		"${out_appendix}"
	
	
	*Date 
		global date = word(c(current_date),1) + word(c(current_date),2) + word(c(current_date),3)

		global graph_opts title(, justification(center) color(black) span pos(20)) graphregion(color(white)) ylab(,angle(0) nogrid) xtit(,placement(center) justification(center)) legend(region(lc(none) fc(none)))

	*What to do
		local CDF   = 0
		local graph = 1
		global value = "ppp"
********************************************************************************
	** Part 1: Create the different graphs
********************************************************************************


	global control_hfs  level_3 level_4_5 i.strata_expanded 
	global qte_outcome  jhic_all outp_as_jan /*inactive*/ oop_all  
						

foreach private_cond in "" "& private==1" /*"& private==0"*/ {
	if "`private_cond'"=="& private==1"  {
		global priv "Private"
	}
	else if "`private_cond'"=="& private==0" {
		global priv "Public"
	} 
	else if "`private_cond'"=="" {
		global priv "All"
	} 
	
local h = 1  /*FWER values 1 and 2*/	
local k = 0
local colnames 
matrix CDF_${priv} = J(4, 4, 0)
    matrix colnames CDF_${priv} = "Mean_Control" "CDF_60" "CI_low" "CI_high" 
	

	foreach var in $qte_outcome {
	
	*Setting specific parameters for each graph
		if "`var'"=="jhic_all" {
			global  title "JHIC Score, $priv Facilities"
			global 	ytitle 	"ytitle(Score Points, margin(medsmall) size(small))"
			global 	ytitle2 "ytitle(Impact (% of control), margin(medsmall) size(small))"
			local 	ylabel 	"ylabel(0(5)15, noticks format(%9.0fc)  labsize(vsmall) angle(0))"
			local 	ylabel2 "ylabel(0(10)30 0 "0%" 10 "10%" 20 "20%" 30 "30%", noticks format(%9.0fc)  labsize(vsmall) angle(0))"
			global  data 	"$inputdata"
			global  weight 		""
			global  weight_p 	""
			global  force 	""
			local   col 	"jhic"
		}
		
		if "`var'"=="outp_as_jan" {
			global title "Daily Outpatients, $priv Facilities"
			global 	ytitle 	"ytitle(Number of Outpatients, margin(medsmall) size(small))"
			global 	ytitle2 "ytitle(Impact (% of control), margin(medsmall) size(small))"
			local 	ylabel 	"ylabel(-20(10)40, noticks format(%9.0fc) labsize(vsmall) angle(0))"
			local 	ylabel2 "ylabel(-10(10)50  -10 "-10%" 0 "0%" 10 "10%" 20 "20%" 30 "30%" 40 "40%" 50 "50%", noticks format(%9.0fc) labsize(vsmall) angle(0))"
			global  data 	"$inputdata"
			global  weight 		""
			global  weight_P 	""
			global force 	""
			local   col 	"outpatient"
		}
		
		if "`var'"=="inactive" {
			global title "Inactive Health Facilities at Endline, $priv Facilities"
			global 	ytitle 	"ytitle(Number of HFs, margin(medsmall) size(small))"
			global 	ytitle2 "ytitle(Impact (% of control), margin(medsmall) size(small))"
			
			local 	ylabel 	"ylabel(0(0.25)1.25 0 "0", noticks format(%9.2f) labsize(vsmall) angle(0))"
			local 	ylabel2 "ylabel(0(0.25)1.25 0 "0", noticks format(%9.2f) labsize(vsmall) angle(0))"
			
			global  data 	"$inputdata"
			global  weight 		""
			global  weight_p 		""
			global force 	""
			local   col 	"inactive"
		}
		
		if "`var'"=="oop_all" {
			global title "Out of Pocket Expenses, $priv Facilities"
					if "${value}" == "kes" {
						global 	ytitle 	"ytitle(KES, margin(medsmall) size(small))"
						global 	ytitle2 "ytitle(Impact (% of control), margin(medsmall) size(small))"
						local 	ylabel 	"ylabel(-300(100)300 0 "0", noticks format(%9.0f) labsize(vsmall) angle(0))"
						local 	ylabel2 	"ylabel(-10(10)30 -10 "-10%" 0 "0%" 10 "10%" 20 "20%" 30 "30%", noticks format(%9.0f) labsize(vsmall) angle(0))"
						}
					if "${value}" == "usd" {
						global 	ytitle 	"ytitle(USD, margin(medsmall) size(small))"
						local 	ylabel 	"ylabel(-3(1)3 0 "0", noticks format(%9.0f) labsize(vsmall) angle(0))"
						}
					if "${value}" == "ppp" {
						global 	ytitle 	"ytitle(PPP, margin(medsmall) size(small))"
						local 	ylabel 	"ylabel(-10(5)15 0 "0", noticks format(%9.0f) labsize(vsmall) angle(0))"
						}
			global  data 	"$inputdata"
			global  weight 		 " " 
			global  weight_p 		" " 
			global force 	" "
			local   col 	"OOP"
		}
				
		use "$data", clear

		keep if !mi(t) `private_cond' //Cannot have missing for the ado file so need to drop 
		gen zero = 0 	
		
		disp "`private_cond'"
		disp "`var'"
		disp "${control_hfs}"
		disp "$weight"
		
		sum `var' $weight
		local control_av = r(mean)	
		
		local k = `k' + 1
		local colnames "`colnames' `col'"
		local i = 2000 //Number of iteration for the bootstrap, can be changed
		local per "5/95"
		

	*Running the two ado files and saving the value of the coefficient and the confidence interval to then use for the graphs
		dte `var' t ,  cluster(market_all_expanded)  ///
		stat(mean sd) perc(`per')  ///
		reps(`i') seed(0101)    ///
		saving("$dataout_qte/`var'_qte.dta", replace)
		
		mat `var' = e(b)

	estat bootstrap, percentile
	bscr using "${dataout_qte}/`var'_qte.dta", fwer(1)

	mat `var'_se = e(se)
	mat `var'_cr = e(cr)

	*Creating variables with the matrices
		gen var_`var'   	= .
		gen var_`var'_se 	= .
		gen var_`var'_cr1 = .
		gen var_`var'_cr2 = .
		gen var_`var'_att = .
		gen var_`var'_att_cr1 = .
		gen var_`var'_att_cr2 = .
		gen count 		= .

	forvalues i =3/93 {
		replace var_`var' 		= `var'[1,`i'] 		if _n == `i' - 2
		replace var_`var'_se 	= `var'_se[1,`i'] 	if _n == `i' - 2
		replace var_`var'_cr1 	= `var'_cr[1,`i'] 	if _n == `i' - 2
		replace var_`var'_cr2 	= `var'_cr[2,`i'] 	if _n == `i' - 2
		replace var_`var'_att 	= `var'[1,1] 		if _n == `i' - 2
		replace var_`var'_att_cr1 	= `var'_cr[1,1] 		if _n == `i' - 2
		replace var_`var'_att_cr2	= `var'_cr[2,1] 		if _n == `i' - 2
		replace count 			= _n + 4 if _n == `i' - 2
	}


	*Different format for monetary variables versus non monetary ones
	if "`var'"=="oop_all"  {
		format %9.0fc var_`var'
	}
	else {
		format %9.3fc var_`var'
	} 


	twoway   ///
			(rarea var_`var'_cr1 var_`var'_cr2 count , color(gs14)) ///
			( line  var_`var' count, lcolor(gs0) ) /// 
			( line  zero count, lcolor(gs0) lwidth(vthin))	,  ///
			 xscale(range(5 95)) xlab(5(5)95 ,labgap(2)  format(%9.0f) noticks labsize(tiny)) $graph_opts  ///
			 xtit("Percentile", size(vsmall)  margin(medsmall) justification(center)) 	///
			 $ytitle `ylabel'  title("	$title",size(medsmall)) ///
			 legend(symys(2) symxs(6) order(2 3 1 5) pos(12) ring(0) col(2) label(1 "95% CI (QTE)") label(2 "QTE") label(3 "Zero")  size(1.5) ) name(qte_`var'_${priv}_`h'fwer) scheme(cleanplots)

	*graph save    "${output_gr}/qte_`var'_${priv}_`h'fwer", replace
	*graph export  "${output_gr}/qte_`var'_${priv}_`h'fwer.pdf", replace as(pdf)
	
	
	
	drop count 
	
	}

    matrix rownames CDF_${priv} = `colnames'
		}
		
********************************************************************************
	** Part 2: Combine the graphs on a single page
********************************************************************************
	if `graph' == 1 {
	graph combine /// 
		qte_jhic_all_All_`h'fwer ///
		qte_outp_as_jan_All_`h'fwer ///
		qte_oop_all_All_`h'fwer ///
		qte_oop_all_Private_`h'fwer ///
		,   graphregion(color(white)) /*title("Quantile Treatment Effect Estimates")*/		
		*"${output_gr}/qte_inactive_$priv.gph" ///	
			
	graph export "${figure_loc}/figure_A9.png" , replace
	
	/* Impact as percentage of control mean
	graph combine /// 
		"${output_gr}/qte_jhic_all_A_`h'fwer2.gph" ///
		"${output_gr}/qte_outp_as_jan_${priv}_`h'fwer2.gph" ///
		"${output_gr}/qte_oop_all_${priv}_`h'fwer2.gph" ///
		,   graphregion(color(white)) /*title("Quantile Treatment Effect Estimates")*/		
		*"${output_gr}/qte_inactive_$priv.gph" ///	
		
		graph export "${output_gr}/qte_all_${priv}_`h'fwer_${end}2.pdf" , replace as(pdf)
	*/

	}
	
		if `CDF' == 1 {
	foreach priv in "Private" "Public" "All" {
		matrix list 	CDF_`priv'
			}
		}
	
*********************************End of dofile***********************************************************************
