/*******************************************************************************	
Project:  	KePSIE
*******************************************************************************/
********************************************************************************
** Create globals for directories and files 
********************************************************************************
clear all
set more off

* Input
glo inputdata	 		"${dt_final}/data_for_analysis.dta"
glo pubprisat 			"${dt_end_fin}/pub_pri_saturation.dta"
		
* Output
loc out 				table_A11
glo tex_`out'			"${do_appendix}/tex/tex_`out'.do"
glo tex_`out'_out 		"${out_appendix}/`out'.tex"

* Programs		
glo save_coeff			"${program}/save_coeff.do"
do "${save_coeff}"

********************************************************************************
** Run table
********************************************************************************
* Treatments	
glo t1 					t1 t2
glo treatments_pooled 	t1_2 t2_2
* Control vars
glo control_hfs 		level_3 level_4_5 						i.strata_expanded
glo control_mks			 per_level_2 per_level_3 per_level_4_5 	i.strata_expanded
* Outcomes
glo main_outcome		jhic_all
* Sample
glo sample 				s2
	
* Setup
use "${pubprisat}", clear	

	* Number of public HFs within market
	recode private (1=0) (0=1), gen(public)	
	bys market_all_expanded: egen pub_no_m = total(public) if active==1
	lab var pub_no_m "Number of public HFs within market"	
	foreach x in pub_no_m {
		gen `x'_t = `x'*t
		loc label : var label `x'
		lab var `x'_t "`label' x T"
		}		

* Table	
keep if private==1

glo interaction		pub_no_m pub_no_m_t	
glo test_B 			T + Public in Market x T = 0
loc treatment		t
loc interaction	 	pub_no_m
loc interaction_t	pub_no_m_t

* Run regression
	* Unweighted	
 foreach var in $main_outcome {
	reg `var'  `treatment' $interaction $control_hfs marketsize_rand_expanded if $sample == 1 , vce(cluster market_all_expanded)
	gen reg_sample = e(sample)
		sum `var'  											if `treatment' == 0 & $sample == 1 & reg_sample == 1
		save_coeff_t `var' 
		save_coeff_interaction `var'_inter  `var'_inter_t  `interaction' `interaction_t'	
		
		sum `var' if t==0 & reg_sample==1 // Mean control
		glo `var'm0 : di  %4.3f `r(mean)' 		
		glo `var'sd : di  %4.2f `r(sd)' 		
				
		sum `interaction' if reg_sample==1 // Mean number of public HFs in markets
		glo `var'mi : di  %4.3f `r(mean)' 	
		
		loc `interaction'c = _b[t] + ${`var'mi} * _b[`interaction_t']
		glo `var'imp1 	: di %2.0f ``interaction'c' /${`var'm0}*100 // Impact {% change}
		glo `var's1 	: di %4.2f ``interaction'c' / ${`var'sd} // SD
		
		test t + ${`var'mi} * `interaction_t' = 0	
		glo `var'pval : di  %4.3f `r(p)'
		
		drop reg_sample
		}
		
* Adding ***
glo coeff_table
foreach var in $main_outcome {
	glo coeff_table $coeff_table `var'1 `var'_inter3 `var'_inter_t3
	} 
	star coeff_table	
	
		
********************************************************************************
** Export
********************************************************************************
glo table_name 		"Table${TableNumber}_$date"

glo C_1 			"JHIC Score (Private Facilities)"
glo R_text 			"$\rm {R}^{2}$" 
glo N_text 			"Observations"

glo B_pr_text 		"Private"
glo B_pu_text 		"Public"	

* Labels
lab var t 				"Treatment"
lab var pub_no_m 		"No. Public Facilities in Market"	
lab var pub_no_m_t 		"No. Public Facilities in Market x T"

glo t 					: variable label t
glo t_B 				: variable label t

glo inter_B 			: variable label pub_no_m 	
glo inter_t_B   		: variable label pub_no_m_t

* Table global
glo table_name "${tex_`out'_out}"

* Start the Latex document
texdoc do "${tex_`out'}"		

			
		
			


		
		
		
		
