/*******************************************************************************

Project:  			KePSIE
Created on:
Last update on:

Written by:

Revision:

********************************************************************************

THIS DO FILE: 	Produces the main table of the "Treatment Effects on Intermediate Outcomes" 


CONTENT:		Setup: Create globals for directories and files

INPUTS:     	* Input files

					* Final data for analysis
					"${KePSIE_DB}/IE_Main_Paper/DataSets/Final/Data_for_analysis.dta"

					* Final OOP data at the patient level
					"${KePSIE_DB}/IE_Main_Paper/DataSets/Intermediate/OOP_p.dta"


				
*******************************************************************************/

********************************************************************************
** Setup: Create globals for directories and files
********************************************************************************
clear all
set more off
	
* Input 
glo inputdata 			"${dt_final}/data_for_analysis.dta" 
glo inputdata_pe		"${dt_end_fin}/pe_for_analysis.dta" 

* Output 
loc out 				table_A12
glo tex_`out'			"${do_appendix}/tex/tex_`out'.do"
glo tex_`out'_out 		"${out_appendix}/`out'.tex"

* Programs		
glo save_coeff			"${program}/save_coeff.do"
do "${save_coeff}"	

		
*-----------------------------------------------------------------------
* Table globals
*-----------------------------------------------------------------------
use "${inputdata}", clear	
				
	** Treatments	
		glo t1 t1 t2
		glo treatments_pooled t1_2 t2_2

	** Control vars
		glo control_hfs level_3 level_4_5 						i.strata_expanded
		glo control_mks per_level_2 per_level_3 per_level_4_5 	i.strata_expanded
		
	** Outcomes
		glo outcomes jhic_all oop_all outp_as_jan inactive

	** Labels
		glo t1_t 	: variable label t1_2
		glo t2_t 	: variable label t2_2
		glo t    	: variable label t
		glo priv 	: variable label private
		glo priv_t  : variable label private_t
		
		glo out_inputdata 	jhic_all outp_as_jan inactive
		glo main_outcome 	jhic_all oop_all outp_as_jan inactive
		
		glo sample s2
			
********************************************************************************
** Table X. Treatment Effects on Select Intermediate Outcomes
********************************************************************************					
*Specific globals		
	
	*Outcomes
		global inter_outcome 	regulationaware_hf scorecardaware_hf scorecardknow2_p scorecardaware_p  improvedq_p inspectedhf_p
	

	capture macro drop C_* L* note
local i = 1
	foreach var in $inter_outcome {
	
	if "`var'" == "scorecardaware_p" | "`var'" == "scorecardknow_p" | "`var'" == "scorecardknow2_p" | "`var'" == "improvedq_p" | "`var'" == "inspectedhf_p" {
	use "${inputdata_pe}", clear
	global weight ""
	global weight2 "[aw=weight_p]"
	global C_`i' : variable label `var' 
	}
		if "`var'" == "regulationaware_hf" | "`var'" == "scorecardaware_hf"  {
	use "$inputdata", clear
	global weight ""
	global weight2 "[aw=weight]"
	}
		if "`var'" == "regulationaware_hf" {	
	global C_`i'  "Familiar with the New Legislation JHIC (Awareness)"
	}
			if "`var'" == "scorecardaware_hf" {	
	global C_`i'  "Ever Noticed a Scorecard (Awareness)"
	}

	reg `var' t1_2 t2_2 ${control_hfs} $weight , vce(cluster market_all_expanded)
		sum `var' $weight if t == 0 & e(sample) == 1
		coeff_treat L1_C`i'_A_ t1_2
		coeff_treat L2_C`i'_A_ t2_2
	*Test of equality
		test t1_2 = t2_2
		global L_C`i'_A_test :  di %4.3f r(p)	
		
capture confirm variable counter_hf		
	if _rc==0 { 
	gen reg_sample = e(sample) if e(sample) == 1
	bys hfid (reg_sample): gen count_hf = _n if reg_sample == 1
	count if count_hf == 1 // Counting number of facilities in the sample
	global L1_C`i'_A_N_hf = r(N)
	drop reg_sample count_hf
	}	
	
	reg `var' t1_2 t2_2 ${control_hfs} $weight2 , vce(cluster market_all_expanded)
		sum `var' $weight2 if t == 0 & e(sample) == 1
		coeff_treat L1_C`i'_B_ t1_2
		coeff_treat L2_C`i'_B_ t2_2
	*Test of equality
		test t1_2 = t2_2
		global L_C`i'_B_test :  di %4.3f r(p)	
		
capture confirm variable counter_hf		
	if _rc==0 { 
	gen reg_sample = e(sample) if e(sample) == 1
	bys hfid (reg_sample): gen count_hf = _n if reg_sample == 1
	count if  count_hf == 1 // Counting number of facilities in the sample
	global L1_C`i'_B_N_hf = r(N)
	drop reg_sample	count_hf
 }
		local i = `i' + 1
	}
	
global N_var    = `i' - 1
global last_var `var'
lab var t1_2 "Inspection Only (T1)"
lab var t2_2 "Inspections plus Information (T2)"
global t1_2 : variable label t1_2
global t2_2 : variable label t2_2
global PanelA  	"Unweighted"
global PanelB 	"Weighted"
global left  	"In-Charge Level"
global right  	"Patient Level"
global note 	""

* Table global
glo table_name "${tex_`out'_out}"

* Start the Latex document
texdoc do "${tex_`out'}"	
