/*******************************************************************************	
Project:  	KePSIE
*******************************************************************************/
********************************************************************************
** Create globals for directories and files 
********************************************************************************
clear all
set more off

* Input
glo inputdata	 		"${dt_final}/data_for_analysis.dta" 
glo adh					"${dt_bl_clean}/pps_kds_bl_adh.dta"
glo kno 				"${dt_bl_clean}/pps_hcw_bl_adh.dta"
glo sup					"${dt_bl_clean}/pps_so_bl_adh.dta"
		
* Output
loc out 				table_A2
glo tex_`out'			"${do_appendix}/tex/tex_`out'.do"
glo tex_`out'_out 		"${out_appendix}/`out'"	

* Programs		
glo save_coeff			"${program}/save_coeff.do"			
do "${save_coeff}"
	
********************************************************************************
** Setup
********************************************************************************
use "${inputdata}", clear		

* Table globals
* ----------------------------------
* Treatments	
glo t1 t1 t2
glo treatments_pooled t1_2 t2_2
* Control vars
glo control_hfs level_3 level_4_5 						i.strata_expanded
glo control_mks per_level_2 per_level_3 per_level_4_5 	i.strata_expanded
* Sample
glo sample 		s2	
* Outcomes
glo vars1  		jhic_all_bl oop_all_bl
glo vars2		outp_as_jan_bl public_bl level_2_bl level_3_bl public_s0 level_2_s0 level_3_s0 unlicensed_s0
* Weights
glo weight		weight_bl

* Setup // to move to construction
use "${inputdata}", clear
recode private (0=1) (1=0), gen(public_bl)
recode private (0=1) (1=0), gen(public)
foreach x in public level level_2 level_3 {
	replace `x'_bl = `x' if mi(`x'_bl) & bl_consent!=.
	replace `x'_bl = . if bl_consent==.
	clonevar `x'_s0 = `x'
	replace `x'_s0 = . if active_s0!=1
	}
			
********************************************************************************
** Run table
********************************************************************************			

* Unweighted			
foreach x in $vars1 $vars2 {
reg `x' t i.strata_expanded, vce(cluster market_all_expanded)
	sum `x' 
	glo `x'1 		:  di %4.3f _b[t]
	glo `x'1sd 		:  di %4.3f _se[t]
	glo `x'1p 		:  di %4.3f (2 * ttail(e(df_r), abs(_b[t]/_se[t])))
	glo N_`x'1 		= e(N)
	sum `x' if t == 0
	glo `x'_mc 		: di %4.3f `r(mean)'
	glo `x'_sdc 	: di %4.3f `r(sd)'
	sum `x' if t == 1
	glo `x'_mt1 	: di %4.3f `r(mean)'
	glo `x'_sdt1	: di %4.3f `r(sd)'
	sum `x'
	glo N_`x' 		: di %4.0f `r(N)'		
	}
														
* Weighted		
foreach x in $vars1 {
reg `x' t i.strata_expanded [aw=$weight], vce(cluster market_all_expanded)
	sum `x' [aw=$weight]
	glo `x'_w_1 	:  di %4.3f _b[t]
	glo `x'_w_1sd 	:  di %4.3f _se[t]
	glo `x'_w_1p 	:  di %4.3f (2 * ttail(e(df_r), abs(_b[t]/_se[t])))
	glo N_`x'_w_1 = e(N)
	sum `x' if t == 0 [aw=$weight]
	glo `x'_w_mc 	: di %4.3f `r(mean)'
	glo `x'_w_sdc 	: di %4.3f `r(sd)'
	sum `x' if t == 1 [aw=$weight]
	glo `x'_w_mt1 	: di %4.3f `r(mean)'
	glo `x'_w_sdt1	: di %4.3f `r(sd)'
	sum `x' [aw=$weight]
	glo N_`x'_w 	: di %4.0f `r(N)'		
	}						
	
foreach x in $vars2 {
reg `x' t i.strata_expanded, vce(cluster market_all_expanded)
	sum `x' 
	glo `x'_w_1 	:  di %4.3f _b[t]
	glo `x'_w_1sd 	:  di %4.3f _se[t]
	glo `x'_w_1p 	:  di %4.3f (2 * ttail(e(df_r), abs(_b[t]/_se[t])))
	glo N_`x'_w_1 	= e(N)
	sum `x' if t == 0
	glo `x'_w_mc 	: di %4.3f `r(mean)'
	glo `x'_w_sdc 	: di %4.3f `r(sd)'
	sum `x' if t == 1
	glo `x'_w_mt1 	: di %4.3f `r(mean)'
	glo `x'_w_sdt1	: di %4.3f `r(sd)'
	sum `x'
	glo N_`x'_w 	: di %4.0f `r(N)'		
	}					

* Adding ***
glo coeff_table
foreach var in $vars1 $vars2 {
	glo coeff_table $coeff_table `var'1 `var'_w_1 
	}
	star coeff_table
		
* Adherence
use "${adh}", clear
	loc x 				adherence
	glo weight			weight_do
	reg `x' t i.strata_expanded, vce(cluster market_all_expanded)
		sum `x' if e(sample)==1
		glo `x'1 		:  di %4.3f _b[t]
		glo `x'1sd 		:  di %4.3f _se[t]
		glo `x'1p 		:  di %4.3f (2 * ttail(e(df_r), abs(_b[t]/_se[t])))
		glo N_`x'1 		= e(N)
		sum `x' if t == 0 & e(sample)==1
		glo `x'_mc 		: di %4.3f `r(mean)'
		glo `x'_sdc 	: di %4.3f `r(sd)'
		sum `x' if t == 1 & e(sample)==1
		glo `x'_mt1 	: di %4.3f `r(mean)'
		glo `x'_sdt1	: di %4.3f `r(sd)'
		sum `x' if `x'!=. & active_s0==1
		glo N_`x' 		: di %4.0f `r(N)'	
		unique hfid if `x'!=. & active_s0==1
		glo N_hf_`x' = r(unique)		
	reg `x' t i.strata_expanded [aw=$weight], vce(cluster market_all_expanded)
		sum `x' [aw=$weight] if `x'!=.
		glo `x'_w_1 	:  di %4.3f _b[t]
		glo `x'_w_1sd 	:  di %4.3f _se[t]
		glo `x'_w_1p 	:  di %4.3f (2 * ttail(e(df_r), abs(_b[t]/_se[t])))
		glo N_`x'_w_1 = e(N)
		sum `x' if t == 0 & e(sample)==1 [aw=$weight]
		glo `x'_w_mc 	: di %4.3f `r(mean)'
		glo `x'_w_sdc 	: di %4.3f `r(sd)'
		sum `x' if t == 1 & e(sample)==1 [aw=$weight]
		glo `x'_w_mt1 	: di %4.3f `r(mean)'
		glo `x'_w_sdt1	: di %4.3f `r(sd)'
		sum `x' [aw=$weight] if e(sample)==1
		glo N_`x'_w 	: di %4.0f `r(N)'				
		lab var adherence		"\makecell[l]{Compliance with IPC Practices \\ (Patient-HCW indication level)}"
		glo adherence 			: variable label adherence
	
* Supplies	
use "${sup}", clear
	loc x 				pps_so_total 
	glo weight			weight_so
	reg `x' t i.strata_expanded, vce(cluster market_all_expanded)
		sum `x' if e(sample)==1
		glo `x'1 		:  di %4.3f _b[t]
		glo `x'1sd 		:  di %4.3f _se[t]
		glo `x'1p 		:  di %4.3f (2 * ttail(e(df_r), abs(_b[t]/_se[t])))
		glo N_`x'1 		= e(N)
		sum `x' if t == 0 & e(sample)==1
		glo `x'_mc 		: di %4.3f `r(mean)'
		glo `x'_sdc 	: di %4.3f `r(sd)'
		sum `x' if t == 1 & e(sample)==1
		glo `x'_mt1 	: di %4.3f `r(mean)'
		glo `x'_sdt1	: di %4.3f `r(sd)'
		sum `x' if `x'!=. & active_s0==1
		glo N_`x' 		: di %4.0f `r(N)'	
		unique hfid if `x'!=. & active_s0==1
		glo N_hf_`x' = r(unique)		
	reg `x' t i.strata_expanded [aw=$weight], vce(cluster market_all_expanded)
		sum `x' [aw=$weight] if e(sample)==1
		glo `x'_w_1 	:  di %4.3f _b[t]
		glo `x'_w_1sd 	:  di %4.3f _se[t]
		glo `x'_w_1p 	:  di %4.3f (2 * ttail(e(df_r), abs(_b[t]/_se[t])))
		glo N_`x'_w_1 = e(N)
		sum `x' if t == 0 & e(sample)==1 [aw=$weight] 
		glo `x'_w_mc 	: di %4.3f `r(mean)'
		glo `x'_w_sdc 	: di %4.3f `r(sd)'
		sum `x' if t == 1 & e(sample)==1 [aw=$weight]
		glo `x'_w_mt1 	: di %4.3f `r(mean)'
		glo `x'_w_sdt1	: di %4.3f `r(sd)'
		sum `x' [aw=$weight] if e(sample)==1
		glo N_`x'_w 	: di %4.0f `r(N)'	
		
lab var pps_so_total	"IPC Supplies (Site level)"
glo pps_so_total 		: variable label pps_so_total
		
* Knowledge
use "${kno}", clear
	loc x 				pps_kn_total 
	glo weight			weight_hcw	
	reg `x' t i.strata_expanded, vce(cluster market_all_expanded)
		sum `x' if e(sample)==1
		glo `x'1 		:  di %4.3f _b[t]
		glo `x'1sd 		:  di %4.3f _se[t]
		glo `x'1p 		:  di %4.3f (2 * ttail(e(df_r), abs(_b[t]/_se[t])))
		glo N_`x'1 		= e(N)
		sum `x' if t == 0 & e(sample)==1
		glo `x'_mc 		: di %4.3f `r(mean)'
		glo `x'_sdc 	: di %4.3f `r(sd)'
		sum `x' if t == 1 & e(sample)==1
		glo `x'_mt1 	: di %4.3f `r(mean)'
		glo `x'_sdt1	: di %4.3f `r(sd)'
		sum `x' if `x'!=. & active_s0==1
		glo N_`x' 		: di %4.0f `r(N)'	
		unique hfid if `x'!=. & active_s0==1
		glo N_hf_`x' = r(unique)	
	reg `x' t i.strata_expanded [aw=$weight], vce(cluster market_all_expanded)
		sum `x' [aw=$weight] if e(sample)==1
		glo `x'_w_1 	:  di %4.3f _b[t]
		glo `x'_w_1sd 	:  di %4.3f _se[t]
		glo `x'_w_1p 	:  di %4.3f (2 * ttail(e(df_r), abs(_b[t]/_se[t])))
		glo N_`x'_w_1 = e(N)
		sum `x' if t == 0 & e(sample)==1 [aw=$weight]
		glo `x'_w_mc 	: di %4.3f `r(mean)'
		glo `x'_w_sdc 	: di %4.3f `r(sd)'
		sum `x' if t == 1 & e(sample)==1 [aw=$weight]
		glo `x'_w_mt1 	: di %4.3f `r(mean)'
		glo `x'_w_sdt1	: di %4.3f `r(sd)'
		sum `x' [aw=$weight] if e(sample)==1
		glo N_`x'_w 	: di %4.0f `r(N)'		
		
lab var pps_kn_total	"IPC Knowledge (HCW level)"
glo pps_kn_total 		: variable label pps_kn_total
		
glo pps_vars 	adherence pps_so_total pps_kn_total
		
* Adding *** if needed
glo coeff_table
foreach var in $pps_vars {
	glo coeff_table $coeff_table `var'1 `var'_w_1 
	}
	star coeff_table	
	

* F-test. Merging all the datasets at the adherence level to be able to run a regression with all the variables 	

use "${adh}", clear
collapse (mean) adherence [aw=weight_do] , by(hfid)
merge 1:1 hfid using "${inputdata}", keepusing(t unlicensed_s0 jhic_all_bl oop_all_bl outp_as_jan_bl private level level_bl level_2_bl level_3_bl level_4_5_bl level_2 level_3 market_all_expanded strata_expanded bl_consent active_s0) nogen
tempfile adh_input 
save `adh_input'

use "${sup}", clear
collapse (mean) pps_so_total [aw=weight_so] , by(hfid)
merge 1:1 hfid using `adh_input', nogen
tempfile adh_input2 
save `adh_input2'

use "${kno}", clear
collapse (mean) pps_kn_total [aw=weight_hcw] , by(hfid)
merge 1:1 hfid using `adh_input2', nogen


recode private (0=1) (1=0), gen(public_bl) // to move to construction
recode private (0=1) (1=0), gen(public)
foreach x in public level level_2 level_3 {
	replace `x'_bl = `x' if mi(`x'_bl) & bl_consent!=.
	replace `x'_bl = . if bl_consent==.
	clonevar `x'_s0 = `x'
	replace `x'_s0 = . if active_s0!=1
	}

* Vars
loc vars jhic_all_bl oop_all_bl outp_as_jan_bl public_bl level_2_bl level_3_bl level_4_5_bl pps_kn_total pps_so_total adherence

* Regression
reg t `vars' i.strata_expanded, vce(cluster market_all_expanded)
testparm `vars'
glo Ftest :  di %4.3f `r(F)'
glo Fpval :  di %4.3f `r(p)'

	
	
********************************************************************************
** Export
********************************************************************************
glo PanelA 		"Balance using baseline sample"
glo PanelB 		"Balance using randomization sample (select variables)"
glo C_1 		"(C) \\ Control \\ Mean"
glo C_2 		"(T-C) \\ Adj. Diff."			
glo C_3 		"Obs."
glo left		"Unweighted"
glo right		"Weighted"	

* Labels
lab var jhic_all_bl 	"JHIC Score (\% of max)"
lab var oop_all_bl 		"OOP (USD PPP)"
lab var outp_as_jan_bl 	"Daily Outpatients"
lab var public_bl		"Public"
lab var level_2_bl 		"Level 2"
lab var level_3_bl 		"Level 3"

lab var public_s0		"Public"
lab var level_2_s0 		"Level 2"
lab var level_3_s0 		"Level 3"
lab var unlicensed_s0 	"\makecell[l]{Unlicensed (Private only)}"

glo jhic_all_bl 	: variable label jhic_all_bl
glo oop_all_bl 		: variable label oop_all_bl
glo outp_as_jan_bl 	: variable label outp_as_jan_bl
glo public_bl 		: variable label public_bl
glo level_2_bl 		: variable label level_2_bl
glo level_3_bl 		: variable label level_3_bl

glo public_s0 		: variable label public_s0
glo level_2_s0 		: variable label level_2_s0
glo level_3_s0 		: variable label level_3_s0
glo unlicensed_s0 	: variable label unlicensed_s0	

glo ftestl	"F-test from regression of treatment \\ on all outcome variables listed above"

glo vars_out1a jhic_all_bl oop_all_bl outp_as_jan_bl 
glo vars_out1b adherence pps_kn_total pps_so_total 
glo vars_out1c public_bl level_2_bl level_3_bl 
glo vars_out2 public_s0 level_2_s0 level_3_s0 unlicensed_s0

* Table specific globals
glo table_name "${tex_`out'_out}"

* Start the Latex document
texdoc do "${tex_`out'}"			
						
						
						
						
						
						
						

