/******************************************************************************* 
 
Project:  			KePSIE 

 
Written by:			Thomas Escande
Revision: 
 
Using PDS lasso to understand whether there are any omitted variable bias when looking at the price / jhic correlation 
 
********************************************************************************* 
 
******************************************************************************** 
** Setup: Create globals for directories and files 
********************************************************************************/ 
 
clear all 
set more off 
 
	* Input files 
 
		* Data 		 
		glo inputdata 					"${dt_final}/data_for_analysis.dta" 
		glo inputdata_item 				"${dt_bl_const}/jhic_compliance_items_bl.dta"	
											 
				  
		glo strata 			i.strata_expanded 

		global date = word(c(current_date),1) + word(c(current_date),2) + word(c(current_date),3) 

		 *Paths
		glo note			"Generated by do file Gradient_pds_oop_JHICtypes_bl on $date" 
  
		global	sample s2

		* Outputs 
		loc out 						table_A3
		glo tex_`out'					"${do_appendix}/tex/tex_`out'.do"
		glo tex_`out'_out 				"${out_appendix}/`out'"	
		
			
	set seed 1234
	 

	 * Controls
*All
global  hd_controls_varlist_0_bl 	i.strata_expanded level_2_bl level_3_bl level_4_5_bl /// 
									unlicensed_s0_all outp_as_jan_bl ///
									private ///
									county startyear_group daysopen_bl  mfl_bl ///
									lab_bl pharm_bl consult_rooms_bl ngofbo_bl nhif_outp_bl nhif_outp_mo_bl nhif_plus_bl  /// 
									staff_total_bl qual_bl qual_per_bl  ///
									marketsize_r0  maintown_km_bl maintown_km_group_bl maintown_m_bl market_e_km_group ///
									market_e_km  ///
									public_tot_s0 public_2plus_s0 allprivate_s0 allpublic_s0 singleton_s0 jhic_all_bl_m 
		 
*Public	 
global  hd_controls_varlist_1_bl 	i.strata_expanded level_2_bl level_3_bl level_4_5_bl ///
									unlicensed_s0_all outp_as_jan_bl ///
									county startyear_group daysopen_bl mfl_bl  ///
									lab_bl pharm_bl consult_rooms_bl ngofbo_bl nhif_outp_bl nhif_outp_mo_bl nhif_plus_bl  /// 
									staff_total_bl qual_bl qual_per_bl  ///
									marketsize_r0  maintown_km_bl maintown_km_group_bl maintown_m_bl market_e_km_group ///
									market_e_km  ///
									public_tot_s0 public_2plus_s0 allprivate_s0 allpublic_s0 singleton_s0 jhic_all_bl_m 	 
								 
*Private								 
global  hd_controls_varlist_2_bl 	i.strata_expanded level_2_bl level_3_bl level_4_5_bl ///
									unlicensed_s0_all outp_as_jan_bl ///									
									county startyear_group daysopen_bl mfl_bl private_type_bl ///
									lab_bl pharm_bl consult_rooms_bl ngofbo_bl nhif_outp_bl nhif_outp_mo_bl nhif_plus_bl  /// 
									staff_total_bl qual_bl qual_per_bl  ///
									marketsize_r0  maintown_km_bl maintown_km_group_bl maintown_m_bl market_e_km_group ///
									market_e_km  ///
									public_tot_s0 public_2plus_s0 allprivate_s0 allpublic_s0 singleton_s0 jhic_all_bl_m 	 								 
								 
*********************************************************************************	

local type = "priv"
	if "`type'" == "all" {
		local priv = 0
		local sample ""
		local control "private"
		local if ""
		local title_main "All Facilities"
	}	
	if "`type'" == "pub" {
		local priv = 1
		local sample "& private == 0"
		local control ""
		local if "if private == 0"
	}
	if "`type'" == "priv" {
		local priv = 2
		local sample "& private == 1"
		local control ""
		local if "if private == 1"	
		local title_main "Private Facilities"
	}
	

	
use "${inputdata_item}", clear
preserve 

merge m:1 hfid using "${inputdata}", nogen keep(3)

	
	*Main var
	local y oop_all_bl
	local x item_adh	


local i = 1

foreach category in Infrastructure Equipment Supplies_lc Supplies_mc  Management Medical_Records SOPs {

********************************Change when needed ***********************************************************
local partial_var_main  "unlicensed_s0_all level_2_bl level_3_bl level_4_5_bl  i.strata_expanded" /**/
**************************************************************************************************************		


	if "`category'" == "Equipment" {
		local title "Equipment"
		local sample  "& item_group_1 == 1"
		local if "if item_group_1 == 1"			
	}	
	
	if "`category'" == "Infrastructure" {
		local title "Infrastructure"
		local sample  "& item_group_2 == 1"
		local if "if item_group_2 == 1"			
	}
	
	if "`category'" == "Management" {
		local title "Management"
		local sample  "& item_group_3 == 1"	
		local if "if item_group_3 == 1"			
	}
	
	if "`category'" == "Medical_Records" {
		local title "Medical Records "
		local sample  "& item_group_4 == 1"	
		local if "if item_group_4 == 1"		
	}	
	
	if "`category'" == "SOPs" {
		local title "SOPs "
		local sample  "& item_group_5 == 1"	
		local if "if item_group_5 == 1"	
	}
	
	if "`category'" == "Supplies_lc" {
		local title "Supplies Low Cost"
		local sample  "& item_group_6 == 1"		
		local if "if item_group_6 == 1"	
	}
	
	if "`category'" == "Supplies_mc" {
		local title "Supplies Middle Cost"
		local sample  "& item_group_7 == 1"	
		local if "if item_group_7 == 1"		
	}

	

******************************************* using pdslasso to select control

		
pdslasso `y' `x'  ///
		(${hd_controls_varlist_`priv'_bl}) `if' ///
		, ///
		partial(`partial_var_main') cluster(market_all_expanded) rlasso

global N_var`i' = e(xselected_ct)		
		
* `e(xselected)' are the controls selected by the PDSlasso		
	reg 	`y' `x'  `partial_var_main' `e(xselected)'	 if e(sample) == 1 `sample' ,  vce(cluster market_all_expanded)	
	
local R : di %4.2f  e(r2_a)
global grad_R_`i'  = "`R'"
*local grad_rmse_`i' = e(rmse)
	
*Saving for later the different coefficients
local c  : di %4.3f  _b[`x']
local p  = r(table)[4,1]	
global grad_`i'_c1  = "`c'"
if `p' <= 0.1 {
global grad_`i'_c1  = "${grad_`i'_c1}"	+ "*"
	if `p' <= 0.05 {
		global grad_`i'_c1  = "${grad_`i'_c1}"	+ "*"
		if `p' <= 0.01 {
			global grad_`i'_c1  = "${grad_`i'_c1}"	+ "*"
		}
	}
}


*Saving for later the different coefficients
local c2  : di %4.3f  _b[unlicensed_s0_all]
local p2  = r(table)[4,2]	
global grad_`i'_c2  = "`c2'"
if `p2' <= 0.1 {
global grad_`i'_c2  = "${grad_`i'_c2}"	+ "*"
	if `p2' <= 0.05 {
		global grad_`i'_c2  = "${grad_`i'_c2}"	+ "*"
		if `p2' <= 0.01 {
			global grad_`i'_c2  = "${grad_`i'_c2}"	+ "*"
		}
	}
}


local se : di %4.3f _se[`x']
global grad_`i'_se1 =  "`se'" 
local se2 : di %4.3f _se[unlicensed_s0_all]
global grad_`i'_se2 =  "`se2'" 

global grad_N_`i' = e(N)


estat ic
global BIC_`i' = r(S)[1,6]


	*JHIC score
	sum `x' if $sample == 1 `sample' & e(sample) == 1
	local `x'_mean : di %4.2f r(mean)
	local `x'_se   : di %4.2f r(sd)	
	global jhic_stat_`i'    = "``x'_mean' (``x'_se')"
	
	
local i = `i' + 1

}
	
*preparing globals for the latex table 
glo R_1		"Item Adherence"
glo R_2		"Unlicensed"

	
* Table global
glo table_name "${tex_`out'_out}"

* Start the Latex document
texdoc do "${tex_`out'}"	
	
