/*******************************************************************************
*					     			KePSIE 		    		       			   *
********************************************************************************		
********************************************************************************
** Create locals for files 
*******************************************************************************/
clear all
set more off
	
* Input 
glo inputdata 			"${dt_final}/data_for_analysis.dta" 

* Output 
loc out 				table_A4
glo tex_`out'			"${do_appendix}/tex/tex_`out'.do"
glo tex_`out'_out 		"${out_appendix}/`out'.tex"

* Programs
glo stats				"${program}/stats.do"
do "${stats}"	

********************************************************************************
** Table 1: Summary statistics at baseline
********************************************************************************
use "${inputdata}", clear

* Setup
* -------
keep if private==1 // only for private facilities

forvalues i=1/5 {

	*Licensed
	qui count if jhic_all_bl_c_q_pri==`i' & unlicensed_s0==0
	loc lic_c_den`i'= `r(N)'	
	qui count if jhic_all_bl_c_q_pri==`i' & inactive==1 & unlicensed_s0==0
	loc lic_c_num`i'= `r(N)'	
	loc lic_c_`i' 	= `lic_c_num`i''/`lic_c_den`i''
	glo lic_c_`i' 	: di %3.2f `lic_c_`i''	

		qui count if !mi(jhic_all_bl_c_q_pri) & unlicensed_s0==0
		loc lic_all_c_den 	= `r(N)'
		qui count if !mi(jhic_all_bl_c_q_pri) & inactive==1 & unlicensed_s0==0
		loc lic_all_c_num	= `r(N)'
		loc lic_all_c		= `lic_all_c_num'/`lic_all_c_den'
		glo lic_all_c		: di %3.2f `lic_all_c'
	
	qui count if jhic_all_bl_t_q_pri==`i' & unlicensed_s0==0
	loc lic_t_den`i'= `r(N)'
	qui count if jhic_all_bl_t_q_pri==`i' & close_enforce==1 & unlicensed_s0==0
	loc lic_tc_num`i'= `r(N)'	
	loc lic_tc_`i' 	= `lic_tc_num`i''/`lic_t_den`i''
	glo lic_tc_`i' 	: di %3.2f `lic_tc_`i''	
	
		qui count if !mi(jhic_all_bl_t_q_pri) & unlicensed_s0==0
		loc lic_all_t_den 	= `r(N)'
		qui count if !mi(jhic_all_bl_t_q_pri) & close_enforce==1 & unlicensed_s0==0
		loc lic_all_tc_num	= `r(N)'
		loc lic_all_tc		= `lic_all_tc_num'/`lic_all_t_den'
		glo lic_all_tc		: di %3.2f `lic_all_tc'	
	
	qui count if jhic_all_bl_t_q_pri==`i' & inactive==1 & unlicensed_s0==0
	loc lic_t_num`i'= `r(N)'	
	loc lic_t_`i' 	= `lic_t_num`i''/`lic_t_den`i''
	glo lic_t_`i' 	: di %3.2f `lic_t_`i''
	
		qui count if !mi(jhic_all_bl_t_q_pri) & inactive==1 & unlicensed_s0==0
		loc lic_all_ti_num	= `r(N)'
		loc lic_all_ti		= `lic_all_ti_num'/`lic_all_t_den'
		glo lic_all_ti		: di %3.2f `lic_all_ti'		
	
	*Unlicensed
	qui count if jhic_all_bl_c_q_pri==`i' & unlicensed_s0==1
	loc unl_c_den`i'= `r(N)'
	qui count if jhic_all_bl_c_q_pri==`i' & inactive==1 & unlicensed_s0==1
	loc unl_c_num`i'= `r(N)'	
	loc unl_c_`i' 	= `unl_c_num`i''/`unl_c_den`i''
	glo unl_c_`i' 	: di %3.2f `unl_c_`i''	
	
	qui count if jhic_all_bl_c_q_pri==`i' & unlicensed_s0==1
	loc unl_c_den`i'= `r(N)'
	qui count if jhic_all_bl_c_q_pri==`i' & close_enforce==1 & unlicensed_s0==1
	loc unl_cc_num`i'= `r(N)'	
	loc unl_cc_`i' 	= `unl_cc_num`i''/`unl_c_den`i''
	glo unl_cc_`i' 	: di %3.2f `unl_cc_`i''		
	
		qui count if !mi(jhic_all_bl_c_q_pri) & unlicensed_s0==1
		loc unl_all_c_den 	= `r(N)'
		qui count if !mi(jhic_all_bl_c_q_pri) & close_enforce==1 & unlicensed_s0==1
		loc unl_all_cc_num	= `r(N)'
		loc unl_all_cc		= `unl_all_cc_num'/`unl_all_c_den'
		glo unl_all_cc		: di %3.2f `unl_all_cc'			
	
		qui count if !mi(jhic_all_bl_c_q_pri) & unlicensed_s0==1
		loc unl_all_c_den 	= `r(N)'
		qui count if !mi(jhic_all_bl_c_q_pri) & inactive==1 & unlicensed_s0==1
		loc unl_all_c_num	= `r(N)'
		loc unl_all_c		= `unl_all_c_num'/`unl_all_c_den'
		glo unl_all_c		: di %3.2f `unl_all_c'	
	
	qui count if jhic_all_bl_t_q_pri==`i' & unlicensed_s0==1
	loc unl_t_den`i'= `r(N)'
	qui count if jhic_all_bl_t_q_pri==`i' & close_enforce==1 & unlicensed_s0==1
	loc unl_tc_num`i'= `r(N)'	
	loc unl_tc_`i' 	= `unl_tc_num`i''/`unl_t_den`i''
	glo unl_tc_`i' 	: di %3.2f `unl_tc_`i''		
	
		qui count if !mi(jhic_all_bl_t_q_pri) & unlicensed_s0==1
		loc unl_all_t_den 	= `r(N)'
		qui count if !mi(jhic_all_bl_t_q_pri) & close_enforce==1 & unlicensed_s0==1
		loc unl_all_tc_num	= `r(N)'
		loc unl_all_tc		= `unl_all_tc_num'/`unl_all_t_den'
		glo unl_all_tc		: di %3.2f `unl_all_tc'		
	
	qui count if jhic_all_bl_t_q_pri==`i' & inactive==1 & unlicensed_s0==1
	loc unl_t_num`i'= `r(N)'	
	loc unl_t_`i' 	= `unl_t_num`i''/`unl_t_den`i''
	glo unl_t_`i' 	: di %3.2f `unl_t_`i''	
	
		qui count if !mi(jhic_all_bl_t_q_pri) & inactive==1 & unlicensed_s0==1
		loc unl_all_ti_num	= `r(N)'
		loc unl_all_ti		= `unl_all_ti_num'/`unl_all_t_den'
		glo unl_all_ti		: di %3.2f `unl_all_ti'		
	
	*All private
	qui count if jhic_all_bl_c_q_pri==`i'
	loc c_den`i'= `r(N)'
	qui count if jhic_all_bl_c_q_pri==`i' & inactive==1
	loc c_num`i'= `r(N)'	
	loc c_`i' 	= `c_num`i''/`c_den`i''
	glo c_`i' 	: di %3.2f `c_`i''
	
		qui count if jhic_all_bl_c_q_pri==`i'
		loc c_den`i'= `r(N)'
		qui count if jhic_all_bl_c_q_pri==`i' & close_enforce==1
		loc cc_num`i'= `r(N)'	
		loc cc_`i' 	= `cc_num`i''/`c_den`i''
		glo cc_`i' 	: di %3.2f `cc_`i''		
	
		qui count if !mi(jhic_all_bl_c_q_pri) 
		loc all_c_den 	= `r(N)'
		qui count if !mi(jhic_all_bl_c_q_pri) & inactive==1 
		loc all_c_num	= `r(N)'
		loc all_c		= `all_c_num'/`all_c_den'
		glo all_c		: di %3.2f `all_c'		
		
		qui count if !mi(jhic_all_bl_c_q_pri) 
		loc all_c_den 	= `r(N)'
		qui count if !mi(jhic_all_bl_c_q_pri) & close_enforce==1 
		loc all_cc_num	= `r(N)'
		loc all_cc		= `all_cc_num'/`all_c_den'
		glo all_cc		: di %3.2f `all_cc'			
	
	qui count if jhic_all_bl_t_q_pri==`i'
	loc t_den`i'= `r(N)'
	qui count if jhic_all_bl_t_q_pri==`i' & close_enforce==1
	loc tc_num`i'= `r(N)'	
	loc tc_`i' 	= `tc_num`i''/`t_den`i''
	glo tc_`i' 	: di %3.2f `tc_`i''	
	
		qui count if !mi(jhic_all_bl_t_q_pri) 
		loc all_t_den 	= `r(N)'
		qui count if !mi(jhic_all_bl_t_q_pri) & close_enforce==1 
		loc all_tc_num	= `r(N)'
		loc all_tc		= `all_tc_num'/`all_t_den'
		glo all_tc		: di %3.2f `all_tc'			
	
	qui count if jhic_all_bl_t_q_pri==`i' & inactive==1
	loc t_num`i'= `r(N)'	
	loc t_`i' 	= `t_num`i''/`t_den`i''
	glo t_`i' 	: di %3.2f `t_`i''	
	
		qui count if !mi(jhic_all_bl_t_q_pri) & inactive==1 
		loc all_ti_num	= `r(N)'
		loc all_ti		= `all_ti_num'/`all_t_den'
		glo all_ti		: di %3.2f `all_ti'		
	}	
		

		
* Run
* ------
glo C_1 		"Licensed"
glo C_2 		"Unlicensed"
glo C_3 		"All Private"

glo SC_1 		"Control"
glo SC_2 		"Treatment"
glo SC_3 		"Closed"
glo SC_4 		"Inactive"

glo panelA 		"JHIC Quintile"
glo R1 			"Lowest"
glo R2 			"2nd"
glo R3 			"3rd"
glo R4 			"4th"
glo R5 			"Top"
glo R6 			"All"



* Table global
glo table_name "${tex_`out'_out}"

* Start the Latex document
texdoc do "${tex_`out'}"	

				


				
				
				
				
				
				
				
