/*******************************************************************************	
*		Project:
*			KePSIE IE

********************************************************************************	

********************************************************************************			

** PURPOSE: 	This do-file runs the regression for the wealth index on the mean and by Quintiles 
				
** INPUTS:     	


** OUTLINE: 	Part 0: 

** OUTPUTS:    
				

** Written by: Thomas Escande

*******************************************************************************/

*******************************************************************************/


********************************************************************************

*** # Part 0: Initiate and import the database

********************************************************************************

clear all
set more off

*Running the adofiles which will be used in the dofile
	do "${program}/bscr.ado" 
	do "${program}/dte.ado"		

 *Uncomment if want to run the do file separately
*Input
global wealth_pe 		"${dt_end_const}/wealth_index_end.dta" 
global inputdata		"${dt_final}/data_for_analysis.dta"
global inputdata_oop	"${dt_final}/oop_p.dta"

*Output
global table_loc 					"${out_appendix}" // "${Dropbox}/Apps/Overleaf/KePSIE_Main_Paper_Tables&Figures/tables" //Change location depending on where final latex output should be found		
		
global tex_table_impact_wealth		"${do_appendix}/tex/tex_table_A6.do"		

*Saving final name 
glo table_name						"${out_appendix}/table_A6"
	
*Global 
global control_hfs 				level_3 level_4_5 
global sample  s2 
global graph_opts title(, justification(center) color(black) span pos(20)) graphregion(color(white)) ylab(,angle(0) nogrid)  legend(region(lc(none) fc(none)))

set seed 5

********************************************************************************
	** Part 1: Create the different regressions
********************************************************************************
use "${inputdata_oop}", clear
cap drop _merge
drop if mi(key)
tempfile inputdata_oop_p
save `inputdata_oop_p'


*Adding the missing variables to the wealth dataset
*At endline
use "${wealth_pe}", clear


merge m:1 hfid using "${inputdata}" , keep(3) keepusing(t market_all_expanded strata_expanded level_3 level_4_5 private private_t ) nogen 

merge 1:1 key using `inputdata_oop_p' , keep(3) keepusing(weight*) nogen 

*Setting up locals for the regressions
local var dhs_wealth_kepsie
local h = 1  /*FWER values 1 and 2*/	
local k = 0

* unweighted
* reg `var' t ${control_hfs} 	i.strata_expanded , vce(cluster market_all_expanded)


reg `var' t ${control_hfs} 	i.strata_expanded  [aw=weight_p]  , vce(cluster market_all_expanded)


*Saving coeff 
global coeff_1 	:  di %4.3f _b[t]
global se_1 	:  di %4.3f r(table)[2,1]
global p_1 		:  di %4.3f r(table)[4,1]			
global N_1 = e(N)



*Quintile Regression for all



	*Running the quantile regression 
foreach quint  in 2 4 6 8 {
  qreg dhs_wealth_kepsie t  ${control_hfs} 	i.strata_expanded [pw=weight_p]  ,  q(0.`quint') 
  
*Saving coefficients
		global coeff_`quint'    :  di %4.3f _b[t] 
		global se_`quint' 		:  di %4.3f r(table)[2,1]
		global p_`quint'  		:  di %4.3f r(table)[4,1]		
		global N_`quint' = e(N)
}	



global title2 = "20th" 
global title4 = "40th" 
global title6 = "60th" 
global title8 = "80th" 

*Regression coefficients
foreach quint  in 1 2 4 6 8 {
global coeff_`quint'  	= "$" + "${coeff_`quint'}" + "$"	
	
	if ${p_`quint'} <= 0.1 {
	global coeff_`quint'  = "${coeff_`quint'}"	+ "*"
		if ${p_`quint'} <= 0.05 {
		global coeff_`quint'  = "${coeff_`quint'}"	+ "*"
			if ${p_`quint'} <= 0.01 {
			global coeff_`quint'  = "${coeff_`quint'}"	+ "*"
			}
		}
	}	
	

global se_`quint' 		= "$" + "(" + "${se_`quint'}" + ")" + "$" 
global p_`quint'  		= "$" + "[" + "${p_`quint'}" + "]"  + "$" 
}	
	
	*Generating table in Latex 
	texdoc do "${tex_table_impact_wealth}"
	
