/*******************************************************************************	
Project:  	KePSIE
*******************************************************************************/
********************************************************************************
** Create globals for directories and files 
********************************************************************************
clear all
set more off
	
* Input 
glo inputdata 			"${dt_final}/data_for_analysis.dta" 
glo inputdata_p 		"${dt_final}/oop_p.dta" 
glo s4a 				"${dt_end_fin}/staff_for_analysis.dta"

* Output 
loc out 				table_A9
glo tex_`out'			"${do_appendix}/tex/tex_`out'.do"
glo tex_`out'_out 		"${out_appendix}/`out'.tex"

* Programs		
glo save_coeff			"${program}/save_coeff.do"
do "${save_coeff}"
	
********************************************************************************
** Setup
********************************************************************************
use "${s4a}", clear	
drop cost_staff_total_mo cost_staff_mo_staff cost_staff_mo_p qual_per qual_p
merge 1:1 hfid using "${inputdata}", keepus(qual_per qual_p unlicensed_s2 unlicensed_s2_t) keep(2 3)
ren staff_cost_mo			cost_staff_total_mo
ren staff_cost_mo_staff		cost_staff_mo_staff
ren staff_cost_mo_p			cost_staff_mo_p

foreach x in cost_staff_total_mo cost_staff_mo_staff cost_staff_mo_p {
	replace `x' = `x'/50.963
	format `x' %20.3f
	}
	
* Table globals
* ----------------------------------
* Treatments	
glo t1 t1 t2
glo treatments_pooled t1_2 t2_2

* Control vars
glo control_hfs level_3 level_4_5 						i.strata_expanded
glo control_mks per_level_2 per_level_3 per_level_4_5 	i.strata_expanded

* Outcomes
glo main_outcome 	  qual_per qual_p cost_staff_total_mo cost_staff_mo_staff cost_staff_mo_p 

* Sample
glo sample s2
			
********************************************************************************
** Run table
********************************************************************************	
local num_p = 0
		
*-------------------------------------------------------------------
* Panel A. Main Outcomes 
*-------------------------------------------------------------------
			
* Run regression
* ----------------------------------
* Unweighted	
foreach var in $main_outcome {
	reg `var' t $control_hfs  			if $sample == 1 , vce(cluster market_all_expanded)
	
		*Saving naive p values to compute q values 
		glo `var'p_q = r(table)[4,1]
		local num_p = `num_p' + 1	
		
		sum `var' 						if t == 0 & $sample == 1 & e(sample) == 1
		save_coeff_t `var'
			}
			
* Adding ***
* --------------
glo coeff_table
foreach var in $main_outcome {
	glo coeff_table $coeff_table `var'1
		}
	star coeff_table

* Computing q values
* --------------	
		*Running Anderson code modified to work here
preserve 
clear  
set obs `num_p' /*Change to number of hypothesis to be included in the MHT*/

local count = 1 
gen float pval = .

		foreach var in $main_outcome  {
			disp "`var'"
replace  pval = ${`var'p_q}				if _n == `count'
local count = `count' + 1
	}


*Run the fdr sharpened q values do file 
do "${program}/fdr_sharpened_qvalues.do"	

*Save the fdr sharpened q values 	
local count_q = 1
	foreach var in $main_outcome {
		global `var'_q_1 : disp %10.3f bky06_qval[`count_q']
local count_q = `count_q' + 1		
	}


restore
	
*-------------------------------------------------------------------
* Panel B. Main Outcomes with Private Interaction - whole sample 
*-------------------------------------------------------------------
glo interaction		private private_t	
glo test_B 			T + Private x T = 0
loc treatment		t
loc interaction	 	private
loc interaction_t	private_t

local num_p = 0

glo main_outcome_B
foreach var in $main_outcome {
clonevar `var'_B=`var' 
glo main_outcome_B $main_outcome_B `var'_B
	}	

* Run regression
* ----------------------------------

reg cost_staff_total_mo_B  `treatment' $interaction $control_hfs  		if $sample == 1 , vce(cluster market_all_expanded)

* Unweighted	
 foreach var in $main_outcome_B {
	reg `var'  `treatment' $interaction $control_hfs  		if $sample == 1 , vce(cluster market_all_expanded)
	gen reg_sample = e(sample)
	
****************************	
	*Saving naive p values to compute q values 
	glo `var'_int_p_q = r(table)[4,1]
	local num_p = `num_p' + 1	
	
	*Interaction 
	glo `var'_int_t_p_q = r(table)[4,3]
	local num_p = `num_p' + 1		
****************************	
	
		sum `var'  											if `treatment' == 0 & $sample == 1 & reg_sample == 1
		save_coeff_t `var' 
		save_coeff_interaction_dec `var'_inter  `var'_inter_t  `interaction' `interaction_t'	
		
		sum `var'  											if `treatment' == 0 & $sample == 1 & private == 0 & reg_sample == 1	
		stat_public `var' 
		
		sum `var'  											if `treatment' == 0 & $sample == 1 & private == 1 & reg_sample == 1								
		stat_private `var' 
		
		drop reg_sample
		}
			
* Adding ***
* --------------
glo coeff_table
foreach var in $main_outcome {
	glo coeff_table $coeff_table `var'_B1 `var'_B_inter3 `var'_B_inter_t3
	} 
	star coeff_table

* Computing q values
* --------------	
		*Running Anderson code modified to work here
preserve 
clear  
set obs `num_p' /*Change to number of hypothesis to be included in the MHT*/

local count = 1 
gen float pval = .

		foreach var in $main_outcome  {
			disp "`var'"
replace  pval = ${`var'_B_int_p_q}			if _n == `count'
local count = `count' + 1	
replace  pval = ${`var'_B_int_t_p_q }		if _n == `count'
local count = `count' + 1	
	}


*Run the fdr sharpened q values do file 
do "${program}/fdr_sharpened_qvalues.do"	

*Save the fdr sharpened q values 	
local count_q = 1
	foreach var in $main_outcome {
		global `var'_qB_2 : disp %10.3f bky06_qval[`count_q']
local count_q = `count_q' + 1	
		global `var'_qB_3 : disp %10.3f bky06_qval[`count_q']
local count_q = `count_q' + 1		
	}


restore	

		
*-------------------------------------------------------------------
* Panel C. Main Outcomes with Unlicensed Interaction - Private and active at endline only 
*-------------------------------------------------------------------
keep if private == 1 & active_s0 == 1  // Sample is restricted to private and active at endline only 

local num_p = 0
	
glo interaction		unlicensed_s2 unlicensed_s2_t
glo test_C 			T + Unlicensed x T = 0
loc treatment		t
loc interaction	 	unlicensed_s2
loc interaction_t	unlicensed_s2_t

global main_outcome_C
foreach var in $main_outcome {
clonevar `var'_C=`var' 
global main_outcome_C $main_outcome_C `var'_C
	}
	
* Run regression
* ----------------------------------	
 foreach var in $main_outcome_C {
		* Unweighted
		reg `var'  `treatment' $interaction $control_hfs  			if $sample == 1   , vce(cluster market_all_expanded)
		gen reg_sample = e(sample)		
		

*******************************	
	*Saving naive p values to compute q values 
	glo `var'_int2_p_q = r(table)[4,1]
	local num_p = `num_p' + 1	
	
	*Interaction 
	glo `var'_int2_t_p_q = r(table)[4,3]
	local num_p = `num_p' + 1	
*****************************
			
				sum `var' 											if `treatment' == 0 & $sample == 1 & reg_sample == 1
				save_coeff_t `var'
				save_coeff_interaction_dec `var'_inter  `var'_inter_t  `interaction' `interaction_t'				
				
				sum `var' 											if `treatment' == 0 & $sample == 1 & unlicensed_s2 == 0 & reg_sample == 1	
				stat_lic `var'
				
				sum `var' 											if `treatment' == 0 & $sample == 1 & unlicensed_s2 == 1 & reg_sample == 1								
				stat_unl `var'
				
				drop reg_sample
				}

	* Adding ***
	* --------------
	glo coeff_table
	foreach var in $main_outcome {
		glo coeff_table $coeff_table `var'_C1 `var'_C_inter3 `var'_C_inter_t3
		} 
		star coeff_table	
		
	
* Computing q values
* --------------	
*Running Anderson code modified to work here
preserve 
clear  
set obs `num_p' /*Change to number of hypothesis to be included in the MHT*/

local count = 1 
gen float pval = .

		foreach var in $main_outcome  {
			disp "`var'"
replace  pval = ${`var'_C_int2_p_q}		if _n == `count'
local count = `count' + 1	
replace  pval = ${`var'_C_int2_t_p_q }	if _n == `count'
local count = `count' + 1	
	}


*Run the fdr sharpened q values do file 
do "${program}/fdr_sharpened_qvalues.do"	

*Save the fdr sharpened q values 	
local count_q = 1
	foreach var in $main_outcome {
		global `var'_qC_2 : disp %10.3f bky06_qval[`count_q']
local count_q = `count_q' + 1	
		global `var'_qC_3 : disp %10.3f bky06_qval[`count_q']
local count_q = `count_q' + 1		
	}


restore	
		

********************************************************************************
** Combine
********************************************************************************	
*Add the stars to the fdr sharpened q values do file 
foreach var in $main_outcome  {	
	foreach i in "_1" "B_2" "B_3" "C_2" "C_3" {	
	global `var'_q2`i' = "$\{" + "${`var'_q`i'}" + "$\}"
	* Add stars
		if ${`var'_q`i'} <= 0.1 {
			glo `var'_q2`i' = "${`var'_q2`i'}" + "*"
		}
		if ${`var'_q`i'} <= 0.05 {
			glo `var'_q2`i' = "${`var'_q2`i'}" + "*"
		}
		if ${`var'_q`i'} <= 0.01 {
			glo `var'_q2`i' = "${`var'_q2`i'}" + "*"
		}
	}	
}		
		

********************************************************************************
** Export
********************************************************************************

* Labels
glo panel_A		"Overall Impact"
glo panel_B		"Interaction with Private"
glo panel_C		"Interaction with Unlicensed (Private and active at endline only)"

glo SC_1 		"Practice, Knowledge, and Supplies in IPC"
glo SC_2 		"Healthcare Staff"

glo R_text 			"$\rm {R}^{2}$" 
glo N_text 			"Observations"

glo C_1 		"Ratio of healthcare workers to total staff"
glo C_2 		"Healthcare workers per outpatient*"
glo C_3 		"Monthly total staff cost (USD PPP)"
glo C_4 		"Monthly staff cost per staff (USD PPP)"
glo C_5 		"Staff cost per outpatient* (USD PPP)"

lab var t 					"Treatment"
lab var unlicensed_s2  		"Unlicensed HF at Endline"	
lab var unlicensed_s2_t 	"Unlicensed HF at Endline x T"	
lab var private 			"Private HF"	
lab var private_t 			"Private HF x T"

glo t 						: variable label t
glo t_B 					: variable label t
glo t_C 					: variable label t

glo inter_B 				: variable label private
glo inter_t_B   			: variable label private_t
glo inter_C 				: variable label unlicensed_s2
glo inter_t_C  				: variable label unlicensed_s2_t

glo B_pr_text 				"Private"
glo B_pu_text 				"Public"	
glo C_unl_text 				"Unlicensed"
glo C_lic_text 				"Licensed"		
	
* Table global
glo table_name "${tex_`out'_out}"

* Start the Latex document
texdoc do "${tex_`out'}"	
			
		
			


		
		
