/*******************************************************************************	
*		Project:
*			KePSIE IE
*		Created on:		2019-06-04
*		Last update: 	2019-06-04
********************************************************************************	

********************************************************************************			

** PURPOSE: 	This do-file plot the wealth index in control versus treatment and test whether the distribution is statistically different	
				
** Written by: Thomas Escande

*******************************************************************************/
********************************************************************************

*** # Part 0: Initiate and import the database

********************************************************************************

clear all
set more off

* Input
glo inputdata 			"${dt_final}/data_for_analysis.dta" 
glo inputdata_p 		"${dt_final}/oop_p.dta" 
glo wealth_pe 			"${dt_end_const}/wealth_index_end.dta" 

*Global 
global control_hfs 				level_3 level_4_5 
global sample  s2 
global graph_opts title(, justification(center) color(black) span pos(20)) graphregion(color(white)) ylab(,angle(0) nogrid)  legend(region(lc(none) fc(none)))

********************************************************************************
	** Part 1: Create the different graphs
********************************************************************************
use "${inputdata_p}", clear
cap drop _merge
drop if mi(key)
tempfile inputdata_oop_p
save `inputdata_oop_p'


*Adding the missing variables to the wealth dataset
*At endline
use "${wealth_pe}", clear

merge m:1 hfid using "${inputdata}" , keep(3) keepusing(t) nogen // Adding the force option as variable time is string in master but long in using
merge 1:1 key using `inputdata_oop_p' , keep(3) keepusing(weight*) nogen // Adding the force option as variable time is string in master but long in using

*Outlier 
drop if kepsie_wealth > 18 & !mi(kepsie_wealth )

*Graph. Need to compute weights manually.
*Doing it by calculating the weighted percentage of the population in DHS bins of 0.5 
gen count = 1
bys t  : egen tot = sum(count*weight_p) if !mi(kepsie_wealth)
gen wealth_kepsie_floor =  floor(kepsie_wealth)
gen diff_dhs = kepsie_wealth - wealth_kepsie_floor


gen wealth_kepsie_split = wealth_kepsie_floor 			if kepsie_wealth >0 & !mi(kepsie_wealth) & diff_dhs < 0.5
replace wealth_kepsie_split = wealth_kepsie_floor + 0.5 if kepsie_wealth >0 & !mi(kepsie_wealth) & diff_dhs > 0.5 & !mi(diff_dhs)
replace wealth_kepsie_split = wealth_kepsie_floor + 0.5 if kepsie_wealth <=0  & diff_dhs > 0.5 & !mi(diff_dhs)
replace wealth_kepsie_split = wealth_kepsie_floor  		if kepsie_wealth <=0  & diff_dhs < 0.5 

*tot_quint is the weighted number of people in each bin and we then get the percentage from that
bys t wealth_kepsie_split : egen tot_quint = sum(count*weight_p)
gen percentage = tot_quint / tot
replace percentage=percentage*100

*set scheme cleanplots
graph set window fontface "Arial Narrow"

twoway  (line percentage wealth_kepsie_split if t == 1, lcolor(dkgreen))   ///
		(line percentage wealth_kepsie_split if t == 0) ,   ///
ytitle(% of Patients in Arm, margin(medsmall) size(medsmall)) ///
xtitle(Wealth Index, margin(medsmall) size(medsmall))  legend(label(1 "Treatment") label(2 "Control") pos(3) col(1) ring(0)) ///
yscale(noline) ylab(0(2)16 0 "0%" 2 "2%" 4 "4%" 6 "6%" 8 "8%" 10 "10%" 12 "12%" 14 "14%" 16 "16%",  format(%9.0f) noticks labsize(small)) ///
 xscale(range(-3.5 14.5)) xlab(-3.5(2)14.5 ,  format(%9.1f) noticks labsize(small)) scheme(cleanplots) $graph_opts

	graph export  "${out_main}/figure_2.png", replace
		
********************************************************************************
	** Part 2: Testing the difference between the two distributions
********************************************************************************	
*ksmirnof test  does not allow for weights so need to expand the dataset to have the number of observations corresponding to weights (or frequency as calculated previously)
keep t weight_p kepsie_wealth dhs_wealth_kepsie

egen tot = sum(weight_p)

 *Keeping the sample at the same size 
replace weight_p = weight_p * 11098/tot
 
*Take the round number
replace weight_p = round(weight_p, 1)

*Dropping observations with very low weights (<0.5), otherwise they will be counted as a weight of 1. 
drop if weight_p == 0

gen count = _n
sum count
forvalues i = 1/`r(max)' {
qui sum weight_p if count == `i'
local N_expand = `r(mean)'
qui expand `N_expand' if count == `i'
disp "`i'"
}


*Using ksmirnof test for equality of distribution of wealth index in treatment and control group at endline
 ksmirnov kepsie_wealth , by(t) exact



*********************************End of dofile***********************************************************************
