/*******************************************************************************	
*******************************************************************************/
********************************************************************************
	** Part 0: Create globals for directories and files 
********************************************************************************
clear all
set more off

glo inputdata	 		"${dt_final}/data_for_analysis.dta" 

* Output files:
glo out_figure 			"${out_main}"

glo control_hfs level_3 level_4_5 						i.strata_expanded
glo control_mks per_level_2 per_level_3 per_level_4_5 	i.strata_expanded
glo sample  s2
	
*Options for graphs
glo graph_opts title(, justification(center) color(black) span pos(20)) graphregion(color(white)) ylab(,angle(0) nogrid noticks)  legend(region(lc(none) fc(none)))
*set scheme cleanplots
graph set window fontface "Arial Narrow"

********************************************************************************
** Setup
********************************************************************************	
use "${inputdata}", clear

* TO CORRECT IN CONSTRUCTION
/*Correcting oop_all_bl_m_mi (should be corrected later on in the construction). Issue is, facilities with missing oop at baseline also have a 0 at the market level variable, instead of the market value*/ 
bys market_all_expanded: egen temp_oop_all_bl_m = max(oop_all_bl_m_mi) 
replace oop_all_bl_m_mi = temp_oop_all_bl_m 
drop temp_oop_all_bl_m 
*For the dummy 
bys market_all_expanded: egen temp_oop_all_bl_m_mi_d = max(oop_all_bl_m_mi_d) 
replace oop_all_bl_m_mi_d = temp_oop_all_bl_m_mi_d 
drop temp_oop_all_bl_m_mi_d 


rename logit_group_2 		logit_group1_2
rename logit_group_2_t 		logit_group1_2_t
rename logit_group_3 		logit_group1_3
rename logit_group_3_t 		logit_group1_3_t

rename logit_group_naive_2 		logit_group2_2
rename logit_group_naive_2_t  	logit_group2_2_t
rename logit_group_naive_3   	logit_group2_3
rename logit_group_naive_3_t 	logit_group2_3_t
	
********************************************************************************
** Figure
********************************************************************************	
glo outcome 		jhic_all outp_as_jan formality inactive
glo blcontrols 		jhic_all_bl_m_mi jhic_all_bl_m_mi_d outp_as_jan_bl_m_mi outp_as_jan_bl_m_mi_d oop_all_bl_m_mi oop_all_bl_m_mi_d
glo control_hfs 	level_3 level_4_5 $blcontrols 				
glo interaction1	logit_group1_2 logit_group1_2_t logit_group1_3 logit_group1_3_t
glo interaction2	logit_group2_2 logit_group2_2_t logit_group2_3 logit_group2_3_t
glo sample 			s2

foreach x in jhic_all /*outp_as_jan formality inactive*/ {

	if "`x'" == "jhic_all" {
		loc y = "JHIC Score (pp max score)"
		loc z = "ylabel(0(5)15) xlabel(0(1)4)"
		loc loc_test1 = 14
		loc loc_test2 = 13
		}
	if "`x'" == "outp_as_jan" {
		loc y = "Daily Outpatients"
		loc z = "ylabel(-15(5)15) xlabel(0(1)4)"
		loc loc_test = 10
		}
	if "`x'" == "formality" {
		loc y = "Formality"
		loc z = "ylabel(0(.2).6) xlabel(0(1)4) "
		loc loc_test = 0.5
		}		
	if "`x'" == "inactive" {
		loc y = "Inactive"
		loc z = "ylabel(-.2(.2).4) xlabel(0(1)4)"
		loc loc_test = 0.35
		}			

*First regression just to use the same sample in the following t statistics 
forvalues i =1/2 {
reg `x' t ${interaction`i'} $control_hfs i.strata_expanded if $sample==1, vce(cluster market_all_expanded) 

tab logit_pred_naive if s2==1
tab logit_group_naive if e(sample)==1
tab logit_group_naive


	* Low
	lincom t	
	gen `x'`i'1 	= r(estimate)		
	gen `x'`i'_lb1 = r(lb)				
	gen `x'`i'_ub1 = r(ub)				
	* Med
	lincom t + logit_group`i'_2_t 		
	gen `x'`i'2 	= r(estimate)				
	gen `x'`i'_lb2 = r(lb) 			
	gen `x'`i'_ub2 = r(ub)			
	* High
	lincom t + logit_group`i'_3_t 		
	gen `x'`i'3 	= r(estimate)			
	gen `x'`i'_lb3 = r(lb) 			
	gen `x'`i'_ub3 = r(ub)	 		
	
	*Test of equality 
	test _b[t] = _b[t] + _b[logit_group`i'_3_t] 
	gen `x'`i'lhtest = round(r(p),0.001) 
	
		*Formatting
		tostring `x'`i'lhtest, replace format("%5.4g") force
		replace  `x'`i'lhtest = substr(`x'`i'lhtest,1,4)	
	
	if `i' == 1 {
		replace `x'`i'lhtest  = "LOO: Test (Low = High), p-value = " + "0" + `x'`i'lhtest 	if `x'`i'lhtest != "0"
		replace `x'`i'lhtest  = "LOO: Test (Low = High), p-value < 0.0005 " 			 		if `x'`i'lhtest == "0"			
	}
	if `i' == 2 {
		replace `x'`i'lhtest  = "Naive: Test (Low = High), p-value = " + "0" + `x'`i'lhtest 	if `x'`i'lhtest != "0"
		replace `x'`i'lhtest  = "Naive: Test (Low = High), p-value < 0.0005 " 			 		if `x'`i'lhtest == "0"			
	}	
	
	*Location of ttest on the graph 
	gen `x'`i'coeff_l		 = `loc_test`i'' 	
	gen `x'`i'order_graph_l = 1.1 			
}	

	keep `x'1? `x'2? `x'1_lb* `x'1_ub* `x'2_lb* `x'2_ub* `x'1coeff_l `x'1order_graph_l `x'1lhtest `x'2coeff_l `x'2order_graph_l `x'2lhtest
	gen n = _n
	keep if n==1
	reshape long `x'1 `x'1_lb `x'1_ub `x'2 `x'2_lb `x'2_ub, i(n `x'1coeff_l `x'1order_graph_l `x'1lhtest `x'2coeff_l `x'2order_graph_l `x'2lhtest) j(logit_group)
	lab def logit_group 1 "Low <=0.4" 2 "Mid (0.4,0.6)" 3 "High >=0.6"
	lab val logit_group logit_group
	drop n
	gen n = _n
	gen logit_group1 = logit_group
	gen logit_group2 = logit_group + 0.2
	
	tw 	(scatter `x'1 logit_group1, mcolor(edkblue) msize(4-pt) msymbol(circle)) ///
		(rcap `x'1_lb `x'1_ub logit_group1, lcolor(edkblue))	///	
		(scatter `x'1coeff_l  `x'1order_graph_l if n==1 , mlabel(`x'1lhtest) ms(none)  mlabc(black) mlabsize(small)) ///  
		(scatter `x'2 logit_group2, mcolor(ebblue) msize(4-pt) msymbol(circle)) ///
		(rcap `x'2_lb `x'2_ub logit_group2, lcolor(ebblue))	///	
		(scatter `x'2coeff_l  `x'2order_graph_l if n==1 , mlabel(`x'2lhtest) ms(none)  mlabc(black) mlabsize(small)) ///  		
		, ///
		ytitle("`y'", size(small)) xtitle("") `z' xlabel( 1 "Low <=0.4" 2 "Mid (0.4,0.6)" 3 "High >=0.6" , nogrid noticks labsize(small)) legend(col(2) pos(6) order(1 4) label(1 "Leave-One-Out Estimation") label(4 "Naive Estimation") region(lstyle(none))) yline(0, lwidth(thin) lpattern(solid) lcolor(black)) ///
		graphregion(color(white)) ylab(,angle(0) nogrid noticks) ///
		xscale(noline titlegap(3) range(0.5 3.5)) yscale(noline titlegap(3)) name(graph_`x') title("`y'", span)
		
		graph export "${out_figure}/figure_4.png", replace 
		}
	/*	
*Combine the  graphs 		
graph combine 	graph_jhic_all graph_formality graph_inactive graph_outp_as_jan, graphregion(fcolor(white) margin(zero))
graph export 	"${out_figure}", replace 		
	
	*/	
			
		
