/*******************************************************************************	
Project:  	KePSIE
*******************************************************************************/
********************************************************************************
** Create globals for directories and files 
********************************************************************************
clear all
set more off
	
* Input 
glo inputdata 			"${dt_final}/data_for_analysis.dta" 
glo inputdata_p 		"${dt_final}/oop_p.dta" 
glo wi_bl 				"${dt_bl_const}/wealth_index_bl.dta" 
glo pe_bl 				"${dt_bl_clean}/pe_bl.dta" 
glo pps_bl 				"${dt_bl_clean}/pps_kds_bl.dta"

* Output 
loc out 				table_1
glo tex_`out'			"${do_main}/tex/tex_`out'.do"
glo tex_`out'_out 		"${out_main}/`out'"	

* Programs
glo stats				"${program}/stats.do"
do "${stats}"	

********************************************************************************
** Table 1: Summary statistics at baseline
********************************************************************************
use "${inputdata}", clear
replace active_s0=1 if active_s0==0 & bl_consent!=.

* Setup
glo panelA 				"Panel A: Facility-level characteristics"
glo panelB 				"Panel B: Patient-level indicators"
glo panelC 				"Panel C: Indication-level indicators from patient-HCW interactions"

glo C_1 				"All"
glo C_2 				"Public"
glo C_3 				"Private"		
glo C_4 				"N"	

glo SR_1 				"Facility is:"
glo SR_2 				"Facility is in JHIC category:"

loc hfs private public level_2 level_3 level_4_5
loc outc outp_as_jan_bl jhic_all_bl risk_c_bl_1 risk_c_bl_2 risk_c_bl_3 risk_c_bl_4 nhif_outp_bl oop_all_bl oop_all_bl_nom

gen hfall = 1
recode private (1=0) (0=1), gen(public)

egen outp_bl_tot 		= sum(outp_as_jan_bl) if outp_as_jan_bl!=.
egen outp_bl_tot_pri 	= sum(outp_as_jan_bl) if private==1 & outp_as_jan_bl!=.
egen outp_bl_tot_pub 	= sum(outp_as_jan_bl) if private==0 & outp_as_jan_bl!=.

egen outp_bl_tot_pri_bl = sum(outp_as_jan_bl) if private_bl==1 & outp_as_jan_bl!=.
egen outp_bl_tot_pub_bl = sum(outp_as_jan_bl) if private_bl==0 & outp_as_jan_bl!=.

gen pri_share 			= outp_bl_tot_pri_bl/outp_bl_tot
gen pub_share 			= outp_bl_tot_pub_bl/outp_bl_tot
gen all_share 			= outp_bl_tot/outp_bl_tot

tab risk_c_bl, gen(risk_c_bl_)

foreach x in oop_all_bl {
	gen `x'_nom = `x'_kes/98.18
	}
	
foreach x in nhif_outp_bl {
	replace `x' = 0 if mi(`x') & active_s0==1	
	}	
	
glo hf 					"HFs"
lab var hfall 			"Facility is public/private"
lab var level_2 		"Level 2: Dispensaries and clinics" // check diff between level and level_bl
lab var level_3 		"Level 3: Health centers and maternity and nursing homes"
lab var level_4_5 		"Level 4 or 5: Primary and secondary hospitals"
lab var nhif_outp_bl	"Facility receives NHIF outpatient disbursements"
lab var outp_as_jan_bl	"Daily outpatients, mean [SD]"
lab var all_share 		"Share of total outpatients"
lab var oop_all_bl 		"Patients' OOP, mean [SD] USD PPP"
lab var oop_all_bl_nom 	"Patients' OOP, mean [SD] USD nominal"
lab var jhic_all_bl 	"JHIC score x 100 (\% of max score) mean [SD]" 
lab var risk_c_bl_1 	"Minimally compliant (11-40\% of max score)"
lab var risk_c_bl_2 	"Partially compliant (41-60\% of max score)"
lab var risk_c_bl_3 	"Substantially compliant (61-75\% of max score)"
lab var risk_c_bl_4 	"Fully compliant ($>$75\% of max score)"
	
foreach i of varlist `hfs' `outc' {
	sum `i' if active_s0==1
	stat_all `i'	
	sum `i' if active_s0==1 & private==0
	stat_pub `i'	
	sum `i' if active_s0==1 & private==1
	stat_pri `i'	
	}	
	
foreach i in unlicensed_s0 {
	sum `i' if active_s0==1 & private==1
	stat_pri `i'
	}	
			
foreach i of varlist hfall all_share pub_share pri_share {
	sum `i' if active_s0==1
	stat_all `i'		
	}	
	
glo unlicensed_s0l 		"Facility is unlicensed (or has an expired license) (private)"
		
use "${inputdata_p}", clear
merge m:1 hfid using "${inputdata}", keepus(private s0 bl_consent active_s0)

gen oop_zero 		= 1 if oop_all_bl==0
replace oop_zero 	= 0 if mi(oop_zero) & oop_all_bl!=.
lab var oop_zero 	"Patients reporting zero OOP, proportion"

foreach i of varlist oop_zero {
	sum `i' if active_s0==1
	stat_all `i'	
	sum `i' if active_s0==1 & private==0
	stat_pub `i'	
	sum `i' if active_s0==1 & private==1
	stat_pri `i'		
	}		
	
keep if key!=""	
merge 1:1 key using "${wi_bl}", keepus(dhs_wealth_kepsie wealth_ranking_kepsie_dhs) nogen
lab var dhs_wealth_kepsie "Patient's wealth index is, mean [SD] (-4 to 12)"
	
foreach i of varlist dhs_wealth_kepsie {
	sum `i' if active_s0==1
	stat_all `i'	
	sum `i' if active_s0==1 & private==0
	stat_pub `i'	
	sum `i' if active_s0==1 & private==1
	stat_pri `i'		
	}		
	
	foreach x in oop_zero dhs_wealth_kepsie {
		unique hfid if `x'!=.
		glo `x'hf = r(unique)
		}
	
use "${pe_bl}", clear
merge m:1 hfid using "${inputdata}", keepus(private s0 bl_consent active_s0)

recode e2 (1/2=1) (3/4=0) (0=.d), gen(l4km)

foreach i of varlist l4km {
	sum `i' if active_s0==1
	stat_all `i'	
	sum `i' if active_s0==1 & private==0
	stat_pub `i'	
	sum `i' if active_s0==1 & private==1
	stat_pri `i'		
	}		
	
glo l4kml "Patients reporting facility distance from home $<$=4km, proportion"	
	foreach x in l4km {
		unique hfid if `x'!=.
		glo `x'hf = r(unique)
		}
	
use "${pps_bl}", clear
ren facilityid hfid
merge m:1 hfid using "${inputdata}", keepus(private s0 bl_consent active_s0)

gen vio 		= violation_total if pp_counter==1 
gen ind 		= indication_total if pp_counter==1
gen hand 		= adherence if hh_ind==1 & adherence!=. & knowledge!=. & supplies!=. & indication_serial<=7
gen inj 		= adherence if ibd_ind==1
gen num 		= 1
clonevar adh 	= adherence

foreach x in vio ind adh inj hand {
	unique hfid if `x'!=. & active_s0==1
	glo `x'hf = r(unique)
	}
	
lab var ind 	"IPC indications in outpatient visit, mean [SD]"	
lab var adh		"Compliance with all IPC practices measured, mean [SD]"
lab var inj 	"Injection and blood draw safety practices"
lab var hand 	"Hand hygiene practices"	

foreach i in vio ind adh inj hand num {
	sum `i' if active_s0==1
	stat_all `i'	
	sum `i' if active_s0==1 & private==0
	stat_pub `i'	
	sum `i' if active_s0==1 & private==1
	stat_pri `i'	
	}

glo viol 		"Violations of IPC practices in outpatient visit, mean [SD]"
	
* Table global
glo table_name "${tex_`out'_out}"

* Start the Latex document
texdoc do "${tex_`out'}"

				


				
				
				
				
				
				
				
