/*******************************************************************************	
Project:  	KePSIE
*******************************************************************************/
********************************************************************************
** Create globals for directories and files 
********************************************************************************
clear all
set more off

* Input
glo inputdata 			"${dt_final}/data_for_analysis.dta" 
glo inputdata_p 		"${dt_final}/oop_p.dta" 
glo input_costs			"${dt_end_const}/jhic_compliance_items.dta" 

* Output
loc out 				table_4
glo tex_`out'			"${do_main}/tex/tex_`out'.do"
glo tex_`out'_out 		"${out_main}/`out'"	
	
* Programs		
glo save_coeff			"${program}/save_coeff.do"
do "${save_coeff}"	
	
********************************************************************************
** Run table
********************************************************************************
* Treatments	
glo t1 t1 t2
glo treatments_pooled t1_2 t2_2
* Control vars
glo control_hfs level_3 level_4_5 						i.strata_expanded
glo control_mks per_level_2 per_level_3 per_level_4_5 	i.strata_expanded
* Sample
glo sample s2
			
*-------------------------------------------------------------------
* Panel A. Main Outcomes 
*-------------------------------------------------------------------
use "${input_costs}", clear
forvalues i=1/7 {
ren item_group_`i' g`i'
clonevar item_adh_`i' = item_adh if g`i'==1
}
glo main_outcome 
forvalues i = 1/7 {
glo main_outcome $main_outcome item_adh_`i'
	}
		
* Run regression
* Unweighted	
foreach var in $main_outcome {
	reg `var' t $control_hfs  			if $sample == 1, vce(cluster market_all_expanded)
		sum `var' 						if t == 0 & $sample == 1 & e(sample) == 1
		save_coeff_t `var'
		}

* Adding ***
glo coeff_table
foreach var in $main_outcome {
	glo coeff_table $coeff_table `var'1
	}
	star coeff_table
			
*-------------------------------------------------------------------
* Panel B. Main outcomes with private interaction - whole sample 
*-------------------------------------------------------------------
glo interaction		private private_t	
glo test_B 			T + Private x T = 0
loc treatment		t
loc interaction	 	private
loc interaction_t	private_t

glo main_outcome_B
foreach var in $main_outcome {
	clonevar `var'_B=`var' 
glo main_outcome_B $main_outcome_B `var'_B
	}

* Run regression
foreach var in $main_outcome_B {
reg `var'  `treatment' $interaction $control_hfs  		if $sample == 1 , vce(cluster market_all_expanded)
gen reg_sample = e(sample)
	sum `var'  											if `treatment' == 0 & $sample == 1 & reg_sample == 1
	save_coeff_t `var' 
	save_coeff_interaction `var'_inter  `var'_inter_t  `interaction' `interaction_t'	
	
	sum `var'  											if `treatment' == 0 & $sample == 1 & private == 0 & reg_sample == 1	
	stat_public `var' 
	
	sum `var'  											if `treatment' == 0 & $sample == 1 & private == 1 & reg_sample == 1								
	stat_private `var' 
	
	drop reg_sample
	}	
								
* Adding ***
glo coeff_table
foreach var in $main_outcome {
	glo coeff_table $coeff_table `var'_B1 `var'_B_inter3 `var'_B_inter_t3
	} 
	star coeff_table
	
*-------------------------------------------------------------------
* Panel C. Main Outcomes with Unlicensed Interaction - Private and active at endline only 
*-------------------------------------------------------------------
merge m:1 hfid using "${inputdata}", keepus(unlic* act*) nogen
keep if private == 1  // Sample is restricted to private and active at endline only 
	
glo interaction		unlicensed_s2 unlicensed_s2_t
glo test_C 			T + Unlicensed x T = 0
loc treatment		t
loc interaction	 	unlicensed_s2
loc interaction_t	unlicensed_s2_t

glo main_outcome_C
foreach var in $main_outcome {
	clonevar `var'_C=`var' 
glo main_outcome_C $main_outcome_C `var'_C
	}

* Run regression
 foreach var in $main_outcome_C {
	reg `var'  `treatment' $interaction $control_hfs  			if $sample == 1   , vce(cluster market_all_expanded)
	gen reg_sample = e(sample)					
			sum `var' 											if `treatment' == 0 & $sample == 1 & reg_sample == 1
			save_coeff_t `var'
			save_coeff_interaction `var'_inter  `var'_inter_t  `interaction' `interaction_t'				
			
			sum `var' 											if `treatment' == 0 & $sample == 1 & unlicensed_s2 == 0 & reg_sample == 1	
			stat_lic `var'
			
			sum `var' 											if `treatment' == 0 & $sample == 1 & unlicensed_s2 == 1 & reg_sample == 1								
			stat_unl `var'
			
			drop reg_sample
			}

														
* Adding ***
glo coeff_table
foreach var in $main_outcome {
	glo coeff_table $coeff_table `var'_C1 `var'_C_inter3 `var'_C_inter_t3
	} 
	star coeff_table	
	
	glo mo_out item_adh_2 item_adh_1 item_adh_6 item_adh_7 item_adh_3 item_adh_4 item_adh_5

********************************************************************************
** Export
********************************************************************************
glo PanelA		"Overall Impact"
glo PanelB		"Interaction with Private"
glo PanelC		"Interaction with Unlicensed (Private and active at endline only)"

glo SC_1 		"Cost Groups"
glo SC_2 		"Marginal and Fixed Costs"

glo C_1 		"Infrastructure"
glo C_2			"Equipment"
glo C_3 		"Supplies \\ (Low cost)"
glo C_4 		"Supplies \\ (Medium cost)"
glo C_5 		"Management"	
glo C_6 		"Medical \\ Records"
glo C_7 		"SOPs"

glo R_text 			"$\rm {R}^{2}$" 
glo N_text 			"Observations"

lab var t 					"Treatment"
lab var unlicensed_s2  		"Unlicensed HF at Endline "	
lab var unlicensed_s2_t 	"Unlicensed HF at Endline x T"	
lab var private 			"Private HF"	
lab var private_t 			"Private HF x T"

glo t 						: variable label t
glo t_B 					: variable label t
glo t_C 					: variable label t

glo inter_B 				: variable label private
glo inter_t_B   			: variable label private_t
glo inter_C 				: variable label unlicensed_s2
glo inter_t_C  				: variable label unlicensed_s2_t

glo B_pr_text 				"Private"
glo B_pu_text 				"Public"	
glo C_unl_text 				"Unlicensed"
glo C_lic_text 				"Licensed"		
	
* Table global
glo table_name "${tex_`out'_out}"

* Start the Latex document
texdoc do "${tex_`out'}"

			
		
			


		
		
