/*******************************************************************************	
Project:  	KePSIE
********************************************************************************/
********************************************************************************
** Setup
********************************************************************************
clear all
set more off

* Input
glo inputdata	 		"${dt_final}/data_for_analysis.dta" 
		
* Output
loc out 				table_5
glo tex_`out'			"${do_main}/tex/tex_`out'.do"
glo tex_`out'_out 		"${out_main}/`out'"	

* Programs		
glo save_coeff			"${program}/save_coeff.do"
do "${save_coeff}"	

* Table globals
* ----------------------------------
* Treatments	
glo t1 t1 t2
glo treatments_pooled t1_2 t2_2
* Control vars
glo control_hfs level_3 level_4_5 						i.strata_expanded
glo control_mks per_level_2 per_level_3 per_level_4_5 	i.strata_expanded
* Outcomes
glo main_outcome 	  outp_as_jan  inactive 
* Sample
glo sample s2

********************************************************************************
** Run table
********************************************************************************
*-------------------------------------------------------------------
* Panel A. Main Outcomes 
*-------------------------------------------------------------------
use "${inputdata}", clear	
keep if active_s0==1 // sample is restricted to active at randomization only
		
* Run regression
* ----------------------------------
* Unweighted	
foreach var in $main_outcome {
	reg `var' t $control_hfs  			if $sample == 1 , vce(cluster market_all_expanded)
		sum `var' 						if t == 0 & $sample == 1 & e(sample) == 1
		save_coeff_t `var'
			}

* Adding ***
* --------------
glo coeff_table
foreach var in $main_outcome {
	glo coeff_table $coeff_table `var'1
		}
	star coeff_table
		
*-------------------------------------------------------------------
* Panel B. Main Outcomes with Private Interaction - whole sample 
*-------------------------------------------------------------------
use "${inputdata}", clear	
keep if active_s0==1 // sample is restricted to active at randomization only

glo interaction		private private_t	
glo test_B 			T + Private x T = 0
loc treatment		t
loc interaction	 	private
loc interaction_t	private_t

global main_outcome_B
foreach var in $main_outcome {
	ren `var' `var'_B
global main_outcome_B $main_outcome_B `var'_B
	}	

* Run regression
* ----------------------------------
	* Unweighted	
 foreach var in $main_outcome_B {
	reg `var'  `treatment' $interaction $control_hfs  		if $sample == 1 , vce(cluster market_all_expanded)
	gen reg_sample = e(sample)
		sum `var'  											if `treatment' == 0 & $sample == 1 & reg_sample == 1
		save_coeff_t `var' 
		save_coeff_interaction `var'_inter  `var'_inter_t  `interaction' `interaction_t'	
		
		sum `var'  											if `treatment' == 0 & $sample == 1 & private == 0 & reg_sample == 1	
		stat_public `var' 
		
		sum `var'  											if `treatment' == 0 & $sample == 1 & private == 1 & reg_sample == 1								
		stat_private `var' 
		
		drop reg_sample
		}
				
														
* Adding ***
* --------------
glo coeff_table
foreach var in $main_outcome {
	glo coeff_table $coeff_table `var'_B1 `var'_B_inter3 `var'_B_inter_t3
	} 
	star coeff_table
	
*-------------------------------------------------------------------
* Panel C. Main Outcomes with Unlicensed Interaction - Private and active at randomization only 
*-------------------------------------------------------------------
use "${inputdata}", clear
keep if private == 1 & active_s0==1 // sample is restricted to private and active at randomization only 
				
glo interaction		unlicensed_s0 unlicensed_s0_t
glo test_C 			T + Unlicensed x T = 0
loc  treatment		t
loc interaction	 	unlicensed_s0
loc interaction_t	unlicensed_s0_t				
			
			
glo interaction		unlicensed_s0 unlicensed_s0_t
glo test_C 			T + Unlicensed x T = 0
loc  treatment		t
loc interaction	 	unlicensed_s0
loc interaction_t	unlicensed_s0_t


global main_outcome_C
foreach var in $main_outcome {
	ren `var' `var'_C
global main_outcome_C $main_outcome_C `var'_C
	}

* Run regression
* ----------------------------------	
 foreach var in $main_outcome_C {
		* Unweighted
		reg `var'  `treatment' $interaction $control_hfs  			if $sample == 1   , vce(cluster market_all_expanded)
		gen reg_sample = e(sample)					
				sum `var' 											if `treatment' == 0 & $sample == 1 & reg_sample == 1
				save_coeff_t `var'
				save_coeff_interaction `var'_inter  `var'_inter_t  `interaction' `interaction_t'				
				
				sum `var' 											if `treatment' == 0 & $sample == 1 & unlicensed_s0 == 0 & reg_sample == 1	
				stat_lic_s0 `var'
				
				sum `var' 											if `treatment' == 0 & $sample == 1 & unlicensed_s0 == 1 & reg_sample == 1								
				stat_unl_s0 `var'
				
				drop reg_sample
				}
	
														
* Adding ***
* --------------
glo coeff_table
foreach var in $main_outcome {
	glo coeff_table $coeff_table `var'_C1 `var'_C_inter3 `var'_C_inter_t3
	} 
	star coeff_table	
	
********************************************************************************
** Export
********************************************************************************
glo table_name 		"Table${TableNumber}_$date"
glo left 			"Facility and Patient Level"
glo PanelA			"Overall Impact"
glo PanelB			"Interaction with Private"
glo PanelC			"Interaction with Unlicensed (Private and active at randomization only)"
glo C_1 			"Daily"
glo C_1_s 			"Outpatients"
glo C_2 			""
glo C_2_s 			"Inactive"

glo R_text 			"$\rm {R}^{2}" 
glo N_text 			"Observations"

* Labels
lab var t 				"Treatment"
lab var private 		"Private HF at Randomization"	
lab var private_t 		"Private HF at Randomization x T"
lab var unlicensed_s0  	"Unlicensed HF at Randomization"	
lab var unlicensed_s0_t "Unlicensed HF at Randomization x T"	

glo t 			: variable label t
glo t_B 		: variable label t
glo t_C 		: variable label t

glo inter_B 	: variable label private
glo inter_t_B   : variable label private_t
glo inter_C 	: variable label unlicensed_s0
glo inter_t_C  	: variable label unlicensed_s0_t

glo B_pr_text "Private"
glo B_pu_text "Public"	
glo C_unl_text "Unlicensed"
glo C_lic_text "Licensed"		

* Table global
glo table_name "${tex_`out'_out}"

* Start the Latex document
texdoc do "${tex_`out'}"		
		
			


		
		
