/*******************************************************************************	

Project:  		KePSIE
Created on:  	July 23, 2019
Last udpate on: July 24, 2019

Written by:  	Thomas Escande			

Revision: 		

********************************************************************************			

THIS DO FILE: 	Following Chandra & Finkelstein (2016), it tries to decompose the different drivers of weighted improvment

CONTENT:		Part 0 - Create globals for directories and files 


INPUTS:     	"${KePSIE_DB}/IE_Main_Paper/DataSets/Final/Data_for_analysis.dta"
					
OUTPUTS:     	

*******************************************************************************/

********************************************************************************
	** Part 0: Create globals for directories and files 
********************************************************************************
	clear all
	set more off
	set maxvar 20000
	

		global scenario 			S1	    
		global N_scenario 			1	  		
		
	*Inputs	
		global 	inputdata	 		"${dt_final}/data_for_analysis.dta" 
		global decomposition_data 	"${dt_end_fin}/decomposition_data_${scenario}.dta"
	*Outputs	
		loc out 					table_6	
		global tex_table_decomp     "${do_main}/tex/tex_`out'.do"		
		global table_name 			"${out_main}/`out'"	
		

	*Controls
		glo control_mks 			per_level_2 per_level_3 per_level_4_5 	
	
	
********************************************************************************
** Part 1: Creating necessary variables and setting up dataset
********************************************************************************

use "${decomposition_data}", clear


*Do it for treatment only and for control only 
forvalues i = 0/1 {
preserve 
keep if t == `i'

		collapse (sum) ///
			weighted_avg_q = q_change_h ///
			within = tsum_within ///
			between = tsum_between ///
			cross = tsum_cross ///
			entry = tsum_entry ///
			exit = tsum_exit ///
			continuing exiting entering ///
			(mean) q_change_m_test (mean) tot_w_bl_t, by(market_all_expanded)

*Checking that by adding all coefficients, we get back to the original variation 
	assert abs(weighted_avg_q - q_change_m_test) < .0001
	drop q_change_m_test
		
*summed components of the change
	gen tot = within + between + cross + entry + exit //Exit is written negatively to have a positive coefficient when facilities are exiting

*they better equal the total change
	assert abs(tot - weighted_avg_q) < .0001 
	drop tot 

*Saving temporarily to reuse later on
	tempfile decomposition_data_`i'
	save `decomposition_data_`i'', replace

*Collapsing to get the value of the coefficients 
			collapse ///
				(mean) weighted_avg_q within between cross entry exit (semean) weighted_avg_q_se = weighted_avg_q within_se = within between_se = between cross_se = cross entry_se = entry exit_se = exit  ///
				(count) N=weighted_avg_q [aw=tot_w_bl_t]
				
*Computing t statistic for the mean
	foreach var in weighted_avg_q within between cross entry exit {
		gen `var'_p = ttail(N-1,abs(`var'/`var'_se))*2 
	}
	
			set obs 3
			mkmat weighted_avg_q within between cross entry exit , matrix(treatment_`i') 
			matrix rownames treatment_`i' = PP % p
			
*Generate as percentage of total effect
local j = 0
	foreach var in weighted_avg_q within between cross entry exit {
	local j = `j' + 1
	gen `var'_per = `var'/ weighted_avg_q * 100
	matrix treatment_`i'[2,`j'] = `var'_per[1]
	matrix treatment_`i'[3,`j'] = `var'_p[1]
	}
	restore
	}
	
*Generating the table


global A_t1 		"Total Impact"
global A_t2 		"Within"
global A_t3 		"Between"
global A_t4 		"Cross"
global A_t5 		"Entry"
global A_t6 		"Exit"

forvalues i = 0/1 {
	forvalues j = 1/6 {
		forvalues k = 1/3 {

	global ${scenario}_`i'_`k'_`j' : di %10.3fc treatment_`i'[`k',`j'] 

	global ${scenario}_`i'_`k'_`j' = "$" + "${${scenario}_`i'_`k'_`j'}" + "$" 
		}
	}
}

******************************************************************************************
** Part 2: Performing regressions using the same coefficients instead of simple difference 
******************************************************************************************
use "${inputdata}", clear	

*Keep only the markets to then merge
duplicates drop market_all_expanded, force
merge 1:1 market_all_expanded using `decomposition_data_0', assert(1 3)
rename _merge _merge0
merge 1:1 market_all_expanded using `decomposition_data_1', assert(1 4) update // Making sure all the observations from the dataset are merged

drop if _merge == 1 & _merge0 == 1 //Markets that were dropped before as they were not part of the sample
drop _merge _merge0

*All results
mat Res_${scenario}=J(7,6,0) 


local j = 0
foreach outcome in weighted_avg_q within between cross  entry exit {
	local j = `j' + 1
	reg `outcome' t ${control_mks} i.strata_expanded [aw = tot_w_bl_t]
	*Saving all the values from the regression
	mat A = r(table)
		mat Res_${scenario}[1,`j'] = _b[t]
		mat Res_${scenario}[2,`j'] = _se[t]
		mat Res_${scenario}[3,`j'] = A[4,1]
		mat Res_${scenario}[5,`j'] = e(N)
		*Saving CI to use later in the graphs
		mat Res_${scenario}[6,`j'] = A[5,1]
		mat Res_${scenario}[7,`j'] = A[6,1]
		
	sum `outcome' if t==0 & e(sample) == 1 			 [aw = tot_w_bl_t]
		mat Res_${scenario}[4,`j'] = r(mean)
}


*Putting matrix coefficients in globals to then transfer to the latex table
 forvalues j = 1/6 {
	forvalues i = 1/4 {
	global reg_${scenario}_`j'_`i' : di %10.3fc Res_${scenario}[`i',`j'] 
	global reg_${scenario}_`j'_`i' = "$" + "${reg_${scenario}_`j'_`i'}" + "$" 
	}
	global reg_${scenario}_`j'_5 : di %10.0fc Res_${scenario}[5,`j'] 
	global reg_${scenario}_`j'_5 = "$" + "${reg_${scenario}_`j'_5}" + "$" 	
	local  p_`j' =  Res_${scenario}[3,`j']
	*Adding the star on the coefficient
	if  `p_`j'' <= 0.1 {
		global reg_${scenario}_`j'_1 = "${reg_${scenario}_`j'_1}" + "*"
			
			if `p_`j'' <= 0.05 {
			global reg_${scenario}_`j'_1 = "${reg_${scenario}_`j'_1}" + "*"

				if `p_`j'' <= 0.01 {
				global reg_${scenario}_`j'_1 = "${reg_${scenario}_`j'_1}" + "*"
				
			}				
		}
	}
	
}

	texdoc do		"${tex_table_decomp}", replace	// Creates a .tex document 
******************************End of do file*********************************

			
