/*******************************************************************************	
Project:  	KePSIE
********************************************************************************/
********************************************************************************
** Setup
********************************************************************************
clear all
set more off

* Input
glo inputdata	 		"${dt_final}/data_for_analysis.dta" 
		
* Output
loc out 				table_7
glo tex_`out'			"${do_main}/tex/tex_`out'.do"
glo tex_`out'_out 		"${out_main}/`out'"	

* Programs		
glo save_coeff			"${program}/save_coeff.do"
do "${save_coeff}"	

* Table globals
* -----------------
* Treatments	
glo t1 t1 t2
glo treatments_pooled t1_2 t2_2
* Control vars
glo control_hfs level_3 level_4_5 						i.strata_expanded
glo control_mks per_level_2 per_level_3 per_level_4_5 	i.strata_expanded
* Outcomes
glo main_outcome 	  	jhic_all oop_all_imp outp_as_jan new_end 
glo outcome_toweight  	jhic_all oop_all_imp
glo outcome_weighted  	jhic_all_w oop_all_imp_w
glo main_outcomes 		jhic_all oop_all_imp jhic_all_w oop_all_imp_w outp_as_jan new_end
* Sample
glo sample s2
	
********************************************************************************
** Run table
********************************************************************************
*-------------------------------------------------------------------
* Panel A. Main Outcomes 
*-------------------------------------------------------------------
use "${inputdata}", clear
replace outp_as_jan = . if inactive==1 // outpatients without inactive coded as zero		
		
* Run regression
* ----------------------------------
* Unweighted	
foreach var in $main_outcome {
	reg `var' $treatments_pooled $control_hfs  			if $sample == 1 , vce(cluster market_all_expanded)
		sum `var' 						if t == 0 & $sample == 1 & e(sample) == 1
		save_coeff `var'
			}
			
* Weighted
foreach var in $outcome_toweight {
	rename `var' `var'_w
	reg `var'_w $treatments_pooled $control_hfs  	[aw = weight]		if $sample == 1 , vce(cluster market_all_expanded)
		sum `var'_w  				[aw = weight]		if t == 0 & $sample == 1 & e(sample) == 1
		save_coeff `var'_w
			}
			
* Adding ***
* --------------
glo coeff_table
foreach var in $main_outcomes {
	glo coeff_table $coeff_table `var'1 `var'2
		}
	star coeff_table
	
********************************************************************************
** Export
********************************************************************************
glo table_name 		"Table${TableNumber}_$date"
glo left 			"Facility and Patient Level"
glo C_1 			"JHIC Score"
glo C_1_s 			"(pp of max)"
glo C_2 			"OOP"
glo C_2_s 			"(USD PPP)"
glo C_3 			"Daily"
glo C_3_s 			"Outpatients"
glo C_4 			"New"
glo C_4_s 			""

glo R_text 			"$\rm {R}^{2}" 
glo N_text 			"Observations"

* Labels
glo t1 				"Inspection Only (T1)"
glo t2 				"Inspections plus Information (T2)"

* Table global
glo table_name "${tex_`out'_out}"

* Start the Latex document
texdoc do "${tex_`out'}"		

			
		
			


		
		
		
		
