/*******************************************************************************	
Project:  	KePSIE
*******************************************************************************/
********************************************************************************
** Create globals for directories and files 
********************************************************************************
clear all
set more off
	
* Input 
glo inputdata 			"${dt_final}/data_for_analysis.dta" 

* Programs		
glo save_coeff			"${program}/save_coeff.do"
do "${save_coeff}"
	
********************************************************************************
** Setup
********************************************************************************
use "${inputdata}", clear	

keep hfid t jhic_all_bl jhic_all
keep if t==0
ren jhic_all_bl jhic_all1
ren jhic_all jhic_all2
reshape long jhic_all, i(hfid) j(bl_end)
lab def bl_end 1 "Baseline" 2 "Endline"
lab val bl_end bl_end

sum jhic_all if bl_end==1
glo mbl = `r(mean)'
loc mbl:  di %4.2f `r(mean)'
di `mbl'

sum jhic_all if bl_end==2
glo mend = `r(mean)'
loc mend:  di %4.2f `r(mean)'
di `mend'

ksmirnov jhic_all, by(bl_end) exact
loc pval:  di %4.2f `r(p_exact)'

kdensity jhic_all if bl_end==1, xtitle(JHIC Score) title("") ///
legend(label(1 "Baseline") label(2 "Endline") pos(6) rows(1)) yscale(range(0 .05)) ylabel(0(.01).05, nogrid) ///
addplot(kdensity jhic_all if bl_end==2, lpattern(vshortline)) note("") ///
text(.04 55 "Mean Baseline=`mbl'" .038 55 "Mean Endline:`mend'".036 54.7 "Test Baseline=Endline KS p-value =`pval'", placement(east) size(vsmall)) scheme(cleanplots)

graph export  	"${out_supp}/figure_S3.png", replace	

