/*******************************************************************************	
Project:  	KePSIE
*******************************************************************************/
********************************************************************************
** Create globals for directories and files 
********************************************************************************
clear all
set more off
	
* Input 
glo inputdata 			"${dt_final}/data_for_analysis.dta" 
	
********************************************************************************
	** Tables
********************************************************************************
use "${inputdata}", clear	
			
* Setup
	
glo first_i 	ti_group_month1to3_m ti_group_month4to6_m time_collect_month1to2 time_collect_month1to2_t1 time_collect_month1to2_t2
glo con 		level_3 level_4_5 maintown_km 
glo sample 		s2

loc y 			jhic_all
loc z 			// ti_group_month1to3_m 
loc i 			// "& private==0" // "& ti_group_month1to3_m!=1"

* Regression
reg jhic_all $first_i $con i.strata_expanded if $sample==1 `i', vce(cluster market_all_expanded)
gen b_1 = _b[ti_group_month1to3_m]
gen b_lb_1 = _b[ti_group_month1to3_m] - invttail(e(df_r),0.025)*_se[ti_group_month1to3_m] // matlist r(table)
gen b_ub_1 = _b[ti_group_month1to3_m] + invttail(e(df_r),0.025)*_se[ti_group_month1to3_m]

lincom ti_group_month1to3_m + time_collect_month1to2_t1
gen b_2 = r(estimate)
gen b_lb_2 = r(lb)
gen b_ub_2 = r(ub)

gen b_3 = _b[ti_group_month4to6_m]
gen b_lb_3 = _b[ti_group_month4to6_m] - invttail(e(df_r),0.025)*_se[ti_group_month4to6_m] // matlist r(table)
gen b_ub_3 = _b[ti_group_month4to6_m] + invttail(e(df_r),0.025)*_se[ti_group_month4to6_m]

lincom ti_group_month4to6_m + time_collect_month1to2_t2
gen b_4 = r(estimate)
gen b_lb_4 = r(lb)
gen b_ub_4 = r(ub)

keep b_1 b_2 b_3 b_4 b_lb_1 b_lb_2 b_lb_3 b_lb_4 b_ub_1 b_ub_2 b_ub_3 b_ub_4
gen n = _n
keep if n==1
reshape long mean b_ b_lb_ b_ub_, i(n) j(c)
drop n
gen n = _n
replace b_ = round(b_,.01)
format b_ %4.2f
gen own = 1
lab def c 1 "1-3 x E1-2" 2 "1-3 x E3-4" 3 "4-6 x E1-2" 4 "4-6 x E3-4"
lab val c c

* Change mlabgap for label position
tw 	(bar b_ c if c==1, fcolor(navy%80) lcolor(navy) barwidth(.5)) ///
	(bar b_ c if c==2, fcolor(maroon%80) lcolor(maroon) barwidth(.5)) ///
	(bar b_ c if c==3, fcolor(navy%80) lcolor(navy) barwidth(.5)) ///
	(bar b_ c if c==4, fcolor(maroon%80) lcolor(maroon) barwidth(.5)) ///
	(rcap b_ub_ b_lb_ c, lcolor(black)) ///
	(scatter b_ c, msymbol(none) mlabel(b_) mlabcolor(black) mlabgap(20) mlabposition(6)), /// 
	xlabel(none, nolabels nogrid) ///
	title("Impact on JHIC Score by Month of Market's First Inspection", size(medium) color(black) span margin(b=5)) ///
	subtitle("", size(medsmall) color(gray) span margin(b=5)) ///
	xtitle("Months of Market's First Inspection", margin(medsmall)) /// 
	ylabel(0(5)10, nogrid) yscale(range(0 10)) /// 
	ytitle("Treatment Effect", margin(medlarge)) ///
	legend(off)	scheme(cleanplots) graphregion(color(white)) 
	
	graph export "${out_supp}/figure_S4.png", replace
	
	
