/*******************************************************************************
*					     			KePSIE 		    		       			   *
********************************************************************************		
********************************************************************************
** Create locals for files 
*******************************************************************************/
clear all
	
* Input 
glo inputdata 			"${dt_final}/data_for_analysis.dta" 
glo mfl 				"${dt_adm}/mfl_facilities.dta"

* Output 
loc out 				table_S1
glo tex_`out'			"${do_supp}/tex/tex_`out'.do"
glo tex_`out'_out 		"${out_supp}/`out'.tex"

* Programs
glo stats				"${program}/stats.do"
do "${stats}"	

********************************************************************************
** Table 1: Summary statistics at baseline
********************************************************************************
use "${inputdata}", clear

* Setup
* -------
glo colA 		"Government Data"
glo colB 		"KePSIE Data"
glo colA1 		"3 Counties"
glo colB1 		"National"
glo unit1 		"\% of patients"
glo unit2 		"\% of facilities"
glo unit3 		"\% of markets"

glo panelA 		"Panel A. Facility level"
glo panelB		"Panel B. Market level"

glo C_1 		"All"
glo C_2 		"Public"
glo C_3 		"Private"	

* Variables for imputations: impute by the mean within similar categories: by level, ownership, and unlicensed at randomization
loc x 	outp_as_jan_bl
bysort 	private level unlicensed_s0: egen `x'_av = mean(`x')
gen 	`x'_imp = `x'
replace `x'_imp = `x'_av if mi(`x'_imp) & active_s0==1
replace `x'_imp = . if active_s0!=1
lab var `x'_av 	"Mean outpatients at baseline by ownership, level, and license status"
lab var `x'_imp "OOP (with imputation by oop_av)"		

glo outp 		outp_as_jan_bl_imp //   outp_as_jan_bl
glo sample 		active_s0 //   s0

recode marketsize_rand_expanded_group (2/5=0), gen(mk_1_s0) // check diff between marketsize_rand_expanded_group & marketsize_group
recode marketsize_rand_expanded_group (2/3=1) (1 4/5=0), gen(mk_2to3_s0)
recode marketsize_rand_expanded_group (4/5=1) (1/3=0), gen(mk_4plus_s0)
gen hfall = 1
recode private (1=0) (0=1), gen(public)

egen tot_outp = total($outp)
foreach x in public private level_2 level_3 level_4_5 mk_1_s0 mk_2to3_s0 mk_4plus_s0 {
	egen `x'_outp = total($outp) if `x'==1 & $sample==1
	gen `x'_share = `x'_outp/tot_outp
	glo `x'_sharel : var label `x'
	}

* Run
* ------
glo SR_1 		"Facility ownership"
glo SR_2 		"Facility level"
glo SR_3 		"Proportion by market size"
glo SR_4 		"Observations"
glo SR_5 		"Market level"

* Facility level
lab var public			"Public"
lab var private			"Private"
lab var level_2 		"Level 2" // check diff between level and level_bl
lab var level_3 		"Level 3"
lab var level_4_5 		"Levels 4 and 5"
lab var mk_1_s0			"1 facility"
lab var mk_2to3_s0		"2-3 facilities"
lab var mk_4plus_s0		"4+ facilities"

foreach x in public private level_2 level_3 level_4_5 mk_1_s0 mk_2to3_s0 mk_4plus_s0 {
	sum `x' if $sample==1
	glo `x'l : var label `x'
	glo `x'm : di %4.2f `r(mean)'
	glo `x'n =`r(N)'
	}
	
foreach x in public private level_2 level_3 level_4_5 mk_1_s0 mk_2to3_s0 mk_4plus_s0 {
	sum `x'_share
	glo `x'_sharel : var label `x'
	glo `x'_sharem_imp : di %4.2f `r(mean)'
	glo `x'_sharen =`r(N)'
	}
	
sum $outp
glo outp_n_imp =`r(N)'
	
* Market level	
bys market_all_expanded: gen counter_m = _n
bys market_all_expanded: egen ${outp}_m=total(${outp})

egen tot_outp_m_in = sum(${outp}_m) if counter_m==1
egen tot_outp_m = mean(tot_outp_m_in), by(market_all_expanded)

loc x sing
egen `x'_outp_m = sum(${outp}_m) if marketsize_rand_expanded_group==1 & counter_m==1
gen `x'_share = `x'_outp_m/tot_outp_m if counter_m==1
lab var `x'_share "Singleton markets"
sum `x'_share
glo `x'_m_imp : di %4.2f `r(mean)'
glo `x'_l : var label `x'_share

loc x singpub
egen `x'_outp_m = sum(${outp}_m) if marketsize_rand_expanded_group==1 & allpublic_s0==1 & counter_m==1
gen `x'_share = `x'_outp_m/tot_outp_m if counter_m==1
lab var `x'_share "Only public"
sum `x'_share
glo `x'_m_imp : di %4.2f `r(mean)'
glo `x'_l : var label `x'_share

loc x singpri
egen `x'_outp_m = sum(${outp}_m) if marketsize_rand_expanded_group==1 & allprivate_s0==1 & counter_m==1
gen `x'_share = `x'_outp_m/tot_outp_m if counter_m==1
lab var `x'_share "Only private"
sum `x'_share
glo `x'_m_imp : di %4.2f `r(mean)'
glo `x'_l : var label `x'_share

loc x onlypub
bys market_all: egen pub_tot = total(public)
bys market_all: egen hfs_tot = count(hfid)
gen 	allpublic = 1 if pub_tot == hfs_tot
replace allpublic = 0 if mi(allpublic)

bys market_all: gen counter_m_s0 = _n

egen `x'_outp_m = sum(${outp}_m) if allpublic==1 & counter_m_s0==1
gen `x'_share = `x'_outp_m/tot_outp_m if counter_m_s0==1
lab var `x'_share "Markets with only public facilities"
sum `x'_share
glo `x'_m : di %4.2f `r(mean)'
glo `x'_l : var label `x'_share

loc x onlypri
bys market_all: egen pri_tot = total(private)
gen allprivate = 1 if pri_tot == hfs_tot
replace allprivate = 0 if mi(allprivate)

egen `x'_outp_m = sum(${outp}_m) if allprivate==1 & counter_m_s0==1
gen `x'_share = `x'_outp_m/tot_outp_m if counter_m_s0==1
lab var `x'_share "Markets with only private facilities"
sum `x'_share
glo `x'_m : di %4.2f `r(mean)'
glo `x'_l : var label `x'_share

egen oth_share_m = sum(${outp}_m) if (allpublic!=1 & allprivate!=1) & counter_m_s0==1
gen oth_share = oth_share_m/tot_outp_m if counter_m_s0==1

bys market_all: egen onepub_in = total(public)
replace onepub_in = . if market_all==.
gen 	onepub = 1 if onepub_in>=1 & onepub_in!=.
replace onepub = 0 if onepub_in==0

loc x onepub
egen `x'_outp_m = sum(${outp}_m) if onepub==1 & counter_m_s0==1
gen `x'_share = `x'_outp_m/tot_outp_m if counter_m_s0==1
lab var `x'_share "Markets with at least 1 public facility"
sum `x'_share
glo `x'_m_imp : di %4.2f `r(mean)'
glo `x'_l : var label `x'_share

sum tot_outp_m if counter_m==1
glo outp_n_m_imp =`r(N)'

gen sing 		= 1 if marketsize_rand_expanded_group==1
replace sing	= 0 if mi(sing) & marketsize_rand_expanded_group!=.

gen singpub 	= 1 if marketsize_rand_expanded_group==1 & private==0
replace singpub	= 0 if mi(singpub) & marketsize_rand_expanded_group!=.

gen singpri 	= 1 if marketsize_rand_expanded_group==1 & private==1
replace singpri	= 0 if mi(singpri) & marketsize_rand_expanded_group!=.

clonevar onlypub = allpublic
clonevar onlypri = allprivate

sort counter_m_s0
foreach x in sing singpub singpri onlypub onlypri {
	sum `x' if counter_m_s0==1
	glo `x'l : var label `x'
	glo `x'm_imp : di %4.2f `r(mean)'
	glo `x'n =`r(N)'
	}

foreach x in onepub {
	sum `x' if counter_m_s0==1
	glo `x'l : var label `x'
	glo `x'm_imp : di %4.2f `r(mean)'
	glo `x'n =`r(N)'
	}	

	drop outp_as_jan_bl_av outp_as_jan_bl_imp mk_1_s0 mk_2to3_s0 mk_4plus_s0 hfall public tot_outp public_outp public_share private_outp private_share level_2_outp level_2_share level_3_outp level_3_share level_4_5_outp level_4_5_share mk_1_s0_outp mk_1_s0_share mk_2to3_s0_outp mk_2to3_s0_share mk_4plus_s0_outp mk_4plus_s0_share counter_m outp_as_jan_bl_imp_m tot_outp_m_in tot_outp_m sing_outp_m sing_share singpub_outp_m singpub_share singpri_outp_m singpri_share pub_tot hfs_tot allpublic counter_m_s0 onlypub_outp_m onlypub_share pri_tot allprivate onlypri_outp_m onlypri_share oth_share_m oth_share onepub_in onepub onepub_outp_m onepub_share sing singpub singpri onlypub onlypri
	
*******************
*******************

glo outp 		outp_as_jan_bl //   outp_as_jan_bl
glo sample 		active_s0 //   s0

recode marketsize_rand_expanded_group (2/5=0), gen(mk_1_s0) // check diff between marketsize_rand_expanded_group & marketsize_group
recode marketsize_rand_expanded_group (2/3=1) (1 4/5=0), gen(mk_2to3_s0)
recode marketsize_rand_expanded_group (4/5=1) (1/3=0), gen(mk_4plus_s0)
gen hfall = 1
recode private (1=0) (0=1), gen(public)

egen tot_outp = total($outp)
foreach x in public private level_2 level_3 level_4_5 mk_1_s0 mk_2to3_s0 mk_4plus_s0 {
	egen `x'_outp = total($outp) if `x'==1 & $sample==1
	gen `x'_share = `x'_outp/tot_outp
	glo `x'_sharel : var label `x'
	}

* Run
* ------
glo SR_1 		"Facility ownership"
glo SR_2 		"Facility level"
glo SR_3 		"Proportion by market size"
glo SR_4 		"Observations"
glo SR_5 		"Market level"

* Facility level
lab var public			"Public"
lab var private			"Private"
lab var level_2 		"Level 2" // check diff between level and level_bl
lab var level_3 		"Level 3"
lab var level_4_5 		"Levels 4 and 5"
lab var mk_1_s0			"1 facility"
lab var mk_2to3_s0		"2-3 facilities"
lab var mk_4plus_s0		"4+ facilities"

foreach x in public private level_2 level_3 level_4_5 mk_1_s0 mk_2to3_s0 mk_4plus_s0 {
	sum `x' if $sample==1
	glo `x'l : var label `x'
	glo `x'm : di %4.2f `r(mean)'
	glo `x'n =`r(N)'
	}
	
foreach x in public private level_2 level_3 level_4_5 mk_1_s0 mk_2to3_s0 mk_4plus_s0 {
	sum `x'_share
	glo `x'_sharel : var label `x'
	glo `x'_sharem : di %4.2f `r(mean)'
	glo `x'_sharen =`r(N)'
	}
	
sum $outp
glo outp_n =`r(N)'

	
* Market level	
bys market_all_expanded: gen counter_m = _n
*bys market_all_expanded: egen ${outp}_m=total(${outp})

egen tot_outp_m_in = sum(${outp}_m) if counter_m==1
egen tot_outp_m = mean(tot_outp_m_in), by(market_all_expanded)

loc x sing
egen `x'_outp_m = sum(${outp}_m) if marketsize_rand_expanded_group==1 & counter_m==1
gen `x'_share = `x'_outp_m/tot_outp_m if counter_m==1
lab var `x'_share "Singleton markets"
sum `x'_share
glo `x'_m : di %4.2f `r(mean)'
glo `x'_l : var label `x'_share

loc x singpub
egen `x'_outp_m = sum(${outp}_m) if marketsize_rand_expanded_group==1 & allpublic_s0==1 & counter_m==1
gen `x'_share = `x'_outp_m/tot_outp_m if counter_m==1
lab var `x'_share "Only public"
sum `x'_share
glo `x'_m : di %4.2f `r(mean)'
glo `x'_l : var label `x'_share

loc x singpri
egen `x'_outp_m = sum(${outp}_m) if marketsize_rand_expanded_group==1 & allprivate_s0==1 & counter_m==1
gen `x'_share = `x'_outp_m/tot_outp_m if counter_m==1
lab var `x'_share "Only private"
sum `x'_share
glo `x'_m : di %4.2f `r(mean)'
glo `x'_l : var label `x'_share

loc x onlypub
bys market_all: egen pub_tot = total(public)
bys market_all: egen hfs_tot = count(hfid)
gen 	allpublic = 1 if pub_tot == hfs_tot
replace allpublic = 0 if mi(allpublic)

bys market_all: gen counter_m_s0 = _n

egen `x'_outp_m = sum(${outp}_m) if allpublic==1 & counter_m_s0==1
gen `x'_share = `x'_outp_m/tot_outp_m if counter_m_s0==1
lab var `x'_share "Markets with only public facilities"
sum `x'_share
glo `x'_m : di %4.2f `r(mean)'
glo `x'_l : var label `x'_share

loc x onlypri
bys market_all: egen pri_tot = total(private)
gen allprivate = 1 if pri_tot == hfs_tot
replace allprivate = 0 if mi(allprivate)

egen `x'_outp_m = sum(${outp}_m) if allprivate==1 & counter_m_s0==1
gen `x'_share = `x'_outp_m/tot_outp_m if counter_m_s0==1
lab var `x'_share "Markets with only private facilities"
sum `x'_share
glo `x'_m : di %4.2f `r(mean)'
glo `x'_l : var label `x'_share

egen oth_share_m = sum(${outp}_m) if (allpublic!=1 & allprivate!=1) & counter_m_s0==1
gen oth_share = oth_share_m/tot_outp_m if counter_m_s0==1

bys market_all: egen onepub_in = total(public)
replace onepub_in = . if market_all==.
gen 	onepub = 1 if onepub_in>=1 & onepub_in!=.
replace onepub = 0 if onepub_in==0

loc x onepub
egen `x'_outp_m = sum(${outp}_m) if onepub==1 & counter_m_s0==1
gen `x'_share = `x'_outp_m/tot_outp_m if counter_m_s0==1
lab var `x'_share "Markets with at least 1 public facility"
sum `x'_share
glo `x'_m : di %4.2f `r(mean)'
glo `x'_l : var label `x'_share

sum tot_outp_m if counter_m==1
glo outp_n_m =`r(N)'

gen sing 		= 1 if marketsize_rand_expanded_group==1
replace sing	= 0 if mi(sing) & marketsize_rand_expanded_group!=.

gen singpub 	= 1 if marketsize_rand_expanded_group==1 & private==0
replace singpub	= 0 if mi(singpub) & marketsize_rand_expanded_group!=.

gen singpri 	= 1 if marketsize_rand_expanded_group==1 & private==1
replace singpri	= 0 if mi(singpri) & marketsize_rand_expanded_group!=.

clonevar onlypub = allpublic
clonevar onlypri = allprivate

foreach x in sing singpub singpri onlypub onlypri {
	sum `x' if counter_m_s0==1
	glo `x'l : var label `x'
	glo `x'm : di %4.2f `r(mean)'
	glo `x'n =`r(N)'
	}

foreach x in onepub {
	sum `x' if counter_m_s0==1
	glo `x'l : var label `x'
	glo `x'm : di %4.2f `r(mean)'
	glo `x'n =`r(N)'
	}	
	

	

* MFL
use "${mfl}", clear

* Prepare key vars
ren facilitycode hfid
drop if hfid==.
gen kepsie = 1 if inlist(county,"Kakamega","Kilifi","Meru")
replace kepsie = 0 if mi(kepsie)
ren county county_mfl

clonevar mfl_private=facility_private
recode mfl_private (1=0) (0=1), gen(mfl_public)

gen mfl_level_2			= 1 if inlist(kephlevel,"Level 2")
gen mfl_level_3			= 1 if inlist(kephlevel,"Level 3")
gen mfl_level_4_5		= 1 if inlist(kephlevel,"Level 4","Level 5")

foreach x in mfl_level_2 mfl_level_3 mfl_level_4_5 {
	replace `x' = 0 if mi(`x') & kephlevel!=""
	}

gen mfl_mk_1_s0 		= 1 if market_facilities==1
gen mfl_mk_2to3_s0 		= 1 if inlist(market_facilities,2,3)
gen mfl_mk_4plus_s0 	= 1 if market_facilities>=4 & market_facilities!=.

foreach x in mfl_mk_1_s0 mfl_mk_2to3_s0 mfl_mk_4plus_s0 {
	replace `x' = 0 if mi(`x') & market_facilities!=.
	}

foreach x in public private level_2 level_3 level_4_5 mk_1_s0 mk_2to3_s0 mk_4plus_s0 {
	sum mfl_`x' if kepsie==1
	glo mfl_`x'm1 : di %4.2f `r(mean)'
	glo mfl_`x'n1 =`r(N)'
	}
	
foreach x in public private level_2 level_3 level_4_5 mk_1_s0 mk_2to3_s0 mk_4plus_s0 {
	sum mfl_`x'
	glo mfl_`x'm2 : di %4.2f `r(mean)'
	glo mfl_`x'n2 =`r(N)'
	}	
	
	
* Generate unique market ID and set counter
encode county_mfl, gen(countyc)
egen marketid = concat(countyc market)
destring marketid, replace

sort marketid hfid
bys marketid: gen counter_m = _n 

* All public or private
foreach x in mfl_private mfl_public {
	by marketid: egen `x'tot = sum(`x')
	replace `x'tot = . if marketid==.
	gen all`x' = 1 if market_facilities==`x'tot
	replace all`x' = . if marketid==.	
	}	

loc x mfl_sing
gen `x' 	= 1 if market_facilities==1
replace `x'	= 0 if mi(`x') & market_facilities!=.

loc x mfl_singpub
gen `x' 	= 1 if market_facilities==1 & mfl_private==0
replace `x'	= 0 if mi(`x') & market_facilities!=.

loc x mfl_singpri
gen `x' 	= 1 if market_facilities==1 & mfl_private==1
replace `x'	= 0 if mi(`x') & market_facilities!=.

by marketid: egen pub_per_mk_in = total(mfl_public)
replace pub_per_mk_in = . if marketid==.
gen mfl_onepub 		= 1 if pub_per_mk_in>=1 & pub_per_mk_in!=.
replace mfl_onepub 	= 0 if pub_per_mk_in==0


clonevar mfl_onlypub = market_public_only
clonevar mfl_onlypri = market_private_only

sort counter_m hfid
foreach x in sing singpub singpri onlypub onlypri onepub {
	sum mfl_`x' if counter_m==1 & kepsie==1
	glo mfl_`x'l : var label mfl_`x'
	glo mfl_`x'm1 : di %4.2f `r(mean)'
	glo mfl_`x'n1 =`r(N)'
	}
	
sort counter_m hfid
foreach x in sing singpub singpri onlypub onlypri onepub {
	sum mfl_`x' if counter_m==1
	glo mfl_`x'l : var label mfl_`x'
	glo mfl_`x'm2 : di %4.2f `r(mean)'
	glo mfl_`x'n2 =`r(N)'
	}	
	
	 
* Table global
glo table_name "${tex_`out'_out}"

* Start the Latex document
texdoc do "${tex_`out'}"	

				

