/*******************************************************************************	
Project:  	KePSIE
********************************************************************************/
********************************************************************************
** Setup
********************************************************************************
clear all
set more off

* Input
glo inputdata	 		"${dt_final}/data_for_analysis.dta" 
		
* Output
loc out 				table_S10
glo tex_`out'			"${do_supp}/tex/tex_`out'.do"
glo tex_`out'_out 		"${out_supp}/`out'.tex"

* Programs		
glo save_coeff			"${program}/save_coeff.do"
do "${save_coeff}"

* Table globals
* -----------------
* Treatments	
glo t1 t1 t2
glo treatments_pooled t1_2 t2_2
* Control vars
glo control_bl			jhic_all_bl_m_mi jhic_all_bl_m_mi_d outp_as_jan_bl_m_mi outp_as_jan_bl_m_mi_d oop_all_bl_m_mi oop_all_bl_m_mi_d
glo control_bl_w		jhic_all_bl_m_w_mi jhic_all_bl_m_w_mi_d outp_as_jan_bl_m_mi outp_as_jan_bl_m_mi_d oop_all_bl_m_w_mi oop_all_bl_m_w_mi_d
glo control_hfs 		level_3 level_4_5 $control_bl i.strata_expanded // per_level_2 per_level_3 per_level_4_5
glo control_hfs_w 		level_3 level_4_5 $control_bl_w i.strata_expanded // per_level_2 per_level_3 per_level_4_5
glo control_mks 			i.strata_expanded // per_level_2 per_level_3 per_level_4_5 
* Outcomes
glo main_outcome 	  	jhic_all oop_all_imp outp_as_jan
glo outcome_toweight  	jhic_all oop_all_imp
glo outcome_weighted  	jhic_all_w oop_all_imp_w
glo mo_all_out			jhic_all oop_all_imp jhic_all_w oop_all_imp_w outp_as_jan
* Sample
glo sample s2
	
********************************************************************************
** Run table
********************************************************************************
*-------------------------------------------------------------------
* Panel A. Main Outcomes 
*-------------------------------------------------------------------
use "${inputdata}", clear
foreach x in oop_all_bl jhic_all_bl outp_as_jan_bl {
	bys market_all_expanded: egen `x'_m_exp = mean(`x'_m)
	drop `x'_m
	ren `x'_m_exp `x'_m
	}
* Missing Indicator method for market level
foreach x in oop_all_bl_m oop_all_bl_m_w {
	drop `x'_mi_d `x'_mi
	gen 	`x'_mi_d 	= 0
	replace `x'_mi_d 	= 1 if mi(`x')
	gen 	`x'_mi 	= `x'
	replace `x'_mi 	= 0 if mi(`x')
	}

	*br market_all_expanded hfid oop_all_bl oop_all_bl_m oop_all_bl_m_mi oop_all_bl_m_mi_d
	*br market_all_expanded hfid jhic_all_bl jhic_all_bl_m jhic_all_bl_m_mi jhic_all_bl_m_mi_d
	
	
replace outp_as_jan = . if inactive==1 // outpatients without inactive coded as zero



* First, computing sharpened q values
* ----------------------------------	
local num_p = 0


foreach var in $main_outcome {
	reg `var' t $control_hfs  			if $sample == 1 , vce(cluster market_all_expanded)
	*Saving naive p values
		glo `var'p_q = r(table)[4,1]
local num_p = `num_p' + 1	
	}

*Weighted 

foreach var in $outcome_toweight {
	reg `var' t $control_hfs_w  	[aw = weight]		if $sample == 1 , vce(cluster market_all_expanded)	
	*Saving naive p values
		glo `var'_wp_q = r(table)[4,1] 
local num_p = `num_p' + 1
		}
	

		*Running Anderson code modified to work here
preserve 
clear  
set obs `num_p' /*Change to number of hypothesis to be included in the MHT*/

local count = 1 
gen float pval = .

	foreach var in $main_outcome  $outcome_weighted {
replace  pval = ${`var'p_q}	if _n == `count'
local count = `count' + 1	
	}


*Run the fdr sharpened q values do file 
do "${program}/fdr_sharpened_qvalues.do"	

*Save the fdr sharpened q values 	
local count_q = 1 
foreach var in $main_outcome $outcome_weighted   {	
		global `var'_q : disp %10.3f bky06_qval[`count_q']
local count_q = `count_q' + 1			
}



*Add the stars to the fdr sharpened q values do file 
foreach var in $main_outcome $outcome_weighted   {		
	global `var'_q2 = "$\{" + "${`var'_q}" + "$\}"
	* Add stars
		if ${`var'_q} <= 0.1 {
			glo `var'_q2 = "${`var'_q2}" + "*"
		}
		if ${`var'_q} <= 0.05 {
			glo `var'_q2 = "${`var'_q2}" + "*"
		}
		if ${`var'_q} <= 0.01 {
			glo `var'_q2 = "${`var'_q2}" + "*"
		}
		}	
		

restore 
		
* Run regression
* ----------------------------------
	* Unweighted	
foreach var in $main_outcome {
	reg `var' t $control_hfs  			if $sample == 1 , vce(cluster market_all_expanded)
		sum `var' 						if t == 0 & $sample == 1 & e(sample) == 1
		save_coeff_t `var'
			}
			
	* Weighted
foreach var in $outcome_toweight {
	rename `var' `var'_w
	reg `var'_w t $control_hfs_w  	[aw = weight]		if $sample == 1 , vce(cluster market_all_expanded)
		sum `var'_w  				[aw = weight]		if t == 0 & $sample == 1 & e(sample) == 1
		save_coeff_t `var'_w
			}
			
* Adding ***
* --------------
glo coeff_table
foreach var in $main_outcome $outcome_weighted {
	glo coeff_table $coeff_table `var'1
		}
	star coeff_table

*-------------------------------------------------------------------
* Panel B. Main Outcomes with Private Interaction - whole sample 
*-------------------------------------------------------------------
use "${inputdata}", clear	
foreach x in oop_all_bl jhic_all_bl outp_as_jan_bl {
	bys market_all_expanded: egen `x'_m_exp = mean(`x'_m)
	drop `x'_m
	ren `x'_m_exp `x'_m
	}
* Missing Indicator method for market level
foreach x in oop_all_bl_m oop_all_bl_m_w {
	drop `x'_mi_d `x'_mi
	gen 	`x'_mi_d 	= 0
	replace `x'_mi_d 	= 1 if mi(`x')
	gen 	`x'_mi 	= `x'
	replace `x'_mi 	= 0 if mi(`x')
	}
	
	
replace outp_as_jan = . if inactive==1 // outpatients without inactive coded as zero

glo interaction		private private_t	
glo test_B 			T + Private x T = 0
loc treatment		t
loc interaction	 	private
loc interaction_t	private_t

global main_outcome_B
foreach var in $main_outcome {
	ren `var' `var'_B
global main_outcome_B $main_outcome_B `var'_B
	}	

* Run regression
* ----------------------------------
	* Unweighted	
 foreach var in $main_outcome_B {
	reg `var'  `treatment' $interaction $control_hfs  		if $sample == 1 , vce(cluster market_all_expanded)
	gen reg_sample = e(sample)
		sum `var'  											if `treatment' == 0 & $sample == 1 & reg_sample == 1
		save_coeff_t `var' 
		save_coeff_interaction `var'_inter  `var'_inter_t  `interaction' `interaction_t'	
		
		sum `var'  											if `treatment' == 0 & $sample == 1 & private == 0 & reg_sample == 1	
		stat_public `var' 
		
		sum `var'  											if `treatment' == 0 & $sample == 1 & private == 1 & reg_sample == 1								
		stat_private `var' 
		
		drop reg_sample
		}
		
	* Weighted	
foreach var in $outcome_toweight {
	rename `var'_B `var'_w_B
	reg `var'_w_B  `treatment' $interaction $control_hfs_w  [aw = weight]	if $sample == 1 , vce(cluster market_all_expanded)
	gen reg_sample = e(sample)
		sum `var'_w_B 										[aw = weight]	if `treatment' == 0 & $sample == 1 & reg_sample == 1
		save_coeff_t `var'_w_B 
		save_coeff_interaction `var'_w_B_inter  `var'_w_B_inter_t  `interaction' `interaction_t'	
		
		sum `var'_w_B 										[aw = weight]	if `treatment' == 0 & $sample == 1 & private == 0 & reg_sample == 1	
		stat_public `var'_w_B 
		
		sum `var'_w_B  										[aw = weight]	if `treatment' == 0 & $sample == 1 & private == 1 & reg_sample == 1								
		stat_private `var'_w_B 
		
		drop reg_sample
		}			
														
* Adding ***
* --------------
glo coeff_table
foreach var in $main_outcome $outcome_weighted {
	glo coeff_table $coeff_table `var'_B1 `var'_B_inter3 `var'_B_inter_t3
	} 
	star coeff_table
		
*-------------------------------------------------------------------
* Panel C. Main Outcomes with Unlicensed Interaction - Private and active at endline only 
*-------------------------------------------------------------------
use "${inputdata}", clear
foreach x in oop_all_bl jhic_all_bl outp_as_jan_bl {
	bys market_all_expanded: egen `x'_m_exp = mean(`x'_m)
	drop `x'_m
	ren `x'_m_exp `x'_m
	}
* Missing Indicator method for market level
foreach x in oop_all_bl_m oop_all_bl_m_w {
	drop `x'_mi_d `x'_mi
	gen 	`x'_mi_d 	= 0
	replace `x'_mi_d 	= 1 if mi(`x')
	gen 	`x'_mi 	= `x'
	replace `x'_mi 	= 0 if mi(`x')
	}
	
	
replace outp_as_jan = . if inactive==1 // outpatients without inactive coded as zero
keep if private == 1  // sample is restricted to Private and active at endline only 
	
glo interaction		unlicensed_s2 unlicensed_s2_t
glo test_C 			T + Unlicensed x T = 0
loc  treatment		t
loc interaction	 	unlicensed_s2
loc interaction_t	unlicensed_s2_t

global main_outcome_C
foreach var in $main_outcome {
	ren `var' `var'_C
global main_outcome_C $main_outcome_C `var'_C
	}

* Run regression
* ----------------------------------	
 foreach var in $main_outcome_C {
		* Unweighted
		reg `var'  `treatment' $interaction $control_hfs  			if $sample == 1   , vce(cluster market_all_expanded)
		gen reg_sample = e(sample)					
				sum `var' 											if `treatment' == 0 & $sample == 1 & reg_sample == 1
				save_coeff_t `var'
				save_coeff_interaction `var'_inter  `var'_inter_t  `interaction' `interaction_t'				
				
				sum `var' 											if `treatment' == 0 & $sample == 1 & unlicensed_s2 == 0 & reg_sample == 1	
				stat_lic `var'
				
				sum `var' 											if `treatment' == 0 & $sample == 1 & unlicensed_s2 == 1 & reg_sample == 1								
				stat_unl `var'
				
				drop reg_sample
				}


	* Weighted	
foreach var in $outcome_toweight {
	rename `var'_C `var'_w_C
	reg `var'_w_C  `treatment' $interaction $control_hfs_w  [aw = weight]	if $sample == 1 , vce(cluster market_all_expanded)
	gen reg_sample = e(sample)			
		sum `var'_w_C 										[aw = weight]	if `treatment' == 0 & $sample == 1 & reg_sample == 1
		save_coeff_t `var'_w_C 
		save_coeff_interaction `var'_w_C_inter  `var'_w_C_inter_t  `interaction' `interaction_t'	
		
		sum `var'_w_C 										[aw = weight]	if `treatment' == 0 & $sample == 1 & unlicensed_s2 == 0 & reg_sample == 1
		stat_lic `var'_w_C 
		
		sum `var'_w_C  										[aw = weight]	if `treatment' == 0 & $sample == 1 & unlicensed_s2 == 1 & reg_sample == 1							
		stat_unl `var'_w_C
		
		drop reg_sample
		}			
														
* Adding ***
* --------------
glo coeff_table
foreach var in $main_outcome $outcome_weighted {
	glo coeff_table $coeff_table `var'_C1 `var'_C_inter3 `var'_C_inter_t3
	} 
	star coeff_table					

********************************************************************************
** Export
********************************************************************************
glo table_name 		"Table${TableNumber}_$date"
glo left 			"Facility and Patient Level"
glo PanelA			"Overall Impact"
glo PanelB			"Interaction with Private"
glo PanelC			"Interaction with Unlicensed (Private and active at endline only)"
glo C_1 			"JHIC Score"
glo C_1_s 			"(pp of max)"
glo C_2 			"OOP"
glo C_2_s 			"(USD PPP)"
glo C_3 			"Daily"
glo C_3_s 			"Outpatients"
glo C_4 			"New"
glo C_4_s 			""
glo C_5 			"Formality"
glo C_5_s 			"(Private)"

glo R_text 			"{R}^{2}" 
glo N_text 			"Observations"

* Labels
lab var t 				"Treatment"
lab var private 		"Private HF"	
lab var private_t 		"Private HF x T"
lab var unlicensed_s2  	"Unlicensed at Endline"	
lab var unlicensed_s2_t "Unlicensed at Endline x T"	

glo t 			: variable label t
glo t_B 		: variable label t
glo t_C 		: variable label t

glo inter_B 	: variable label private
glo inter_t_B   : variable label private_t
glo inter_C 	: variable label unlicensed_s2
glo inter_t_C  	: variable label unlicensed_s2_t

glo B_pr_text "Private"
glo B_pu_text "Public"	
glo C_unl_text "Unlicensed"
glo C_lic_text "Licensed"		

* Table global
glo table_name "${tex_`out'_out}"

* Start the Latex document
texdoc do "${tex_`out'}"		

			
		
			


		
		
		
		
