/*******************************************************************************	
Project:  	KePSIE
*******************************************************************************/
********************************************************************************
** Create globals for directories and files 
********************************************************************************
clear all
set more off

* Input
glo inputdata	 		"${dt_final}/data_for_analysis.dta" 
		
* Output
loc out 				table_S12
glo tex_`out'			"${do_supp}/tex/tex_`out'.do"
glo tex_`out'_out 		"${out_supp}/`out'.tex"

* Programs		
glo save_coeff			"${program}/save_coeff.do"
do "${save_coeff}"
	
********************************************************************************
** Setup
********************************************************************************
use "${inputdata}", clear	

foreach x in oop_all_bl jhic_all_bl outp_as_jan_bl {
bys market_all_expanded: egen `x'_m_exp = mean(`x'_m)
drop `x'_m
ren `x'_m_exp `x'_m
}
* Missing Indicator method for market level
foreach x in oop_all_bl_m oop_all_bl_m_w {
drop `x'_mi_d `x'_mi
gen 	`x'_mi_d 	= 0
replace `x'_mi_d 	= 1 if mi(`x')
gen 	`x'_mi 	= `x'
replace `x'_mi 	= 0 if mi(`x')
}
drop per_level_2 per_level_3 per_level_4_5 new_*
merge 1:1 hfid using "${dt_end_fin}/profile_add", keepus(per_level_2 per_level_3 per_level_4_5 new_*)

* Table globals
* ----------------------------------	

glo PanelA			"Unweighted"
glo PanelB			"Weighted"

glo C_1 			"JHIC Score \\ (pp of max)"
glo C_2				"OOP \\ (USD PPP)"
glo C_3 			"Daily \\ Outpatients"
glo C_4 			"Inactive"
glo C_5 			"New"	

glo t 				: variable label t
glo km4_t			"Number of T HFs within 4 kms"
glo km48_t			"Number of T HFs between 4 and 8 kms"
glo km4				"Number of HFs within 4 kms"
glo km48			"Number of HFs between 4 and 8 kms"			
glo priv 			: variable label private
glo priv_t 			: variable label private_t
glo dis_p_t 		"Number of HFs within Distance x Private x T"	

glo outcomes 		jhic_all oop_all outp_as_jan inactive new_end
glo interaction		hfs_km_4_t hfs_km_4
glo control_bl		jhic_all_bl_m_mi jhic_all_bl_m_mi_d outp_as_jan_bl_m_mi outp_as_jan_bl_m_mi_d oop_all_bl_m_mi oop_all_bl_m_mi_d
glo control_mks 	per_level_2 per_level_3 per_level_4_5
glo control_hfs		$control_bl $control_mks i.strata_expanded

glo test 			No. T HFs in 4kms + 4-8 kms = 0
global p_test   	"hfs_km_4_t + hfs_km_4to8_t = 0" 
glo subsample		"hfs_km_4_t<40"	
glo sample s2
	
********************************************************************************
** Run table
********************************************************************************
keep if t==0 // Keep control HFs only	

* JHIC, outpatients, and inactive
* ----------------------------------
foreach x of glo outcomes {
	* Unweighted
	reg `x' t $interaction $control_hfs if $sample==1 & $subsample, vce(cluster market_all_expanded)
	sum `x' if t==0 & $sample==1 & e(sample)==1
	* Statistics
	stat_general `x'_1 "$p_test"
	foreach i in $interaction t {					
	* Store estimates
	stat_estim `x'_`i'_1 `i'		
			}		
			}	
			* Number of T HFs in d distance
			use "${inputdata}", clear
			keep if t==0
			sum hfs_km_4_t if hfs_km_4_t<40 
			glo md_4: di %4.1f `r(mean)'
			glo md "Mean No. T HFs in 4kms"
					
* Adding ***
* --------------					
glo coeff_table
foreach var in $outcomes {
	glo coeff_table $coeff_table `var'_hfs_km_4_t_1 `var'_hfs_km_4_1
	}
	star coeff_table
		
********************************************************************************
** Export
********************************************************************************
* Table global
glo table_name "${tex_`out'_out}"

* Start the Latex document
texdoc do "${tex_`out'}"		


			
		
											
											
