/*******************************************************************************	
Project:  	KePSIE
*******************************************************************************/
********************************************************************************
** Create globals for directories and files 
********************************************************************************
clear all
set more off

* Input
glo inputdata	 		"${dt_final}/data_for_analysis.dta"
glo fade 				"${dt_end_fin}/inspections_fadeout.dta"
		
* Output
loc out 				table_S14
glo tex_`out'			"${do_supp}/tex/tex_`out'.do"
glo tex_`out'_out 		"${out_supp}/`out'.tex"

* Programs		
glo save_coeff			"${program}/save_coeff.do"
do "${save_coeff}"

********************************************************************************
** Run table
********************************************************************************
* Treatments	
glo t1 					t1 t2
glo treatments_pooled 	t1_2 t2_2
* Control vars
glo control_hfs 		level_3 level_4_5 						i.strata_expanded
glo control_mks			 per_level_2 per_level_3 per_level_4_5 	i.strata_expanded
* Outcomes
glo main_outcome		jhic_all
* Sample
glo sample 				s2
	
* Setup
use "${inputdata}", clear
merge 1:1 hfid using "${fade}", nogen

loc y 				jhic_all
glo first_i 		ti_group_month1to3_m ti_group_month4to6_m time_collect_month1to2 time_collect_month1to2_t1 time_collect_month1to2_t2 // ** missing labels makes the review difficult
glo con  			level_3 level_4_5 maintown_km
	
reg jhic_all $first_i $con i.strata_expanded, vce(cluster market_all_expanded)

loc int1 ti_group_month1to3_m
loc int2 ti_group_month4to6_m
loc int3 time_collect_month1to2
loc int4 time_collect_month1to2_t1
loc int5 time_collect_month1to2_t2

loc var jhic_all
forvalues i=1/5 {
	glo `var'`i' 	:  di %4.3f _b[`int`i'']
	glo `var'`i'sd 	:  di %4.3f _se[`int`i''] // ** AVOID USING SD WHEN IS ABOUT SE EVEN IF ONLY FOR NAMING VARS
	glo `var'`i'p 	:  di %4.3f (2 * ttail(e(df_r), abs(_b[`int`i'']/_se[`int`i''])))
}

	gen r_sample = e(sample) if e(sample) == 1
	glo R_`var' :  di %4.3f e(r2)
	glo N_`var' = `e(N)'
	
	sum `var' if r_sample==1
	glo `var'm0 :  di %4.3f `r(mean)'
	
	lincom ti_group_month1to3_m
	lincom ti_group_month1to3_m + time_collect_month1to2_t1
		glo i1 	: di %4.3f `r(estimate)'
		glo i1p : di %4.3f `r(p)'
	lincom ti_group_month4to6_m + time_collect_month1to2_t2
		glo i2 	: di %4.3f `r(estimate)'
		glo i2p : di %4.3f `r(p)'	

* Add ***
* ---------
glo varstar
foreach x in jhic_all {
	glo varstar $varstar `x'1 `x'2 `x'3 `x'4 `x'5
	}	
	
foreach i in $varstar {		

		if  ${`i'p} <= 0.1 {
		glo `i' = "${`i'}" + "*"

			if ${`i'p} <= 0.05 {
			glo `i' = "${`i'}" + "*"

				if ${`i'p} <= 0.01 {
				glo `i' = "${`i'}" + "*"
				
	}
	}
	}
	}
	
glo varstar
foreach x in i {
	glo varstar $varstar `x'1 `x'2 
	}	
	
foreach i in $varstar {		

		if  ${`i'p} <= 0.1 {
		glo `i' = "${`i'}" + "*"

			if ${`i'p} <= 0.05 {
			glo `i' = "${`i'}" + "*"

				if ${`i'p} <= 0.01 {
				glo `i' = "${`i'}" + "*"
				
	}
	}
	}
	}	
	
			* 1-3, 1-2 
				* Control mean and SD
				loc x ti_group_month1to3_m
				loc z 1312
				sum jhic_all if t==0 & r_sample==1
				local m0`z' = `r(mean)' 
				local s0`z' = `r(sd)' 
				* Impact (% change; SD)
				glo s1`z': di %4.2f (_b[`x']) / `s0`z'' 
				glo m0`z': di %4.3f `r(mean)'
				glo lab: var label `x' 
				glo imp1`z' = (_b[`x']) /`m0`z''*100 
				glo imp1`z': di %2.0f ${imp1`z'}
			* 1-3, 3-4 stats
				* Control mean and SD
				loc x ti_group_month1to3_m
				loc y time_collect_month1to2_t1
				loc z 1334
				sum jhic_all if t==0 & r_sample==1
				local m0`z' = `r(mean)' 
				local s0`z' = `r(sd)' 
				* Impact (% change; SD)
				glo s1`z': di %4.2f (_b[`x'] + _b[`y']) / `s0`z'' 
				glo m0`z': di %4.3f `r(mean)'
				glo lab: var label `x' 
				glo imp1`z' = (_b[`x'] + _b[`y']) /`m0`z''*100 
				glo imp1`z': di %2.0f ${imp1`z'}				
			* 4-6, 1-2 
				* Control mean and SD
				loc x ti_group_month4to6_m
				loc z 4612
				sum jhic_all if t==0 & r_sample==1
				local m0`z' = `r(mean)' 
				local s0`z' = `r(sd)' 
				* Impact (% change; SD)
				glo s1`z': di %4.2f (_b[`x']) / `s0`z'' 
				glo m0`z': di %4.3f `r(mean)'
				glo lab: var label `x' 
				glo imp1`z' = (_b[`x']) /`m0`z''*100 
				glo imp1`z': di %2.0f ${imp1`z'}
			* 4-6, 3-4 stats
				* Control mean and SD
				loc x ti_group_month4to6_m
				loc y time_collect_month1to2_t2
				loc z 4634
				sum jhic_all if t==0 & r_sample==1 
				local m0`z' = `r(mean)' 
				local s0`z' = `r(sd)' 
				* Impact (% change; SD)
				glo s1`z': di %4.2f (_b[`x'] + _b[`y']) / `s0`z'' 
				glo m0`z': di %4.3f `r(mean)'
				glo lab: var label `x' 
				glo imp1`z' = (_b[`x'] + _b[`y']) /`m0`z''*100 
				glo imp1`z': di %2.0f ${imp1`z'}	

		
********************************************************************************
** Export
********************************************************************************
glo table_name 		"Table${TableNumber}_$date"

glo C_1 			"JHIC Score (pp of max)"
glo R_text 			"$\rm {R}^{2}$" 
glo N_text 			"Observations"

* Labels
lab var ti_group_month1to3_m		"First Market Inspection in Months 1-3 (Ta)"
lab var ti_group_month4to6_m		"First Market Inspection in Months 4-6 (Tb)"
lab var time_collect_month1to2		"Endline in Months 1-2"
lab var time_collect_month1to2_t1	"Endline in Months 1-2 x Ta"
lab var time_collect_month1to2_t2	"Endline in Months 1-2 x Tb"

glo inter_1 		: variable label ti_group_month1to3_m 	
glo inter_2   		: variable label ti_group_month4to6_m
glo inter_3   		: variable label time_collect_month1to2
glo inter_4   		: variable label time_collect_month1to2_t1
glo inter_5   		: variable label time_collect_month1to2_t2

* Table global
glo table_name "${tex_`out'_out}"

* Start the Latex document
texdoc do "${tex_`out'}"	

			
		
			


		
		
		
		
