/*******************************************************************************	

Project:  		KePSIE - Kenya


Written by:  	Thomas Escande (tescande@worldbank.org)

Revision: 		

********************************************************************************			

THIS DO FILE: 	 Computes UQTE results using qreg2 stata written command 

*******************************************************************************/

********************************************************************************
	** Part 0: Create globals for directories and files 
********************************************************************************
	clear all
	set more off
	set maxvar 20000

  * Set the environment to make randomization replicable
    version 12.0 	
	
	*Running the adofiles which will be used in the dofile
		do "${program}/bscr.ado" 
		do "${program}/dte.ado"		
		do "${program}/qreg2.ado"			
		
		glo inputdata	 	"${dt_final}/data_for_analysis.dta"
		glo date = 			word(c(current_date),1) + word(c(current_date),2) + word(c(current_date),3)
		
		* Output 
		loc out 				table_S16
		glo tex_`out'			"${do_supp}/tex/tex_`out'.do"
		glo tex_`out'_out 		"${out_supp}/`out'.tex"
	
		set seed 33
			
********************************************************************************
** Part 1: Setup 
********************************************************************************
use "${inputdata}"

	keep if !mi(t)  //Cannot have missing for the ado file so need to drop 
	gen zero = 0 	
	local first 1
	local 	bs_rep 	= 1000
	
	*Changing categories of marketsize_rand_expanded_group for this specific analysis:
	* 1-2 HFs, 3-10HFs, 11+ HFs
	ren  	marketsize_rand_expanded_group marketsize_rand_exp_group_o
	gen     marketsize_rand_expanded_group = 1 if marketsize_rand_exp_group_o == 1 | marketsize_rand_exp_group_o == 2
	replace marketsize_rand_expanded_group = 2 if marketsize_rand_exp_group_o == 3 | marketsize_rand_exp_group_o == 4
	replace marketsize_rand_expanded_group = 3 if marketsize_rand_exp_group_o == 5	
	
	*Generate county dummy
		forvalues i = 1/3 {
			gen county_`i' = 0
			replace county_`i' = 1 if county == `i'
		}
		
	
	loc x 3 // toggle based on market size group // update later in loops
	loc q 0.10 0.25 0.50 0.75 0.90 // set quantiles	
	

	
	* Switches
	* ---------
foreach var  in    jhic_all /*outp_as_jan oop_all*/ {
	

********************************************************************************
** Part 2: Run the different regressions
********************************************************************************
local col = 1 
*Regression with no controls, by ownership 
foreach sample in All priv pub  { 
	preserve 

if "`sample'" == "pub" {
    keep if private == 0
}
if "`sample'" == "priv" {
    keep if private == 1
}
local row = 1
		foreach j in `q'  {
*Saving Test as with different command (only once)
if `j' == 0.10 {
		cap	sqreg `var' t  , q(`q')  reps(`bs_rep')
		test [q10]t = [q90]t
		global Test_`col' :  di %10.3fc r(p)	
	    global N_`col'    = e(N)
				}
				
*Now using qreg2 to have more accurate standard errors and t statistics	
			qui sum `var' if t==0  & e(sample) == 1 
			loc control_mean `r(mean)'	
		
		cap	qreg2 `var' t  , q(`j') cluster(market_all_expanded) 
			
			if _rc==0 {		
			*Saving coefficients 
			global C_`row'_`col'_exact 	:  di %10.3fc r(table)[1,1]
			global C_`row'_`col'se 	:  di %10.3fc r(table)[2,1]	
			global p_`row'_`col' =  r(table)[4,1]
			
			*Adding stars 
			global C_`row'_`col'   = "${C_`row'_`col'_exact}"
					if  ${p_`row'_`col'} <= 0.1 {
					global C_`row'_`col' = "${C_`row'_`col'}" + "*"

						if ${p_`row'_`col'} <= 0.05 {
						global C_`row'_`col' = "${C_`row'_`col'}" + "*"

							if ${p_`row'_`col'} <= 0.01 {
							global C_`row'_`col' = "${C_`row'_`col'}" + "*"

						}
					}
				}			
				}
local row = `row' + 1						
			}		
	restore	
local col = `col' + 1	
		}
	
		
	
		

* Regression with no controls, by marketsize 
foreach sample in All  priv { 
	preserve 
	
if "`sample'" == "priv" {
    keep if private == 1
}

forvalues x = 1/3 {
local row = 1		
		foreach j in `q'  {
		
*Saving Test as with different command (only once)
if `j' == 0.1 {
		cap	sqreg `var' t  if inlist(marketsize_rand_expanded_group,`x') , q(`q')  reps(`bs_rep')
		test [q10]t = [q90]t
		global Test_`col'  :  di %10.3fc r(p)
	    global N_`col'    = e(N)		
				}

*Now using qreg2 to have more accurate standard errors and t statistics				
			lab var `var' "`var' Mkt `x' Quantile `j' baseline control `sample'"
			qui sum `var' if t==0 & inlist(marketsize_rand_expanded_group,`x')
			loc control_mean `r(mean)'
			
		cap	qreg2 `var' t if inlist(marketsize_rand_expanded_group,`x') , q(`j') cluster(market_all_expanded) 
			glo con:  di %4.3f `e(convcode)'
			if _rc==0 {
			*Saving coefficients 
			global C_`row'_`col'_exact 	:  di %10.3fc r(table)[1,1]
			global C_`row'_`col'se 	:  di %10.3fc r(table)[2,1]	
			global p_`row'_`col' =  r(table)[4,1]
			
			*Adding stars 
			global C_`row'_`col'   = "${C_`row'_`col'_exact}"
					if  ${p_`row'_`col'} <= 0.1 {
					global C_`row'_`col' = "${C_`row'_`col'}" + "*"

						if ${p_`row'_`col'} <= 0.05 {
						global C_`row'_`col' = "${C_`row'_`col'}" + "*"

							if ${p_`row'_`col'} <= 0.01 {
							global C_`row'_`col' = "${C_`row'_`col'}" + "*"

						}
					}
				} 
				}	
local row = `row' + 1				
			}		
	
local col = `col' + 1		
		}	
	restore	
	
	}	
					
}		


********************************************************************************
** Export
********************************************************************************
***Setting globals for text in the table 

* Table global
glo table_name "${tex_out}"
glo Percentile_1 "10th"
glo Percentile_2 "25th"
glo Percentile_3 "50th"
glo Percentile_4 "75th"
glo Percentile_5 "90th"

* Table global
glo table_name "${tex_`out'_out}"

* Start the Latex document
texdoc do "${tex_`out'}"	
