/*******************************************************************************
*					     			KePSIE 		    		       			   *
********************************************************************************		
********************************************************************************
** Create locals for files 
*******************************************************************************/
clear all
set more off

* Input
glo inputdata	 		"${dt_final}/data_for_analysis.dta" 

* Output
loc out 				table_S17
glo tex_`out'			"${do_supp}/tex/tex_`out'.do"
glo tex_`out'_out 		"${out_supp}/`out'.tex"

* Programs		
glo save_coeff			"${program}/save_coeff.do"
do "${save_coeff}"	

********************************************************************************
** Setup
********************************************************************************
use "${inputdata}", clear
do "${save_coeff}"

* TO UPDATE IN CONSTRUCTION
/*Correcting oop_all_bl_m_mi (should be corrected later on in the construction). Issue is, facilities with missing oop at baseline also have a 0 at the market level variable, instead of the market value*/ 
bys market_all_expanded: egen temp_oop_all_bl_m = max(oop_all_bl_m_mi) 
replace oop_all_bl_m_mi = temp_oop_all_bl_m 
drop temp_oop_all_bl_m 
*For the dummy 
bys market_all_expanded: egen temp_oop_all_bl_m_mi_d = max(oop_all_bl_m_mi_d) 
replace oop_all_bl_m_mi_d = temp_oop_all_bl_m_mi_d 
drop temp_oop_all_bl_m_mi_d 



********************************************************************************
** Table
********************************************************************************
glo outcome 		jhic_all /*formality inactive outp_as_jan*/
glo blcontrols 		jhic_all_bl_m_mi jhic_all_bl_m_mi_d outp_as_jan_bl_m_mi outp_as_jan_bl_m_mi_d oop_all_bl_m_mi oop_all_bl_m_mi_d
glo control_hfs 	level_3 level_4_5 $blcontrols 				
glo interaction		logit_group_2 logit_group_2_t logit_group_3 logit_group_3_t
glo sample 			s2

loc x outp_as_jan
reg `x' t $interaction $control_hfs i.strata_expanded if $sample==1, vce(cluster market_all_expanded) 
	
local i = 1		
foreach x in $outcome {

*Regression
reg `x' t $interaction $control_hfs i.strata_expanded if $sample==1, vce(cluster market_all_expanded)	
	
	*Saving coefficients
	gen sample`x' = e(sample)
	save_coeff_interaction_all `x' t L1_C`i'_ logit_group_2 L2_C`i'_ logit_group_2_t L3_C`i'_ ""
	save_coeff_interaction_all `x' t L1_2_C`i'_ logit_group_3 L4_C`i'_ logit_group_3_t L5_C`i'_ ""
		
*saving control mean for low group 
sum `x'  if t == 0 & sample`x' ==1 & logit_group_2 == 0 & logit_group_3 == 0 
glo L1_C`i'_m0 :  di %4.3f `r(mean)'

*saving impact low group  
	glo L1_C`i'_impsd0 :  di %4.2f _b[t] / `r(sd)'
			glo L1_C`i'_imp0 =  _b[t] /`r(mean)'*100
		if ${L1_C`i'_imp0} >= 10 {
			glo L1_C`i'_imp0 :  di %2.0f ${L1_C`i'_imp0}
		}
		if ${L1_C`i'_imp0} < 10 {
			glo L1_C`i'_imp0 :  di %1.0f ${L1_C`i'_imp0}
		}
		
glo L1_C`i'_impsd0 = "$" + "${L1_C`i'_impsd0}" 	+ "$"
glo L1_C`i'_imp0   = "$" + "${L1_C`i'_imp0}" 	+ "$"	

local i = `i' + 1	
			}	
				
foreach x in $outcome {				
*First regression just to use the same sample in the following t statistics 
reg `x' t $interaction $control_hfs i.strata_expanded if $sample==1, vce(cluster market_all_expanded) 

* Mean control	
	sum `x' if t==0 & e(sample)==1 &  logit_group_2 == 0 & logit_group_3 == 0 
		glo `x'_mc_l: di %4.3f `r(mean)'
		glo `x'_sd_l: di %4.3f `r(sd)'
	sum `x' if t==0 & e(sample)==1 & logit_group_2==1
		glo `x'_mc_m: di %4.3f `r(mean)'
		glo `x'_sd_m: di %4.3f `r(sd)'
	sum `x' if t==0 & e(sample)==1 & logit_group_3==1
		glo `x'_mc_h: di %4.3f `r(mean)'
		glo `x'_sd_h: di %4.3f `r(sd)'
* Low
	* Coefficient
	lincom _b[t] 	
	glo `x'_l 	= r(estimate)	
	* Impact {%, SD}
	glo `x'_imp_l 	: di %1.0f ${`x'_l}/${`x'_mc_l} * 100 
	glo `x'_isd_l 	: di %4.2f ${`x'_l}/${`x'_sd_l}
* Med
	* Coefficient
	lincom _b[t] + _b[logit_group_2_t]
	glo `x'_m 	= r(estimate)	
	* Impact {%, SD}
	glo `x'_imp_m 	: di %1.0f ${`x'_m}/${`x'_mc_m} * 100 
	glo `x'_isd_m 	: di %4.2f ${`x'_m}/${`x'_sd_m}
* High
	* Coefficient
	lincom _b[t] + _b[logit_group_3_t]	
	glo `x'_h 	= r(estimate)	
	* Impact {%, SD}
	glo `x'_imp_h 	: di %1.0f ${`x'_h}/${`x'_mc_h} * 100 
	glo `x'_isd_h 	: di %4.2f ${`x'_h}/${`x'_sd_h}	
* Tests	
	test _b[t] + _b[logit_group_2_t] = 0
	glo `x'_test_m : di %4.3f `r(p)'
	test _b[t] + _b[logit_group_3_t] = 0
	glo `x'_test_h : di %4.3f `r(p)'
	test _b[t] = _b[t] + _b[logit_group_3_t]
	glo `x'_test_lh : di %4.3f `r(p)'
	}
				
*Global for table
glo title_1    	"Treatment"
glo title_2 	"Mid prob. (0.4,0.6)"
glo title_3 	"Mid prob. (0.4,0.6) x T"
glo title_4		"High prob. $>$=0.6"
glo title_5 	"High prob. $>$=0.6 x T"

glo title_specific_0 "Low $<$=0.4"
glo title_specific_1 "Mid (0.4,0.6)"
glo title_specific_2 "High $>$=0.6"

glo C_1 			"JHIC Score"
glo C_2 			"Formality"
glo C_3 			"Inactive"
glo C_4 			"Outpatients (coded zero if inactive)"

* Table global
glo table_name "${tex_`out'_out}"

* Start the Latex document
texdoc do "${tex_`out'}"
		
		 
