/*******************************************************************************	
Project:  	KePSIE
********************************************************************************/
********************************************************************************
** Setup
********************************************************************************
clear all
set more off

* Input
glo inputdata	 		"${dt_final}/data_for_analysis.dta" 
		
* Output
loc out 				table_S18a
glo tex_`out'			"${do_supp}/tex/tex_`out'.do"
glo tex_`out'_out 		"${out_supp}/`out'.tex"

* Programs		
glo save_coeff			"${program}/save_coeff.do"
do "${save_coeff}"	

* Table globals
* -----------------
* Treatments	
glo t1 t1 t2
glo treatments_pooled t1_2 t2_2
* Control vars
glo control_hfs level_3 level_4_5 						i.strata_expanded
glo control_mks per_level_2 per_level_3 per_level_4_5 	i.strata_expanded
* Outcomes
glo main_outcome		jhic_all oop_all_imp outp_as_jan new_end
glo main_outcome_fwer 	jhic_all oop_all_imp outp_as_jan
glo main_outcome_all 	jhic_all oop_all_imp outp_as_jan new_end formality
glo outcome_toweight  	jhic_all oop_all_imp
glo outcome_weighted  	jhic_all_w oop_all_imp_w
glo mo_all_out 			jhic_all oop_all_imp jhic_all_w oop_all_imp_w outp_as_jan new_end 
glo mo_out 				jhic_all oop_all_imp jhic_all_w oop_all_imp_w outp_as_jan new_end
* Sample
glo sample s2
	
********************************************************************************
** Run table
********************************************************************************

*-------------------------------------------------------------------
* Panel . Main Outcomes with  Interaction on high quality facilities
*-------------------------------------------------------------------
use "${inputdata}", clear	
replace outp_as_jan = . if inactive==1 // outpatients without inactive coded as zero

gen high_q_bl = (jhic_all_bl >= 40 & !mi(jhic_all_bl)) if !mi(jhic_all_bl)

gen high_q_bl_t =  high_q_bl * t

drop private private_t 

gen private   = high_q_bl
gen private_t = high_q_bl_t

glo interaction		private private_t	

loc treatment		t
loc interaction	 	private
loc interaction_t	private_t

global main_outcome_B
foreach var in $main_outcome {
	ren `var' `var'_B
global main_outcome_B $main_outcome_B `var'_B
	}	

* Run regression
* ----------------------------------
	* Unweighted	
 foreach var in $main_outcome_B {
	reg `var'  `treatment' $interaction $control_hfs  		if $sample == 1 , vce(cluster market_all_expanded)
	gen reg_sample = e(sample)
		sum `var'  											if `treatment' == 0 & $sample == 1 & reg_sample == 1
		save_coeff_t `var' 
		save_coeff_interaction `var'_inter  `var'_inter_t  `interaction' `interaction_t'	
		
		sum `var'  											if `treatment' == 0 & $sample == 1 & private == 0 & reg_sample == 1	
		stat_public `var' 
		
		sum `var'  											if `treatment' == 0 & $sample == 1 & private == 1 & reg_sample == 1								
		stat_private `var' 
		
		drop reg_sample
		}
		
	* Weighted	
foreach var in $outcome_toweight {
	rename `var'_B `var'_w_B
	reg `var'_w_B  `treatment' $interaction $control_hfs  	[aw = weight]	if $sample == 1 , vce(cluster market_all_expanded)
	gen reg_sample = e(sample)
		sum `var'_w_B 										[aw = weight]	if `treatment' == 0 & $sample == 1 & reg_sample == 1
		save_coeff_t `var'_w_B 
		save_coeff_interaction `var'_w_B_inter  `var'_w_B_inter_t  `interaction' `interaction_t'	
		
		sum `var'_w_B 										[aw = weight]	if `treatment' == 0 & $sample == 1 & private == 0 & reg_sample == 1	
		stat_public `var'_w_B 
		
		sum `var'_w_B  										[aw = weight]	if `treatment' == 0 & $sample == 1 & private == 1 & reg_sample == 1								
		stat_private `var'_w_B 
		
		drop reg_sample
		}			
														
* Adding ***
* --------------
glo coeff_table
foreach var in $main_outcome $outcome_weighted {
	glo coeff_table $coeff_table `var'_B1 `var'_B_inter3 `var'_B_inter_t3
	} 
	star coeff_table
		


********************************************************************************
** Export
********************************************************************************
glo table_name 		"Table${TableNumber}_$date"
glo left 			"Facility and Patient Level"
glo PanelB			"Interaction with High Quality"
glo C_1 			"JHIC Score"
glo C_1_s 			"(pp of max)"
glo C_2 			"OOP"
glo C_2_s 			"(USD PPP)"
glo C_3 			"Daily"
glo C_3_s 			"Outpatients"
glo C_4 			"New"
glo C_4_s 			""
glo C_5 			"Formality"
glo C_5_s 			"(Private)"

glo R_text 			"$\rm {R}^{2}$" 
glo N_text 			"Observations"

* Labels
lab var t 				"Treatment"
lab var private 		"JHIC Score at Baseline $>$40"	
lab var private_t 		"JHIC Score at Baseline $>$40 x T"

glo t 			: variable label t
glo t_B 		: variable label t
glo t_C 		: variable label t

glo inter_B 	= "JHIC Score at Baseline $>$40"
glo inter_t_B   = "JHIC Score at Baseline $>$40 x T"
glo inter_C 	: variable label unlicensed_s2
glo inter_t_C  	: variable label unlicensed_s2_t

glo B_pr_text "JHIC $>$40"
glo B_pu_text "JHIC $<$=40"	
glo C_unl_text "Unlicensed"
glo C_lic_text "Licensed"		

glo test_B 			T + JHIC $>$40 x T = 0

* Table global
glo table_name "${tex_`out'_out}"

* Start the Latex document
texdoc do "${tex_`out'}"		

			
		
			


		
		
		
		
