/*******************************************************************************
*					     			KePSIE 		    		       			   *
********************************************************************************		
********************************************************************************
** Create locals for files 
*******************************************************************************/
clear all
set more off
	
* Input 
glo inputdata 			"${dt_final}/data_for_analysis.dta" 
glo inputdata_p 		"${dt_final}/oop_p.dta" 
glo pe_bl 		 		"${dt_bl_clean}/pe_bl.dta" 
glo pe_end 		 		"${dt_end_clean}/pe_end.dta" 
glo pps_do_bl 			"${dt_bl_clean}/pps_do_bl_clean.dta" 
glo pps_hcw_bl 			"${dt_bl_clean}/pps_hcw_bl_clean.dta" 
glo pps_so_bl 			"${dt_bl_clean}/pps_so_bl_clean.dta" 
glo pps_do_end 			"${dt_end_clean}/pps_do_end_clean.dta" 
glo pps_hcw_end 		"${dt_end_clean}/pps_hcw_end_clean.dta" 
glo pps_so_end 			"${dt_end_clean}/pps_so_end_clean.dta" 

* Output 
loc out 				table_S3
glo tex_`out'			"${do_supp}/tex/tex_`out'.do"
glo tex_`out'_out 		"${out_supp}/`out'.tex"

* Programs
glo stats				"${program}/stats.do"
do "${stats}"	

********************************************************************************
** Table 1: Summary statistics at baseline
********************************************************************************
use "${inputdata}", clear

* Facility level
foreach x in bl fl {
	count if `x'_consent!=.
	glo active_`x' = `r(N)'

	sum `x'_consent 
	glo ref_`x' : di %4.2f `r(mean)'

	count if `x'_consent==1
	glo survey_`x' = `r(N)'
	}
	
* Surveys
foreach x in pe_bl pe_end {
	use "${`x'}", clear
	merge m:1 hfid using "${inputdata}", nogen keep(3)
	count 
	glo `x'_s : di %4.0f `r(N)'
	}


foreach x in pps_do_bl pps_do_end pps_hcw_bl pps_hcw_end pps_so_bl pps_so_end {
	use "${`x'}", clear
	merge m:1 hfid using "${inputdata}", nogen keep(3) force
	count
	glo `x'_s : di %4.0f `r(N)'
	}		
	
foreach x in pps_do_bl {
	use "${`x'}", clear
	merge m:1 hfid using "${inputdata}", nogen keep(3) force
	count if aa13_a==1
	glo `x'_s : di %4.0f `r(N)'
	}	

	
	
glo rr_pe_bl 		"0.88"
glo rr_pe_end 		"0.85"

glo rr_pps_hcw_bl 	"0.97"
glo rr_pps_hcw_end 	"0.98"

glo rr_pps_so_bl 	"1.00"
glo rr_pps_so_end 	"1.00"

glo rr_pps_do_bl 	"0.99"
glo rr_pps_do_end 	"1.00"

		
* Export
* ------
glo C_1 			"Baseline"
glo C_2 			"Endline"

glo panelA 			"Panel A. Surveys completed"
glo panelB 			"Panel B. Response rates"


glo survey 			"In-charge/staff surveys"
glo pe_l 			"Patient exit surveys"
glo pps_do_l 		"HCW-patient observations"
glo pps_hcw_l 		"Healthcare worker surveys"
glo pps_so_l 		"Site observations"

glo ref_l 			"Facility-level interviews"
glo pe_rr 			"Patient exit surveys" 	
glo pps_do_rr 		"HCW-patient observations (patient consent to observation)"	
glo pps_hcw_rr 		"Healthcare worker surveys"	
glo pps_so_rr		"Site observations"

		

* Table global
glo table_name "${tex_`out'_out}"

* Start the Latex document
texdoc do "${tex_`out'}"	

				


				
				
				
				
				
				
				
