/*******************************************************************************
*					     			KePSIE 		    		       			   *
********************************************************************************		
********************************************************************************
** Create locals for files 
*******************************************************************************/
clear all
set more off
	
* Input 
glo inputdata 			"${dt_final}/data_for_analysis.dta" 

* Output 
loc out 				table_S4
glo tex_`out'			"${do_supp}/tex/tex_`out'.do"
glo tex_`out'_out 		"${out_supp}/`out'.tex"

* Programs
glo stats				"${program}/stats.do"
do "${stats}"	

********************************************************************************
** Table 1: Summary statistics at baseline
********************************************************************************
use "${inputdata}", clear

* Setup
* -------
loc consent_pr	private==1 & fl_consent==1
loc consent_pu 	private==0 & fl_consent==1

* Randomization census
count if s0==1
glo rand = `r(N)'
count if s0==1 & private==1
glo rand_pr = `r(N)'
count if s0==1 & private==0
glo rand_pu = `r(N)'
count if s0==1 & fl_consent==1

glo rand_c = `r(N)'
count if s0==1 & `consent_pr'
glo rand_c_pr = `r(N)'
count if s0==1 & `consent_pu'
glo rand_c_pu = `r(N)'

* Facilities that were active at randomization but missed in census
count if s0==0 & active_s0==1
glo rand_miss = `r(N)'
count if s0==0 & active_s0==1 & private==1
glo rand_miss_pr = `r(N)'
count if s0==0 & active_s0==1 & private==0
glo rand_miss_pu = `r(N)'

count if s0==0 & active_s0==1 & fl_consent==1
glo rand_miss_c = `r(N)'
count if s0==0 & active_s0==1 & `consent_pr'
glo rand_miss_c_pr = `r(N)'
count if s0==0 & active_s0==1 & `consent_pu'
glo rand_miss_c_pu = `r(N)'

* Facilities active at randomization
count if active_s0==1
glo rand_all = `r(N)'
count if active_s0==1 & private==1
glo rand_all_pr = `r(N)'
count if active_s0==1 & private==0
glo rand_all_pu = `r(N)'

count if active_s0==1
glo rand_all_c = `r(N)'
count if active_s0==1 & `consent_pr'
glo rand_all_c_pr = `r(N)'
count if active_s0==1 & `consent_pu'
glo rand_all_c_pu = `r(N)'

* New facilities after randomization
count if active_s0==0 & s2==1
glo new = `r(N)'
count if active_s0==0 & s2==1 & private==1
glo new_pr = `r(N)'
count if active_s0==0 & s2==1 & private==0
glo new_pu = `r(N)'

count if active_s0==0 & s2==1
glo new_c = `r(N)'
count if active_s0==0 & s2==1 & `consent_pr'
glo new_c_pr = `r(N)'
count if active_s0==0 & s2==1 & `consent_pu'
glo new_c_pu = `r(N)'

* Inactive facilities at endline
count if active==0 & s2==1
glo ina = `r(N)'
count if active==0 & s2==1 & private==1
glo ina_pr = `r(N)'
count if active==0 & s2==1 & private==0
glo ina_pu = `r(N)'

count if active==0 & s2==1
glo ina_c = `r(N)'
count if active==0 & s2==1 & `consent_pr'
glo ina_c_pr = `r(N)'
count if active==0 & s2==1 & `consent_pu'
glo ina_c_pu = `r(N)'

* Total in study from randomization to endline
count if s2==1
glo all = `r(N)'
count if s2==1 & private==1
glo all_pr = `r(N)'
count if s2==1 & private==0
glo all_pu = `r(N)'

count if s2==1
glo all_c = ""
count if s2==1 & `consent_pr'
glo all_c_pr = ""
count if s2==1 & `consent_pu'
glo all_c_pu = ""

* Active at endline
count if inactive==0
glo all_end = `r(N)'
count if inactive==0 & private==1
glo all_end_pr = `r(N)'
count if inactive==0 & private==0
glo all_end_pu = `r(N)'

count if inactive==0
glo all_end_c = `r(N)'
count if inactive==0 & `consent_pr'
glo all_end_c_pr = `r(N)'
count if inactive==0 & `consent_pu'
glo all_end_c_pu = `r(N)'

		
* Export
* ------
glo C_1 			"Total"
glo C_2 			"Consented at endline"

glo SC_1 			"All"
glo SC_2 			"Public"
glo SC_3 			"Private"

glo rand_l 			"a. Randomization census (Dec 2016)"
glo rand_miss_l 	"b. Facilities active at randomization but missed in census [1]"
glo rand_all_l 		"c. Facilities active at randomization (a+b) [2]"
glo new_l 			"d. New facilities after randomization [3]"
glo ina_l 			"e. Inactive facilities at endline"
glo all_l 			"f. Total in study from randomization to endline (c+d)"
glo all_end_l 		"g.    Of which, active at endline (f-e)"

* Table global
glo table_name "${tex_`out'_out}"

* Start the Latex document
texdoc do "${tex_`out'}"	

				


				
				
				
				
				
				
				
