/*******************************************************************************
*					     			KePSIE 		    		       			   *
********************************************************************************		
********************************************************************************
** Create locals for files 
*******************************************************************************/
clear all
set more off
	
* Input 
glo inputdata 			"${dt_final}/data_for_analysis.dta" 

* Output 
loc out 				table_S5
glo tex_`out'			"${do_supp}/tex/tex_`out'.do"
glo tex_`out'_out 		"${out_supp}/`out'.tex"

* Programs
glo stats				"${program}/stats.do"
do "${stats}"	

********************************************************************************
** Table 1: Summary statistics at baseline
********************************************************************************
use "${inputdata}", clear

* At randomization
preserve 
sort market_all hfid
bys market_all: gen counter_m_s0 = _n
keep if active_s0==1

* Markets
forvalues i=1/3 {
count if treatment_expanded==1 & county==`i' & counter_m_s0==1 
glo t1_c`i'_m = `r(N)'
	}
forvalues i=1/3 {
count if treatment_expanded==2 & county==`i' & counter_m_s0==1
glo t2_c`i'_m = `r(N)'
	}	
forvalues i=1/3 {
count if treatment_expanded==0 & county==`i' & counter_m_s0==1
glo t0_c`i'_m = `r(N)'
	}	

	forvalues i=0/2 {
	count if treatment_expanded==`i' & counter_m_s0==1
	glo t`i'_c4_m = `r(N)'
		}
		
forvalues i=1/3 {
count if county==`i' & counter_m_s0==1
glo t3_c`i'_m = `r(N)'
	}		
	
	count if counter_m_s0==1
	glo t3_c4_m = `r(N)'
	
	
* Facilities	
forvalues i=1/3 {
count if treatment_expanded==1 & county==`i'
glo t1_c`i' = `r(N)'
	}
forvalues i=1/3 {
count if treatment_expanded==2 & county==`i'
glo t2_c`i' = `r(N)'
	}	
forvalues i=1/3 {
count if treatment_expanded==0 & county==`i'
glo t0_c`i' = `r(N)'
	}	
	
	forvalues i=0/2 {
	count if treatment_expanded==`i'
	glo t`i'_c4 = `r(N)'
		}	
		
forvalues i=1/3 {
count if county==`i' 
glo t3_c`i' = `r(N)'
	}			

	count if t!=.
	glo t3_c4 = `r(N)'	
	
restore
		

* At endline
keep if fl_consent!=.
sort market_all_expanded hfid
bys market_all_expanded: gen counter_m_s0 = _n

* Markets
forvalues i=1/3 {
count if treatment_expanded==1 & county==`i' & counter_m_s0==1 
glo t1_c`i'_m_end = `r(N)'
	}
forvalues i=1/3 {
count if treatment_expanded==2 & county==`i' & counter_m_s0==1
glo t2_c`i'_m_end = `r(N)'
	}	
forvalues i=1/3 {
count if treatment_expanded==0 & county==`i' & counter_m_s0==1
glo t0_c`i'_m_end = `r(N)'
	}	

	forvalues i=0/2 {
	count if treatment_expanded==`i' & counter_m_s0==1
	glo t`i'_c4_m_end = `r(N)'
		}
		
forvalues i=1/3 {
count if county==`i' & counter_m_s0==1
glo t3_c`i'_m_end = `r(N)'
	}		
	
	count if counter_m_s0==1
	glo t3_c4_m_end = `r(N)'
	
	
* Facilities	
forvalues i=1/3 {
count if treatment_expanded==1 & county==`i'
glo t1_c`i'_end = `r(N)'
	}
forvalues i=1/3 {
count if treatment_expanded==2 & county==`i'
glo t2_c`i'_end = `r(N)'
	}	
forvalues i=1/3 {
count if treatment_expanded==0 & county==`i'
glo t0_c`i'_end = `r(N)'
	}	
	
	forvalues i=0/2 {
	count if treatment_expanded==`i'
	glo t`i'_c4_end = `r(N)'
		}	
		
forvalues i=1/3 {
count if county==`i' 
glo t3_c`i'_end = `r(N)'
	}			

	count if t!=.
	glo t3_c4_end = `r(N)'	
	
		
* Export
* ------
glo C_1 			"Markets"
glo C_2 			"Facilities"

glo SC_1 			"Kakamega"
glo SC_2 			"Kilifi"
glo SC_3 			"Meru"
glo SC_4 			"Total"

glo panelA 			"Panel A. At Randomization [1]"
glo panelB 			"Panel B. At Endline [2]"

glo t1				"Treatment 1"
glo t2				"Treatment 2 (Scorecards)"
glo t0				"Control"
glo t3				"Total"



* Table global
glo table_name "${tex_`out'_out}"

* Start the Latex document
texdoc do "${tex_`out'}"	

				


				
				
				
				
				
				
				
