/*******************************************************************************	
Project:  	KePSIE
*******************************************************************************/
********************************************************************************
** Create globals for directories and files 
********************************************************************************
clear all
set more off

* Input
glo inputdata	 		"${dt_final}/data_for_analysis.dta"

* Output
loc out 				table_S6
glo tex_`out'			"${do_supp}/tex/tex_`out'.do"
glo tex_`out'_out 		"${out_supp}/`out'.tex"

* Programs		
glo save_coeff			"${program}/save_coeff.do"
do "${save_coeff}"	
	
********************************************************************************
** Setup
********************************************************************************

* Table globals
* ----------------------------------
* Treatments	
glo t1 t1 t2
glo treatments_pooled t1_2 t2_2
* Control vars
glo control_hfs level_3 level_4_5 						i.strata_expanded
glo control_mks per_level_2 per_level_3 per_level_4_5 	i.strata_expanded
* Sample
glo sample s2	
			
********************************************************************************
** Run table
********************************************************************************			
use "${inputdata}", clear

*recode bl_consent (1=0) (0=1), gen(refusal_bl)
*recode fl_consent (1=0) (0=1), gen(refusal)

clonevar s0_consent = bl_consent
replace s0_consent = 0 if mi(s0_consent) & active_s0==1
replace s0_consent = . if active_s0!=1

glo vars bl_consent s0_consent fl_consent	
	
foreach x in $vars {
	reg `x' t i.strata_expanded, vce(cluster market_all_expanded)
		sum `x' 
		glo `x'1 		:  di %4.3f _b[t]
		glo `x'1sd 		:  di %4.3f _se[t]
		glo `x'1p 		:  di %4.3f (2 * ttail(e(df_r), abs(_b[t]/_se[t])))
		glo N_`x'1 		= e(N)
		sum `x' if t == 0
		glo `x'_mc 		: di %4.3f `r(mean)'
		glo `x'_sdc 	: di %4.3f `r(sd)'
		sum `x' if t == 1
		glo `x'_mt1 	: di %4.3f `r(mean)'
		glo `x'_sdt1	: di %4.3f `r(sd)'
		sum `x'
		glo N_`x' 		: di %4.0f `r(N)'		
		}
																
* Adding *** if needed
glo coeff_table
foreach var in $vars {
	glo coeff_table $coeff_table `var'1
	}
	star coeff_table
	
********************************************************************************
** Export
********************************************************************************
glo C_1 		"(C) \\ Control \\ Mean"
glo C_2 		"(T-C) \\ Adj. Diff."			
glo C_3 		"Obs."
glo left		"Unweighted"
glo right		"Weighted"	

* Labels
lab var bl_consent 	"Response Rate at Baseline"
lab var s0_consent 	"Surveyed Facilities at Baseline (Randomization sample)"
lab var fl_consent 	"Response Rate at Endline"

glo bl_consent 	: variable label bl_consent
glo s0_consent 	: variable label s0_consent
glo fl_consent 	: variable label fl_consent

* Table specific globals
glo table_name "${tex_`out'_out}"

* Start the Latex document
texdoc do "${tex_`out'}"			
						
						
						
						
						
						
						

