/*******************************************************************************
*					     			KePSIE 		    		       			   *
********************************************************************************		
********************************************************************************
** Create locals for files 
*******************************************************************************/
clear all
set more off
	
* Input 
glo inputdata 			"${dt_final}/data_for_analysis.dta" 

* Output 
loc out 				table_S7
glo tex_`out'			"${do_supp}/tex/tex_`out'.do"
glo tex_`out'_out 		"${out_supp}/`out'.tex"

* Programs
glo stats				"${program}/stats.do"
do "${stats}"	

********************************************************************************
** Table 1: Summary statistics at baseline
********************************************************************************
use "${inputdata}", clear

clonevar treatment_eff_exp = treatment_eff
replace treatment_eff_exp = 0 if mi(treatment_eff_exp) & !mi(treatment_expanded)

clonevar treatment_eff_noin = treatment_eff_exp
replace treatment_eff_noin = . if treatment_eff_noin==3

count if treatment_eff_exp!=. & treatment_expanded!=. & active_s0==1
count if treatment_eff_noin!=. & treatment_expanded!=. & active_s0==1

count if treatment_eff_exp!=. & treatment_expanded==1 & active_s0==1
count if treatment_eff_exp==1 & treatment_expanded==1 & active_s0==1

count if treatment_eff_noin!=. & treatment_expanded==1 & active_s0==1
count if treatment_eff_noin==1 & treatment_expanded==1 & active_s0==1

* Randomization
loc x 1
count if treatment_eff_exp!=. & treatment_expanded==`x' & active_s0==1
glo t`x'_den = `r(N)'

	forvalues i =0/3 {
	count if treatment_eff_exp==`i' & treatment_expanded==`x' & active_s0==1
	loc t`x'_t`i'_num = `r(N)'
	glo t`x'_t`i' : di %4.2f `t`x'_t`i'_num'/${t`x'_den}
	}
	
loc x 2	
count if treatment_eff_exp!=. & treatment_expanded==`x' & active_s0==1
glo t`x'_den = `r(N)'

	forvalues i =0/3 {
	count if treatment_eff_exp==`i' & treatment_expanded==`x' & active_s0==1
	loc t`x'_t`i'_num = `r(N)'
	glo t`x'_t`i' : di %4.2f `t`x'_t`i'_num'/${t`x'_den}
	}
	
loc x 0	
count if treatment_eff_exp!=. & treatment_expanded==`x' & active_s0==1
glo t`x'_den = `r(N)'

	forvalues i =0/3 {
	count if treatment_eff_exp==`i' & treatment_expanded==`x' & active_s0==1
	loc t`x'_t`i'_num = `r(N)'
	glo t`x'_t`i' : di %4.2f `t`x'_t`i'_num'/${t`x'_den}
	}
	
loc x 3
count if treatment_eff_exp!=. & treatment_expanded!=. & active_s0==1
glo t`x'_den = `r(N)'

	forvalues i =0/3 {
	count if treatment_eff_exp==`i' & treatment_expanded==`x' & active_s0==1
	loc t`x'_t`i'_num = `r(N)'
	glo t`x'_t`i' : di %4.2f `t`x'_t`i'_num'/${t`x'_den}
	}
	
	
	* Randomization (no out of business)
	loc x 1
	count if treatment_eff_noin!=. & treatment_expanded==`x' & active_s0==1
	glo t`x'_den_wo = `r(N)'

		forvalues i =0/3 {
		count if treatment_eff_noin==`i' & treatment_expanded==`x' & active_s0==1
		loc t`x'_t`i'_num = `r(N)'
		glo t`x'_t`i'_wo : di %4.2f `t`x'_t`i'_num'/${t`x'_den_wo}
		}
		
	loc x 2	
	count if treatment_eff_noin!=. & treatment_expanded==`x' & active_s0==1
	glo t`x'_den_wo = `r(N)'

		forvalues i =0/3 {
		count if treatment_eff_noin==`i' & treatment_expanded==`x' & active_s0==1
		loc t`x'_t`i'_num = `r(N)'
		glo t`x'_t`i'_wo : di %4.2f `t`x'_t`i'_num'/${t`x'_den_wo}
		}
		
	loc x 0	
	count if treatment_eff_noin!=. & treatment_expanded==`x' & active_s0==1
	glo t`x'_den_wo = `r(N)'

		forvalues i =0/3 {
		count if treatment_eff_noin==`i' & treatment_expanded==`x' & active_s0==1
		loc t`x'_t`i'_num = `r(N)'
		glo t`x'_t`i'_wo : di %4.2f `t`x'_t`i'_num'/${t`x'_den_wo}
		}
		
	loc x 3
	count if treatment_eff_noin!=. & treatment_expanded!=. & active_s0==1
	glo t`x'_den_wo = `r(N)'

		forvalues i =0/3 {
		count if treatment_eff_noin==`i' & treatment_expanded==`x' & active_s0==1
		loc t`x'_t`i'_num = `r(N)'
		glo t`x'_t`i'_wo : di %4.2f `t`x'_t`i'_num'/${t`x'_den_wo}
		}
	
	
* Endline
loc x 1
count if treatment_eff_exp!=. & treatment_expanded==`x' & fl_consent!=.
glo t`x'_den_end = `r(N)'

	forvalues i =0/3 {
	count if treatment_eff_exp==`i' & treatment_expanded==`x' & fl_consent!=.
	loc t`x'_t`i'_num_end = `r(N)'
	glo t`x'_t`i'_end : di %4.2f `t`x'_t`i'_num_end'/${t`x'_den_end}
	}
	
loc x 2	
count if treatment_eff_exp!=. & treatment_expanded==`x' & fl_consent!=.
glo t`x'_den_end = `r(N)'

	forvalues i =0/3 {
	count if treatment_eff_exp==`i' & treatment_expanded==`x' & fl_consent!=.
	loc t`x'_t`i'_num_end = `r(N)'
	glo t`x'_t`i'_end : di %4.2f `t`x'_t`i'_num_end'/${t`x'_den_end}
	}
	
loc x 0	
count if treatment_eff_exp!=. & treatment_expanded==`x' & fl_consent!=.
glo t`x'_den_end = `r(N)'

	forvalues i =0/3 {
	count if treatment_eff_exp==`i' & treatment_expanded==`x' & fl_consent!=.
	loc t`x'_t`i'_num_end = `r(N)'
	glo t`x'_t`i'_end : di %4.2f `t`x'_t`i'_num_end'/${t`x'_den_end}
	}
	
loc x 3
count if treatment_eff_exp!=. & treatment_expanded!=. & fl_consent!=.
glo t`x'_den_end = `r(N)'

	forvalues i =0/3 {
	count if treatment_eff_exp==`i' & treatment_expanded==`x' & fl_consent!=.
	loc t`x'_t`i'_num_end = `r(N)'
	glo t`x'_t`i'_end : di %4.2f `t`x'_t`i'_num_end'/${t`x'_den_end}
	}

glo t0_t3 "NA"
glo t0_t3_wo "NA"
glo t1_t3_end "NA"	
glo t2_t3_end "NA"	
glo t0_t3_end "NA"
	
		
* Export
* ------
glo C_1 			"Treatment Received"
glo SC_0			"Treatment Assigned"
glo SC_1			"Treatment 1"
glo SC_2			"Treatment 2 \\ (Scorecards)"
glo SC_3			"No \\ Treatment"
glo SC_4 			"Out of \\ business at \\ 1st inspection"
glo SC_5 			"Total"

glo panelA 			"Panel A. Active at Randomization"
glo panelB 			"Panel B. Active at Endline"

glo t1				"Treatment 1"
glo t2				"Treatment 2 (Scorecards)"
glo t0				"Control"
glo t3				"All"


* Table global
glo table_name "${tex_`out'_out}"

* Start the Latex document
texdoc do "${tex_`out'}"	

