/*******************************************************************************	
Project:  	KePSIE
*******************************************************************************/
********************************************************************************
** Create globals for directories and files 
********************************************************************************
clear all
set more off

* Input
glo inputdata	 		"${dt_final}/data_for_analysis.dta"
		
* Output
loc out 				table_S8
glo tex_`out'			"${do_supp}/tex/tex_`out'.do"
glo tex_`out'_out 		"${out_supp}/`out'.tex"

* Programs		
glo save_coeff			"${program}/save_coeff.do"
do "${save_coeff}"

********************************************************************************
** Run table
********************************************************************************
* Treatments	
glo t1 					t1 t2
glo treatments_pooled 	t1_2 t2_2
* Control vars
glo control_hfs 		level_3 level_4_5 						i.strata_expanded
glo control_mks			 per_level_2 per_level_3 per_level_4_5 	i.strata_expanded
* Outcomes
glo main_outcome_q 		jhic_all oop_all_imp outp_as_jan
glo main_outcome		jhic_all oop_all_imp outp_as_jan new_end
glo outcome_toweight  	jhic_all oop_all_imp
glo outcome_weighted  	jhic_all_w oop_all_imp_w
glo main_outcome_all 	jhic_all oop_all_imp jhic_all_w oop_all_imp_w outp_as_jan new_end
* Sample
glo sample 				s2
	
*-------------------------------------------------------------------
* 
*-------------------------------------------------------------------
use "${inputdata}", clear

* Setup

	* Average inspections per market
	bys market_all_expanded: egen inspections_m = mean(inspections)
	lab var inspections_m "Average Inspections in the Market"
	bys market_all_expanded: gen counter_m = _n


	
* JHIC and market size	
loc var jhic_all_bl_m
reg `var' marketsize_rand_expanded $control_mks if $sample==1 & counter_m==1
	sum `var' if t == 0 & $sample == 1 & e(sample) == 1
	glo `var'1 		:  di %4.3f _b[marketsize_rand_expanded]
	glo `var'1sd 	:  di %4.3f _se[marketsize_rand_expanded]
	glo `var'm0 	:  di %4.3f `r(mean)'
	glo R_`var' 	:  di %4.3f e(r2)
	glo N_`var' 	= e(N)
	

* Market size
loc var marketsize_rand_expanded
reg `var' ti_m $control_mks jhic_all_bl_m if $sample==1 & t==1 & counter_m==1
	sum `var' if t == 0 & $sample == 1 & e(sample) == 1
	glo `var'1 		:  di %4.3f _b[ti_m]
	glo `var'1sd 	:  di %4.3f _se[ti_m]
	glo R_`var' 	:  di %4.3f e(r2)
	glo N_`var' 	= e(N)
	
	
* # inspections
loc var marketsize_rand_expanded
reg `var' inspections_m $control_mks jhic_all_bl_m if $sample==1 & t==1 & counter_m==1
	sum `var' if t == 0 & $sample == 1 & e(sample) == 1
	glo `var'2m0 	:  di %4.3f `r(mean)'
	glo `var'2 		:  di %4.3f _b[inspections_m]
	glo `var'2sd 	:  di %4.3f _se[inspections_m]
	glo R_`var'2 	:  di %4.3f e(r2)
	glo N_`var'2	= e(N)

********************************************************************************
** Export
********************************************************************************
glo table_name 		"Table${TableNumber}_$date"
glo left 			"Facility and Patient Level"

glo C_1 			"JHIC Score at Baseline at the Market Level (All Markets)"
glo C_2 			"Market Size at Randomization (Treated Markets Only)"


* Table global
glo table_name "${tex_`out'_out}"

* Start the Latex document
texdoc do "${tex_`out'}"							
						
						
						
						
						
						
						
		
