/*******************************************************************************
*					     			KePSIE 		    		       			   *
********************************************************************************		
********************************************************************************
** Create locals for files 
*******************************************************************************/
clear all
set more off
	
* Input 
glo inputdata	 		"${dt_final}/data_for_analysis.dta" 
glo inputdata_p 		"${dt_final}/oop_p.dta" 

* Output 
loc out 				table_S9
glo tex_`out'			"${do_supp}/tex/tex_`out'.do"
glo tex_`out'_out 		"${out_supp}/`out'.tex"

* Programs
glo stats				"${program}/stats.do"
do "${stats}"	

********************************************************************************
** Table 1: Summary statistics at baseline
********************************************************************************
use "${inputdata}", clear

* Public, Private Stable (in operation for 3+ years), and Private Unstable at Baseline and Endline

* Endline
gen private_stable = 0 if private==1 & startyear>=2015
replace private_stable = 1 if private==1 & startyear<=2015
replace private_stable = . if startyear==.
replace private_stable = 0 if private==1 & new_year ==1 & mi(private_stable)
replace private_stable = 1 if private==1 & new_year ==0 & mi(private_stable)

gen pp_stable = private_stable
replace pp_stable = 2 if private==0
lab def pp_stable 1 "Private stable" 0 "Private unstable" 2 "Public"
lab val pp_stable pp_stable

	* Entered
	gen enter = 1 if fl_consent!=. & bl_consent==.
	replace enter = 0 if pp_stable!=. & mi(enter)

* Baseline
gen private_stable_bl = 0 if private==1 & startyear>=2012
replace private_stable_bl = 1 if private==1 & startyear<=2012 
replace private_stable_bl = . if startyear==.
replace private_stable_bl = 0 if mi(private_stable_bl) & private==1 & new_year ==1
replace private_stable_bl = 1 if mi(private_stable_bl) & private==1 & new_year ==0

gen pp_stable_bl = private_stable_bl
replace pp_stable_bl = 2 if private==0
lab val pp_stable_bl pp_stable

	* Exited
	gen exit = 1 if bl_consent!=. & fl_consent==.
	replace exit = 0 if pp_stable_bl!=. & mi(exit)




* All 
count if outp_as_jan_bl!=. 
loc hf_bl = `r(N)'

count if outp_as_jan!=. 
loc hf = `r(N)'

count if outp_as_jan!=. & t==0
loc hf_c = `r(N)'

egen outp_tot_bl = total(outp_as_jan_bl) 
sum outp_tot_bl
loc outp_tot_bl = `r(mean)'

egen outp_tot = total(outp_as_jan) 
sum outp_tot
loc outp_tot = `r(mean)'

egen outp_tot_c = total(outp_as_jan) if t==0
sum outp_tot_c
loc outp_tot_c = `r(mean)'
 
* Exited by endline 
count if exit==1 & outp_as_jan_bl!=. 
loc hf_exit = `r(N)'
glo hf_exit : di %4.2f `hf_exit'/`hf_bl'

egen outp_tot_exit = total(outp_as_jan_bl) if exit==1
sum outp_tot_exit
loc outp_tot_exit = `r(mean)'
glo outp_tot_exit : di %4.2f `outp_tot_exit'/`outp_tot_bl'
 
* Entered by endline 
count if enter==1 & outp_as_jan!=. 
loc hf_enter = `r(N)'
glo hf_enter : di %4.2f `hf_enter'/`hf'

egen outp_tot_ent = total(outp_as_jan) if enter==1
sum outp_tot_ent
loc outp_tot_ent = `r(mean)'
glo outp_tot_ent : di %4.2f `outp_tot_ent'/`outp_tot'

* Entered by endline (control)
count if enter==1 & outp_as_jan!=. & t==0 
loc hf_enter_c = `r(N)'
glo hf_enter_c : di %4.2f `hf_enter_c'/`hf_c'

egen outp_tot_ent_c = total(outp_as_jan) if enter==1 & t==0
sum outp_tot_ent_c
loc outp_tot_ent_c = `r(mean)'
glo outp_tot_ent_c : di %4.2f `outp_tot_ent_c'/`outp_tot_c'
	
		
* Export
* ------
glo C_1 			"Share of patients \\ when operational"
glo C_2 			"Share of facilities \\ when operational"

glo bl 				"Exited by endline (active at baseline)"
glo end 			"Entered by endline"
glo end_c 			"Entered by endline (control only)"

* Table global
glo table_name "${tex_`out'_out}"

* Start the Latex document
texdoc do "${tex_`out'}"	

				


				
				
				
				
				
				
				
