/*******************************************************************************	
*		Project:
*			KePSIE
*		Last udpate: May 5, 2016
********************************************************************************			

** PURPOSE:    This do-file builts and cleans the final QPS1 dataset
				
** INPUTS:     	"$directory/DataAnalysis/Baseline/RawData/QPS1_final.dta"
				"$directory/Data Collection/Baseline/Questionnaires/Electronic/QPS1/QPS1_eQuestionnaire2_103_Baseline.xlsx"
				"$directory/DataAnalysis/Baseline/ConstructedData/Checklist/QPS2_Clean_15Dec2015.dta"
				"$directory/DataAnalysis/Baseline/ConstructedData/Listing_15Dec2015.dta"				

** OUTPUTS:     "$directory/DataAnalysis/Baseline/ConstructedData/Checklist_adherence_nodeliveries.dta"

** Written by: Gudalupe Bedoya, Amy Dolinger & Tatiana Zarate

*******************************************************************************/

********************************************************************************

	** Part 0: Define directories

********************************************************************************

	* Globals for input files
	glo	qps1_bl_raw		"${volume}/qps1_bl_raw.dta"
	glo	qps1_bl_q		"${doc_bl}/codebooks/qps1_bl_equestionnaire_2.xlsx" 
	glo qps2_bl 		"${dt_bl_clean}/qps2_bl.dta"
	glo listing_bl 		"${dt_mast}/listing_bl.dta"

	* Globals for output files 
	glo jhic_bl 		"${dt_bl_clean}/jhic_bl.dta"

********************************************************************************

	** Part 1: Basic cleaning QPS1

********************************************************************************	

	cls
	clear all
	
* Mount veracrypt drive
*veracrypt "${encrypt}/Baseline Raw Identified Data", mount drive("${mount}")
	
	use "${qps1_bl_raw}"

	keep if a12 ==1 // Keeping only those that finished QPS1

	* Searching for duplicates
	duplicates tag a5, gen(tag2)
		
	* HF with ID 901703 is duplicate. I'm dropping the data that was uploaded on Apr 16, 2015, because it has lesser staff data than the other row. 
	drop if key == "uuid:3b802bdb-b149-4a74-87d7-906e581cd3d0"
	* HF with ID 800050 is duplicate. I'm dropping the data that was uploaded on Jul 16, 2015, there is no difference in terms of data. 
	drop if key == "uuid:4289e290-bfcb-4388-8bd2-9361f8b8322a"
	* HF with ID 800042 but facilitycode 900846 is duplicate in terms of a5 (ID). You can check that (i) variables a5 and facilitycode are different, (ii) the HF was visited by/// 
	// different Senior FO and FO, and (iii) the ID 900846 doesn't exist in the records. It was a coding mistake.  
	replace a5 = 900846 if facilitycode == "900846"

	drop tag2

	* Manual change: Dropping HFs that did not complete both QPS1 and QPS2
	drop if a5 == 16622
	drop if a5 == 18700
	drop if a5 == 800028
	drop if a5 == 900478
	drop if a5 == 901253

	** Drop misscoded hf: 900899
	drop if a5 == 900899

	** Manual change: The survey for HF with code 800004 was coded as 800020, so we need to change those values.
	preserve 
	keep if a5 == 800020
	keep submissiondate	deviceid date a2 a2_1 time a4 a5 a6 a6_c a7 a8 a8_c a9 a11 - c18_47
	replace a5 = 800004
	tempfile temp1
	save `temp1'
	restore

	append using `temp1'

	** Separates select_multiple questions 

	qui {
	cap prog drop splitmult
	prog def splitmult

	syntax anything using
		import excel `using', clear first
		keep if regexm(type,"^select_multiple")
		count
		local nQuestions = `r(N)'
		forvalues i = 1/`nQuestions' {

			import excel `using', clear first
				keep if regexm(type,"^select_multiple")

				local theName = name[`i']
				local theChoices = type[`i']
					local theChoices = regexr("`theChoices'","select_multiple ","")
				
			import excel `using', clear first sheet("choices")
				keep if list_name == "`theChoices'"
				
				count
				local nChoices = `r(N)'
				
				forvalues j = 1/`nChoices' {
				
					local theNextLabel = label[`j']
					local theNextValue  = name[`j']
				
					local `theName'L `" ``theName'L' "`theNextLabel'" "'
					local `theName'V ``theName'V' `theNextValue'
					
					}
					
			use `anything', clear
				
				forvalues j = 1/`nChoices' {
					
					local theNextLabel : word `j' of ``theName'L'
					local theNextValue : word `j' of ``theName'V'
					
					cap tostring `theName', replace
					
					cap gen `theName'_ch_`j' = 1 if regexm(`theName',"`theNextValue'")
						cap replace `theName'_ch_`j' = 0 if `theName' != "" & `theName'_ch_`j' != 1
						cap label var `theName'_ch_`j' "`theNextLabel'"
						
					}
					
				save `anything', replace					
			}			
	end
	}

	tempfile split
	save `split'

	* Split the multiple-choice questions
	splitmult `split' using "${qps1_bl_q}"

	save `split', replace

********************************************************************************

	** Part 2: Checklist cleaning (Section 3) from QPS1 questions

********************************************************************************
		
	* Section 3

	* Facilityname
	replace facilityname = d1_v if d1_v != ""

	* We won't need these variables in the checklist
	drop submissiondate	deviceid subscriberid simid	devicephonenum	audio a1accuracy pri_string a10 a7 a9 a1_cal a1_v a4_1	a2 a2_1 a4_pri	a4_level a4_county time_startinteraction b1	b2	b3	b4	time_start_d	d1	d1_v	d2	d3	d4	d5	d6	d7	d8	d9	d10	d11	d12	d13	d14	d15	d16	d17	d18	d18_1	time_end_d	time_start_e	e1_1	e1_2	e1	e2	e21	e3_1	e3_1_1	e4_1	e4_1_1	e5_1	e3_2	e3_2_1	e4_2	e4_2_1	e5_2	e3_3	e3_3_1	e4_3	e4_3_1	e5_3	e6	e6_1	e7_1	e8_1	e9_1	e10_1	e3_4	e3_4_1	e4_4	e4_4_1	e5_4	e7_2	e8_2	e9_2	e10_2	e3_5	e3_5_1	e4_5	e4_5_1	e5_5	e7_3	e8_3	e9_3	e10_3	e3_6	e3_6_1	e4_6	e4_6_1	e5_6	e7_4	e8_4	e9_4	e10_4	e3_14	e3_14_1	e4_14	e4_14_1	e5_14	e7_5	e8_5	e9_5	e10_5	e3_11	e3_11_1	e4_11	e4_11_1	e5_11	e7_6	e8_6	e9_6	e10_6	e3_7	e3_7_1	e4_7	e4_7_1	e5_7	e11	e11_1	e11_v	e12_1	e13_1	e14_1	e15_1	e3_8	e3_8_1	e4_8	e4_8_1	e5_8	e12_2	e13_2	e14_2	e15_2	e3_9	e3_9_1	e4_9	e4_9_1	e5_9	e12_3	e13_3	e14_3	e15_3	e3_10	e3_10_1	e4_10	e4_10_1	e5_10	e16	e16_1	e16_v	e17_1	e18_1	e19_1	e20_1	e3_12	e3_12_1	e4_12	e4_12_1	e5_12	e17_2	e18_2	e19_2	e20_2	e3_13	e3_13_1	e4_13	e4_13_1	e5_13	time_end_e	time_start_f  time_start_staffroster	c1	c2_1	c2_2	c2_c	roster_repeat	roster_repeat_v1	roster_repeat_v2	roster_repeat_c	staff_ros_t1	staff_ros_t2	c20	c21	time_end_staffroster	time_endinteraction	g1	g2	g3	g4	g5	g6	g7	g8	g9	g10_1	g10_2	g10_3	g10_4	g10_5	g10_6	g11	h1_1	h1_2	h2_1latitude	h2_1longitude	h2_1altitude	h2_1accuracy	h2_2	h2_3	speedviolcount	speedviollist	formdef_version	key	c61	c51	c71	c81	c91	c101	c111	c121	c12_a1	c131	c13_a1	c141	c14_a1	c14_b1	c151	c15_a1	c161	c171	c18_v11	c18_v21	c18_11	c18_21	c18_31	c18_41	c62	c52	c72	c82	c92	c102	c112	c122	c12_a2	c132	c13_a2	c142	c14_a2	c14_b2	c152	c15_a2	c162	c172	c18_v12	c18_v22	c18_12	c18_22	c18_32	c18_42	c63	c53	c73	c83	c93	c103	c113	c123	c12_a3	c133	c13_a3	c143	c14_a3	c14_b3	c153	c15_a3	c163	c173	c18_v13	c18_v23	c18_13	c18_23	c18_33	c18_43	c64	c54	c74	c84	c94	c104	c114	c124	c12_a4	c134	c13_a4	c144	c14_a4	c14_b4	c154	c15_a4	c164	c174	c18_v14	c18_v24	c18_14	c18_24	c18_34	c18_44	c65	c55	c75	c85	c95	c105	c115	c125	c12_a5	c135	c13_a5	c145	c14_a5	c14_b5	c155	c15_a5	c165	c175	c18_v15	c18_v25	c18_15	c18_25	c18_35	c18_45	c66	c56	c76	c86	c96	c106	c116	c126	c12_a6	c136	c13_a6	c146	c14_a6	c14_b6	c156	c15_a6	c166	c176	c18_v16	c18_v26	c18_16	c18_26	c18_36	c18_46	c67	c57	c77	c87	c97	c107	c117	c127	c12_a7	c137	c13_a7	c147	c14_a7	c14_b7	c157	c15_a7	c167	c177	c18_v17	c18_v27	c18_17	c18_27	c18_37	c18_47	c68	c58	c78	c88	c98	c108	c118	c128	c12_a8	c138	c13_a8	c148	c14_a8	c14_b8	c158	c15_a8	c168	c178	c18_v18	c18_v28	c18_18	c18_28	c18_38	c18_48	c69	c59	c79	c89	c99	c109	c119	c129	c12_a9	c139	c13_a9	c149	c14_a9	c14_b9	c159	c15_a9	c169	c179	c18_v19	c18_v29	c18_19	c18_29	c18_39	c18_49	c610	c510	c710	c810	c910	c1010	c1110	c1210	c12_a10	c1310	c13_a10	c1410	c14_a10	c14_b10	c1510	c15_a10	c1610	c1710	c18_v110	c18_v210	c18_110	c18_210	c18_310	c18_410	c611	c511	c711	c811	c911	c1011	c1111	c1211	c12_a11	c1311	c13_a11	c1411	c14_a11	c14_b11	c1511	c15_a11	c1611	c1711	c18_v111	c18_v211	c18_111	c18_211	c18_311	c18_411	c612	c512	c712	c812	c912	c1012	c1112	c1212	c12_a12	c1312	c13_a12	c1412	c14_a12	c14_b12	c1512	c15_a12	c1612	c1712	c18_v112	c18_v212	c18_112	c18_212	c18_312	c18_412	c613	c513	c713	c813	c913	c1013	c1113	c1213	c12_a13	c1313	c13_a13	c1413	c14_a13	c14_b13	c1513	c15_a13	c1613	c1713	c18_v113	c18_v213	c18_113	c18_213	c18_313	c18_413	c614	c514	c714	c814	c914	c1014	c1114	c1214	c12_a14	c1314	c13_a14	c1414	c14_a14	c14_b14	c1514	c15_a14	c1614	c1714	c18_v114	c18_v214	c18_114	c18_214	c18_314	c18_414	c615	c515	c715	c815	c915	c1015	c1115	c1215	c12_a15	c1315	c13_a15	c1415	c14_a15	c14_b15	c1515	c15_a15	c1615	c1715	c18_v115	c18_v215	c18_115	c18_215	c18_315	c18_415	c616	c516	c716	c816	c916	c1016	c1116	c1216	c12_a16	c1316	c13_a16	c1416	c14_a16	c14_b16	c1516	c15_a16	c1616	c1716	c18_v116	c18_v216	c18_116	c18_216	c18_316	c18_416	c617	c517	c717	c817	c917	c1017	c1117	c1217	c12_a17	c1317	c13_a17	c1417	c14_a17	c14_b17	c1517	c15_a17	c1617	c1717	c18_v117	c18_v217	c18_117	c18_217	c18_317	c18_417	c618	c518	c718	c818	c918	c1018	c1118	c1218	c12_a18	c1318	c13_a18	c1418	c14_a18	c14_b18	c1518	c15_a18	c1618	c1718	c18_v118	c18_v218	c18_118	c18_218	c18_318	c18_418	c619	c519	c719	c819	c919	c1019	c1119	c1219	c12_a19	c1319	c13_a19	c1419	c14_a19	c14_b19	c1519	c15_a19	c1619	c1719	c18_v119	c18_v219	c18_119	c18_219	c18_319	c18_419	c620	c520	c720	c820	c920	c1020	c1120	c1220	c12_a20	c1320	c13_a20	c1420	c14_a20	c14_b20	c1520	c15_a20	c1620	c1720	c18_v120	c18_v220	c18_120	c18_220	c18_320	c18_420	c621	c521	c721	c821	c921	c1021	c1121	c1221	c12_a21	c1321	c13_a21	c1421	c14_a21	c14_b21	c1521	c15_a21	c1621	c1721	c18_v121	c18_v221	c18_121	c18_221	c18_321	c18_421	c622	c522	c722	c822	c922	c1022	c1122	c1222	c12_a22	c1322	c13_a22	c1422	c14_a22	c14_b22	c1522	c15_a22	c1622	c1722	c18_v122	c18_v222	c18_122	c18_222	c18_322	c18_422	c623	c523	c723	c823	c923	c1023	c1123	c1223	c12_a23	c1323	c13_a23	c1423	c14_a23	c14_b23	c1523	c15_a23	c1623	c1723	c18_v123	c18_v223	c18_123	c18_223	c18_323	c18_423	c624	c524	c724	c824	c924	c1024	c1124	c1224	c12_a24	c1324	c13_a24	c1424	c14_a24	c14_b24	c1524	c15_a24	c1624	c1724	c18_v124	c18_v224	c18_124	c18_224	c18_324	c18_424	c625	c525	c725	c825	c925	c1025	c1125	c1225	c12_a25	c1325	c13_a25	c1425	c14_a25	c14_b25	c1525	c15_a25	c1625	c1725	c18_v125	c18_v225	c18_125	c18_225	c18_325	c18_425	c626	c526	c726	c826	c926	c1026	c1126	c1226	c12_a26	c1326	c13_a26	c1426	c14_a26	c14_b26	c1526	c15_a26	c1626	c1726	c18_v126	c18_v226	c18_126	c18_226	c18_326	c18_426	c627	c527	c727	c827	c927	c1027	c1127	c1227	c12_a27	c1327	c13_a27	c1427	c14_a27	c14_b27	c1527	c15_a27	c1627	c1727	c18_v127	c18_v227	c18_127	c18_227	c18_327	c18_427	c628	c528	c728	c828	c928	c1028	c1128	c1228	c12_a28	c1328	c13_a28	c1428	c14_a28	c14_b28	c1528	c15_a28	c1628	c1728	c18_v128	c18_v228	c18_128	c18_228	c18_328	c18_428	c629	c529	c729	c829	c929	c1029	c1129	c1229	c12_a29	c1329	c13_a29	c1429	c14_a29	c14_b29	c1529	c15_a29	c1629	c1729	c18_v129	c18_v229	c18_129	c18_229	c18_329	c18_429	c630	c530	c730	c830	c930	c1030	c1130	c1230	c12_a30	c1330	c13_a30	c1430	c14_a30	c14_b30	c1530	c15_a30	c1630	c1730	c18_v130	c18_v230	c18_130	c18_230	c18_330	c18_430	c631	c531	c731	c831	c931	c1031	c1131	c1231	c12_a31	c1331	c13_a31	c1431	c14_a31	c14_b31	c1531	c15_a31	c1631	c1731	c18_v131	c18_v231	c18_131	c18_231	c18_331	c18_431	c632	c532	c732	c832	c932	c1032	c1132	c1232	c12_a32	c1332	c13_a32	c1432	c14_a32	c14_b32	c1532	c15_a32	c1632	c1732	c18_v132	c18_v232	c18_132	c18_232	c18_332	c18_432	c633	c533	c733	c833	c933	c1033	c1133	c1233	c12_a33	c1333	c13_a33	c1433	c14_a33	c14_b33	c1533	c15_a33	c1633	c1733	c18_v133	c18_v233	c18_133	c18_233	c18_333	c18_433	c634	c534	c734	c834	c934	c1034	c1134	c1234	c12_a34	c1334	c13_a34	c1434	c14_a34	c14_b34	c1534	c15_a34	c1634	c1734	c18_v134	c18_v234	c18_134	c18_234	c18_334	c18_434	c635	c535	c735	c835	c935	c1035	c1135	c1235	c12_a35	c1335	c13_a35	c1435	c14_a35	c14_b35	c1535	c15_a35	c1635	c1735	c18_v135	c18_v235	c18_135	c18_235	c18_335	c18_435	c636	c536	c736	c836	c936	c1036	c1136	c1236	c12_a36	c1336	c13_a36	c1436	c14_a36	c14_b36	c1536	c15_a36	c1636	c1736	c18_v136	c18_v236	c18_136	c18_236	c18_336	c18_436	c637	c537	c737	c837	c937	c1037	c1137	c1237	c12_a37	c1337	c13_a37	c1437	c14_a37	c14_b37	c1537	c15_a37	c1637	c1737	c18_v137	c18_v237	c18_137	c18_237	c18_337	c18_437	c638	c538	c738	c838	c938	c1038	c1138	c1238	c12_a38	c1338	c13_a38	c1438	c14_a38	c14_b38	c1538	c15_a38	c1638	c1738	c18_v138	c18_v238	c18_138	c18_238	c18_338	c18_438	c639	c539	c739	c839	c939	c1039	c1139	c1239	c12_a39	c1339	c13_a39	c1439	c14_a39	c14_b39	c1539	c15_a39	c1639	c1739	c18_v139	c18_v239	c18_139	c18_239	c18_339	c18_439	c640	c540	c740	c840	c940	c1040	c1140	c1240	c12_a40	c1340	c13_a40	c1440	c14_a40	c14_b40	c1540	c15_a40	c1640	c1740	c18_v140	c18_v240	c18_140	c18_240	c18_340	c18_440	c641	c541	c741	c841	c941	c1041	c1141	c1241	c12_a41	c1341	c13_a41	c1441	c14_a41	c14_b41	c1541	c15_a41	c1641	c1741	c18_v141	c18_v241	c18_141	c18_241	c18_341	c18_441	c642	c542	c742	c842	c942	c1042	c1142	c1242	c12_a42	c1342	c13_a42	c1442	c14_a42	c14_b42	c1542	c15_a42	c1642	c1742	c18_v142	c18_v242	c18_142	c18_242	c18_342	c18_442	c643	c543	c743	c843	c943	c1043	c1143	c1243	c12_a43	c1343	c13_a43	c1443	c14_a43	c14_b43	c1543	c15_a43	c1643	c1743	c18_v143	c18_v243	c18_143	c18_243	c18_343	c18_443	c644	c544	c744	c844	c944	c1044	c1144	c1244	c12_a44	c1344	c13_a44	c1444	c14_a44	c14_b44	c1544	c15_a44	c1644	c1744	c18_v144	c18_v244	c18_144	c18_244	c18_344	c18_444	c645	c545	c745	c845	c945	c1045	c1145	c1245	c12_a45	c1345	c13_a45	c1445	c14_a45	c14_b45	c1545	c15_a45	c1645	c1745	c18_v145	c18_v245	c18_145	c18_245	c18_345	c18_445	c646	c546	c746	c846	c946	c1046	c1146	c1246	c12_a46	c1346	c13_a46	c1446	c14_a46	c14_b46	c1546	c15_a46	c1646	c1746	c18_v146	c18_v246	c18_146	c18_246	c18_346	c18_446	c647	c547	c747	c847	c947	c1047	c1147	c1247	c12_a47	c1347	c13_a47	c1447	c14_a47	c14_b47	c1547	c15_a47	c1647	c1747	c18_v147	c18_v247	c18_147	c18_247	c18_347	c18_447	c648	c548	c748	c848	c948	c1048	c1148	c1248	c12_a48	c1348	c13_a48	c1448	c14_a48	c14_b48	c1548	c15_a48	c1648	c1748	c18_v148	c18_v248	c18_148	c18_248	c18_348	c18_448	c649	c549	c749	c849	c949	c1049	c1149	c1249	c12_a49	c1349	c13_a49	c1449	c14_a49	c14_b49	c1549	c15_a49	c1649	c1749	c18_v149	c18_v249	c18_149	c18_249	c18_349	c18_449	starttime	endtime	a2_v e21_v	f38_v	time_endinteraction2	c650	c550	c750	c850	c950	c1050	c1150	c1250	c12_a50	c1350	c13_a50	c1450	c14_a50	c14_b50	c1550	c15_a50	c1650	c1750	c18_v150	c18_150	c18_250	c18_350	c18_450	c651	c551	c751	c851	c951	c1051	c1151	c1251	c12_a51	c1351	c13_a51	c1451	c14_a51	c14_b51	c1551	c15_a51	c1651	c1751	c18_v151	c18_151	c18_251	c18_351	c18_451	c652	c552	c752	c852	c952	c1052	c1152	c1252	c12_a52	c1352	c13_a52	c1452	c14_a52	c14_b52	c1552	c15_a52	c1652	c1752	c18_v152	c18_152	c18_252	c18_352	c18_452	c653	c553	c753	c853	c953	c1053	c1153	c1253	c12_a53	c1353	c13_a53	c1453	c14_a53	c14_b53	c1553	c15_a53	c1653	c1753	c18_v153	c18_153	c18_253	c18_353	c18_453	c654	c554	c754	c854	c954	c1054	c1154	c1254	c12_a54	c1354	c13_a54	c1454	c14_a54	c14_b54	c1554	c15_a54	c1654	c1754	c18_v154	c18_154	c18_254	c18_354	c18_454	c655	c555	c755	c855	c955	c1055	c1155	c1255	c12_a55	c1355	c13_a55	c1455	c14_a55	c14_b55	c1555	c15_a55	c1655	c1755	c18_v155	c18_155	c18_255	c18_355	c18_455	c656	c556	c756	c856	c956	c1056	c1156	c1256	c12_a56	c1356	c13_a56	c1456	c14_a56	c14_b56	c1556	c15_a56	c1656	c1756	c18_v156	c18_156	c18_256	c18_356	c18_456	c657	c557	c757	c857	c957	c1057	c1157	c1257	c12_a57	c1357	c13_a57	c1457	c14_a57	c14_b57	c1557	c15_a57	c1657	c1757	c18_v157	c18_157	c18_257	c18_357	c18_457	c658	c558	c758	c858	c958	c1058	c1158	c1258	c12_a58	c1358	c13_a58	c1458	c14_a58	c14_b58	c1558	c15_a58	c1658	c1758	c18_v158	c18_158	c18_258	c18_358	c18_458	c659	c559	c759	c859	c959	c1059	c1159	c1259	c12_a59	c1359	c13_a59	c1459	c14_a59	c14_b59	c1559	c15_a59	c1659	c1759	c18_v159	c18_159	c18_259	c18_359	c18_459	c660	c560	c760	c860	c960	c1060	c1160	c1260	c12_a60	c1360	c13_a60	c1460	c14_a60	c14_b60	c1560	c15_a60	c1660	c1760	c18_v160	c18_160	c18_260	c18_360	c18_460	c661	c561	c761	c861	c961	c1061	c1161	c1261	c12_a61	c1361	c13_a61	c1461	c14_a61	c14_b61	c1561	c15_a61	c1661	c1761	c18_v161	c18_161	c18_261	c18_361	c18_461	c662	c562	c762	c862	c962	c1062	c1162	c1262	c12_a62	c1362	c13_a62	c1462	c14_a62	c14_b62	c1562	c15_a62	c1662	c1762	c18_v162	c18_162	c18_262	c18_362	c18_462	c663	c563	c763	c863	c963	c1063	c1163	c1263	c12_a63	c1363	c13_a63	c1463	c14_a63	c14_b63	c1563	c15_a63	c1663	c1763	c18_v163	c18_163	c18_263	c18_363	c18_463	c664	c564	c764	c864	c964	c1064	c1164	c1264	c12_a64	c1364	c13_a64	c1464	c14_a64	c14_b64	c1564	c15_a64	c1664	c1764	c18_v164	c18_164	c18_264	c18_364	c18_464	c665	c565	c765	c865	c965	c1065	c1165	c1265	c12_a65	c1365	c13_a65	c1465	c14_a65	c14_b65	c1565	c15_a65	c1665	c1765	c18_v165	c18_165	c18_265	c18_365	c18_465	c666	c566	c766	c866	c966	c1066	c1166	c1266	c12_a66	c1366	c13_a66	c1466	c14_a66	c14_b66	c1566	c15_a66	c1666	c1766	c18_v166	c18_166	c18_266	c18_366	c18_466	c667	c567	c767	c867	c967	c1067	c1167	c1267	c12_a67	c1367	c13_a67	c1467	c14_a67	c14_b67	c1567	c15_a67	c1667	c1767	c18_v167	c18_167	c18_267	c18_367	c18_467	c668	c568	c768	c868	c968	c1068	c1168	c1268	c12_a68	c1368	c13_a68	c1468	c14_a68	c14_b68	c1568	c15_a68	c1668	c1768	c18_v168	c18_168	c18_268	c18_368	c18_468	c669	c569	c769	c869	c969	c1069	c1169	c1269	c12_a69	c1369	c13_a69	c1469	c14_a69	c14_b69	c1569	c15_a69	c1669	c1769	c18_v169	c18_169	c18_269	c18_369	c18_469	c670	c570	c770	c870	c970	c1070	c1170	c1270	c12_a70	c1370	c13_a70	c1470	c14_a70	c14_b70	c1570	c15_a70	c1670	c1770	c18_v170	c18_170	c18_270	c18_370	c18_470	c671	c571	c771	c871	c971	c1071	c1171	c1271	c12_a71	c1371	c13_a71	c1471	c14_a71	c14_b71	c1571	c15_a71	c1671	c1771	c18_v171	c18_171	c18_271	c18_371	c18_471	c672	c572	c772	c872	c972	c1072	c1172	c1272	c12_a72	c1372	c13_a72	c1472	c14_a72	c14_b72	c1572	c15_a72	c1672	c1772	c18_v172	c18_172	c18_272	c18_372	c18_472	c673	c573	c773	c873	c973	c1073	c1173	c1273	c12_a73	c1373	c13_a73	c1473	c14_a73	c14_b73	c1573	c15_a73	c1673	c1773	c18_v173	c18_173	c18_273	c18_373	c18_473	c674	c574	c774	c874	c974	c1074	c1174	c1274	c12_a74	c1374	c13_a74	c1474	c14_a74	c14_b74	c1574	c15_a74	c1674	c1774	c18_v174	c18_174	c18_274	c18_374	c18_474	c675	c575	c775	c875	c975	c1075	c1175	c1275	c12_a75	c1375	c13_a75	c1475	c14_a75	c14_b75	c1575	c15_a75	c1675	c1775	c18_v175	c18_175	c18_275	c18_375	c18_475	c676	c576	c776	c876	c976	c1076	c1176	c1276	c12_a76	c1376	c13_a76	c1476	c14_a76	c14_b76	c1576	c15_a76	c1676	c1776	c18_v176	c18_176	c18_276	c18_376	c18_476	c677	c577	c777	c877	c977	c1077	c1177	c1277	c12_a77	c1377	c13_a77	c1477	c14_a77	c14_b77	c1577	c15_a77	c1677	c1777	c18_v177	c18_177	c18_277	c18_377	c18_477	c678	c578	c778	c878	c978	c1078	c1178	c1278	c12_a78	c1378	c13_a78	c1478	c14_a78	c14_b78	c1578	c15_a78	c1678	c1778	c18_v178	c18_178	c18_278	c18_378	c18_478	b4_ch_1	b4_ch_2	b4_ch_3	b4_ch_4	b4_ch_5	b4_ch_6	b4_ch_7	b4_ch_8	b4_ch_9	b4_ch_10	b4_ch_11	b4_ch_12	b4_ch_13	b4_ch_14	b4_ch_15	b4_ch_16	b4_ch_17	b4_ch_18	d9_ch_1	d9_ch_2	d9_ch_3	d9_ch_4	d9_ch_5	d9_ch_6	d13_ch_1	d13_ch_2	d13_ch_3	d13_ch_4	e21_ch_1	e21_ch_2	e21_ch_3	e21_ch_4	e21_ch_5	e21_ch_6	e21_ch_7	e21_ch_8	e21_ch_9	e21_ch_10	e11_ch_1	e11_ch_2	e11_ch_3	e11_ch_4	e16_ch_1	e16_ch_2	e16_ch_3 f38_ch_1	f38_ch_2	f38_ch_3	f38_ch_4	f38_ch_5	f38_ch_6	f38_ch_7	f44_ch_1	f44_ch_2	f44_ch_3	f44_ch_4	g9_ch_1	g9_ch_2	g9_ch_3	g9_ch_4	g9_ch_5	g9_ch_6	g9_ch_7	g9_ch_8	g9_ch_9	g9_ch_10	g9_ch_11	g9_ch_12	g9_ch_13	g9_ch_14	g9_ch_15 ///
				
	* We won't need outpatients self reported questions in the checklist
	drop f34_1	f34_2	f30	f31	f32	f33_t1	f33_1	f33_2	f33_3	f33_4	f33_t2	f33_1_c	f33_2_c	f33_3_c	f33_4_c	f33_s	f33_4_s_v	f35_t1	f35_1u	f35_2u	f35_3u	f35_4u	f35_1u_c	f35_2u_c	f35_3u_c	f35_4u_c	f35_u_s	f35_u_s_v	f35_1o	f35_2o	f35_3o	f35_4o	f35_t2	f35_1o_c	f35_2o_c	f35_3o_c	f35_4o_c	f35_o_s	f35_o_s_v	f38	f38_1	f38_2	f38_3	f38_4	f38_5	f38_6	f36_v	f36_t1_1	f36_1_1	f36_2_1	f36_3_1	f36_4_1	f36_1_c_1	f36_2_c_1	f36_3_c_1	f36_4_c_1	f36_s_1	f36_1_c_4	f36_2_c_4	f36_3_c_4	f36_4_c_4	f36_s_total	f36_s_v_1	f36_t2_1	f37_t1	f37_1	f37_2	f37_3	f37_4	f37_t2	f37_1_c	f37_2_c	f37_3_c	f37_4_c	f37_s	f37_s_v	f37_1_c2	f37_2_c2	f37_3_c2	f37_4_c2	patients	labtest	g24_v	f44_v	f44	time_end_f time_start_g time_end_g


	* Drop -99 and -98 for all variables
	foreach var of varlist a1altitude * f10_ch_5 {

	capture confirm string var `var'
		if _rc != 0 {
			replace `var' = . if `var' == -99 
			replace `var' = . if `var' == -98
		}
		else { 
			replace `var' = "" if `var' == "-99"
			replace `var' = "" if `var' == "-98"
		}
	}

	* Destring variables 
	foreach var in facilitycode level pri  {
	destring `var', replace
	}

	* Formatting date
	gen date1 = date(date,"DMY")
	format date1 %td
	drop date
	rename date1 date
			
	* Generate county as numerical value
	gen county_n =1 if county == "Kakamega" 
	replace county_n = 2 if county == "Kilifi"
	replace county_n = 3 if county == "Meru"
	drop county
	rename county_n county
	lab define countyl 1 "Kakamega" 2 "Kilifi" 3 "Meru"
	lab val county countyl

	* Define values for level
	lab define levell 2 "Level 2" 3 "Level 3" 4 "Level 4" 5 "Level 5"
	lab val level levell

	* Define values for private 
	lab define pril 0 "Public" 1 "Private"
	lab values pri pril

	* Creating a dummy variable for each category in f17. Eliminating the option "There is no inpatient beds"
	gen f17_d = 1 if f17 == 1
	replace f17_d = 0 if f17 == 0 
	lab define f17_dl 1 "Yes" 0 "No"
	lab val f17_d f17_dl
	lab var f17_d "Are inpatient registers kept?"

	* Group in one variable f16_2 & f16_3
	gen f16_23 = 1 if f16_2 == 1 & f16_3 == 1
	replace f16_23 = 0 if f16_23 == . & (f16_2 != . & f16_3 != .) 
	lab define f16_23l 1 "Yes" 0 "No"
	lab val f16_23 f16_23l
	lab var f16_23 "Do the records include names and unique patient numbers?"

	* Group in one variable f16_4 & f16_5
	gen f16_45 = 1 if f16_4 == 1 & f16_5 == 1
	replace f16_45 = 0 if f16_45 == . & (f16_4 != . & f16_5 != .) 
	lab define f16_45l 1 "Yes" 0 "No"
	lab val f16_45 f16_45l
	lab var f16_45 "Are all the records legible and signed?"

	* Questions/answers added by QPS1
	global added f10_ch_5 f16_1 f16_2 f16_3 f16_4 f16_5
		
	* Checklist variables
	global cvariables f1 f2 f3 f4	f5 f5_1 f5_2 f5_3 f5_4 f5_5 f6 f7 f8 f9	f10_ch_1 f10_ch_2 f10_ch_3 f10_ch_4 f11 f12 f13 f14 f16 f16_23 f16_45 f18 f17_d f20 f21 f22 f23 f24 f26 f25 f27 f39 f40 f41 f42 f43

	order a1latitude a1longitude date time a5 facilityname sublocation location	county subcounty_c level pri a6	a6_c a8	a8_c a11 a12 $cvariables 
	drop a1altitude	a4	facilitycode
	
********************************************************************************

	** Part 3: Merging with QPS2 - Sections 2 - 12 Checklist

********************************************************************************

	* Renaming variables for merging with QPS2
	rename county county_1
	rename subcounty_c subcounty_1
	rename level level_1
	rename sublocation sublocation_1
	rename location location_1
	rename a8 a8_qps1 // There is a question "a8" in QPS2
		
	** Manual change: The survey for HF with code 800004 was coded as 800020, so we need to change those values. 
	preserve 
	use "${qps2_bl}", clear
	tempfile temp2
	save `temp2'
	restore
			
	preserve 
	use `temp2', clear
	keep if a5 == 800020
	keep enumeratorid enumname supervisorid supname a5 a8 - nutrition
	replace a5 = 800004
	tempfile temp3
	save `temp3'
	restore
		
	preserve 
	use `temp2', clear
	append using `temp3'
	tempfile temp4
	save `temp4'
	restore
	
	** Merging with QPS2
	mmerge a5 using `temp4', type (n:1)
	
	* Drop hfid 800020 because we just replaced it with the correct id: 800004
	drop if a5 == 800020
	
	** We didn't collect the second question for these types of questions in QPS2 for section 6: Does the hygiene protocol have a dedicated staff roster? 
	** We need to create this variable
	gen s4b_2 = 1 if s4a_12==1
	replace s4b_2 = 0 if s4a_12 == 0
	replace s4b_2 = . if s4b_1 == . 

	* If the HF reported that it does not have inpatient services in QPS2 (a8_ch_9 = 0), the inpatients records should be missing (f17_d = .)
	* In addition, there are 6 HFs that reported inpatients but they didn't answer the question about inpatients records: br f17_d a8_ch_9 if f17_d ==. & a8_ch_9 == 1
	replace f17_d = . if a8_ch_9 == 0
	replace f17_d = 1 if a8_ch_9 == 1 & f17_d == 1
	replace f17_d = 0 if a8_ch_9 == 1 & f17_d == 0	

	
	* Changing inpatients variable in QPS1 regarding QPS2 question. There are 21 HFs that reported inpatients but they didn't answer the question 
	*about inpatients records: br f20 a8_ch_9 if f20 == . & a8_ch_9 == 1
	replace f20 = . if a8_ch_9 == 0
	replace f20 = 1 if a8_ch_9 == 1 & f20 == 1 & f18 == 1
	replace f20 = 0 if a8_ch_9 == 0 & f20 == 0 & f18 == 1
	
	* We need to split question f5 from in QPS1 in two variables, because in the checklist this question is separated in 2 (s3a_2a & s3a_2b)
	gen f5_b = 1 if f5 == 1
	replace f5_b = 0 if f5 == 0
	replace f5_b = . if f5 == .

	* Renaming variables as checklist
	rename s1a_1 s2a_1a
	rename s1a_2 s2a_1b
	rename s1a_3 s2a_1c
	rename s1a_5 s2a_1d
	rename s1a_6 s2a_1e
	rename s1a_7_ch_1 s2a_2a1
	rename s1a_7_ch_2 s2a_2a2
	rename s1a_7_ch_3 s2a_2a3
	rename s1a_7_ch_4 s2a_2a4
	rename s1a_8_ch_1 s2a_3a1
	rename s1a_8_ch_2 s2a_3a2
	rename s1a_8_ch_3 s2a_3a3
	rename s1a_8_ch_4 s2a_3a4
	rename s1b_1 s2b_1a
	rename s1b_2 s2b_1b
	rename s1b_3 s2b_2a
	rename s1b_5 s2b_3a
	rename s1b_6 s2b_3b
	rename s1c_1 s2c_1a
	rename s1c_2 s2c_1b
	rename s1c_3 s2c_2a
	rename s1c_4 s2c_2b
	rename s1c_5 s2c_3a
	rename s1c_7 s2c_3b
	rename s1c_9 s2c_3c
	rename s1c_10 s2c_3d
	rename s1c_11 s2c_4a
	rename f1 s3a_1a
	rename f2 s3a_1b
	rename f3 s3a_1c
	rename f4 s3a_1d
	rename f5 s3a_2a
	rename f5_b s3a_2b	
	rename f5_1 s3a_2c
	rename f5_2 s3a_2d
	rename f5_3 s3a_2e
	rename f5_4 s3a_2f
	rename f5_5 s3a_2g
	rename f6 s3a_2h
	rename f7 s3a_3a

	rename f8 s3b_1a
	rename f9 s3b_1b
	rename f10_ch_1 s3b_2a
	rename f10_ch_2 s3b_2b
	rename f10_ch_3 s3b_2c
	rename f10_ch_4 s3b_2d
	rename f11 s3b_2e
	rename f12 s3b_3a
	rename f13 s3b_3b
	rename f14 s3b_3c
	rename f16 s3c_1a
	rename f16_23 s3c_1b
	rename f16_45 s3c_1c
	rename f18 s3c_2a
	rename f17_d s3c_2b
	rename f20 s3c_2c
	rename f21 s3c_2d
	rename f22 s3c_3a
	rename f23 s3c_3b
	rename f24 s3c_3c
	rename f26 s3c_4a
	rename f25 s3c_4b
	rename f27 s3c_5a

	rename f39 s3d_1a
	rename f40 s3d_1b
	rename f41 s3d_2a
	rename f42 s3d_2b
	rename f43 s3d_2c
	rename s2a_1 s4a_1a
	rename s2a_2 s4a_1b
	rename s2a_3 s4a_2a
	rename s2a_4 s4a_2b
	rename s2a_5 s4a_2c
	rename s2a_7_ch_1 s4a_3a1
	rename s2a_7_ch_2 s4a_3a2
	rename s2a_7_ch_3 s4a_3a3
	rename s2a_7_ch_4 s4a_3a4
	rename s2a_8 s4a_3b
	rename s2a_9_other s4a_3c
	rename s2a_10_other s4a_3d
	rename s2a_13 s4a_4a
	rename s2a_14 s4a_4b
	rename s2a_15 s4a_4c
	rename s2b_1 s4b_1a
	rename s2b_2 s4b_1b
	rename s2b_3 s4b_1c
	rename s2b_4 s4b_1d
	rename s3a_1 s5a_1a
	rename s3a_2 s5a_1b
	rename s3a_3 s5a_1c
	rename s3a_4 s5a_1d
	rename s3a_5 s5a_2a
	rename s3a_6 s5a_2b
	rename s3a_7 s5a_2c
	rename s3a_8 s5a_3a
	rename s3a_9 s5a_3b
	rename s3a_10 s5a_3c
	rename s3a_11 s5a_3d
	rename s3a_12 s5a_3e
	rename s3a_13 s5a_3f
	rename s3a_14 s5a_3g
	rename s3a_15 s5a_3h
	rename s3a_16 s5a_3i
	clonevar s3a_17=s3a_17_other
	rename s3a_17 s5a_4a
	rename s3a_18 s5a_4b
	rename s3a_19_ch_1 s5a_4c
	rename s3a_19_ch_2 s5a_4d
	rename s3a_19_ch_3 s5a_4e
	rename s3a_19_ch_4 s5a_4f
	rename s3a_19_ch_5 s5a_4g
	rename s3a_20_ch_1 s5a_4h
	rename s3a_20_ch_2 s5a_4i
	rename s3a_20_ch_3 s5a_4j
	rename s3a_20_ch_4 s5a_4k
	rename s3a_20_ch_5 s5a_4l
	rename s3b_1 s5b_1a
	rename s3b_2 s5b_1b
	rename s3b_3 s5b_2a
	rename s3b_4 s5b_2b
	rename s3b_6 s5b_3a
	rename s3b_match s5b_3b
	rename s3b_5 s5b_3c
	rename s3b_11 s5b_4a
	rename s3b_12 s5b_4b
	rename s3b_13 s5b_5a
	rename s3b_14 s5b_5b
	rename s3b_15 s5b_5c
	rename s3b_16 s5b_5d
	rename s4a_1 s6a_1a
	rename s4a_2 s6a_1b
	rename s4a_3 s6a_1c
	rename s4a_4 s6a_1d
	rename s4a_5 s6a_1e
	rename s4a_6 s6a_1f
	rename s4a_7 s6a_1g
	rename s4a_8 s6a_1h
	rename s4a_9 s6a_1i
	rename s4a_10 s6a_2a
	rename s4a_11 s6a_2b
	rename s4a_12 s6a_2c
	rename s4a_13 s6a_3a
	rename s4a_14 s6a_3b
	rename s4a_15 s6a_3c
	rename s4a_16 s6a_4a
	rename s4a_17 s6a_4b
	rename s4a_18 s6a_5a
	rename s4a_19 s6a_5b
	rename s4a_20 s6a_6a
	rename s4a_21 s6a_6b
	rename s4a_22 s6a_6c
	rename s4a_23 s6a_6d
	rename s4a_24 s6a_6e
	rename s4a_25 s6a_6f
	rename s4a_26 s6a_6g
	rename s4a_27 s6a_7a
	rename s4a_28 s6a_7b
	rename s4a_29 s6a_7c
	rename s4a_30 s6a_7d
	rename s4a_31 s6a_7e
	rename s4a_32 s6a_8a
	rename s4a_33 s6a_8b
	rename s4a_34 s6a_8c
	rename s4a_35 s6a_8d
	rename s4b_1 s6b_1a
	rename s4b_2 s6b_1b
	rename s4b_3 s6b_2a
	rename s4b_4 s6b_2b
	rename s4b_6 s6b_3a
	rename s4b_match s6b_3b
	rename s4b_5 s6b_3c
	rename s4b_11 s6b_4a
	rename s4b_12 s6b_4b
	rename s4b_13 s6b_5a
	rename s4b_14 s6b_5b
	rename s4b_15 s6b_5c
	rename s4b_16 s6b_5d
	rename s5a_1 s7a_1a
	rename s5a_2 s7a_1b
	rename s5a_3 s7a_1c
	rename s5a_4 s7a_1d
	rename s5a_5 s7a_2a
	rename s5a_6 s7a_2b
	rename s5a_7 s7a_3a
	rename s5a_8 s7a_3b
	rename s5a_9 s7a_3c
	rename s5a_10 s7a_3d
	rename s5a_11 s7a_3e
	rename s5b_1 s7b_1a
	rename s5b_2 s7b_1b
	rename s5b_3 s7b_2a
	rename s5b_4 s7b_2b
	rename s5b_6 s7b_3a
	rename s5b_match s7b_3b
	rename s5b_5 s7b_3c
	rename s5b_11 s7b_4a
	rename s5b_12 s7b_4b
	rename s5b_13 s7b_5a
	rename s5b_14 s7b_5b
	rename s5b_15 s7b_5c
	rename s5b_16 s7b_5d
	rename s6a_2 s8a_1a
	rename s6a_3 s8a_1b
	rename s6a_4 s8a_1c
	rename s6a_5 s8a_1d
	rename s6a_6 s8a_2a
	rename s6a_7 s8a_2b
	rename s6a_8 s8a_2c
	rename s6a_9 s8a_2d
	rename s6a_10 s8a_2e
	rename s6a_1_ch_3 s8a_2f
	rename s6a_11 s8a_2g
	rename s6a_12 s8a_2h
	rename s6a_13 s8a_3a
	rename s6a_14 s8a_3b
	rename s6a_15 s8a_3c
	rename s6a_16 s8a_3d
	rename s6a_17 s8a_3e
	rename s6a_18 s8a_3f
	rename s6a_19 s8a_3g
	rename s6a_20 s8a_3h
	rename s6a_21 s8a_3i
	rename s6a_22 s8a_3j
	rename s6a_23 s8a_3k
	rename s6a_24 s8a_3l
	rename s6a_25 s8a_4a
	rename s6a_26 s8a_4b
	rename s6a_27 s8a_5a
	rename s6a_28 s8a_5b
	rename s6a_29 s8a_5c
	rename s6b_1 s8b_1a
	rename s6b_2 s8b_1b
	rename s6b_3 s8b_2a
	rename s6b_4 s8b_2b
	rename s6b_6 s8b_3a
	rename s6b_match s8b_3b
	rename s6b_5 s8b_3c
	rename s6b_11 s8b_4a
	rename s6b_12 s8b_4b
	rename s6b_13 s8b_5a
	rename s6b_14 s8b_5b
	rename s6b_15 s8b_5c
	rename s6b_16 s8b_5d
	rename s7a_1_ch_1 s9a_1a1
	rename s7a_1_ch_2 s9a_1a2
	rename s7a_1_ch_3 s9a_1a3
	rename s7a_1_ch_4 s9a_1a4
	rename s7a_2_ch_1 s9a_2a1
	rename s7a_2_ch_2 s9a_2a2
	rename s7a_2_ch_3 s9a_2a3
	rename s7a_2_ch_4 s9a_2a4
	rename s7a_3 s9a_2b
	rename s7b_1 s9b_1a
	rename s7b_2 s9b_1b
	rename s7b_3 s9b_1c
	rename s7c_1 s9c_1a
	rename s7c_2 s9c_1b
	rename s7c_3 s9c_1c
	rename s7c_4 s9c_1d
	rename s7c_5 s9c_1e
	rename s7c_6 s9c_1f
	rename s7d_1 s9d_1a
	rename s7d_2 s9d_1b
	rename s7e_1 s9e_1a
	rename s7e_2 s9e_1b
	rename s7e_3 s9e_2a
	rename s7e_4 s9e_2b
	rename s7e_6 s9e_3a
	rename s7e_match s9e_3b
	rename s7e_5 s9e_3c
	rename s7e_11 s9e_4a
	rename s7e_12 s9e_4b
	rename s7e_13 s9e_5a
	rename s7e_14 s9e_5b
	rename s7e_15 s9e_5c
	rename s7e_16 s9e_5d
	rename s8a_1 s10a_2a
	rename s8a_3 s10a_2b
	rename s8a_4 s10a_3a
	rename s8a_5 s10a_3b
	rename s8a_6 s10a_4a
	rename s8a_7 s10a_4b
	rename s8a_8 s10a_5a
	rename s8b_2 s10b_1a
	rename s8b_3 s10b_1b
	rename s8b_4 s10b_2a
	rename s8b_5 s10b_2b
	rename s8b_6 s10b_3a
	rename s8b_7 s10b_4a
	rename s8b_8 s10b_4b
	rename s8c_1 s10c_1a
	rename s8b_1 s10d_1a
	rename s8d_1 s10d_1b
	rename s8d_2 s10d_1c
	rename s8d_3 s10d_1d
	rename s8d_4 s10d_1e
	rename s8d_5 s10d_1f
	rename v478 s10d_2a
	rename s8d_6 s10d_2b
	rename s8e_1 s10e_1a
	rename s8e_2 s10e_1b
	rename s8e_3 s10e_2a
	rename s8e_4 s10e_2b
	rename s8e_6 s10e_3a
	rename s8e_match s10e_3b
	rename s8e_5 s10e_3c
	rename s8e_11 s10e_4a
	rename s8e_12 s10e_4b
	rename s8e_13 s10e_5a
	rename s8e_14 s10e_5b
	rename s8e_15 s10e_5c
	rename s8e_16 s10e_5d
	rename s9a_1 s11a_1a
	rename s9a_2 s11a_2a
	rename s9a_3 s11a_3a
	rename s9a_4 s11a_4a
	rename s9a_5 s11a_5a
	rename s9b_1 s11b_1a
	rename s9b_2 s11b_1b
	rename s9b_3 s11b_1c
	rename s9b_4 s11b_2a
	rename s9b_5 s11b_3a
	rename s9b_6 s11b_4a
	rename s9b_7 s11b_4b
	rename s9b_8 s11b_4c
	rename s9b_9 s11b_4d
	rename s9c_1 s11c_1a
	rename s9c_2 s11c_1b
	rename s9c_3 s11c_2a
	rename s9c_4 s11c_2b
	rename s9c_5 s11c_3a
	rename s9d_1 s11d_1a
	rename s9d_2 s11d_1b
	rename s9d_3 s11d_2a
	rename s9d_4 s11d_2b
	rename s9d_5 s11d_3a
	rename s9d_6 s11d_3b
	rename s9d_7 s11d_4a
	rename s9d_8 s11d_4b
	rename s9d_9 s11d_4c
	rename s9d_10 s11d_4d
	rename s10a_1 s12a_1a
	rename s10a_2 s12a_1b
	rename s10a_3 s12a_1c
	rename s10a_4 s12a_1d
	rename s10a_5 s12a_1e
	rename s10a_6 s12a_1f
	rename s10a_7 s12a_1g
	rename s10a_8 s12a_2a
	rename s10a_9 s12a_2b
	rename s10a_10 s12a_2c
	rename s10a_11 s12a_2d
	rename s10a_12 s12a_2e
	rename s10a_13 s12a_2f
	rename s10a_14 s12a_2g
	rename s10a_15 s12a_2h
	rename s10a_16 s12a_2i
	rename s10a_17 s12a_2j
	rename s10b_1 s12b_1a
	rename s10b_2 s12b_1b
	rename s10b_3 s12b_1c
	rename s10b_4 s12b_1d
	rename s10b_5 s12b_1e
	rename s10b_6 s12b_1f
	rename s10b_7 s12b_1g
	rename s10b_8 s12b_1h
	rename s10c_1 s12c_1a
	rename s10c_2 s12c_1b
	rename s10c_3 s12c_1c
	rename s10c_4 s12c_1d
	rename s10d_1 s12d_1a
	rename s10d_2 s12d_1b
	rename s10d_3 s12d_1c
	rename s10d_4 s12d_1d
	rename s10d_5 s12d_1e
	rename s10d_6 s12d_1f
	rename s10d_7 s12d_1g
	rename s10d_8 s12d_2a
	rename s10d_9 s12d_2b
	rename s10e_2 s12e_1a
	rename s10e_3 s12e_1b
	rename s10e_4 s12e_1c
	rename s10e_5 s12e_1d
	rename s10e_6 s12e_1e
	rename s10e_7 s12e_1f
	rename s10e_8 s12e_2a
	rename s10e_9 s12e_2b
	rename s10e_10 s12e_2c
	rename s10e_11 s12e_2d
	rename s10e_12 s12e_2e
	rename s10e_13 s12e_3a
	rename s10e_14 s12e_3b
	rename s10f_1 s12f_1a
	rename s10f_2 s12f_1b
	rename s10f_3 s12f_2a
	rename s10f_4 s12f_2b
	rename s10f_6 s12f_3a
	rename s10f_match s12f_3b
	rename s10f_5 s12f_3c
	rename v635 s12f_4a
	rename s10f_11 s12f_4b
	rename s10f_12 s12f_5a
	rename s10f_13 s12f_5b
	rename s10f_14 s12f_5c
	rename s10f_15 s12f_5d

	lab var s3a_2a "Is a client service chart displayed?"
	lab var s3a_2b "Is it displayed in all key departments/areas? if charter displayed"
	lab var s4a_3a1 "Cleanliness: Very Dissatisfactory"
	lab var s4a_3a2 "Cleanliness: Dissatisfactory"
	lab var s4a_3a3 "Cleanliness: Satisfactory"
	lab var s4a_3a4 "Cleanliness: Very satisfactory"
	lab var s6b_1b "Does the hygiene protocol have a dedicated staff roster"
	lab var s9a_1a1 "Ventilation: Very Dissatisfactory"
	lab var s9a_1a2 "Ventilation: Dissatisfactory"
	lab var s9a_1a3 "Ventilation: Satisfactory"
	lab var s9a_1a4 "Ventilation: Very Satisfactory"
	lab var s9a_2a1 "Lighting: Very Dissatisfactory"
	lab var s9a_2a2 "Lighting: Dissatisfactory"
	lab var s9a_2a3 "Lighting: Satisfactory"
	lab var s9a_2a4 "Lighting: Very Satisfactory"

	** Amy didn't clean these variables in QPS2 --> Need to check with her
	replace s4a_3d = 0 if s4a_3d == 2
	replace s4a_3c = 0 if s4a_3c == 2

	* the var s10a_1a is not scored in the checklist and was no included in QPS2
	
	foreach x in labour wards theatre pharmacy lab radiology nutrition {
		replace `x'=. if `x'==0
		}

********************************************************************************

	** Part 4: Adherence variables 

******************************************************************************** 

	* Case I: No changes. Adherence variables are equal as original variables. No change was needed. 
	* s2c_3a: 16 observations missing because the HFs didn't answer both questions in QPS2: s1c_5 & s1c_6
	* s3c_2a s3c_2c: Inpatients variables remain the same 
	global dummies s2a_1a s2c_3d s2c_2b s2c_3a s2a_1e s2a_2a1 s2a_2a2	s2a_2a3	s2a_2a4	s2a_3a1	s2a_3a2	s2a_3a3	s2a_3a4	s2b_1a	s2b_1b	s2b_2a	s2b_3a	s2b_3b	s2c_1a	s2c_1b	s2c_2a	s2c_3b	s2c_3c	s2c_4a	s3a_1a	s3a_1b	s3a_1d	s3a_2a	s3a_3a	s3b_1a	s3b_2a	s3b_2b	s3b_2c	s3b_2d	s3b_3a	s3c_1a	s3c_2b	s3c_2c s3c_2d	s3c_4a	s3c_5a	s3d_1a	s3d_1b	s3d_2a	s3d_2b	s3d_2c	s4a_1a	s4a_1b	s4a_2a	s4a_2b	s4a_2c	s4a_3a1	s4a_3a2	s4a_3a3	s4a_3a4	s4a_3b	s4a_3c	s4a_3d	s4a_4a	s4a_4b	s4a_4c	s4b_1a	s4b_1b	s4b_1c	s4b_1d	s5a_1d	s5a_2a	s5a_2b	s5a_2c	s5a_3a	s5a_3b	s5a_3c	s5a_3d	s5a_3e	s5a_3f	s5a_3g	s5a_3h	s5a_3i	s5a_4h	s5a_4i	s5a_4j	s5a_4k	s5a_4l	s5b_1a	s5b_1b s5b_2a	s5b_2b	s5b_3a	s5b_3c	s5b_4a	s5b_4b	s5b_5a	s5b_5b	s5b_5c	s5b_5d	s6a_1a	s6a_1b	s6a_1c	s6a_1d	s6a_1e	s6a_1f	s6a_1g	s6a_1h	s6a_1i	s6a_2a	s6a_2b	s6a_2c	s6a_3a	s6a_4a	s6a_4b	s6a_5a	s6a_5b	s6a_6a	s6a_7a	s6a_7e	s6a_8a	s6b_1a	s6b_1b s6b_2a	s6b_2b	s6b_3a	s6b_3c	s6b_4a	s6b_4b	s6b_5a	s6b_5b	s6b_5c	s6b_5d	s7a_1a	s7a_1b	s7a_1c	s7a_1d	s7a_2a	s7a_2b	s7a_3a	s7a_3b	s7a_3c	s7a_3d	s7a_3e	s7b_1a	s7b_1b s7b_2a	s7b_2b	s7b_3a	s7b_3c	s7b_4a	s7b_4b	s7b_5a	s7b_5b	s7b_5c	s7b_5d	s8a_2f	s8a_2h	s8a_4a	s8a_4b	s8b_1a s8b_1b s8b_2a	s8b_2b	s8b_3a	s8b_3c	s8b_4a	s8b_4b	s8b_5a	s8b_5b	s8b_5c	s8b_5d	s9a_1a1	s9a_1a2	s9a_1a3	s9a_1a4	s9a_2a1	s9a_2a2	s9a_2a3	s9a_2a4	s9a_2b	s9b_1a	s9b_1b	s9b_1c	s9c_1a	s9c_1b	s9c_1c	s9c_1d	s9c_1e	s9c_1f	s9d_1a	s9e_1a	s9e_1b s9e_2a	s9e_2b	s9e_3a s9e_3c	s9e_4a	s9e_4b	s9e_5a	s9e_5b	s9e_5c	s9e_5d	s10a_2a	s10a_3a	s10a_4a	s10a_5a	s10b_1a	s10b_2a	s10b_2b	s10b_3a	s10b_4a	s10b_4b	s10c_1a	s10d_1a	s10d_1b	s10d_1c	s10d_1d	s10d_1e	s10d_1f	s10d_2a	s10d_2b	s10e_1a	s10e_1b s10e_2a	s10e_2b	s10e_3a	s10e_3c	s10e_4a	s10e_4b	s10e_5a	s10e_5b	s10e_5c	s10e_5d	s11a_1a	s11a_2a	s11a_3a	s11a_4a	s11a_5a	s11b_1a	s11b_1c	s11b_2a	s11b_3a	s11b_4a	s11b_4c	s11b_4d	s11c_1a	s11c_1b	s11d_2a	s11d_2b	s11d_3a	s11d_3b	s11d_4a	s11d_4b	s11d_4c	s11d_4d	s12a_1a	s12a_1b	s12a_1c	s12a_1d	s12a_1e	s12a_1f	s12a_1g	s12a_2a	s12a_2b	s12a_2c	s12a_2d	s12a_2e	s12a_2f	s12a_2g	s12a_2h	s12a_2i	s12a_2j	s12b_1a	s12b_1b	s12b_1c	s12b_1d	s12b_1e	s12b_1f	s12c_1a	s12c_1b	s12d_1a	s12d_1c	s12d_1d	s12d_1e	s12d_1f	s12d_1g	s12d_2a	s12d_2b	s12f_2a	s12f_2b	s12f_3a	s12f_3b	s12f_3c	s12f_4a	s12f_4b	s12f_5a	s12f_5b	s12f_5c	s12f_5d s11d_1a s11d_1b s12f_1a s12f_1b

	foreach var in $dummies {
		gen `var'_a = `var'
	}

	* Case II: Orange (as the excel file)
	global case2 s12b_1g s2a_1b s2a_1c s2a_1d s3a_1c s3a_2b	s3a_2c	s3a_2d	s3a_2e	s3a_2f	s3a_2g s3a_2h s3b_1b	s3b_3b	s3b_3c	s3c_1b	s3c_1c	s3c_2a s3c_3a	s5a_1a s5a_1b	s5a_1c	s5a_4a s5a_4b	s5a_4c	s5a_4d	s5a_4e	s5a_4f	s5a_4g	s5b_3b s6a_3b	s6a_3c	s6a_6b	s6a_6c	s6a_6d	s6a_6e	s6a_6f	s6a_6g	s6a_7b	s6a_7c	s6a_7d	s6a_8b	s6a_8c	s6a_8d	s6b_3b  s7b_3b s8b_3b s9d_1b s9e_3b s10a_2b	s10a_3b	s10a_4b	s10b_1b	s10e_3b s11b_1b	s11b_4b	s11c_2a	s11c_2b	s11c_3a	s12c_1c	s12c_1d	s12d_1b	s12e_1a	s12e_1b	s12e_1c	s12e_1d	s12e_1e	s12e_1f	s12e_2a	s12e_2b	s12e_2c	s12e_2d	s12e_2e	s12e_3a	s12e_3b s12b_1h

	foreach var in $case2 {
		gen `var'_a = `var'
	}

	replace s5a_4a_a=0 if s3a_17_other==0
	replace s5a_4a_a=0 if s3a_17b_other==0 & s3a_17_other==1
	replace s9d_1b_a = 0 if s9d_1b ==. & s9d_1a== 0
	replace s6a_8d_a = 0 if s6a_8d ==. & s6a_8a== 0
	replace s6a_8c_a = 0 if s6a_8c ==. & s6a_8a== 0
	replace s6a_8b_a = 0 if s6a_8b ==. & s6a_8a== 0
	replace s6a_7d_a = 0 if s6a_7d ==. & s6a_7a== 0
	replace s6a_7c_a = 0 if s6a_7c ==. & s6a_7a== 0
	replace s6a_7b_a = 0 if s6a_7b ==. & s6a_7a== 0
	replace s6a_6g_a = 0 if s6a_6g ==. & s6a_6a== 0
	replace s6a_6f_a = 0 if s6a_6f ==. & s6a_6a== 0
	replace s6a_6e_a = 0 if s6a_6e ==. & s6a_6a== 0
	replace s6a_6d_a = 0 if s6a_6d ==. & s6a_6a== 0
	replace s6a_6c_a = 0 if s6a_6c ==. & s6a_6a== 0
	replace s6a_6b_a = 0 if s6a_6b ==. & s6a_6a== 0
	replace s6a_3c_a = 0 if s6a_3c ==. & s6a_3a== 0
	replace s6a_3b_a = 0 if s6a_3b ==. & s6a_3a== 0
	replace s5a_4g_a= 0 if s5a_4g==. & s5a_4a==.
	replace  s5a_4f_a= 0 if s5a_4f==. & s5a_4a==.
	replace  s5a_4e_a= 0 if s5a_4e==. & s5a_4a==.
	replace  s5a_4d_a= 0 if s5a_4d==. & s5a_4a==. 
	replace s5a_4c_a= 0 if s5a_4c==. & s5a_4a==. 
	replace s5a_4b_a= 0 if s5a_4b==. & s5a_4a==. 
	replace s5a_1c_a=0 if s5a_1c==. &  s5a_1a==. 
	replace s5a_1b_a=0 if s5a_1b==. &  s5a_1a==.
	replace s5a_1a_a = 0 if s5a_1a_a == . 
	replace s3c_3a_a = 0 if s3c_3a ==. & s3c_1a== 0
	replace s3c_1c_a = 0 if s3c_1c ==. & s3c_1a== 0
	replace s3c_1b_a = 0 if s3c_1b ==. & s3c_1a== 0
	replace s3b_3c_a = 0 if s3b_3c ==. & s3b_3a== 0
	replace s3b_3b_a = 0 if s3b_3b ==. & s3b_3a== 0
	replace s3b_1b_a = 0 if s3b_1b ==. & s3b_1a== 0
	replace s3a_2g_a = 0 if s3a_2g ==. & s3a_2a== 0
	replace s3a_2f_a = 0 if s3a_2f ==. & s3a_2a== 0
	replace s3a_2h_a = 0 if s3a_2h ==. & s3a_2a== 0
	replace s3a_2e_a = 0 if s3a_2e ==. & s3a_2a== 0
	replace s3a_2d_a = 0 if s3a_2d ==. & s3a_2a== 0
	replace s3a_2c_a = 0 if s3a_2c ==. & s3a_2a== 0
	replace s3a_2b_a = 0 if s3a_2b ==. & s3a_2a== 0
	replace s3a_1c_a = 0 if s3a_1a == 0
	replace s3a_1b_a = 0 if s3a_1a == 0
	replace s3a_1c_a = 0 if s3a_1a == 0
	replace s2a_1d_a = 0 if s2a_1d ==. & s2a_1a== 0
	replace s2a_1c_a = 0 if s2a_1c ==. & s2a_1a== 0
	replace s2a_1b_a = 0 if s2a_1b ==. & s2a_1a== 0
	replace s12b_1g_a = 0 if s10b_g2_c<1 & nutrition==1
	replace s12b_1h_a = 0 if s10b_g2_c<1 & nutrition==1
	replace s12e_3b_a = 0 if s12e_3b ==. & s10e_1== 0
	replace s12e_3a_a = 0 if s12e_3a ==. & s10e_1== 0
	replace s12e_2e_a = 0 if s12e_2e ==. & s10e_1== 0
	replace s12e_2d_a = 0 if s12e_2d ==. & s10e_1== 0
	replace s12e_2c_a = 0 if s12e_2c ==. & s10e_1== 0
	replace s12e_2b_a = 0 if s12e_2b ==. & s10e_1== 0
	replace s12e_2a_a = 0 if s12e_2a ==. & s10e_1== 0
	replace s12e_1f_a = 0 if s12e_1f ==. & s10e_1== 0
	replace s12e_1e_a = 0 if s12e_1e ==. & s10e_1== 0
	replace s12e_1d_a = 0 if s12e_1d ==. & s10e_1== 0
	replace s12e_1c_a = 0 if s12e_1c ==. & s10e_1== 0
	replace s12e_1b_a = 0 if s12e_1b ==. & s10e_1== 0
	replace s12e_1a_a = 0 if s12e_1a ==. & s10e_1== 0
	replace s12d_1b_a=0 if s12d_1a==0
	replace s12c_1d_a = 0 if s12c_1d ==. & s12c_1a== 0
	replace s12c_1c_a = 0 if s12c_1c ==. & s12c_1a== 0
	replace s11c_3a_a = 0 if s11c_3a ==. & s11c_1a== 0
	replace s11c_2b_a = 0 if s11c_2b ==. & s11c_1a== 0
	replace s11c_2a_a = 0 if s11c_2a ==. & s11c_1a== 0
	replace s11b_4b_a = 0 if s11b_4b ==. & s11b_4a== 0
	replace s11b_1b_a = 0 if s11b_1b ==. & s11b_1a== 0
	replace s10b_1b_a = 0 if s10b_1b ==. & s10b_1a== 0
	replace s10a_4b_a = 0 if s10a_4b ==. & s10a_4a== 0
	replace s10a_3b_a = 0 if s10a_3b ==. & s10a_3a== 0
	replace s10a_2b_a = 0 if s10a_2b ==. & s10a_2a== 0

	replace s5b_3b_a = 0 if s5b_3b_a == . & consultation == 1
	replace s6b_3b_a = 0 if s6b_3b_a == . & labour == 1
	replace s7b_3b_a = 0 if s7b_3b_a == . & wards == 1
	replace s8b_3b_a = 0 if s8b_3b_a == . & theatre == 1
	replace s9e_3b_a = 0 if s9e_3b_a == . & pharmacy == 1
	replace s10e_3b_a = 0 if s10e_3b_a == . & lab == 1
	replace s12f_3b_a = 0 if s12f_3b_a == . & nutrition == 1

	** Case III: Yellow (as the excel file)
	global case3 s3b_2e	s3c_3b	s3c_3c	s3c_4b	s8a_1a	s8a_1b	s8a_1c	s8a_1d	s8a_2a	s8a_2b	s8a_2c	s8a_2d	s8a_2e	s8a_2g	s8a_3a	s8a_3b	s8a_3c	s8a_3d	s8a_3e	s8a_3f	s8a_3g	s8a_3h	s8a_3i	s8a_3j	s8a_3k	s8a_3l	s8a_5a	s8a_5b	s8a_5c
	
	foreach var in $case3 {
		gen `var'_a = `var'
	}

	replace s3b_2e_a= 0 if s3b_2a==0 | s3b_2b==0 | s3b_2c==0 | s3b_2d==0
	replace s3c_3b_a=0 if s3c_1a==0 | s3c_3a==0
	replace s3c_3c_a=0 if s3c_1a==0 | s3c_3a==0
	replace s3c_4b_a=0 if s3c_1a==0 | s3c_3a==0

	** Amy added this conditions in QPS2 before the merging. 
	/*
	replace s8a_1a_a = 0 if s6a_1_ch_1 == 0 
	replace s8a_1b_a = 0 if s6a_1_ch_1 == 0
	replace s8a_1c_a = 0 if s6a_1_ch_1 == 0
	replace s8a_1d_a = 0 if s6a_1_ch_1 == 0
	replace s8a_2a_a = 0 if s6a_1_ch_2 == 0
	replace s8a_2b_a = 0 if s6a_1_ch_2 == 0
	replace s8a_2c_a = 0 if s6a_1_ch_2 == 0
	replace s8a_2d_a = 0 if s6a_1_ch_2 == 0
	replace s8a_2e_a = 0 if s6a_1_ch_2 == 0
	replace s8a_2f_a = 0 if s6a_1_ch_2 == 0
	// s8a_2g_a is filter with s8a_2f_a
	replace s8a_2g_a = 0 if s8a_2f == 0
	replace s8a_3a_a = 0 if s6a_1_ch_4 == 0
	replace s8a_3b_a = 0 if s6a_1_ch_4 == 0
	replace s8a_3c_a = 0 if s6a_1_ch_4 == 0
	replace s8a_3d_a = 0 if s6a_1_ch_4 == 0 
	replace s8a_3e_a = 0 if s6a_1_ch_4 == 0
	replace s8a_3f_a = 0 if s6a_1_ch_4 == 0
	replace s8a_3g_a = 0 if s6a_1_ch_4 == 0
	replace s8a_3h_a = 0 if s6a_1_ch_4 == 0
	replace s8a_3i_a = 0 if s6a_1_ch_4 == 0
	replace s8a_3j_a = 0 if s6a_1_ch_4 == 0
	replace s8a_3k_a = 0 if s6a_1_ch_4 == 0
	replace s8a_3l_a = 0 if s6a_1_ch_4 == 0
	replace s8a_5a_a = 0 if s6a_1_ch_5 == 0
	replace s8a_5b_a = 0 if s6a_1_ch_5 == 0
	replace s8a_5c_a = 0 if s6a_1_ch_5 == 0
	*/
	replace s12b_1h_a = 0 if s10b_g2_c < 1 & nutrition == 1


	* Amy's changes 

	* L4 only questions
	replace s2c_3d_a=0 if s1c_5_other==0
	replace s2c_2b_a=0 if s2c_2a==0 & [level==4 | level==5] 
	//replace s2c_2b_a=. if a5==11976
	

	* Inpatient questions

	replace s3c_2b_a = 0 if s3c_2b_a == . & nutrition == 1 
	replace s3c_2b_a = . if s3c_2b_a !=. & nutrition!=1

	replace s3c_2c_a = 0 if s3c_2c_a==. & nutrition==1 
	replace s3c_2c_a =. if s3c_2c_a!=. & nutrition!=1
	

	** Modify adherence variables for special questions
	replace s2a_2a1_a = . if s2a_2a1_a == 0 & (s2a_2a2_a == 1 | s2a_2a3_a == 1 | s2a_2a4_a == 1)
	replace s2a_2a2_a = . if s2a_2a2_a == 0 & (s2a_2a1_a == 1 | s2a_2a3_a == 1 | s2a_2a4_a == 1)
	replace s2a_2a3_a = . if s2a_2a3_a == 0 & (s2a_2a1_a == 1 | s2a_2a2_a == 1 | s2a_2a4_a == 1)
	replace s2a_2a4_a = . if s2a_2a4_a == 0 & (s2a_2a1_a == 1 | s2a_2a2_a == 1 | s2a_2a3_a == 1)
	
	replace s2a_3a1_a = . if s2a_3a1_a == 0 & (s2a_3a2_a == 1 | s2a_3a3_a == 1 | s2a_3a4_a == 1)
	replace s2a_3a2_a = . if s2a_3a2_a == 0 & (s2a_3a1_a == 1 | s2a_3a3_a == 1 | s2a_3a4_a == 1)
	replace s2a_3a3_a = . if s2a_3a3_a == 0 & (s2a_3a1_a == 1 | s2a_3a2_a == 1 | s2a_3a4_a == 1)
	replace s2a_3a4_a = . if s2a_3a4_a == 0 & (s2a_3a1_a == 1 | s2a_3a2_a == 1 | s2a_3a3_a == 1)
	
	replace s4a_3a1_a = . if s4a_3a1_a == 0 & (s4a_3a2_a == 1 | s4a_3a3_a == 1 | s4a_3a4_a == 1)
	replace s4a_3a2_a = . if s4a_3a2_a == 0 & (s4a_3a1_a == 1 | s4a_3a3_a == 1 | s4a_3a4_a == 1)
	replace s4a_3a3_a = . if s4a_3a3_a == 0 & (s4a_3a1_a == 1 | s4a_3a2_a == 1 | s4a_3a4_a == 1)
	replace s4a_3a4_a = . if s4a_3a4_a == 0 & (s4a_3a1_a == 1 | s4a_3a2_a == 1 | s4a_3a3_a == 1)

	replace s9a_1a1_a = . if s9a_1a1_a == 0 & (s9a_1a2_a == 1 | s9a_1a3_a == 1 | s9a_1a4_a == 1)
	replace s9a_1a2_a = . if s9a_1a2_a == 0 & (s9a_1a1_a == 1 | s9a_1a3_a == 1 | s9a_1a4_a == 1)
	replace s9a_1a3_a = . if s9a_1a3_a == 0 & (s9a_1a1_a == 1 | s9a_1a2_a == 1 | s9a_1a4_a == 1)
	replace s9a_1a4_a = . if s9a_1a4_a == 0 & (s9a_1a1_a == 1 | s9a_1a2_a == 1 | s9a_1a3_a == 1)

	replace s9a_2a1_a = . if s9a_2a1_a == 0 & (s9a_2a2_a == 1 | s9a_2a3_a == 1 | s9a_2a4_a == 1)
	replace s9a_2a2_a = . if s9a_2a2_a == 0 & (s9a_2a1_a == 1 | s9a_2a3_a == 1 | s9a_2a4_a == 1)
	replace s9a_2a3_a = . if s9a_2a3_a == 0 & (s9a_2a1_a == 1 | s9a_2a2_a == 1 | s9a_2a4_a == 1)
	replace s9a_2a4_a = . if s9a_2a4_a == 0 & (s9a_2a1_a == 1 | s9a_2a2_a == 1 | s9a_2a3_a == 1)
	
	gen s2a_2a_a = s2a_2a1_a*0 if  s2a_2a1_a == 1
	replace s2a_2a_a = (s2a_2a2_a*(1/3)) if s2a_2a2_a == 1
	replace s2a_2a_a = (s2a_2a3_a*(2/3)) if s2a_2a3_a == 1
	replace s2a_2a_a = (s2a_2a4_a*1) if s2a_2a4_a == 1
	
	*br s2a_2a1_a s2a_2a2_a s2a_2a3_a s2a_2a4_a s2a_2a_a
	
	gen s2a_3a_a = s2a_3a1_a*0 if  s2a_3a1_a == 1
	replace s2a_3a_a = (s2a_3a2_a*(1/3)) if s2a_3a2_a == 1
	replace s2a_3a_a = (s2a_3a3_a*(2/3)) if s2a_3a3_a == 1
	replace s2a_3a_a = (s2a_3a4_a*1) if s2a_3a4_a == 1

	*br s2a_3a1_a s2a_3a2_a s2a_3a3_a s2a_3a4_a s2a_3a_a
	
	gen s4a_3a_a = s4a_3a1_a*0 if  s4a_3a1_a == 1
	replace s4a_3a_a = (s4a_3a2_a*(1/6)) if s4a_3a2_a == 1
	replace s4a_3a_a = (s4a_3a3_a*(1/3)) if s4a_3a3_a == 1
	replace s4a_3a_a = (s4a_3a4_a*1) if s4a_3a4_a == 1

	*br s4a_3a1_a s4a_3a2_a s4a_3a3_a s4a_3a4_a s4a_3a_a
	
	gen s9a_1a_a = s9a_1a1_a*0 if  s9a_1a1_a == 1
	replace s9a_1a_a = (s9a_1a2_a*(1/3)) if s9a_1a2_a == 1
	replace s9a_1a_a = (s9a_1a3_a*(2/3)) if s9a_1a3_a == 1
	replace s9a_1a_a = (s9a_1a4_a*1) if s9a_1a4_a == 1
	
	*br s9a_1a1_a s9a_1a2_a s9a_1a3_a s9a_1a4_a s9a_1a_a
	
	gen s9a_2a_a = s9a_2a1_a*0 if  s9a_2a1_a == 1
	replace s9a_2a_a = (s9a_2a2_a*(1/6)) if s9a_2a2_a == 1
	replace s9a_2a_a = (s9a_2a3_a*(1/3)) if s9a_2a3_a == 1
	replace s9a_2a_a = (s9a_2a4_a*1) if s9a_2a4_a == 1

	*br s9a_2a1_a s9a_2a2_a s9a_2a3_a s9a_2a4_a s9a_2a_a
	
	** Question s11c_1b should be filtered by question s11c_1a, but it wasn't. So, in terms of adherence we should filtered in that way
	replace s11c_1b_a = . if s11c_1a_a == 0
	replace s11c_2a_a = . if s11c_1a_a == 0
	replace s11c_2b_a = . if s11c_1a_a == 0
	replace s11c_3a_a = . if s11c_1a_a == 0	

	global adherence s2a_1a_a	s2a_1b_a	s2a_1c_a	s2a_1d_a	s2a_1e_a	s2a_2a1_a	s2a_2a2_a	s2a_2a3_a	s2a_2a4_a	s2a_2a_a s2a_3a1_a	s2a_3a2_a	s2a_3a3_a	s2a_3a4_a	s2a_3a_a s2b_1a_a	s2b_1b_a	s2b_2a_a	s2b_3a_a	s2b_3b_a	s2c_1a_a	s2c_1b_a	s2c_2a_a	s2c_2b_a	s2c_3a_a	s2c_3b_a	s2c_3c_a	s2c_3d_a	s2c_4a_a	s3a_1a_a	s3a_1b_a	s3a_1c_a	s3a_1d_a	s3a_2a_a	s3a_2b_a	s3a_2c_a	s3a_2d_a	s3a_2e_a	s3a_2f_a	s3a_2g_a	s3a_3a_a	s3b_1a_a	s3b_1b_a	s3b_2a_a	s3b_2b_a	s3b_2c_a	s3b_2d_a	s3b_2b_a	s3b_3a_a	s3b_3b_a	s3b_3c_a	s3c_1a_a	s3c_1b_a	s3c_1c_a	s3c_2a_a	s3c_2b_a	s3c_2c_a	s3c_2d_a	s3c_3a_a	s3c_3b_a	s3c_3c_a	s3c_4a_a	s3c_4b_a	s3c_5a_a	s3d_1a_a	s3d_1b_a	s3d_2a_a	s3d_2b_a	s3d_2c_a	s4a_1a_a	s4a_1b_a	s4a_2a_a	s4a_2b_a	s4a_2c_a	s4a_3a1_a	s4a_3a2_a	s4a_3a3_a	s4a_3a4_a s4a_3a_a	s4a_3b_a	s4a_3c_a	s4a_3d_a	s4a_4a_a	s4a_4b_a	s4a_4c_a	s4b_1a_a	s4b_1b_a	s4b_1c_a	s4b_1d_a	s5a_1a_a	s5a_1b_a	s5a_1c_a	s5a_1d_a	s5a_2a_a	s5a_2b_a	s5a_2c_a	s5a_3a_a	s5a_3b_a	s5a_3c_a	s5a_3d_a	s5a_3e_a	s5a_3f_a	s5a_3g_a	s5a_3h_a	s5a_3i_a	s5a_4a_a	s5a_4b_a	s5a_4c_a	s5a_4d_a	s5a_4e_a	s5a_4f_a	s5a_4g_a	s5a_4h_a	s5a_4i_a	s5a_4j_a	s5a_4k_a	s5a_4l_a	s5b_1a_a	s5a_1b_a s5b_2a_a	s5b_2b_a	s5b_3a_a	s5b_3b_a	s5b_3c_a	s5b_4a_a	s5b_4b_a	s5b_5a_a	s5b_5b_a	s5b_5c_a	s5b_5d_a	s6a_1a_a	s6a_1b_a	s6a_1c_a	s6a_1d_a	s6a_1e_a	s6a_1f_a	s6a_1g_a	s6a_1h_a	s6a_1i_a	s6a_2a_a	s6a_2b_a	s6a_2c_a	s6a_3a_a	s6a_3b_a	s6a_3c_a	s6a_4a_a	s6a_4b_a	s6a_5a_a	s6a_5b_a	s6a_6a_a	s6a_6b_a	s6a_6c_a	s6a_6d_a	s6a_6e_a	s6a_6f_a	s6a_6g_a	s6a_7a_a	s6a_7b_a	s6a_7c_a	s6a_7d_a	s6a_7e_a	s6a_8a_a	s6a_8b_a	s6a_8c_a	s6a_8d_a	s6b_1a_a	s6b_1b_a s6b_2a_a	s6b_2b_a	s6b_3a_a	s6b_3b_a	s6b_3c_a	s6b_4a_a	s6b_4b_a	s6b_5a_a	s6b_5b_a	s6b_5c_a	s6b_5d_a	s7a_1a_a	s7a_1b_a	s7a_1c_a	s7a_1d_a	s7a_2a_a	s7a_2b_a	s7a_3a_a	s7a_3b_a	s7a_3c_a	s7a_3d_a	s7a_3e_a	s7b_1a_a	s7b_1b_a s7b_2a_a	s7b_2b_a	s7b_3a_a	s7b_3b_a	s7b_3c_a	s7b_4a_a	s7b_4b_a	s7b_5a_a	s7b_5b_a	s7b_5c_a	s7b_5d_a	s8a_1a_a	s8a_1b_a	s8a_1c_a	s8a_1d_a	s8a_2a_a	s8a_2b_a	s8a_2c_a	s8a_2d_a	s8a_2e_a	s8a_2f_a	s8a_2g_a	s8a_2h_a	s8a_3a_a	s8a_3b_a	s8a_3c_a	s8a_3d_a	s8a_3e_a	s8a_3f_a	s8a_3g_a	s8a_3h_a	s8a_3i_a	s8a_3j_a	s8a_3k_a	s8a_3l_a	s8a_4a_a	s8a_4b_a	s8a_5a_a	s8a_5b_a	s8a_5c_a	s8b_1a_a	s8b_1b_a s8b_2a_a	s8b_2b_a	s8b_3a_a	s8b_3b_a	s8b_3c_a	s8b_4a_a	s8b_4b_a	s8b_5a_a	s8b_5b_a	s8b_5c_a	s8b_5d_a	s9a_1a1_a	s9a_1a2_a	s9a_1a3_a	s9a_1a4_a	s9a_1a_a s9a_2a1_a	s9a_2a2_a	s9a_2a3_a	s9a_2a4_a	s9a_2a_a s9a_2b_a	s9b_1a_a	s9b_1b_a	s9b_1c_a	s9c_1a_a	s9c_1b_a	s9c_1c_a	s9c_1d_a	s9c_1f_a	s9c_1e_a	s9d_1a_a	s9d_1b_a	s9e_1a_a s9e_1b_a s9e_2a_a	s9e_2b_a	s9e_3a_a	s9e_3b_a	s9e_3c_a	s9e_4a_a	s9e_4b_a	s9e_5a_a	s9e_5b_a	s9e_5c_a	s9e_5d_a	s10a_2a_a	s10a_2b_a	s10a_3a_a	s10a_3b_a	s10a_4a_a	s10a_4b_a	s10a_5a_a	s10b_1a_a	s10b_1b_a	s10b_2a_a	s10b_2b_a	s10b_3a_a	s10b_4a_a	s10b_4b_a	s10c_1a_a	s10d_1a_a	s10d_1b_a	s10d_1c_a	s10d_1d_a	s10d_1e_a	s10d_1f_a	s10d_2a_a	s10d_2b_a	s10e_1a_a	s10e_1b_a s10e_2a_a	s10e_2b_a	s10e_3a_a	s10e_3b_a	s10e_3c_a	s10e_4a_a	s10e_4b_a	s10e_5a_a	s10e_5b_a	s10e_5c_a	s10e_5d_a	s11a_1a_a	s11a_2a_a	s11a_3a_a	s11a_4a_a	s11a_5a_a	s11b_1a_a	s11b_1b_a	s11b_1c_a	s11b_2a_a	s11b_3a_a	s11b_4a_a	s11b_4b_a	s11b_4c_a	s11b_4d_a	s11c_1a_a	s11c_1b_a	s11c_2a_a	s11c_2b_a	s11c_3a_a s11d_1a_a s11d_1b_a s11d_2a_a	s11d_2b_a	s11d_3a_a	s11d_3b_a	s11d_4a_a	s11d_4b_a	s11d_4c_a	s11d_4d_a	s12a_1a_a	s12a_1b_a	s12a_1c_a	s12a_1d_a	s12a_1e_a	s12a_1f_a	s12a_1g_a	s12a_2a_a	s12a_2b_a	s12a_2c_a	s12a_2d_a	s12a_2e_a	s12a_2f_a	s12a_2g_a	s12a_2h_a	s12a_2i_a	s12a_2j_a	s12b_1a_a	s12b_1b_a	s12b_1c_a	s12b_1d_a	s12b_1e_a	s12b_1f_a	s12b_1g_a	s12b_1h_a	s12c_1a_a	s12c_1b_a	s12c_1c_a	s12c_1d_a	s12d_1a_a	s12d_1b_a	s12d_1c_a	s12d_1d_a	s12d_1e_a	s12d_1f_a	s12d_1g_a	s12d_2a_a	s12d_2b_a	s12e_1a_a	s12e_1b_a	s12e_1c_a	s12e_1d_a	s12e_1e_a	s12e_1f_a	s12e_2a_a	s12e_2b_a	s12e_2c_a	s12e_2d_a	s12e_2e_a	s12e_3a_a	s12e_3b_a	s12f_1a_a	s12f_1b_a s12f_2a_a	s12f_2b_a	s12f_3a_a	s12f_3b_a	s12f_3c_a	s12f_4a_a	s12f_4b_a	s12f_5a_a	s12f_5b_a	s12f_5c_a	s12f_5d_a

	* Labeling variables 
	lab var s2a_1a_a "Does the facility display legible signage?"
	lab var s2a_1b_a "Does HF display signage that is accurateif signage?"
	lab var s2a_1c_a "Does the signage outside the HF include the facility name if signage?"
	lab var s2a_1d_a "Does the signage inside the HF include department names & direction if signage?"
	lab var s2a_1e_a "Does the facility have an accessibility ramp for disabled/wheelchair patients?"
	lab var s2a_2a1_a "Adequate ventilation: Very dissatisfactory"
	lab var s2a_2a2_a "Adequate ventilation: Dissatisfactory"
	lab var s2a_2a3_a "Adequate ventilation: Satisfactory"
	lab var s2a_2a4_a "Adequate ventilation: Very Satisfactory"
	lab var s2a_2a_a  "Adequate ventilation"
	lab var s2a_3a1_a "Adequate lighting: Very Dissatisfactory"
	lab var s2a_3a2_a "Adequate lighting: Dissatisfactory"
	lab var s2a_3a3_a "Adequate lighting: Satisfactory"
	lab var s2a_3a4_a "Adequate lighting: Very Satisfactory"
	lab var s2a_3a_a  "Adequate lighting"
	lab var s2b_1a_a "Is safe, clean water available from a tap or container?"
	lab var s2b_1b_a "Is there sufficient storage for the water?"
	lab var s2b_2a_a "Is there a stable source of power?"
	lab var s2b_3a_a "Are clean toilets available for both male and female clients?"
	lab var s2b_3b_a "Is there a cleaning roster displayed?"
	lab var s2c_1a_a "Does the facility have a lockable door?"
	lab var s2c_1b_a "Is the door secured with grills or another security mechanism?"
	lab var s2c_2a_a "Does the facility have a fire control mechanism such as a fire extinguisher, sand buckets?"
	lab var s2c_2b_a "Is the equipment available in the reception area as well as specific departments? if L4/L5"
	lab var s2c_3a_a "Does the facility have a fire assembly point or fire assembly protocol? if L4/L5"
	lab var s2c_3b_a "Is there a documented firefighting protocol?"
	lab var s2c_3c_a "Does the facility display emergency exit?"
	lab var s2c_3d_a "Does the facility display fire assembly point signage? if L4/L5 & assembly signage"
	lab var s2c_4a_a "Is there a security system present (e.g. security guard, alarm system)?"
	lab var s3a_1a_a "Does the facility have a strategic plan with its vision, values, and objectives?"
	lab var s3a_1b_a "Is the plan displayed and shared to all staff? if strategic plan" 
	lab var s3a_1c_a "Does the facility have an annual work plan or a business plan?"
	lab var s3a_1d_a "Is there an organizational chart available and approved by management?"
	lab var s3a_2a_a "Is a client service charter displayed?"
	lab var s3a_2b_a "Is it displayed in all key departments/areas? if charter displayed"
	lab var s3a_2c_a "Mention common services offered? if charter displayed"
	lab var s3a_2d_a "Mention obligations to clients? if charter displayed"
	lab var s3a_2e_a "Mention waiting times for clients? if charter displayed"
	lab var s3a_2f_a "Mention ways to communicate with management regarding problems? if charter displ"
	lab var s3a_2g_a "Mention services offered for free if charter displayed"
	lab var s3a_2h_a "Does the facility have a regular performance review for the charter targets?"
	lab var s3a_3a_a "Does the facility have a list of all staff with qualifications and job descripti"
	lab var s3b_1a_a "Does the facility have a quality improvement team?"
	lab var s3b_1b_a "Are there minutes for the last meeting (ask for a sample)?"
	lab var s3b_2a_a "Infant mortality"
	lab var s3b_2b_a "Maternal mortality"
	lab var s3b_2c_a "Immunization"
	lab var s3b_2d_a "Notifiable diseases"
	lab var s3b_2e_a "Are performance indicators shared with staff and published regularly?"
	lab var s3b_3a_a "Is there a functional feedback mechanism, such as a suggestion box, hotline numb"
	lab var s3b_3b_a "Is client feedback reviewed at least biweekly? if feedback"
	lab var s3b_3c_a "Are client suggestions documented in a report? if feedback"
	lab var s3c_1a_a "Are medical records kept for each patient?"
	lab var s3c_1b_a "Do the records include names and unique patient numbers? if records"
	lab var s3c_1c_a "Are all the records legible and signed?  if records"
	lab var s3c_2a_a "Are outpatient registers kept?"
	lab var s3c_2b_a "Are inpatient registers kept? if inpatient services" 
	lab var s3c_2c_a "Are inpatient and outpatient records kept separately?"
	lab var s3c_2d_a "Are the registers up to date?"
	lab var s3c_3a_a "Is there a system in place for storing medical records? if records"
	lab var s3c_3b_a "Is there a filing and numbering system for easy retrieval? if records & system"
	lab var s3c_3c_a "Are the records protected in cabinets (if paper) or by password (if digital)?"
	lab var s3c_4a_a "Does a system exist for keeping facility data?"
	lab var s3c_4b_a "Does the system for storing medical records have off-site backup functionality?"
	lab var s3c_5a_a "Does the facility contribute to the DHIS?"
	lab var s3d_1a_a "Is there a service contract for maintenance?"
	lab var s3d_1b_a "Is there a written schedule (including next service date) for maintaining equipm"
	lab var s3d_2a_a "Is there a written calibration schedule available at the area where equipment is"
	lab var s3d_2b_a "Is there a document showing regular calibration?"
	lab var s3d_2c_a "Are contracts available at the facility administration?"
	lab var s4a_1a_a "Does the facility have a hygiene protocol?"
	lab var s4a_1b_a "Does the facility have a dedicated staff roster for cleaning?"
	lab var s4a_2a_a "Is there a standard operating procedure for waste management?"
	lab var s4a_2b_a "Is there an incinerator or contracted waste management company?"
	lab var s4a_2c_a "Does the facility have a waste holding area?"
	lab var s4a_3a1_a "Facility cleanliness: Very dissatisfactory"
	lab var s4a_3a2_a "Facility cleanliness: Dissatisfactory"
	lab var s4a_3a3_a "Facility cleanliness: Satisfactory"
	lab var s4a_3a4_a "Facility cleanliness: Very Satisfactory"
	lab var s4a_3a_a  "HF cleanliness"	
	lab var s4a_3b_a "Is the paint work acceptable?"
	lab var s4a_3c_a "Is the floor smooth?"
	lab var s4a_3d_a "Is the ceiling free of cobwebs and dust?"
	lab var s4a_4a_a "Is the grass well maintained?"
	lab var s4a_4b_a "Are the bushes neatly kept?"
	lab var s4a_4c_a "Is the site free of odor?"
	lab var s4b_1a_a "Is there a separate area for cleaning with decontamination and sterilization processes?"
	lab var s4b_1b_a "Are standard operating procedures available for sterilization?"
	lab var s4b_1c_a "Is there storage available for sterile supplies?"
	lab var s4b_1d_a "Are sterile supplies labeled and stored in a designated area?"
	lab var s5a_1a_a "Does the facility have a triage area with a qualified nurse(s)?"
	lab var s5a_1b_a "Is it located at the first point of contact with patients? if triage"
	lab var s5a_1c_a "Is there a standard operating procedure for triage? if triage"
	lab var s5a_1d_a "Is there a system for coding patients?"
	lab var s5a_2a_a "Does the examination room have a coach and a mackintosh?"
	lab var s5a_2b_a "Does the room have a consultation table with at least two chairs?"
	lab var s5a_2c_a "Does the room have a pedal bin and stepper?"
	lab var s5a_3a_a "Is a thermometer available?"
	lab var s5a_3b_a "Is a stethoscope available?"
	lab var s5a_3c_a "Is a tongue depressor available?"
	lab var s5a_3d_a "Is a weighing scale available/accessible?"
	lab var s5a_3e_a "Is a blood pressure (BP) machine available/accessible?"
	lab var s5a_3f_a "Is a torch available?"
	lab var s5a_3g_a "Is a privacy screen available?"
	lab var s5a_3h_a "Is a diagnostic set available?"
	lab var s5a_3i_a "Is a lamp available?"
	lab var s5a_4a_a "Does the facility have an emergency tray available at designated sites?"
	lab var s5a_4b_a "Is there a checklist for regular review and updates to the emergency tray? if emerg tray"
	lab var s5a_4c_a "Glucose if emerg tray"
	lab var s5a_4d_a "Adrenaline if emerg tray"
	lab var s5a_4e_a "Sodium bicarbonate if emerg tray"
	lab var s5a_4f_a "Diazepam if emerg tray"
	lab var s5a_4g_a "Phenobarbitone if emerg tray"
	lab var s5a_4h_a "Ambu bag and mask available in pediatric and adult sizes"
	lab var s5a_4i_a "Adjustable bed  "
	lab var s5a_4j_a "Functional suction machine"
	lab var s5a_4k_a "Oxygen cylinder and flowmeter, or piped oxygen"
	lab var s5a_4l_a "Endotracheal tubes"
	lab var s5b_1a_a "Is there a hygiene protocol?"
	lab var s5b_1b_a "Does the hygiene protocol have a dedicated staff roster?"
	lab var s5b_2a_a "Is a sink present with running water from a tap or modified storage container?"
	lab var s5b_2b_a "Is soap available at the hand washing area?"
	lab var s5b_3a_a "Are there at least two color-coded bins (red, black and/or yellow)?"
	lab var s5b_3b_a "Are there coded lining bags that match the color of the bins?"
	lab var s5b_3c_a "Are there standard operating procedures for waste management?"
	lab var s5b_4a_a "Is there disinfectant readily available in the consultation room?"
	lab var s5b_4b_a "Are you able to observe disinfectant containers used for cleaning?"
	lab var s5b_5a_a "Are gloves available?"
	lab var s5b_5b_a "Are gowns or dust coats available?"
	lab var s5b_5c_a "Are face masks available?"
	lab var s5b_5d_a "Are safety boots available?"
	lab var s6a_1a_a "Is there privacy in the ward (privacy during delivery)?"
	lab var s6a_1b_a "Is a delivery bed available?"
	lab var s6a_1c_a "Is a sterile delivery set available?"
	lab var s6a_1d_a "Is a vacuum extractor available?"
	lab var s6a_1e_a "Is a suction machine available?"
	lab var s6a_1f_a "Is an ambu bag and mask available?"
	lab var s6a_1g_a "Is a cord ligature available?"
	lab var s6a_1h_a "Is there sufficient lighting?"
	lab var s6a_1i_a "Are maintenance plans available for all equipment?"
	lab var s6a_2a_a "Is the floor appropriately covered (e.g. ceramic tiles or terrazzo)?"
	lab var s6a_2b_a "Is there a drainage system?"
	lab var s6a_2c_a "Is there a cleaning chart?"
	lab var s6a_3a_a "Does the labour ward have oxygen cylinder or piped oxygen connection?"
	lab var s6a_3b_a "Are there standard operating procedures for oxygen?"
	lab var s6a_3c_a "Is there a maintenance plan for oxygen?"
	lab var s6a_4a_a "Are there procedures available for handling obstructed labour, foetal distress, eclampsia and APH/PPH/HELLP?"
	lab var s6a_4b_a "Is a functional resusitaire available with oxygen, suction machine and ambu bags?"
	lab var s6a_5a_a "Is an ambulance (or contact details) available?"
	lab var s6a_5b_a "Is a fully equipped theatre near the labour ward?"
	lab var s6a_6a_a "Is a partograph available?"
	lab var s6a_6b_a "Is contraction properly charted?"
	lab var s6a_6c_a "Is cervical dilation recorded?"
	lab var s6a_6d_a "Is color coding done?"
	lab var s6a_6e_a "Is TPR/BP recorded?"
	lab var s6a_6f_a "Is urine output/input charted?"
	lab var s6a_6g_a "Are drugs coded?"
	lab var s6a_7a_a "Is a functional incubator available?"
	lab var s6a_7b_a "Does the incubator have a temperature regulator? if incubator"
	lab var s6a_7c_a "Does the incubator have an oxygen connection? if incubator"
	lab var s6a_7d_a "Are maintenance plans available for the incubator? if incubator"
	lab var s6a_7e_a "Is there a sitting area for nursing mothers?"
	lab var s6a_8a_a "Is a sluice room with a sluicing sink available?"
	lab var s6a_8b_a "Does the sluice room have running water? if sluice room"
	lab var s6a_8c_a "Does it have a decontamination bucket? if sluice room"
	lab var s6a_8d_a "Are standard operating procedures available? if sluice room"
	lab var s6b_1a_a "Is there a hygiene protocol?"
	lab var s6b_1b_a "Does that hygiene protocol have a dedicated staff roster available?"
	lab var s6b_2a_a "Is a sink present with running water from a tap or modified storage container?"
	lab var s6b_2b_a "Is soap available at the handwashing area?"
	lab var s6b_3a_a "Are there at least two color-coded bins (red, black and/or yellow)?"
	lab var s6b_3b_a "Are there coded lining bags that match the color of the bins?"
	lab var s6b_3c_a "Are there standard operating procedures for waste management?"
	lab var s6b_4a_a "Is there evidence of disinfectant use?"
	lab var s6b_4b_a "Are you able to observe disinfectant containers used for cleaning?"
	lab var s6b_5a_a "Are gloves available?"
	lab var s6b_5b_a "Are gowns or dust coats available?"
	lab var s6b_5c_a "Are face masks available?"
	lab var s6b_5d_a "Are safety boots available?"
	lab var s7a_1a_a "Are admissions procedures standardized with patient categorizations?"
	lab var s7a_1b_a "Are patients in hospital uniform?"
	lab var s7a_1c_a "Are there regular ward rounds?"
	lab var s7a_1d_a "Are there handover and discharge reports on a standard form?"
	lab var s7a_2a_a "Are patient records kept with unique reference numbers?"
	lab var s7a_2b_a "Is the filing system secure?"
	lab var s7a_3a_a "Does each ward have a BP machine?"
	lab var s7a_3b_a "Does each ward have a thermometer?"
	lab var s7a_3c_a "Does each ward have a pulse oxymeter?"
	lab var s7a_3d_a "Does each ward have a suction machine?"
	lab var s7a_3e_a "Does each ward have an emergency room?"
	lab var s7b_1a_a "Is there a hygiene protocol?"
	lab var s7b_1b_a "Does the hygiene protocol have a dedicated staff roster available?"
	lab var s7b_2a_a "Is a sink present with running water from a tap or modified storage container?"
	lab var s7b_2b_a "Is soap available at the handwashing area?"
	lab var s7b_3a_a "Are there at least two color-coded bins (red, black and/or yellow)?"
	lab var s7b_3b_a "Are there coded lining bags that match the color of the bins?"
	lab var s7b_3c_a "Are there standard operating procedures for waste management?"
	lab var s7b_4a_a "Is there evidence of disinfectant use?"
	lab var s7b_4b_a "Are you able to observe disinfectant containers used for cleaning?"
	lab var s7b_5a_a "Are gloves available?"
	lab var s7b_5b_a "Are gowns or dust coats available?"
	lab var s7b_5c_a "Are face masks available?"
	lab var s7b_5d_a "Are safety boots available?"
	lab var s8a_1a_a "Does the receiving area have a barrier?"
	lab var s8a_1b_a "Does the receiving area have a shoe rack?"
	lab var s8a_1c_a "Does the receiving area have a coach?"
	lab var s8a_1d_a "Does the receiving area have adequate lighting?"
	lab var s8a_2a_a "Does the theatre have male and female changing rooms with barrier?"
	lab var s8a_2b_a "Do changing rooms have clean clothing?"
	lab var s8a_2c_a "Do changing rooms have masks?"
	lab var s8a_2d_a "Do changing rooms have caps?"
	lab var s8a_2e_a "Do changing rooms have theatre shoes?"
	lab var s8a_2f_a "Is there a scrubbing area present?"
	lab var s8a_2g_a "Is there a hands-free tap?"
	lab var s8a_2h_a "Are there swinging theatre doors?"
	lab var s8a_3a_a "Does the operating area have adequate space?"
	lab var s8a_3b_a "Does the operating area have adequate lighting?"
	lab var s8a_3c_a "Does the operating area have adequate cabinets for non-pharms?"
	lab var s8a_3d_a "Does the operating area have adequate sterile gloves?"
	lab var s8a_3e_a "Does the operating area have a standard operating table?"
	lab var s8a_3f_a "Does the operating area have an adequate functional anaesthetic machine?"
	lab var s8a_3g_a "Does the operating area have adequate ambu-bags, both adult and paediatric?"
	lab var s8a_3h_a "Does the operating area have adequate monitors?"
	lab var s8a_3i_a "Does the operating area have adequate laryngoscopes?"
	lab var s8a_3j_a "Does the operating area have adequate endotracheal tubes?"
	lab var s8a_3k_a "Does the operating room have a functioning suction machine?"
	lab var s8a_3l_a "Does the operating room have adequate back-up oxygen, separate from anaesthetic "
	lab var s8a_4a_a "Are there at least three nurses (scrub, runner and anaesthetic nurse)?"
	lab var s8a_4b_a "Are nurses skilled with peri-operative training?"
	lab var s8a_5a_a "Does the recovery room have adequate lighting?"
	lab var s8a_5b_a "Does the recovery room have a monitor?"
	lab var s8a_5c_a "Does the recovery room have a drip stand?"
	lab var s8b_1a_a "Is there a hygiene protocol?"
	lab var s8b_1b_a "Does the hygiene protocol have a dedicated staff roster available?"
	lab var s8b_2a_a "Is a sink present with running water from a tap or modified storage container?"
	lab var s8b_2b_a "Is soap available at the hand washing area?"
	lab var s8b_3a_a "Are there at least two color-coded bins (red, black and/or yellow)?"
	lab var s8b_3b_a "Are there coded lining bags that match the color of the bins?"
	lab var s8b_3c_a "Are there standard operating procedures for waste management?"
	lab var s8b_4a_a "Is there evidence of disinfectant use?"
	lab var s8b_4b_a "Are you able to observe disinfectant containers used for cleaning?"
	lab var s8b_5a_a "Are gloves available?"
	lab var s8b_5b_a "Are gowns or dust coats available?"
	lab var s8b_5c_a "Are face masks available?"
	lab var s8b_5d_a "Are safety boots available?"
	lab var s9a_1a1_a "Adequate ventilation: Very dissatisfactory"
	lab var s9a_1a2_a "Adequate ventilation: Dissatisfactory"
	lab var s9a_1a3_a "Adequate ventilation: Satisfactory"
	lab var s9a_1a4_a "Adequate ventilation: Very Satisfactory"
	lab var s9a_1a_a  "Adequate ventilation in Pharm"
	lab var s9a_2a1_a "Adequate lighting: Very dissatisfactory"
	lab var s9a_2a2_a "Adequate lighting: Dissatisfactory"
	lab var s9a_2a3_a "Adequate lighting: Satisfactory"
	lab var s9a_2a4_a "Adequate lighting: Very Satisfactory"
	lab var s9a_2a_a  "Adequate ventilation in Pharm"
	lab var s9a_2b_a "Does the pharmacy have adequate space for staff movement in the dispensing area?"
	lab var s9b_1a_a "Does the pharmacy have secure, lockable cupboards for restricted drugs only acce"
	lab var s9b_1b_a "Are drugs stored and displayed to good standards?"
	lab var s9b_1c_a "Are there standard operating procedures for the storage of medicines?"
	lab var s9c_1a_a "Does the pharmacy have a well-explained system for recording prescriptions?"
	lab var s9c_1b_a "Does the pharmacy have standard operating procedures for disposal of expired dru"
	lab var s9c_1c_a "Is there a daily updated inventory system showing which commodities are availabl"
	lab var s9c_1d_a "Is there documentation showing where medicines are procured?"
	lab var s9c_1e_a "Are there systems for documenting and feeding back medication errors?"
	lab var s9c_1f_a "Are there separate records for narcotic and psychotropic medicines?"
	lab var s9d_1a_a "Does the pharmacy have reference materials for medicines (e.g. drug index)?"
	lab var s9d_1b_a "Is the staff familiar with these reference materials? if reference materials"
	lab var s9e_1a_a "Is there a hygiene protocol?"
	lab var s9e_1b_a "Does the hygiene protocol have a dedicated staff roster available?"
	lab var s9e_2a_a "Is a sink present with running water from a tap or modified storage container?"
	lab var s9e_2b_a "Is soap available at the handwashing area?"
	lab var s9e_3a_a "Are there at least two color-coded bins (red, black and/or yellow)?"
	lab var s9e_3b_a "Are there coded lining bags that match the color of the bins?"
	lab var s9e_3c_a "Are there standard operating procedures for waste management?"
	lab var s9e_4a_a "Is there evidence of disinfectant use?"
	lab var s9e_4b_a "Are you able to observe disinfectant containers used for cleaning?"
	lab var s9e_5a_a "Are gloves available?"
	lab var s9e_5b_a "Are gowns or dust coats available?"
	lab var s9e_5c_a "Are face masks available?"
	lab var s9e_5d_a "Are safety boots available?"
	lab var s10a_2a_a "Does the laboratory have SOPs and guidelines for reporting lab procedures?"
	lab var s10a_2b_a "Are the SOPs and guidelines for reporting lab procedures displayed? if SOPs"
	lab var s10a_3a_a "Does the laboratory have SOPs and guidelines for handling, labeling and storage "
	lab var s10a_3b_a "Are the SOPs and guidelines for handling, labeling and storage of specimens disp"
	lab var s10a_4a_a "Does the laboratory have SOPs and guidelines for disposal of specimens? if SOPs"
	lab var s10a_4b_a "Are the SOPs and guidelines for disposal of specimens displayed? if SOPs"
	lab var s10a_5a_a "Does the laboratory have standard quality operational manual (SOP of SOPs) avail"
	lab var s10b_1a_a "Does the lab have a system for regular calibration/validation of equipment avail"
	lab var s10b_1b_a "Is the system for calibration of equipment placed close to respective... if system"
	lab var s10b_2a_a "Does the laboratory have a systematic, well-documented equipment maintenance sch"
	lab var s10b_2b_a "Are service contracts available for all lab equipment?"
	lab var s10b_3a_a "Does lab have a system for equipment procurement that is known by staff?"
	lab var s10b_4a_a "Does the laboratory have a list of all equipment in use?"
	lab var s10b_4b_a "Does the laboratory have a functional inventory management system?"
	lab var s10c_1a_a "Does lab have a records system integrated in the facility record system, i.e. La"
	lab var s10d_1a_a "Are equipment registered, validated and calibrated?"
	lab var s10d_1b_a "Is there documentation of quality control of tests?"
	lab var s10d_1c_a "Is there a documented system for regular review and improvement of laboratory te"
	lab var s10d_1d_a "Is there documentation of sample archiving, retrieval and disposal?"
	lab var s10d_1e_a "Is Internal Quality Control (IQC) done regularly?"
	lab var s10d_1f_a "Is the laboratory enrolled in External Quality Assurance?"
	lab var s10d_2a_a "Does the laboratory have a functional temperature recording system in place?"
	lab var s10d_2b_a "Are standards for procurement and safe storage of reagents in place, including a"
	lab var s10e_1a_a "Is there a hygiene protocol?"
	lab var s10e_1b_a "Does the hygiene protocol have a dedicated staff roster available?"
	lab var s10e_2a_a "Is a sink present with running water from a tap/modified storage cont? if hygiene prot"
	lab var s10e_2b_a "Is soap available at the handwashing area?"
	lab var s10e_3a_a "Are there at least two color-coded bins (red, black and/or yellow)?"
	lab var s10e_3b_a "Are there coded lining bags that match the color of the bins?"
	lab var s10e_3c_a "Are there standard operating procedures for waste management?"
	lab var s10e_4a_a "Is there evidence of disinfectant use?"
	lab var s10e_4b_a "Are you able to observe disinfectant containers used for cleaning?"
	lab var s10e_5a_a "Are gloves available?"
	lab var s10e_5b_a "Are gowns or dust coats available?"
	lab var s10e_5c_a "Are face masks available?"
	lab var s10e_5d_a "Are safety boots available?"
	lab var s11a_1a_a "Are personal radiation dose monitoring badges worn daily and evaluated monthly b"
	lab var s11a_2a_a "Does the facility have records confirming that there is a radiation safety servi"
	lab var s11a_3a_a "Is there an adequate number of lead aprons, i.e. a minimum of three: one each fo"
	lab var s11a_4a_a "Is a code of practice for pregnant women available and producible?"
	lab var s11a_5a_a "Is there evidence of quality assurance of the image processing system"
	lab var s11b_1a_a "Are standard operating procedures available for radiology and imaging services?"
	lab var s11b_1b_a "Is there evidence that they have been reviewed in the past year and reviewed ann"
	lab var s11b_1c_a "Is a code of practice displayed next to the respective device?"
	lab var s11b_2a_a "Is reporting, testing and calibrating up to date and displayed?"
	lab var s11b_3a_a "Is there a register of eradiating activities and a monthly dose report for worke"
	lab var s11b_4a_a "Is there a quality assurance program?"
	lab var s11b_4b_a "Does the quality assurance program include safety of the patient, worker, enviro"
	lab var s11b_4c_a "Is there a designated or appointed quality assurance staff member in the facilit"
	lab var s11b_4d_a "Is there updated annual documentation for quality assurance procedures?"
	lab var s11c_1a_a "Does the facility produce radioactive waste?"
	lab var s11c_1b_a "Are patient and staff safety measures implemented alongside routine waste manage"
	lab var s11c_2a_a "Is there designated staff in charge of radioactive waste management?"
	lab var s11c_2b_a "Are there records showing that radioactive waste management systems are in place"
	lab var s11c_3a_a "Does the facility have designated personnel to oversee radioactive waste managem"
	lab var s11d_1a_a "Is there a hygiene protocol?"
	lab var s11d_1b_a "Does the hygiene protocol have a dedicated staff roster available?"
	lab var s11d_2a_a "Is a sink present with running water from a tap or modified storage container?"
	lab var s11d_2b_a "Is soap available at the handwashing area?"
	lab var s11d_3a_a "Is there evidence of disinfectant use?"
	lab var s11d_3b_a "Are you able to observe disinfectant containers used for cleaning?"
	lab var s11d_4a_a "Are gloves available?"
	lab var s11d_4b_a "Are gowns or dust coats available?"
	lab var s11d_4c_a "Are face masks available?"
	lab var s11d_4d_a "Are safety boots available?"
	lab var s12a_1a_a "Is a functional calibrated weighing scale available?"
	lab var s12a_1b_a "Is a stadiometer available?"
	lab var s12a_1c_a "Are Mid-Upper Arm Circumference (MUAC) tapes available?"
	lab var s12a_1d_a "Is a waist circumference tape available?"
	lab var s12a_1e_a "Is a functional blood pressure machine available?"
	lab var s12a_1f_a "Is a functional glucometer available?"
	lab var s12a_1g_a "Are reference charts available?"
	lab var s12a_2a_a "Is food store available with evidence of regular stock replenishment?"
	lab var s12a_2b_a "Are Ready to Use Therapeutic Foods (RUTF) available and accessible?"
	lab var s12a_2c_a "Are Ready to Use Supplementary Foods (RUSF) available and accessible?"
	lab var s12a_2d_a "Are the F75 and F100 diet milks available and adequate for clients?"
	lab var s12a_2e_a "Are food fortifiers available and acceptable?"
	lab var s12a_2f_a "Are nutrition formulations for specialized nutrition support available and acces"
	lab var s12a_2g_a "Are Vitamin A Supplements available for children and expectant mothers?"
	lab var s12a_2h_a "Are iron supplements available in the acceptable form?"
	lab var s12a_2i_a "Are folate supplements available in the acceptable form?"
	lab var s12a_2j_a "Is zinc supplement available?"
	lab var s12b_1a_a "Are there SOPs for comprehensive nutritional assessment?"
	lab var s12b_1b_a "Are there adequate guidelines for nutritional diagnosis?"
	lab var s12b_1c_a "Are there guidelines for choice of appropriate nutrition care intervention?"
	lab var s12b_1d_a "Are there adequate guidelines for monitoring patient care?"
	lab var s12b_1e_a "Are there adequate SOPs for food formulations?"
	lab var s12b_1f_a "Are there adequate SOPs for food supplementation?"
	lab var s12b_1g_a "Are SOPs reviewed and regularly updated (within a 5-year framework)?"
	lab var s12b_1h_a "Are staff familiar with the SOPs and guidelines?"
	lab var s12c_1a_a "Is the system for record keeping linked to the facility information management s"
	lab var s12c_1b_a "Is there a designated person aware of the documentation processes?"
	lab var s12c_1c_a "Is there security for the information in the system?"
	lab var s12c_1d_a "Is there a documented plan for regular updating?"
	lab var s12d_1a_a "Is there an inpatient feeding committee?"
	lab var s12d_1b_a "Does the composition of the committee include qualified nutritionist and dietici"
	lab var s12d_1c_a "Is there a comprehensive protocol for inpatient feeding?"
	lab var s12d_1d_a "Is there a food inspection committee with at least one licensed nutritionist?"
	lab var s12d_1e_a "Is there a communication link between patients in the ward and the food preparat"
	lab var s12d_1f_a "Are there food modification schemes for groups with special needs?"
	lab var s12d_1g_a "Is there an option for patients to choose from available sources of foods?"
	lab var s12d_2a_a "Are postpartum mothers fed on an appropriately tailored diet?"
	lab var s12d_2b_a "Is breastfeeding initiated within one hour after delivery?"
	lab var s12e_1a_a "Is a functional blender available?"
	lab var s12e_1b_a "Is a functional mincer available?"
	lab var s12e_1c_a "Is a functional food weighing scale available and regularly calibrated?"
	lab var s12e_1d_a "Are measuring jars available?"
	lab var s12e_1e_a "Are food trolleys available?"
	lab var s12e_1f_a "Are reliable sources of fuel available?"
	lab var s12e_2a_a "Is the layout and physical structure of the kitchen adequate?"
	lab var s12e_2b_a "Is a diet therapy kitchen available and separated from normal food kitchen?"
	lab var s12e_2c_a "Is a mini store available in the kitchen for food from the main store?"
	lab var s12e_2d_a "Does the paediatric ward have room to prepare special food?"
	lab var s12e_2e_a "Is there adequate space for storage of food commodities?"
	lab var s12e_3a_a "Are kitchen personnel qualified caterers and trained cooks?"
	lab var s12e_3b_a "Is the supervisor qualified and licensed by the Nutritionist and Dieticians Inst"
	lab var s12f_1a_a "Is there a hygiene protocol?"
	lab var s12f_1b_a "Does the hygiene protocol have a dedicated staff roster available?"
	lab var s12f_2a_a "Is a sink present with running water from a tap or modified storage container?"
	lab var s12f_2b_a "Is soap available at the hand washing area?"
	lab var s12f_3a_a "Are there at least two color-coded bins (red, black and/or yellow)?"
	lab var s12f_3b_a "Are there coded lining bags that match the color of the bins?"
	lab var s12f_3c_a "Are there standard operating procedures for waste management?"
	lab var s12f_4a_a "Is there evidence of disinfectant use?"
	lab var s12f_4b_a "Are you able to observe disinfectant containers used for cleaning?"
	lab var s12f_5a_a "Are gloves available and accessible?"
	lab var s12f_5b_a "Are gowns or dust coats available and accessible?"
	lab var s12f_5c_a "Are face masks available and accessible?"
	lab var s12f_5d_a "Are safety boots available and accessible?"

	
	* Lab values
	global values s2a_1a s2b_3a s2c_2b s2c_3a s2c_3d s3a_2b s3b_2a s3b_2b s3b_2c s3b_2d s4a_3b s4a_4a s4a_4b s4a_4c s5a_1a s5a_4a s5a_4c s5a_4d s5a_4e s5a_4f s5a_4g s5a_4h s5a_4i s5a_4j s5a_4k s5a_4l s5b_3a s5b_3b s6a_4b s6b_1b s6b_3a s6b_3b s7b_3a s7b_3b s8a_1a s8a_1b s8a_1c s8a_1d s8a_2b s8a_2a s8a_2c s8a_2d s8a_2e s8a_2f s8a_2g s8a_2h s8a_3a s8a_3b s8a_3c s8a_3d s8a_3f s8a_3g s8a_3h s8a_3i s8a_3j s8a_3k s8a_3l s8a_4a s8a_4b s8a_5a s8a_5b s8a_5c s8b_3a s8b_3b s8b_3c s9e_3a	s9e_3b s10e_3a	s10e_3b s12f_3a	s12f_3b  
	foreach var in $values {
	
		lab define `var'l 0 "No" 1 "Yes"
		lab val `var' `var'l
	}

	** Renaming variables to merge with listing
	rename county county_2
	rename location location_2
	rename sublocation sublocation_2
	rename level level_2

********************************************************************************

	** Part 5: Merging with Listing - Basic info from HFs

********************************************************************************
	
	preserve 
	use "${listing_bl}", clear
	keep latitude	longitude	hfid	hfname	county	subcounty	location	sublocation	level	d8	d9	d10 market_all hf_m marketsize patients_month
	rename hfid a5
	rename d8 pub
	rename d9 pri_c
	rename d10 faith_c

	tempfile listing 
	save `listing'
	restore

	mmerge a5 using `listing', type (n:1)

	* We didn't applied QPS1/2 to HF 800020, because the HF did not give approval. So we need to drop this observation. 
	drop if a5 == 800020

	** One of the HFs in QPS is not in the listing dataset (we need to check, I replaced the info for now)
	replace latitude = a1latitude if a5 == 17824
	replace longitude = a1longitude if a5 == 17824
	replace hfname = facilityname if a5 == 17824
	replace county = county_1 if a5 == 17824
	replace subcounty = subcounty_1 if a5 == 17824
	replace location = location_1 if a5 == 17824
	replace sublocation = sublocation_1 if a5 == 17824
	replace pub = pri if a5 == 17824
	replace level = level_1 if a5 == 17824

	drop if _merge == 2

	* Drop basic info from QPS1 and QPS2. We only want to use the cleaned basic info from Listing file
	drop a6	a6_c	a8_qps1	a8_c f10	f16_1	f16_2	f16_3	f16_4	f16_5	f16_6	f17	f28	f29	f10_ch_5	enumeratorid	enumname	supervisorid	supname	a2_1_v	a2_3_v  a12 a1latitude	lat a1longitude	lon date	time	facilityname	sublocation_1	sublocation_2 location_1 location_2	county_1 county_2 subcounty_1 level_1 level_2 pri private 	facilitycode	
	order latitude	longitude	a5	hfname	county	subcounty	location	sublocation a11	level	pub pri_c faith_c market_all hf_m marketsize patients_month a8_1	a8_2	a8_3	a8_4	a8_5 s2a_1a	s2a_1b	s2a_1c	s2a_1d	s2a_1e	s2a_2a1	s2a_2a2	s2a_2a3	s2a_2a4	s2a_3a1	s2a_3a2	s2a_3a3	s2a_3a4	s2b_1a	s2b_1b	s2b_2a	s2b_3a	s2b_3b	s2c_1a	s2c_1b	s2c_2a	s2c_2b	s2c_3a	s2c_3b	s2c_3c	s2c_3d	s2c_4a	s3a_1a	s3a_1b	s3a_1c	s3a_1d	s3a_2a	s3a_2b	s3a_2c	s3a_2d	s3a_2e	s3a_2f	s3a_2g s3a_2h	s3a_3a	s3b_1a	s3b_1b	s3b_2a	s3b_2b	s3b_2c	s3b_2d	s3b_2e	s3b_3a	s3b_3b	s3b_3c	s3c_1a	s3c_1b	s3c_1c	s3c_2a	s3c_2b	s3c_2c	s3c_2d	s3c_3a	s3c_3b	s3c_3c	s3c_4a	s3c_4b	s3c_5a	s3d_1a	s3d_1b	s3d_2a	s3d_2b	s3d_2c	s4a_1a	s4a_1b	s4a_2a	s4a_2b	s4a_2c	s4a_3a1	s4a_3a2	s4a_3a3	s4a_3a4	s4a_3b	s4a_3c	s4a_3d	s4a_4a	s4a_4b	s4a_4c	s4b_1a	s4b_1b	s4b_1c	s4b_1d	s5a_1a	s5a_1b	s5a_1c	s5a_1d	s5a_2a	s5a_2b	s5a_2c	s5a_3a	s5a_3b	s5a_3c	s5a_3d	s5a_3e	s5a_3f	s5a_3g	s5a_3h	s5a_3i	s5a_4a	s5a_4b	s5a_4c	s5a_4d	s5a_4e	s5a_4f	s5a_4g	s5a_4h	s5a_4i	s5a_4j	s5a_4k	s5a_4l	s5b_1a	s5b_2a	s5b_2b	s5b_3a	s5b_3b	s5b_3c	s5b_4a	s5b_4b	s5b_5a	s5b_5b	s5b_5c	s5b_5d	s6a_1a	s6a_1b	s6a_1c	s6a_1d	s6a_1e	s6a_1f	s6a_1g	s6a_1h	s6a_1i	s6a_2a	s6a_2b	s6a_2c	s6a_3a	s6a_3b	s6a_3c	s6a_4a	s6a_4b	s6a_5a	s6a_5b	s6a_6a	s6a_6b	s6a_6c	s6a_6d	s6a_6e	s6a_6f	s6a_6g	s6a_7a	s6a_7b	s6a_7c	s6a_7d	s6a_7e	s6a_8a	s6a_8b	s6a_8c	s6a_8d	s6b_1a s6b_1b	s6b_2a	s6b_2b	s6b_3a	s6b_3b	s6b_3c	s6b_4a	s6b_4b	s6b_5a	s6b_5b	s6b_5c	s6b_5d	s7a_1a	s7a_1b	s7a_1c	s7a_1d	s7a_2a	s7a_2b	s7a_3a	s7a_3b	s7a_3c	s7a_3d	s7a_3e	s7b_1a	s7b_2a	s7b_2b	s7b_3a	s7b_3b	s7b_3c	s7b_4a	s7b_4b	s7b_5a	s7b_5b	s7b_5c	s7b_5d	s8a_1a	s8a_1b	s8a_1c	s8a_1d	s8a_2a	s8a_2b	s8a_2c	s8a_2d	s8a_2e	s8a_2f	s8a_2g	s8a_2h	s8a_3a	s8a_3b	s8a_3c	s8a_3d	s8a_3e	s8a_3f	s8a_3g	s8a_3h	s8a_3i	s8a_3j	s8a_3k	s8a_3l	s8a_4a	s8a_4b	s8a_5a	s8a_5b	s8a_5c	s8b_1a	s8b_2a	s8b_2b	s8b_3a	s8b_3b	s8b_3c	s8b_4a	s8b_4b	s8b_5a	s8b_5b	s8b_5c	s8b_5d	s9a_1a1	s9a_1a2	s9a_1a3	s9a_1a4	s9a_2a1	s9a_2a2	s9a_2a3	s9a_2a4	s9a_2b	s9b_1a	s9b_1b	s9b_1c	s9c_1a	s9c_1b	s9c_1c	s9c_1d	s9c_1e	s9c_1f	s9d_1a	s9d_1b	s9e_1a	s9e_2a	s9e_2b	s9e_3a	s9e_3b	s9e_3c	s9e_4a	s9e_4b	s9e_5a	s9e_5b	s9e_5c	s9e_5d	s10a_2a	s10a_2b	s10a_3a	s10a_3b	s10a_4a	s10a_4b	s10a_5a	s10b_1a	s10b_1b	s10b_2a	s10b_2b	s10b_3a	s10b_4a	s10b_4b	s10c_1a	s10d_1a	s10d_1b	s10d_1c	s10d_1d	s10d_1e	s10d_1f	s10d_2a	s10d_2b	s10e_1a	s10e_2a	s10e_2b	s10e_3a	s10e_3b	s10e_3c	s10e_4a	s10e_4b	s10e_5a	s10e_5b	s10e_5c	s10e_5d	s11a_1a	s11a_2a	s11a_3a	s11a_4a	s11a_5a	s11b_1a	s11b_1b	s11b_1c	s11b_2a	s11b_3a	s11b_4a	s11b_4b	s11b_4c	s11b_4d	s11c_1a	s11c_1b	s11c_2a	s11c_2b	s11c_3a	s11d_1a	s11d_2a	s11d_2b	s11d_3a	s11d_3b	s11d_4a	s11d_4b	s11d_4c	s11d_4d	s12a_1a	s12a_1b	s12a_1c	s12a_1d	s12a_1e	s12a_1f	s12a_1g	s12a_2a	s12a_2b	s12a_2c	s12a_2d	s12a_2e	s12a_2f	s12a_2g	s12a_2h	s12a_2i	s12a_2j	s12b_1a	s12b_1b	s12b_1c	s12b_1d	s12b_1e	s12b_1f	s12b_1g	s12b_1h	s12c_1a	s12c_1b	s12c_1c	s12c_1d	s12d_1a	s12d_1b	s12d_1c	s12d_1d	s12d_1e	s12d_1f	s12d_1g	s12d_2a	s12d_2b	s12e_1a	s12e_1b	s12e_1c	s12e_1d	s12e_1e	s12e_1f	s12e_2a	s12e_2b	s12e_2c	s12e_2d	s12e_2e	s12e_3a	s12e_3b	s12f_1a	s12f_2a	s12f_2b	s12f_3a	s12f_3b	s12f_3c	s12f_4a	s12f_4b	s12f_5a	s12f_5b	s12f_5c	s12f_5d	s2a_1a_a	s2a_1b_a	s2a_1c_a	s2a_1d_a	s2a_1e_a	s2a_2a_a s2a_2a1_a	s2a_2a2_a	s2a_2a3_a	s2a_2a4_a	s2a_3a_a s2a_3a1_a	s2a_3a2_a	s2a_3a3_a	s2a_3a4_a	s2b_1a_a	s2b_1b_a	s2b_2a_a	s2b_3a_a	s2b_3b_a	s2c_1a_a	s2c_1b_a	s2c_2a_a	s2c_2b_a	s2c_3a_a	s2c_3b_a	s2c_3c_a	s2c_3d_a	s2c_4a_a	s3a_1a_a	s3a_1b_a	s3a_1c_a	s3a_1d_a	s3a_2a_a	s3a_2b_a	s3a_2c_a	s3a_2d_a	s3a_2e_a	s3a_2f_a	s3a_2g_a s3a_2h_a	s3a_3a_a	s3b_1a_a	s3b_1b_a	s3b_2a_a	s3b_2b_a	s3b_2c_a	s3b_2d_a	s3b_2e_a	s3b_3a_a	s3b_3b_a	s3b_3c_a	s3c_1a_a	s3c_1b_a	s3c_1c_a	s3c_2a_a	s3c_2b_a	s3c_2c_a	s3c_2d_a	s3c_3a_a	s3c_3b_a	s3c_3c_a	s3c_4a_a	s3c_4b_a	s3c_5a_a	s3d_1a_a	s3d_1b_a	s3d_2a_a	s3d_2b_a	s3d_2c_a	s4a_1a_a	s4a_1b_a	s4a_2a_a	s4a_2b_a	s4a_2c_a	s4a_3a_a s4a_3a1_a	s4a_3a2_a	s4a_3a3_a	s4a_3a4_a	s4a_3b_a	s4a_3c_a	s4a_3d_a	s4a_4a_a	s4a_4b_a	s4a_4c_a	s4b_1a_a	s4b_1b_a	s4b_1c_a	s4b_1d_a	s5a_1a_a	s5a_1b_a	s5a_1c_a	s5a_1d_a	s5a_2a_a	s5a_2b_a	s5a_2c_a	s5a_3a_a	s5a_3b_a	s5a_3c_a	s5a_3d_a	s5a_3e_a	s5a_3f_a	s5a_3g_a	s5a_3h_a	s5a_3i_a	s5a_4a_a	s5a_4b_a	s5a_4c_a	s5a_4d_a	s5a_4e_a	s5a_4f_a	s5a_4g_a	s5a_4h_a	s5a_4i_a	s5a_4j_a	s5a_4k_a	s5a_4l_a	s5b_1a_a s5b_1b_a	s5b_2a_a	s5b_2b_a	s5b_3a_a	s5b_3b_a	s5b_3c_a	s5b_4a_a	s5b_4b_a	s5b_5a_a	s5b_5b_a	s5b_5c_a	s5b_5d_a	s6a_1a_a	s6a_1b_a	s6a_1c_a	s6a_1d_a	s6a_1e_a	s6a_1f_a	s6a_1g_a	s6a_1h_a	s6a_1i_a	s6a_2a_a	s6a_2b_a	s6a_2c_a	s6a_3a_a	s6a_3b_a	s6a_3c_a	s6a_4a_a	s6a_4b_a	s6a_5a_a	s6a_5b_a	s6a_6a_a	s6a_6b_a	s6a_6c_a	s6a_6d_a	s6a_6e_a	s6a_6f_a	s6a_6g_a	s6a_7a_a	s6a_7b_a	s6a_7c_a	s6a_7d_a	s6a_7e_a	s6a_8a_a	s6a_8b_a	s6a_8c_a	s6a_8d_a	s6b_1a_a s6b_1b_a	s6b_2a_a	s6b_2b_a	s6b_3a_a	s6b_3b_a	s6b_3c_a	s6b_4a_a	s6b_4b_a	s6b_5a_a	s6b_5b_a	s6b_5c_a	s6b_5d_a	s7a_1a_a	s7a_1b_a	s7a_1c_a	s7a_1d_a	s7a_2a_a	s7a_2b_a	s7a_3a_a	s7a_3b_a	s7a_3c_a	s7a_3d_a	s7a_3e_a	s7b_1a_a s7b_1b_a	s7b_2a_a	s7b_2b_a	s7b_3a_a	s7b_3b_a	s7b_3c_a	s7b_4a_a	s7b_4b_a	s7b_5a_a	s7b_5b_a	s7b_5c_a	s7b_5d_a	s8a_1a_a	s8a_1b_a	s8a_1c_a	s8a_1d_a	s8a_2a_a	s8a_2b_a	s8a_2c_a	s8a_2d_a	s8a_2e_a	s8a_2f_a	s8a_2g_a	s8a_2h_a	s8a_3a_a	s8a_3b_a	s8a_3c_a	s8a_3d_a	s8a_3e_a	s8a_3f_a	s8a_3g_a	s8a_3h_a	s8a_3i_a	s8a_3j_a	s8a_3k_a	s8a_3l_a	s8a_4a_a	s8a_4b_a	s8a_5a_a	s8a_5b_a	s8a_5c_a	s8b_1a_a s8b_1b_a	s8b_2a_a	s8b_2b_a	s8b_3a_a	s8b_3b_a	s8b_3c_a	s8b_4a_a	s8b_4b_a	s8b_5a_a	s8b_5b_a	s8b_5c_a	s8b_5d_a	s9a_1a_a s9a_1a1_a	s9a_1a2_a	s9a_1a3_a	s9a_1a4_a	s9a_2a_a s9a_2a1_a	s9a_2a2_a	s9a_2a3_a	s9a_2a4_a	s9a_2b_a	s9b_1a_a	s9b_1b_a	s9b_1c_a	s9c_1a_a	s9c_1b_a	s9c_1c_a	s9c_1d_a	s9c_1e_a	s9c_1f_a	s9d_1a_a	s9d_1b_a	s9e_1a_a s9e_1b_a	s9e_2a_a	s9e_2b_a	s9e_3a_a	s9e_3b_a	s9e_3c_a	s9e_4a_a	s9e_4b_a	s9e_5a_a	s9e_5b_a	s9e_5c_a	s9e_5d_a	s10a_2a_a	s10a_2b_a	s10a_3a_a	s10a_3b_a	s10a_4a_a	s10a_4b_a	s10a_5a_a	s10b_1a_a	s10b_1b_a	s10b_2a_a	s10b_2b_a	s10b_3a_a	s10b_4a_a	s10b_4b_a	s10c_1a_a	s10d_1a_a	s10d_1b_a	s10d_1c_a	s10d_1d_a	s10d_1e_a	s10d_1f_a	s10d_2a_a	s10d_2b_a	s10e_1a_a s10e_1b_a	s10e_2a_a	s10e_2b_a	s10e_3a_a	s10e_3b_a	s10e_3c_a	s10e_4a_a	s10e_4b_a	s10e_5a_a	s10e_5b_a	s10e_5c_a	s10e_5d_a	s11a_1a_a	s11a_2a_a	s11a_3a_a	s11a_4a_a	s11a_5a_a	s11b_1a_a	s11b_1b_a	s11b_1c_a	s11b_2a_a	s11b_3a_a	s11b_4a_a	s11b_4b_a	s11b_4c_a	s11b_4d_a	s11c_1a_a	s11c_1b_a	s11c_2a_a	s11c_2b_a	s11c_3a_a	s11d_1a_a s11d_1b_a	s11d_2a_a	s11d_2b_a	s11d_3a_a	s11d_3b_a	s11d_4a_a	s11d_4b_a	s11d_4c_a	s11d_4d_a	s12a_1a_a	s12a_1b_a	s12a_1c_a	s12a_1d_a	s12a_1e_a	s12a_1f_a	s12a_1g_a	s12a_2a_a	s12a_2b_a	s12a_2c_a	s12a_2d_a	s12a_2e_a	s12a_2f_a	s12a_2g_a	s12a_2h_a	s12a_2i_a	s12a_2j_a	s12b_1a_a	s12b_1b_a	s12b_1c_a	s12b_1d_a	s12b_1e_a	s12b_1f_a	s12b_1g_a	s12b_1h_a	s12c_1a_a	s12c_1b_a	s12c_1c_a	s12c_1d_a	s12d_1a_a	s12d_1b_a	s12d_1c_a	s12d_1d_a	s12d_1e_a	s12d_1f_a	s12d_1g_a	s12d_2a_a	s12d_2b_a	s12e_1a_a	s12e_1b_a	s12e_1c_a	s12e_1d_a	s12e_1e_a	s12e_1f_a	s12e_2a_a	s12e_2b_a	s12e_2c_a	s12e_2d_a	s12e_2e_a	s12e_3a_a	s12e_3b_a	s12f_1a_a s12f_1b_a	s12f_2a_a	s12f_2b_a	s12f_3a_a	s12f_3b_a	s12f_3c_a	s12f_4a_a	s12f_4b_a	s12f_5a_a	s12f_5b_a	s12f_5c_a	s12f_5d_a, first

	drop _merge a8 a9 a9	a8_v2	a8_v9	a8_v3	a8_v4	a8_v5	a8_v8	a8_v6	a8_v7	a8_g1_c	a8_v2_a	a8_v9_a	a8_v3_a	a8_v4_a	a8_v5_a	a8_v8_a	a8_v6_a	a8_v7_a	a8_v2_b	a8_v9_b	a8_v3_b	a8_v4_b	a8_v5_b	a8_v8_b	a8_v6_b	a8_v7_b	a8_g3_c s1a_7	s1a_8 s1b_4 s1a_7	s1a_8	s1b_4	s1b_5_other	s1c_4_other	s1c_5_other	s1c_6_other	s1c_8	s1c_10_other	s2a_6	s2a_7	s2a_8_other	s2a_13_other	s2a_14_other	s2a_15_other	s2b_5	s2b_6	s2b_7	v156	s3a_1_other	s3a_b_other	s3a_17_other	s3a_17b_other	s3a_19	s3a_20	s3b_6_other	s3b_7	s3b_8	s3b_9	s3b_10	s4a_17_other	s4a_17_a	s4b_6_other	s4b_7	s4b_8	s4b_9	s4b_10	s5b_6_other	s5b_7	s5b_8	s5b_9	s5b_10	s6a_1	s6a_2_other	s6a_3_other	s6a_4_other	s6a_5_other	s6a_6_other	s6a_7_other	s6a_8_other	s6a_9_other	s6a_10_other	s6a_11_other	s6a_25_other	s6a_27_other	s6a_28_other	s6a_29_other	s6b_6_other	s6b_7	s6b_8	s6b_9	s6b_10	s7a_1	s7a_2	s7e_6_other	s7e_7	s7e_8	s7e_9	s7e_10	s8a_2	s8e_6_other	s8e_7	s8e_8	s8e_9	s10b_g2_c	s10e_1	s10f_6_other	s10f_7	s10f_8	s10f_9	s10f_10	g1	g1_2	g3	g3_2	g5	g5_2	g7	g7_2	a8_v2_c	a8_v9_c	a8_v3_c	a8_v4_c	a8_v5_c	a8_v8_c	a8_v6_c	a8_v7_c	a8_v	a8_c1	a8_c2	a8_c3	a8_ch_1	a8_ch_2	a8_ch_3	a8_ch_4	a8_ch_5	a8_ch_6	a8_ch_7	a8_ch_8	a8_ch_9	s3a_19_ch_6	s3a_20_ch_6	s3b_6_ch_1	s3b_6_ch_2	s3b_6_ch_3	s3b_6_ch_4	s3b_6_ch_5	s4a_17_a_ch_1	s4a_17_a_ch_2	s4a_17_a_ch_3	s4a_17_a_ch_4	s4b_6_ch_1	s4b_6_ch_2	s4b_6_ch_3	s4b_6_ch_4	s4b_6_ch_5	s5b_6_ch_1	s5b_6_ch_2	s5b_6_ch_3	s5b_6_ch_4	s5b_6_ch_5	s6a_1_ch_1	s6a_1_ch_2	s6a_1_ch_4	s6a_1_ch_5	s6a_25_ch_1	s6a_25_ch_2	s6a_25_ch_3	s6a_25_ch_4	s6b_6_ch_1	s6b_6_ch_2	s6b_6_ch_3	s6b_6_ch_4	s6b_6_ch_5	s7e_6_ch_1	s7e_6_ch_2	s7e_6_ch_3	s7e_6_ch_4	s7e_6_ch_5	s8e_6_ch_1	s8e_6_ch_2	s8e_6_ch_3	s8e_6_ch_4	s8e_6_ch_5	s10f_6_ch_1	s10f_6_ch_2	s10f_6_ch_3	s10f_6_ch_4	s10f_6_ch_5	s2a_9	s2a_10	s3b_bb	s3b_yy	s3b_rr	s4b_bb	s4b_yy	s4b_rr	s5b_bb	s5b_yy	s5b_rr	s6b_bb	s6b_yy	s6b_rr	s7e_bb	s7e_yy	s7e_rr	s8e_bb	s8e_yy	s8e_rr	s10f_bb	s10f_yy	s10f_rr // s1a_4_other

	label data "This file contains the baseline checklist variables: adherence, scores, max scores, percentage scores"
	label var a5 "HF ID"
	label var a11 "Urban"
	** Drop special questions, because we calulated the adherence as a whole
	//drop s2a_2a1_a s2a_2a2_a s2a_2a3_a	s2a_2a4_a s2a_3a1_a	s2a_3a2_a s2a_3a3_a	s2a_3a4_a s4a_3a1_a	s4a_3a2_a s4a_3a3_a	s4a_3a4_a s9a_1a2 s9a_1a3_a	s9a_1a4_a s9a_2a1_a	s9a_2a2_a s9a_2a3_a	s9a_2a4_a
	
	save "${jhic_bl}", replace

	* Dismount
	*veracrypt, dismount drive("${mount}") 
