/*******************************************************************************	
*		Project:
*			KePSIE IE
*		Created on:		2018-10-01
*		Last update: 	2018-10-01
********************************************************************************			

** PURPOSE: 	This do-file cleans the  QPS1 endline backchecks done by supervisors	
				
** INPUTS:     	Backcheck_QPS1.dta Dropbox/DataAnalysis/Follow-up/Data/Raw/QPS1


** OUTLINE: 	Part 1: Performs basic cleaning
				Part 4: Anonymize data for general dataset and save

** OUTPUTS:    Backcheck_QPS1_clean_end.dta Github\kepsie\DataWork\Endline\DataSets\Intermediate
				

** Written by: Thomas Escande

*******************************************************************************/
	

********************************************************************************
	** Part 0: Create globals for directories and files 
********************************************************************************

clear all
set more off				

	* Input files
	
		glo backcheck		"${volume}/supplemental/qps1_bl_bc.dta"
		glo backcheck1		"${volume}/supplemental/qps1_bl_bc"
		glo backcheck2		"${volume}/supplemental/qps1_bl_bc_3"
		glo backcheck3		"${volume}/supplemental/qps1_bl_bc_3_full"

		* QPS1 questionnaire (electronic)
		glo	qps1_bl_q		"${doc_bl}/codebooks/qps1_bl_equestionnaire.xlsx" /*Replace with version _103_ later on with Stata 15*/
	
	* Output files: 
		glo qps1_bl_bc 		"${dt_bl_clean}/qps1_bl_bc.dta"

		
		
* Mount veracrypt drive
veracrypt "${encrypt}/Baseline Raw Identified Data", mount drive("${mount}")
		
*Some previous data are missing from backcheck1, so we append a previous version and then drop all the duplicates, keeping the previous ones
*and the new ones
	import delimited "${backcheck1}.csv", clear
	drop if bc_g1 == 3 // Survey not started

	append using "${backcheck}", force
	drop if bc_g1 == 3 

	duplicates drop a5, force

	tempfile bc1 
	save 	"`bc1'"

	import delimited "${backcheck2}.csv", clear
	drop if bc_g1 == 3

	append using "`bc1'", force

	tempfile bc2 
	save 	"`bc2'"

	import delimited "${backcheck3}.csv", clear

	append using "`bc2'", force	

	drop if a5 == 928003904 //Does not seem to correspond to any facility

		** Separates select_multiple questions 

	/*** SL, 2017-9-3: The split code is the old one (NOT the new one Camila corrected) since the raw QPS2 is modified and the new code cannot be applied to the modified data
					I checked all the multiple-selection variables and no errors found	*/
	
	qui {
	cap prog drop splitmult
	prog def splitmult

	syntax anything using
		import excel `using', clear first
		keep if regexm(type,"^select_multiple")
		count
		local nQuestions = `r(N)'
		forvalues i = 1/`nQuestions' {

			import excel `using', clear first
				keep if regexm(type,"^select_multiple")

				local theName = name[`i']
				local theChoices = type[`i']
					local theChoices = regexr("`theChoices'","select_multiple ","")
				
			import excel `using', clear first sheet("choices")
				keep if list_name == "`theChoices'"
				
				count
				local nChoices = `r(N)'
				
				forvalues j = 1/`nChoices' {
				
					local theNextLabel = label[`j']
					local theNextValue  = name[`j']
				
					local `theName'L `" ``theName'L' "`theNextLabel'" "'
					local `theName'V ``theName'V' `theNextValue'
					
					}
					
			use `anything', clear
				
				forvalues j = 1/`nChoices' {
					
					local theNextLabel : word `j' of ``theName'L'
					local theNextValue : word `j' of ``theName'V'
					
					cap tostring `theName', replace					
					cap gen `theName'_ch_`j' = 1 if regexm(`theName',"`theNextValue'")
						cap replace `theName'_ch_`j' = 0 if `theName' != "" & `theName'_ch_`j' != 1
						cap label var `theName'_ch_`j' "`theNextLabel'"
						
					}
					
				save `anything', replace
					
			}			
		end
	}

	tempfile split
	save `split'

	* Split the multiple-choice questions
	splitmult `split' using "${qps1_bl_q}"
	save `split', replace

	** droping splitted variables 
	drop 	 d9 d13 f10 f38 f44 e16_v
	

	* Destring variables 
	destring facilitycode level pri f36_s_total patients labtest e16 d16 c2_c, replace

	* Formatting date
	gen date1 = date(date,"DMY")
	format date1 %td
	drop date
	rename date1 date
			
	* Formating time
	foreach var in time time_start_d time_end_d time_start_e time_end_e time_start_f time_end_f time_start_g time_end_g	time_startinteraction	{
		gen double `var'_1 = clock(`var', "hm")
		format `var'_1 %tcHH:MM
		drop `var' 
		rename `var'_1 `var'
		tostring	`var', replace usedisplayformat force
	}
		

	* Generate county as numerical value
	encode county, gen(county_n)
	drop county
	rename county_n county


	* Drop unnecessary variables
	
		drop	submissiondate	deviceid	a1altitude	subscriberid	simid	devicephonenum	formdef_version	///
				a1_cal	a1_v a2 a2_1	a8_c	a9	a10	///
				h2_1latitude h2_1longitude h2_1altitude h2_1accuracy	h1_1	h1_2	h2_2	h2_3	e11_v
	
	
	* Rename variables to follow the paper questionnaire
	replace facilitycode = a5 if mi(facilitycode)

	rename	facilitycode	hfid
	rename	(time_startinteraction time_endinteraction)	(time_start	time_end)
		tostring time time_start,replace force usedisplayformat
	
	rename	(g1	g2)	(i1 i1a)
	rename	(g3 g4)	(i2	i2a)
	rename	(g5 g6)	(i3	i3a)
	rename	(g7	g8)	(i4	i4a)

	rename c1 h1
	rename c2_1  h2a
	rename c2_2  h2b
	rename c2_c h2_total
	
	rename	a4	a2
	rename	a4_1	a2a
	rename	a4_pri	a2b
	rename	a4_level	a2c
	rename	a4_county	a2d
	rename	a5	a3
	rename	a8	a5
	rename a11 a6

	rename d2 c2
	
	rename d1 c1
	rename d1_v	c1a
	rename d3  c3
	rename d4 c4
	rename d5 c5
	rename d6 c5a
	rename d7 c6
	rename d8 c6a	
	rename d9_ch_1 c7_1
	rename d9_ch_2 c7_2
	rename d9_ch_3 c7_3
	rename d9_ch_4 c7_4
	rename d9_ch_5 c7_5
	rename d9_ch_6 c7_6
	rename d10 c8
	rename d11 c9a
	rename d12 c9b
	rename d13_ch_1 c10_1
	rename d13_ch_2 c10_2
	rename d13_ch_3 c10_3
	rename d13_ch_4 c10_4
	rename d14 c10a
	rename d15 c10b
	rename d16 c11
	rename d17 c12
	rename d18 c12a
	rename d18_1 c12b
	
	rename e1_1  d1_x
	rename e1_2  d2_x
	rename e1  d3_x
	rename e2  d4_x	
	rename e21  d5_x
	rename e21_ch_1 d5_1
	rename e21_ch_2 d5_2
	rename e21_ch_3 d5_3
	rename e21_ch_4 d5_4
	rename e21_ch_5 d5_5
	rename e21_ch_6 d5_6
	rename e21_ch_7 d5_7
	rename e21_ch_8 d5_8
	rename e21_ch_9 d5_9
	rename e21_ch_10 d5_10
	
	rename	(e3_1 e3_1_1)	(d5a_1	d5a_2)
	rename e4_1  d5a_3
	rename e4_1_1  d5a_4
	rename e5_1  d5a_5	
	rename	(e3_2 e3_2_1)	(d5b_1	d5b_2)
	rename e4_2  d5b_3
	rename e4_2_1  d5b_4
	rename e5_2  d5b_5
	rename	(e3_3 e3_3_1)	(d5c_1	d5c_2)
	rename e4_3  d5c_3
	rename e4_3_1  d5c_4
	rename e5_3  d5c_5
	order	d5a_? d5b_? d5c_?, after(d5_x)
	
	rename e6  d6_x
	rename e6_1  d6a
	rename e7_1  d6b_1
	rename e8_1  d6c_1
	rename e9_1  d6c1_1
	rename e10_1  d6c2_1
	rename e4_4  d6f_1
	rename e4_4_1  d6g_1
	rename e5_4  d6h_1
	rename e7_2  d6b_2
	rename e8_2  d6c_2
	rename e9_2  d6c1_2
	rename e10_2  d6c2_2
	rename e4_5  d6f_2
	rename e4_5_1  d6g_2
	rename e5_5  d6h_2
	rename e7_3  d6b_3
	rename e8_3  d6c_3
	rename e9_3  d6c1_3
	rename e10_3  d6c2_3
	rename e4_6  d6f_3
	rename e4_6_1  d6g_3
	rename e5_6  d6h_3
	rename e7_4  d6b_4
	rename e8_4  d6c_4
	rename e9_4  d6c1_4
	rename e10_4  d6c2_4
	rename e4_14  d6f_4
	rename e4_14_1  d6g_4
	rename e5_14  d6h_4
	rename e7_5  d6b_5
	rename e8_5  d6c_5
	rename e9_5  d6c1_5
	rename e10_5  d6c2_5
	rename e4_11  d6f_5
	rename e4_11_1  d6g_5
	rename e5_11  d6h_5
	rename e7_6  d6b_6
	rename e8_6  d6c_6
	rename e9_6  d6c1_6
	rename e10_6  d6c2_6
	rename e4_7  d6f_6
	rename e4_7_1  d6g_6
	rename e5_7  d6h_6
	
	rename	(e3_4 e3_4_1)	(d6d_1	d6e_1)
	rename	(e3_5 e3_5_1)	(d6d_2	d6e_2)
	rename	(e3_6 e3_6_1)	(d6d_3	d6e_3)
	rename	(e3_14 e3_14_1)	(d6d_4	d6e_4)
	rename	(e3_11 e3_11_1)	(d6d_5	d6e_5)
	rename	(e3_7 e3_7_1)	(d6d_6	d6e_6)
	
	rename e11  d7_x
		rename e11_ch_1 d7_1
		rename e11_ch_2 d7_2
		rename e11_ch_3 d7_3
		rename e11_ch_4 d7_4
	rename e11_1  d7a
	rename e12_1  d7b_1
	rename e13_1  d7c_1
	rename e14_1  d7d_1
	rename e15_1  d7e_1
	rename e4_8  d7h_1
	rename e4_8_1  d7i_1
	rename e5_8  d7j_1
	rename e12_2  d7b_2
	rename e13_2  d7c_2
	rename e14_2  d7d_2
	rename e15_2  d7e_2
	rename e4_9  d7h_2
	rename e4_9_1  d7i_2
	rename e5_9  d7j_2
	rename e12_3  d7b_3
	rename e13_3  d7c_3
	rename e14_3  d7d_3
	rename e15_3  d7e_3
	rename e4_10  d7h_3
	rename e4_10_1  d7i_3
	rename e5_10  d7j_3
	
	rename	(e3_8 e3_8_1)	(d7f_1	d7g_1)
	rename	(e3_9 e3_9_1)	(d7f_2	d7g_2)
	rename	(e3_10 e3_10_1)	(d7f_3	d7g_3)
	
	rename	e16	d8
	rename e16_1  d8a
		rename e16_ch_1 d8_1
		rename e16_ch_2 d8_2
		rename e16_ch_3 d8_3
	rename e17_1  d8b_1
	rename e18_1  d8c_1
	rename e19_1  d8d_1
	rename e20_1  d8e_1
	rename e4_12  d8h_1
	rename e4_12_1  d8i_1
	rename e5_12  d8j_1
	rename e17_2  d8b_2
	rename e18_2  d8c_2
	rename e19_2  d8d_2
	rename e20_2  d8e_2
	rename e4_13  d8h_2
	rename e4_13_1  d8i_2
	rename e5_13  d8j_2
	
	rename	(e3_12 e3_12_1)	(d8f_1	d8g_1)
	rename	(e3_13 e3_13_1)	(d8f_2	d8g_2)

	rename f1  e1_x
	rename f2  e2_x
	rename f3  e3_x
	rename f4  e4_x
	rename f5  e5_x
	rename f5_1  e5a
	rename f5_2  e5b
	rename f5_3  e5c
	rename f5_4  e5d
	rename f5_5  e5e
	rename f6  e5f
	rename f7  e6_x
	rename f8  e7_x
	rename f9  e7a
	rename f10_ch_1 e8_1
	rename f10_ch_2 e8_2
	rename f10_ch_3 e8_3
	rename f10_ch_4 e8_4
	rename f10_ch_5 e8_5
	rename f11  e8a
	rename f12  e9_x
	rename f13  e9a
	rename f14  e9b
	rename f16  f1_x
	rename f16_1  f1a
	rename f16_2  f1b
	rename f16_3  f1c
	rename f16_4  f1d
	rename f16_5  f1e
	rename f16_6  f1f
	rename f22  f1g
	rename f23  f1h
	rename f24  f1i
	rename f25  f1j
	rename f17  f2_x
	rename f18  f3_x
	rename f20  f4_x
	rename f21  f5_x
	rename f26  f6_x
	rename f27  f7_x
	rename f28  f7a
	rename f29  f7b
	rename f34_1  f8_x
	rename f34_2  f9_x
	rename f30  f10a
	rename f31  f10b
	rename f32  f10c
	rename f33_4  f11a
	rename f33_3  f11b
	rename f33_2  f11c
	rename f33_1  f11d
	rename f35_1u  f12a
	rename f35_2u  f12b
	rename f35_3u  f12c
	rename f35_4u  f12d
	rename f35_1o  f13a
	rename f35_2o  f13b
	rename f35_3o  f13c
	rename f35_4o  f13d
	rename f38_ch_1 f14_1
	rename f38_ch_2 f14_2
	rename f38_ch_3 f14_3
	rename f38_ch_4 f14_4
	rename f38_ch_5 f14_5
	rename f38_ch_6 f14_6
	rename f38_ch_7 f14_7
	order	f14_1-f14_7, after(f13d)
	
	rename f38_1  f14a
	rename f38_2  f14b
	rename f38_3  f14c
	rename f38_4  f14d
	rename f38_5  f14e
	rename f38_6  f14f
	rename f36_v  f15_x
	rename f36_1_1  f16d
	rename f36_2_1  f16c
	rename f36_3_1  f16b
	rename f36_4_1  f16a
		order	f16a f16b f16c f16d, after(f15_x)
	rename f37_1  f17d
	rename f37_2  f17c
	rename f37_3  f17b
	rename f37_4  f17a
		order	f17a f17b f17c f17d, after(f16d)
	rename f44_v  f18_x
	rename f44_ch_1 f18a_1
	rename f44_ch_2 f18a_2
	rename f44_ch_3 f18a_3
	rename f44_ch_4 f18a_4
		order	f18a_1 f18a_2 f18a_3 f18a_4, after(f18_x)
	rename f39  g1_x
	rename f40  g2_x
	rename f41  g3_x
	rename f42  g4_x
	rename f43  g5_x
	rename d1_x d1
	rename d2_x d2
	rename d3_x d3
	rename d4_x d4
	rename d5_x d5
	rename d6_x d6
	rename d7_x d7
	rename e1_x e1
	rename e2_x e2
	rename e3_x e3
	rename e4_x e4
	rename e5_x e5
	rename e6_x e6
	rename e7_x	e7
	rename e9_x e9
	rename f1_x f1
	rename f2_x f2
	rename f3_x f3
	rename f4_x f4
	rename f5_x f5
	rename f6_x f6
	rename f7_x f7
	rename f8_x f8
	rename f9_x f9
	rename f15_x f15
	rename f18_x f18
	rename g1_x g1
	rename g2_x g2
	rename g3_x g3
	rename g4_x g4
	rename g5_x g5

	rename g10_?	i6_?
	rename g11		i7
	
	
	** Labeling variables
	label var  hfid	"Facility ID"
	label var  time_start	"Time after consent"
	label var  time_end		"Time after the last question"
	lab	var	key				"SurveyCTO ID"
	lab	var	date			"Survey Date"
	lab	var	time			"Survey Time"
	


	
	label var  c7_1 "Water source includes: No water source"
	label var  c7_2 "Water source includes: Piped water 24 hours"
	label var  c7_3 "Water source includes: Piped water less than 24 hours"
	label var  c7_4 "Water source includes: Clean tank water"
	label var  c7_5 "Water source includes: outside HF"
	label var  c7_6 "Water source includes: Unknown"
	order	c7_?, after(c6a)
	
	label var  c10_1 "Available phones at HF includes: Mobile phone (owned by HF)"
	label var  c10_2 "Available phones at HF includes: Functioning landline (owned by HF)"
	label var  c10_3 "Available phones at HF includes: Phone (owned by staff)"
	label var  c10_4 "Available phones at HF includes: No phone available"
	order	c10_?, after(c9b)
	
	label var  c11 "Does the facility own a functioning computer or laptop?"
	label var  c12 "If we want to send you information, could we send this to your email address? (if there is access to email or internet)"
	label var  c12b "Please specify you email"
	label var  d1 "Do you know that the boards/councils/MOH are conducting Joint Inspections where they inspect all departments at the same time?"
	label var  d2 "Have you ever seen the Joint Inspection Checklist that was gazetted by the government in 2012?"
	label var  d3 "In the last 12 months, did the boards/councils/MOH come to conduct a joint inspection of the entire HF with a Joint Inspections Checklist?"
	label var  d4 "In the last 12 months, did the health management team from the county, subcounty or both come to do any type of supervision?"
		lab	define	localgov	1	"County"	///
								2	"Subcounty"	///
								3	"Both"	///
								0	"None of the above"
		lab	val	d4	localgov		
	label var  d5_1 "Boards and councils inspections includes:  Clinical Officers Council (12 months)"
	label var  d5_2 "Boards and councils inspections includes:  Kenya Medical Laboratory Technicians and Technologists Board 12 months"
	label var  d5_3 "Boards and councils inspections includes:  Medical Practitioners and Dentists Board 12 months"
	label var  d5_4 "Boards and councils inspections includes:  Nursing Council of Kenya 12 months"
	label var  d5_5 "Boards and councils inspections includes:  Nutrition Council 12 months"
	label var  d5_6 "Boards and councils inspections includes:  Pharmacy and Poisons Board 12 months"
	label var  d5_7 "Boards and councils inspections includes:  Public Health Technologists Board 12 months"
	label var  d5_8 "Boards and councils inspections includes:  Radiation Protection Board 12 months"
	label var  d5_9 "Boards and councils inspections includes:  Do not remember which one(s) came 12 months"
	label var  d5_10 "Boards and councils inspections includes:  None of the above 12 months"
	order	d5_?	d5_10, after(d5)
	drop	d5

	label var  d6	"Which of the following social franchises are you an active member of?"
		lab	define	socialfranchises	1	"Tunza (Population Services International)"	///
										2	"AMUA (Marie Stopes International)"	///
										3	"CFW Shops (HealthStore Foundation)"	///
										4	"Gold Star (FHI 360)"	///
										5	"Huduma Poa Health Network (Kisumu Medical and Education Trust)"	///
										6	"Other, please specify"	///
										0	"Not part of a social franchise"
		lab	value	d6	socialfranchises
	
	label var  d6c_1	"Do you send periodic information to Tunza about your health facility?"
	label var  d6c_2	"Do you send periodic information to AMUA about your health facility?"
	label var  d6c_3	"Do you send periodic information to CFW Shops about your health facility?"
	label var  d6c_4	"Do you send periodic information to Gold Star about your health facility?"
	label var  d6c_5	"Do you send periodic information to Huduma Poa Health Network about your health facility?"
	
	label var  d6b_6 "Which year did you become part of other social franchise?"
	label var  d6c_6 "Do you send periodic information to that franchise about your health facility?"
	label var  d6c1_6 "How often do you send information?"
	label var  d6c2_6 "Select the units: months/years"
	label var  d6d_6 "When was the last time the other social franchise came?"
	label var  d6e_6 "Enter the year"
	label var  d6f_6 "How much time did the other socialfranchise spend in the last visit?(hours)"
	label var  d6h_6 "How often does other social franchise come ? (months)"
	
	
	label var  d7 "Is your health facility accredited by any of the following accreditation agencies?"
	label var  d7_1 "Accreditation includes: National Hospital Insurance Fund (NHIF)"
	label var  d7_2 "Accreditation includes: Safecare"
	label var  d7_3 "Accreditation includes: Other, please specify"
	label var  d7_4 "Accreditation includes: Not accredited"
	label var  d7a "Accreditation: Other, please specify"
	order	d7_1-d7_4, before(d7a)
	
	label var  d7b_3 "Which year did you obtain accreditation from other agency?"
	label var  d7f_3 "When was the last time the other agency came?"
	label var  d7h_3 "How much time did  the other agency spend in the last visit?"
	label var  d7j_3 "How often does the other agency come? (months)"
	
	lab	define	d8	0	"Not accredited"	///
					1	"KENAS"	///
					2	"Other, please specify"
	lab	val	d8	d8
	
	label var  d8_1 "Lab accreditation includes: KENAS "
	label var  d8_2 "Lab accreditation includes: Other accreditation agency "
	label var  d8_3 "Lab accreditation includes: Not accredited"
	order	d8_1 d8_2 d8_3, after(d7j_3)
	
	label var  d8a "Lab accreditation includes: other, please specify"
	label var  d8b_1 "In which year did you obtain accreditation from KENAS?"
	label var  d8c_1 "Do you send periodic information to this accrediting agency about the laboratory?"
	label var  d8j_1 "How often does KENAS come? (months)"
	label var  d8b_2 "In which year did you obtain accreditation from other lab agency?"
	label var  d8f_2 "When was the last time the other lab agency came?"
	label var  d8h_2 "How much time did the other lab agency spend in the last visit? (hours)"
	label var  d8j_2 "How often does the other lab agency come? (months)"

	label var  e8_1 "Performance Indicators includes: Infant mortality"
	label var  e8_2 "Performance Indicators includes: Maternal mortality"
	label var  e8_3 "Performance Indicators includes: Immunization"
	label var  e8_4 "Performance Indicators includes: Notifiable diseases"
	label var  e8_5 "Performance Indicators includes: None of the above"
	order	e8_1-e8_5, after(e7a)
	
	label var  f11a "No. of outpatients: November 2014 (if MOH 717 form or own books available)"	
	label var  f11b "No. of outpatients: December 2014 (if MOH 717 form or own books available)"	
	label var  f11c "No. of outpatients: January 2015 (if MOH 717 form or own books available)"	
	label var  f11d "No. of outpatients: February 2015 (if MOH 717 form or own books available)"
	order	f11a f11b f11c f11d, after(f10c)
	label var  f12a "No. of outpatients under 5: November 2014 (if over 5 under 6 books are available)"	
	label var  f12b "No. of outpatients under 5: December 2014 (if over 5 under 6 books are available)"	
	label var  f12c "No. of outpatients under 5: January 2015 (if over 5 under 6 books are available)"	
	label var  f12d "No. of outpatients under 5: February 2015 (if over 5 under 6 books are available)"	
	label var  f13a "No. of outpatients over 5: November 2014"	
	label var  f13b "No. of outpatients over 5: December 2014"	
	label var  f13c "No. of outpatients over 5: January 2015"	
	label var  f13d "No. of outpatients over 5: February 2015"	

	label var  f14_1 "Lab services includes: Malaria blood smear"
	label var  f14_2 "Lab services includes: Stool O/C"
	label var  f14_3 "Lab services includes: Tuberculosis (Sputum test for AFB)"
	label var  f14_4 "Lab services includes: Urinalysis"
	label var  f14_5 "Lab services includes: Brucella"
	label var  f14_6 "Lab services includes: Blood type"
	label var  f14_7 "Lab services includes: None of the above"
	
	label var  f14a "Lab prices: Malaria blood smear"
	label var  f14b "Lab prices: Stool O/C"
	label var  f14c "Lab prices: Tuberculosis (Sputum test for AFB)"
	label var  f14d "Lab prices: Urinalysis"
	label var  f14e "Lab prices: Brucella"
	label var  f14f "Lab prices: Blood type"
	label var  f15  "Does the facility have records on lab patients and lab tests performed?"
	label var  f16a "# of patients received lab test: November 2014"
	label var  f16b "# of patients received lab test: December 2014"
	label var  f16c "# of patients received lab test: January 2015"
	label var  f16d "# of patients received lab test: February 2015"
	label var  f17a "# of lab tets received: November 2014"
	label var  f17b "# of lab tets received: December 2014"
	label var  f17c "# of lab tets received: January 2015"
	label var  f17d "# of lab tets received: February 2015"
	
	
	label var  f18 "Were there any months where the lab was partially operating or not operating, in the 4 months for which information is requested for?"
	label var  f18a_1 "Partially/not operating lab includes: November 2014"
	label var  f18a_2 "Partially/not operating lab includes: December 2014"
	label var  f18a_3 "Partially/not operating lab includes: January 2015"
	label var  f18a_4 "Partially/not operating lab includes: February 2015"
	
	
	label var  g1 "Is there a service contract for maintenance?"
	label var  g2 "Is there a written schedule (including next service date) for maintaining equipment?"
	label var  g3 "Is there a written calibration schedule available at the area where equipment is used?"
	label var  g4 "Is there a document showing regular calibration?"
	label var  g5 "Are contracts available at the facility administration?"
	label var  h1 "Does the owner of this health facility work in this health facility part time or full time?"
	label var  h2a "How many staff, NOT INCLUDING THE OWNER, work in this health facility, paid or unpaid, part time or full time? "
	label var  h2b "How many staff work in this health facility, paid or unpaid, part time or full time?"
	
		
	* Drop more variables after re-naming and re-labling is done
	drop	d7 f18 speedviolcount speedviollist g9_ch_1 g9_ch_2 g9_ch_3 g9_ch_4 g9_ch_5 g9_ch_6 g9_ch_7 g9_ch_8 g9_ch_9 g9_ch_10 g9_ch_11 ///
			g9_ch_12 g9_ch_13 g9_ch_14 g9_ch_15 g24_v	time_start_d time_end_d time_start_e time_end_e time_start_f time_end_f ///
			time_start_g time_end_g /*faith_c*/	 patients labtest h2_total	///
			f36_t1_1 f37_t2  f37_1_c  f37_2_c  f37_3_c  f37_4_c  f37_s  f37_s_v  f37_1_c2  f37_2_c2  f37_3_c2  f37_4_c2   f36_1_c_1 f36_2_c_1 f36_3_c_1 f36_4_c_1 f36_s_1 ///
			f36_1_c_4 f36_2_c_4 f36_3_c_4 f36_4_c_4 f36_s_total f36_s_v_1 f36_t2_1 f37_t1	///
			f33_t1	f33_t2	f33_1_c f33_2_c f33_3_c f33_4_c f33_s f33_4_s_v f35_t1	f35_1u_c f35_2u_c f35_3u_c f35_4u_c f35_u_s f35_u_s_v ///
			f35_t2 f35_1o_c f35_2o_c f35_3o_c f35_4o_c f35_o_s f35_o_s_v	g9	
			replace hfid=500119 if hfid==901138 // recode duplicate ID 
			
		*Replacing all the missing -99 by missing // Double check
		foreach var of varlist * {
		capture confirm string var `var'
		
		if _rc != 0 {
			replace `var' =.d if inlist(`var',-9,-99,99)

		}
		
		else { 
			replace `var' = "Don't Know" if inlist(`var',"-99","_99","-98")
		}
		rename `var' bcheck_`var'
	}	

			* Save
			save	"${qps1_bl_bc}", replace
			
	* Dismount
	veracrypt, dismount drive("${mount}") 
			

************************************************End of do file****************************************************
