/*******************************************************************************	

Project:  		KePSIE
Created on:  	December 11, 2018
Last udpate on: December 11, 2018

Written by:  	Thomas Escande (tescande@worldbank.org)

Revision: 		

********************************************************************************			

THIS DO FILE: 	This do-file prepare the variables needed for the construction of the price / demand database  


CONTENT:		Part 0 - Create globals for directories and files 
				Part 1 - Keep variables of interest
				Part 2 - Merging with facilities profile database
				Part 4 - Merge with back checks done by supervisor
				Part 5 - Save dataset

INPUTS:     	* Cleaned data taken from the QPS1 database. 
				"${KePSIE_DB}/Baseline/DataSets/Intermediate/QPS1_clean_nopii_bl.dta"

				*Backchecks done by supervisors for QPS1
				"${KePSIE_DB}/Baseline/DataSets/Intermediate/backcheck_QPS1_clean_bl.dta"


OUTPUTS:     	
				* Dropbox files: Latest versions created by person in charge (Thomas Escande)
				
					* Cleaned database ready for price / demand database construction
					"${KePSIE_DB}/Baseline/DataSets/Intermediate/Fees_Outpatient_QPS1_clean_bl.dta"
					
				
				* Local files: Produced when running this code and saved in your local GitHub folder
				
					* Cleaned database ready for price / demand database construction
					"${bl_dt}/Intermediate/Fees_Outpatient_QPS1_clean_bl.dta"
					

*******************************************************************************/

********************************************************************************
	** Part 0: Create globals for directories and files 
********************************************************************************

clear all
set more off				

	* Input files
		glo qps1_bl				"${dt_bl_clean}/qps1_bl_clean.dta"
		glo qps1_bl_bc 			"${dt_bl_clean}/qps1_bl_bc_clean.dta"
		glo listing_bl			"${dt_mast}/listing_bl.dta"
	
	* Output files 
		glo qps1_fees_outp_bl	"${dt_bl_clean}/qps1_fees_outp_bl.dta"
	 	
********************************************************************************

	** Part 1: Keep variables of interest

********************************************************************************
* Mount veracrypt drive
veracrypt "${encrypt}/Baseline Raw Identified Data", mount drive("${mount}")


use "${qps1_bl}", clear

keep f11* f12* f13* f8 f10a	f10b f10c key date hfid


********************************************************************************

	** Part 2: Merge with back checks done by supervisor

********************************************************************************	

rename hfid bcheck_hfid 

merge 1:m bcheck_hfid using "${qps1_bl_bc}", keepusing(bcheck_f11* bcheck_f12* bcheck_f13* bcheck_f8 bcheck_f10a bcheck_f10b bcheck_f10c bcheck_date)
drop if _merge == 2
drop _merge
rename bcheck_hfid hfid

*drop duplicates, taking only the later onse
drop if (hfid == 15895 & bcheck_date == 20221) | (hfid == 19239 & bcheck_date == 20271 )

********************************************************************************

	** Part 3: Merge with Listing

********************************************************************************	

rename date date_QPS1
merge 1:1 hfid using "${listing_bl}", keepusing(d37 date d4 d5 daysopen)
drop if _merge == 2
drop _merge 
rename date listing_date
rename date_QPS1 date

*Getting starting year 
gen startyear = d4
gen listing_date_year  = year(listing_date)
replace startyear = listing_date_year - d5 if mi(d4)

*Replacing I don't know using .d

foreach var of varlist f11* f12* f13* f8 bcheck_f11* bcheck_f12* bcheck_f13* bcheck_f8 bcheck_f10a	bcheck_f10b	bcheck_f10c {
	cap replace `var' = .d if `var' == -99 //Use a cap so that it just pass the string variables without breaking
}
replace hfid=500119 if hfid==901138 // recode duplicate ID 

********************************************************************************

	** Part 5: Save dataset

********************************************************************************	


		save "${qps1_fees_outp_bl}", replace
		
	* Dismount
	veracrypt, dismount drive("${mount}") 
		
	

************************************************End of do file****************************************************

