	/*****************************************************************
	PROJECT: 		KePSIE, Kenya Patient Safety Impact Evaluation
					
	TITLE:			Clean_QPS1_HCWRoster_microdata_catalog.do
				
	AUTHOR: 		Tatiana Zarate
					Seungmin Lee (slee31@worldbank.org, eatorange@gmail.com)					

	DATE CREATED:	May 23, 2016

	LAST EDITED:	Sep 4, 2017, by Seungmin Lee (slee31@worldbank.org)

	DESCRIPTION: 	Clean QPS1 HCW Roster to be published on WB Microdata Catalog.
		
	ORGANIZATION:	0 -	Preamble
					1 -	Split multiple choices questions and clean profile variables
					2 - Clean roster variables
					3 -	Reshape the database
					X - Save and Exit 

	INPUTS: 		* Raw QPS1 HCWroster data
						${KePSIE_DB}/DataAnalysis/Baseline/RawData/StaffRoster_raw_15Dec2015.dta
					
					* QPS1 questionnaire (electronic)
						${KePSIE_DB}/Data Collection/Baseline/Questionnaires/Electronic/QPS1/QPS1_eQuestionnaire2_103_Baseline.xlsx
						
					* Helper data			
						${KePSIE_DB}/DataWork/Baseline/HCW_Roster_bl/DataSets/Final/HCW_Roster_Helper_clean_pii.dta
					
					* HF Baseline profile data (as of Oct 13, 2017)
						${KePSIE_DB}/DataAnalysis/Baseline/ConstructedData/KePSIE_Baseline_Profile_13Oct2017.dta

	OUTPUTS: 		* Cleaned QPS1 HCW roster data
						${bl_dt}/Final/QPS1_HCWroster_pii.dta
						
					* Cleaned anonymized QPS1 data, to be pulished to the micro data catalog
						${bl_dt}/Final/QPS1_HCWroster_nopii.dta
						
					* Dictionary of anonymized data
						${bl_out}/Final/QPS1_HCWroster_nopii_dictionary.xlsx

	NOTE:			This do-file is based on "Clean_Staff.do" file written by Tatiana Zarate in May 2016, with the necessary changes for microdata catalog.
										
	******************************************************************/
 
 
	/****************************************************************
		SECTION 0: Preamble			 									
	****************************************************************/	
	
	* Input files
		* Raw QPS1 HCW Roster data
		glo qps1_roster_bl_raw 		"${volume}/qps1_roster_bl_raw.dta"	
			
		* QPS1 questionnaire (electronic)
		glo	qps1_bl_q				"${doc_bl}/codebooks/qps1_bl_equestionnaire_2.xlsx"
		
		* Helper data			
		glo qps1_helper_bl			"${dt_bl_clean}/qps1_helper_bl.dta"
		
		* HF Baseline profile data (as of Oct 13, 2017)
		glo profile_bl				"${dt_mast}/profile_bl.dta"

	* Output files
		glo	qps1_roster_bl			"${dt_bl_clean}/qps1_roster_bl.dta"
		
********************************************************************************

	** Part 1: Split multiple choices questions and clean profile variables

********************************************************************************	
	
	cls
	clear all
	
	* Mount veracrypt drive
	veracrypt "${encrypt}/Baseline Raw Identified Data", mount drive("${mount}")
	
	use "${qps1_roster_bl_raw}"
	
	* Keeping only those that finished QPS1
	keep if a12 ==1

	** Separates select_multiple questions 
/*** SL, 2017-9-3: The split code is the old one (NOT the new one Camila corrected) since the raw QPS2 is modified and the new code cannot be applied to the modified data
					I checked all the multiple-selection variables and no errors found	*/
	qui {
	cap prog drop splitmult
	prog def splitmult

	syntax anything using
		import excel `using', clear first
		keep if regexm(type,"^select_multiple")
		count
		local nQuestions = `r(N)'
		forvalues i = 1/`nQuestions' {

			import excel `using', clear first
				keep if regexm(type,"^select_multiple")

				local theName = name[`i']
				local theChoices = type[`i']
					local theChoices = regexr("`theChoices'","select_multiple ","")
				
			import excel `using', clear first sheet("choices")
				keep if list_name == "`theChoices'"
				
				count
				local nChoices = `r(N)'
				
				forvalues j = 1/`nChoices' {
				
					local theNextLabel = label[`j']
					local theNextValue  = name[`j']
				
					local `theName'L `" ``theName'L' "`theNextLabel'" "'
					local `theName'V ``theName'V' `theNextValue'
					
					}
					
			use `anything', clear
				
				forvalues j = 1/`nChoices' {
					
					local theNextLabel : word `j' of ``theName'L'
					local theNextValue : word `j' of ``theName'V'
					
					cap tostring `theName', replace
					
					cap gen `theName'_ch_`j' = 1 if regexm(`theName',"`theNextValue'")
						cap replace `theName'_ch_`j' = 0 if `theName' != "" & `theName'_ch_`j' != 1
						cap label var `theName'_ch_`j' "`theNextLabel'"
						
					}
					
				save `anything', replace
					
			}			
		end
	}

	tempfile split
	save `split'

	* Split the multiple-choice questions
	splitmult `split' using "${qps1_bl_q}"

	foreach var in c91 c92 c93 c94 c95 c96 c97 c98 c99 c910 c911 c912 c913 c914 c915 c916 c917 c918 c919 c920 c921 c922 c923 c924 c925 c926 c927 c928 c929 c930 c931 c932 c933 c934 c935 c936 c937 c938 c939 c940 c941 c942 c943 c944 c945 c946 c947 c948 c949 c950 c951 c952 c953 c954 c955 c956 c957 c958 c959 c960 c961 c962 c963 c964 c965 c966 c967 c968 c969 c970 c971 c972 c973 c974 c975 c976 c977 c978 {	
	gen `var'_ch_1 = 1 if  strpos(`var',"1")
	replace `var'_ch_1 = 0 if `var'_ch_1 == . & `var' != ""
	gen `var'_ch_2 = 1 if  strpos(`var',"2")
	replace `var'_ch_2 = 0 if `var'_ch_2 == . & `var' != ""
	gen `var'_ch_3 = 1 if  strpos(`var',"3")
	replace `var'_ch_3 = 0 if `var'_ch_3 == . & `var' != ""	
	}	
	
	* Destring variables before cleaning
	foreach var in facilitycode level pri c2_c roster_repeat roster_repeat_c  c14_a* c15* {
		destring `var', replace
	}
	
	* Geocodes
	rename	a1latitude latitude
	rename	a1longitude longitude
	
	lab	var	latitude	"Latitude"
	lab	var	longitude	"Longitude"
	
	* Survey Date
	gen date1 = date(date,"DMY")
	format date1 %td
	drop date
	rename date1 date
	lab	var	date	"Survey Date"
	
	* Survey time & other time variables
	foreach var in time time_start_staffroster time_end_staffroster	time_startinteraction time_endinteraction staff_ros_t1 staff_ros_t2 {
		gen double `var'_1 = clock(`var', "hm")
		order	`var'_1, after(`var')
		format `var'_1 %tcHH:MM
		drop `var' 
		rename `var'_1 `var'
		tostring	`var', replace usedisplayformat force
	}
	lab	var	time	"Survey Time"
	
	* Facility ID & Name
	replace	facilitycode=a5	if	mi(facilitycode)	&	!mi(a5)
	rename	facilitycode	hfid
	rename	facilityname	hfname
	lab	var	hfid	"Facility ID"
	lab	var	hfname	"Facility Name"
	
	* Location (county, etc.)
	gen county_n =1 if county == "Kakamega" 
	replace county_n = 2 if county == "Kilifi"
	replace county_n = 3 if county	==	"Meru"
	drop	county
	rename county_n county
	lab define countyl 1 "Kakamega" 2 "Kilifi" 3 "Meru"
	lab val county countyl
	lab	var	county	"County"
	
	rename	subcounty_c	subcounty
	replace	subcounty	=	proper(subcounty)
	lab	var	subcounty	"Subcounty"
	
	lab	var	location	"Location"
	lab	var	sublocation	"Sublocation"
	
	* Level & Ownership
	lab	define	levell	2	"Level 2"	///
						3	"Level 3"	///
						4	"Level 4"	///
						5	"Level 5"
	lab	val	level	levell
	lab	var	level	"Level"
	
	replace pri_string = "0" if pri_string=="public"
	replace pri_string = "1" if pri_string=="private"
	destring pri_string, replace
	rename	pri_string	ownership
	lab	define	ownershipl	0	"Public"	1	"Private"
	lab	val	ownership	ownershipl
	lab	var	ownership	"Ownership"
	
	* Enumerator & Supervisor
	clonevar	enumeratorid	=	a8
	clonevar	enumeratorname	=	a8_c
	clonevar	supervisorid	=	a6
	clonevar	supervisorname	=	a6_c
	
	lab	var	enumeratorid	"Enumerator ID"
	lab	var	enumeratorname	"Enumerator Name"
	lab	var	supervisorid	"Supervisor ID"
	lab	var	supervisorname	"Supervisor Name"
	
	* Start time after consent & time survey done
	/*** SL,2017-9-4: Since this is the staff roster survey, I defined start time as "time the survey started staff roster section", and end time as "the time staff roster section is done"	***/
	clonevar	time_start=time_start_staffroster
	clonevar	time_end=time_end_staffroster
	
	lab var time_start "Time staff roster started"
	lab	var	time_end "Time after the last question"
	
	* SurveyCTO key
	lab	var	key	"SurveyCTO ID"
	
	* Update profile information from HF profile data
	merge	1:1	hfid	using	"${profile_bl}", keepusing(latitude	longitude	hfname	county	subcounty	location	sublocation	/*d8*/)	update replace 	assert(2 4	5) keep(4 5) nogen
	
	* Clean other cover section variables
	drop	deviceid subscriberid simid devicephonenum audio a1altitude a1accuracy submissiondate	a1_cal a1_v a2 a2_1	pri a10 a6_c a7 a8_c a9	d1_v	///
			time_startinteraction	time_endinteraction	time_start_staffroster time_end_staffroster	formdef_version
	
	rename	(a4 a4_1 a4_pri a4_level a4_county)	(a2	a2a	a2b	a2c	a2d)
	rename	(a5 a6 a8 a11 a12)	(a3	a4	a5	a6	a7)
	
	* Update total number of staff variable from Helper data
	merge	1:1	hfid	using	"${qps1_helper_bl}", keepusing(b2_total) assert(1 3)
	gen		_helper=0	if	_merge==1
	replace	_helper=1	if	_merge==3
	lab	var	_helper	"Facility also completed Helper form"
	drop	_merge
	
	replace	c2_1	=	b2_total-1	if	_helper==1	&	c1==1
	replace	c2_2	=	b2_total	if	_helper==1	&	c1!=1
	drop	b2_total	

********************************************************************************

	** Part 2: Clean roster variables

********************************************************************************
	
	
	* Group the job group variables in one
	forvalues i = 1(1)49 {
		replace c18_v1`i' = c18_v2`i' if c18_v1`i' == . &  c18_v2`i' !=.
	}	
	drop c18_v2*
	
	* Renaiming variables to follow the paper questionnaire
	rename c1 				h1
	rename c2_1 			h2a
	rename c2_2 			h2b
	rename roster_repeat_v1 h3a
	rename roster_repeat_v2 h3b
	rename c20 				h16
	rename c6* 				h4_*
	rename c5* 				h5_*
	rename c7* 				h6_*
	rename c8* 				h7_*
	rename c9*_ch_1 		h8_1_*
	rename c9*_ch_2 		h8_2_*
	rename c9*_ch_3 		h8_3_*
	rename c10* 			h9_*
	rename c11* 			h10_*
	
	forvalues i = 1(1)78 {
		rename  c12`i' h10a_`i'
		rename  c13`i' h10c_`i'
		rename  c14`i' h10e_`i'
		rename  c15`i' h10h_`i'
	}
	
	rename c12_a* 	h10b_*	
	rename c13_a* 	h10d_*	
	rename c14_a* 	h10f_*
	rename c14_b* 	h10g_*
	rename c15_a* 	h10i_*
	rename c16* 	h11_*
	rename c17* 	h12_*
	rename c18_v1* 	h13_v1_*
	rename c18_1* 	h14a_*
	rename c18_2* 	h14b_*
	rename c18_3* 	h14c_*
	rename c18_4* 	h15_*
	
	* Define value labels
	
		* Institution
		lab	define	institution	1 "Aga Khan University"  ///
								2 "AIC Kapsowar School of Nursing"  ///
								3 "AIC Litein School of Nursing"  ///
								4 "American World University"  ///
								5 "AMREF Virtual Nursing School"  ///
								6 "Armed Forces Memorial School of Nursing"  ///
								7 "Catherine McAuley School of Nursing"  ///
								8 "Central Memorial Hospital Thika"  ///
								9 "Chogoria Hospital"  ///
								10 "Clive Irvine College ofˎursing"  ///
								11 "Consolata Hospital, Kiambu"  ///
								12 "Consolata Hospital, Nkubu School of Nursing"  ///
								13 "Consolata Hospital, Nyeri School of Nursing"  ///
								14 "Consolata Hospital, Ortum School of Nursing"  ///
								15 "Consolata Hospital, Wamba School of Nursing"  ///
								16 "Cooperative University College"  ///
								17 "Dar-es-salaam University"  ///
								18 "Egerton University"  ///
								19 "Eldoret EPAC College"  ///
								20 "Eldoret Polytechnic"  ///
								21 "Fidenza School of Nursing, Kyeni"  ///
								22 "Focus Business Institute"  ///
								23 "Getrudes Training Center"  ///
								24 "Gulu University"  ///
								25 "Haydom School Of Nursing"  ///
								26 "Health Management Agency"  ///
								27 "Hope Africa University"  ///
								28 "Hubert Kairuki Memorial University"  ///
								29 "Joan School of Nursing"  ///
								30 "Jomo Kenyatta University of Agriculture and Technology"  ///
								31 "Kabete Technical Training Institute"  ///
								32 "Kampala International University"  ///
								33 "KAPC Nairobi"  ///
								34 "Karen Hospital Training College"  ///
								35 "Kendu Adventist Hospital School of Nursing"  ///
								36 "Kendu Mission Hospital"  ///
								37 "Kenya Institute Of Professional Studies"  ///
								38 "Kenya Medical Training College"  ///
								39 "Kenya Methodist University"  ///
								40 "Kenya Polytechnic University College"  ///
								41 "Kenya Red Cross School of Emergency Technology"  ///
								42 "Kenyatta National Hospital Nursing School"  ///
								43 "Kenyatta University"  ///
								44 "Kijabe Mission Hospital"  ///
								45 "Kijabe School of Nursing"  ///
								46 "Kitui Afya Medical Centre"  ///
								47 "Kitui Mission Hospital"  ///
								48 "Kyeni Mission Hospital"  ///
								49 "Makerere University"  ///
								50 "Manipal University in India"  ///
								51 "Maseno Mission Hospital School of Nursing"  ///
								52 "Maseno University"  ///
								53 "Matata Hospital"  ///
								54 "Matric Institute of Professional Studies"  ///
								55 "Maua Methodist Hospital"  ///
								56 "Maua Methodist Hospital School of Nursing"  ///
								57 "Mbarara University"  ///
								58 "Mbukiwa College of Professional Studies"  ///
								59 "Moi Teaching and Referral Hospital"  ///
								60 "Moi University"  ///
								61 "Mombasa Polytechnic University College"  ///
								62 "Mount Kenya University"  ///
								63 "Multimedia University of Kenya"  ///
								64 "Muranga School of Nursing"  ///
								65 "Nairobi Aviation College"  ///
								66 "Nairobi Institute of Business Studies"  ///
								67 "Nairobi Technical Training Institute"  ///
								68 "Nairobi Womens Hospital"  ///
								69 "National University of Rwanda"  ///
								70 "Nazareth Medical College"  ///
								71 "Nazareth School of Nursing"  ///
								72 "Ndunyu Chege Youth Polytechnic"  ///
								73 "NEP College of Health Sciences"  ///
								74 "Ngozi University"  ///
								75 "North Coast Medical Training College"  ///
								76 "Nyansiongo High School"  ///
								77 "Nyanza School of Nursing"  ///
								78 "Nzoia College Nursing"  ///
								79 "Ortum Medical Training College"  ///
								80 "Our Lady Lourdes Mission Hospital School of Nursing, Mwea"  ///
								81 "Outspan Medical College"  ///
								82 "Parklands Training School"  ///
								83 "PC Kinyanjui Technical Training Institute"  ///
								84 "PCEA"  ///
								85 "PCEA Surburb College Nakuru"  ///
								86 "PCEA Tumutumu School of Nursing"  ///
								87 "Presbyterian University of East Africa"  ///
								88 "Pumwani Maternity School of Midwifery" ///
								89 "Ram School of Nursing"  ///
								90 "SAPTA"  ///
								91 "Shinyanga Medical Training College"  ///
								92 "St. Augustine Bugando University"  ///
								93 "St. Camillus School of Nursing"  ///
								94 "St. Clares Kaplong School of Nursing"  ///
								95 "St. Elizabeth School of Nursing, Mukumu"  ///
								96 "St. Joseph Kilgoris Medical Training College"  ///
								97 "St. Josephֳ School of Nursing Nyabondo"  ///
								98 "St. Josephӳ School of Nursing, Nyabondo"  ///
								99 "St. Lukes Hospital School of Nursing, Kaloleni"  ///
								100 "St. Lukes Hospital School of Nursing, North Kinangop"  ///
								101 "St. Maryֳ Mission Hospital"  ///
								102 "St. Paul's University"  ///
								103 "Technical University of Kenya"  ///
								104 "Tenwek School of Nursing"  ///
								105 "The Nairobi Hospital Cicely McDonnell School of Nursing"  ///
								106 "Thika Nursing Home"  ///
								107 "Thika Technical Training Institute"  ///
								108 "Tumaini University"  ///
								109 "Universal Group of Colleges"  ///
								110 "University of Burundi"  ///
								111 "University of Nairobi"  ///
								112 "Uzima University"  ///
								113 "Vision Institute of Profesionals"  ///
								0 "Other, please specify" 
							
	
		* Location
		lab define location 	1 "Eldoret"  ///
								2 "Embu" ///
								3 "Garissa" ///
								4 "Homabay" ///
								5 "Kabernet" ///
								6 "Kakamega" ///
								7 "Kapkatet" ///
								8 "Kilifi" ///
								9 "Kisumu" ///
								10 "Kitui" ///
								11 "Lodwar" ///
								12 "Loitoktok" ///
								13 "Machakos" ///
								14 "Meru" /// 
								15 "Mombasa" ///
								16 "Msambweni" ///
								17 "Muranga" ///
								18 "Nairobi" ///
								19 "Nakuru" ///
								20 "NRB-Karen" ///
								21 "NRB-Mathare" ///
								22 "Nyeri" ///
								23 "Port Reitz" ///
								24 "Siaya" ///
								25 "Thika" ///
								26 "Webuye" ///
								0 "Others, please specify"
								
		* Overseas university
		lab define overseas_univ	1 "UK" ///
									2 "US" ///
									3 "India" ///
									4 "Tanzania" ///
									5 "Uganda" ///
									0 "Other, please specify"
									
		* Job group
		lab define jobgroup		0 "Other job group, please specify" ///
								1 "A" ///
								2 "B" ///
								3 "C" ///
								4 "D" ///
								5 "E" ///
								6 "F" ///
								7 "G" ///
								8 "H" ///
								9 "I" ///
								10 "J" ///
								11 "K" ///
								12 "L" ///
								13 "M" ///
								14 "N" ///
								15 "O" ///
								16 "P" ///
								17 "Q" ///
								18 "R" ///
								19 "S" ///
								20 "T"
							
	* Universities if health background: asign names to each value
	foreach var in h10a_1 h10a_2 h10a_3 h10a_4 h10a_5 h10a_6 h10a_7 h10a_8 h10a_9 h10a_10 h10a_11 h10a_12 h10a_13 h10a_14 h10a_15 h10a_16 h10a_17 h10a_18 h10a_19 h10a_20 h10a_21 h10a_22 h10a_23 h10a_24 h10a_25 h10a_26 h10a_27 h10a_28 h10a_29 h10a_30 h10a_31 h10a_32 h10a_33 h10a_34 h10a_35 h10a_36 h10a_37 h10a_38 h10a_39 h10a_40 h10a_41 h10a_42 h10a_43 h10a_44 h10a_45 h10a_46 h10a_47 h10a_48 h10a_49 h10a_50 h10a_51 h10a_52 h10a_53 h10a_54 h10a_55 h10a_56 h10a_57 h10a_58 h10a_59 h10a_60 h10a_61 h10a_62 h10a_63 h10a_64 h10a_65 h10a_66 h10a_67 h10a_68 h10a_69 h10a_70 h10a_71 h10a_72 h10a_73 h10a_74 h10a_75 h10a_76 h10a_77 h10a_78 {
		loc	varlab:	value	label	`var'
		cap	lab	drop	`varlab'
		lab	value	`var'	institution
	}

	* Universities' location if health background: asign names to each value
	foreach var in h10c_1 h10c_2 h10c_3 h10c_4 h10c_5 h10c_6 h10c_7 h10c_8 h10c_9 h10c_10 h10c_11 h10c_12 h10c_13 h10c_14 h10c_15 h10c_16 h10c_17 h10c_18 h10c_19 h10c_20 h10c_21 h10c_22 h10c_23 h10c_24 h10c_25 h10c_26 h10c_27 h10c_28 h10c_29 h10c_30 h10c_31 h10c_32 h10c_33 h10c_34 h10c_35 h10c_36 h10c_37 h10c_38 h10c_39 h10c_40 h10c_41 h10c_42 h10c_43 h10c_44 h10c_45 h10c_46 h10c_47 h10c_48 h10c_49 h10c_50 h10c_51 h10c_52 h10c_53 h10c_54 h10c_55 h10c_56 h10c_57 h10c_58 h10c_59 h10c_60 h10c_61 h10c_62 h10c_63 h10c_64 h10c_65 h10c_66 h10c_67 h10c_68 h10c_69 h10c_70 h10c_71 h10c_72 h10c_73 h10c_74 h10c_75 h10c_76 h10c_77 h10c_78 {
		loc	varlab:	value	label	`var'
		cap	lab	drop	`varlab'
		lab	value	`var'	location
	}
	
	* Universities outsite Kenya: asign names to each value
	foreach var in h10f_1 h10f_2 h10f_3 h10f_4 h10f_5 h10f_6 h10f_7 h10f_8 h10f_9 h10f_10 h10f_11 h10f_12 h10f_13 h10f_14 h10f_15 h10f_16 h10f_17 h10f_18 h10f_19 h10f_20 h10f_21 h10f_22 h10f_23 h10f_24 h10f_25 h10f_26 h10f_27 h10f_28 h10f_29 h10f_30 h10f_31 h10f_32 h10f_33 h10f_34 h10f_35 h10f_36 h10f_37 h10f_38 h10f_39 h10f_40 h10f_41 h10f_42 h10f_43 h10f_44 h10f_45 h10f_46 h10f_47 h10f_48 h10f_49 h10f_50 h10f_51 h10f_52 h10f_53 h10f_54 h10f_55 h10f_56 h10f_57 h10f_58 h10f_59 h10f_60 h10f_61 h10f_62 h10f_63 h10f_64 h10f_65 h10f_66 h10f_67 h10f_68 h10f_69 h10f_70 h10f_71 h10f_72 h10f_73 h10f_74 h10f_75 h10f_76 h10f_77 h10f_78 {
		loc	varlab:	value	label	`var'
		cap	lab	drop	`varlab'
		lab	value	`var'	overseas_univ	
	}

	* Job type categories: asign labels to each value
	foreach var in h14b_1 h14b_2 h14b_3 h14b_4 h14b_5 h14b_6 h14b_7 h14b_8 h14b_9 h14b_10 h14b_11 h14b_12 h14b_13 h14b_14 h14b_15 h14b_16 h14b_17 h14b_18 h14b_19 h14b_20 h14b_21 h14b_22 h14b_23 h14b_24 h14b_25 h14b_26 h14b_27 h14b_28 h14b_29 h14b_30 h14b_31 h14b_32 h14b_33 h14b_34 h14b_35 h14b_36 h14b_37 h14b_38 h14b_39 h14b_40 h14b_41 h14b_42 h14b_43 h14b_44 h14b_45 h14b_46 h14b_47 h14b_48 h14b_49 h14b_50 h14b_51 h14b_52 h14b_53 h14b_54 h14b_55 h14b_56 h14b_57 h14b_58 h14b_59 h14b_60 h14b_61 h14b_62 h14b_63 h14b_64 h14b_65 h14b_66 h14b_67 h14b_68 h14b_69 h14b_70 h14b_71 h14b_72 h14b_73 h14b_74 h14b_75 h14b_76 h14b_77 h14b_78 {
		replace `var' = "0"  if `var' == "0"
		replace `var' = "1"  if `var' == "A"
		replace `var' = "2"  if `var' == "B"
		replace `var' = "3"  if `var' == "C"
		replace `var' = "4"  if `var' == "D"
		replace `var' = "5"  if `var' == "E"
		replace `var' = "6"  if `var' == "F"
		replace `var' = "7"  if `var' == "G"
		replace `var' = "8"  if `var' == "H"
		replace `var' = "9"  if `var' == "I"
		replace `var' = "10" if `var' == "J"
		replace `var' = "11" if `var' == "K"
		replace `var' = "12" if `var' == "L"
		replace `var' = "13" if `var' == "M"
		replace `var' = "14" if `var' == "N"
		replace `var' = "15" if `var' == "O"
		replace `var' = "16" if `var' == "P"
		replace `var' = "17" if `var' == "Q"
		replace `var' = "18" if `var' == "R"
		replace `var' = "19" if `var' == "S"
		replace `var' = "20" if `var' == "T"	
		
		destring `var', replace		
	 
		loc	varlab:	value	label	`var'
		cap	lab	drop	`varlab'
		lab	value	`var'	jobgroup
	}

	** These variables should be string
	foreach var in h10i_16	h10i_17	h10i_18	h10i_19	h10i_20	h10i_21	h10i_22	h10i_23	h10i_24	h10i_25	h10i_26	h10i_27	h10i_28	h10i_29	h10i_30	h10i_31	h10i_32	h10i_33	h10i_34	h10i_35	h10i_36	h10i_37	h10i_38	h10i_39	h10i_40	h10i_41	h10i_42	h10i_43	h10i_44	h10i_45	h10i_46	h10i_47	h10i_48	h10i_49	h10i_50	h10i_51	h10i_52	h10i_53	h10i_54	h10i_55	h10i_56	h10i_57	h10i_58	h10i_59	h10i_60	h10i_61	h10i_62	h10i_63	h10i_64	h10i_65	h10i_66	h10i_67	h10i_68	h10i_69	h10i_70	h10i_71	h10i_72	h10i_73	h10i_74	h10i_75	h10i_76	h10i_77	h10i_78 {
		tostring `var', replace	
		replace `var' = "" if `var' == "."
		replace `var' = "" if `var' == "99"
	}
		

********************************************************************************

	** Part 3: Reshape the data and clean long-format data

********************************************************************************

	* Drop unnecessary variables before reshaping
	drop	c2_c	roster_repeat	roster_repeat_c	c9?	c9??	staff_ros_t1 staff_ros_t2 starttime endtime time_endinteraction2	c21
	
	**  Reshape the database 
	reshape long h4_ h5_ h6_ h7_ h8_1_ h8_2_ h8_3_ h9_ h10_ h10a_ h10b_ h10c_ h10d_ h10e_ h10f_ h10g_ h10h_ h10i_ h11_ h12_ h13_v1_ h14a_ h14b_ h14c_ h15_, i(hfid) j(j)
	
	drop if (j!=1	&	(h4_ == "" | h4_ == "0"))
		
		
	* Replace value for those didn't get proper value assigned from the questionnaire
	replace	h10e_	=	"Outside of Kenya"	if	h10e_=="0"
	
	* Combine h10f and h10g
	decode	h10f_, gen(h10f_str)
	replace h10f_str = h10g_ if h10f_str=="Other, please specify"
	replace h10f_str = "Don't know" if inlist(h10f_str,"-99","_99")
	replace h10f_str = itrim(trim(upper(h10f_str)))
	order	h10f_str, after(h10f_)
	drop	h10f_		h10g_
	rename	h10f_str	h10f_
	
	** Labeling staff variables 
	lab var h4_ 		"Enter staff name"
	lab var h5_ 		"Enter [staff name]'s detailed staff type"
	lab var h6_ 		"Enter [staff name]'s gender"
	lab var h7_ 		"Enter [staff name]'s age"
	lab var h8_1_ 		"Staff type group includes: Clinical staff"
	lab var h8_2_ 		"Staff type group includes: Administrative staff"
	lab var h8_3_ 		"Staff type group includes: Support staff"
	lab var h9_			"Enter the highest level of education [staff name] has completed"
	lab var h10_ 		"Enter if [staff name] has a health background"
	lab var h10a_ 		"Enter institution where [staff name] completed his/her most recent health-related education?"
	lab var h10b_ 		"Other, please specify"
	lab var h10c_ 		"Enter the branch of KMTC [staff name] attended"
	lab var h10d_ 		"Other, please specify"
	lab var h10e_ 		"Enter county that [staff name] completed his/her most recent health-related education"
	lab var h10f_ 		"If not in Kenya, in which country?"
	*lab var h10g_ 		"Other, please specify"
	lab var h10h_ 		"Enter city or town that this institution is located in"
	lab var h10i_ 		"Other, please specify"
	lab var h11_ 		"Enter year in which [staff name] completed his/her education"
	lab var h12_ 		"How many days per month does [staff name] usually work at this facility?"
	lab var h13_v1_	 	"How will you be entering take-home pay?"
	lab var h14a_ 		"How much take-home pay does [staff name] receive every month from working in this health facility?"
	lab var h14b_		"Which job group does [staff name]'s take-home pay every month from working in this health facility fall under?"
	lab var h14c_ 		"Other, please specify"
	lab var h15_ 		"Is the take-home pay:"
	
	** Labeling categories for cities
	lab define h10h_1 	0 "Other, please specify" ///	
						1 "Mombasa" ///
						2 "Eldama Ravine" ///
						3 "Bomet" ///
						4 "Bungoma" ///
						5 "Kimilili" ///
						6 "Malakisi" ///
						7 "Webuye" ///
						8 "Busia" ///
						9 "Malaba" ///
						10 "Nambale" ///
						11 "Iten/Tambach" ///
						12 "Embu" ///
						13 "Runyenjes" ///
						14 "Garissa" ///
						15 "Homa Bay" ///
						16 "Kendu Bay" ///
						17 "Mbita Point" ///
						18 "Isiolo" ///
						19 "Kitengela" ///
						20 "Ngong" ///
						21 "Ongata Rongai" ///
						22 "Kakamega" ///
						23 "Malava" ///
						24 "Mumias" ///
						25 "Kericho" ///
						26 "Kipkelion" ///
						27 "Litein" ///
						28 "Londiani" ///
						29 "Juja" ///
						30 "Karuri" ///
						31 "Kiambu" ///
						32 "Kikuyu" ///
						33 "Limuru" ///
						34 "Ruiru" ///
						35 "Thika" ///
						36 "Kilifi" ///
						37 "Malindi" ///
						38 "Mariakani" ///
						39 "Mtwapa" ///
						40 "Kerugoya/Kutus" ///
						41 "Keroka" ///
						42 "Kisii" ///
						43 "Ogembo" ///
						44 "Suneka" ///
						45 "Tabaka" ///
						46 "Ahero" ///
						47 "Awasi" ///
						48 "Kisumu" ///
						49 "Muhoroni" ///
						50 "Oyugis" ///
						51 "Kitui" ///
						52 "Mwingi" ///
						53 "Ukunda" ///
						54 "Nanyuki" ///
						55 "Nyahururu" ///
						56 "Rumuruti" ///
						57 "Athi River(Mavoko)" ///
						58 "Kangundo-Tala" ///
						59 "Machakos" ///
						60 "Matuu" ///
						61 "Mandera" ///
						62 "Moyale" ///
						63 "Maua" ///
						64 "Meru" ///
						65 "Kehancha" ///
						66 "Migori" ///
						67 "Rongo" ///
						68 "Makuyu" ///
						69 "Maragua" ///
						70 "Nairobi" ///
						71 "Gilgil" ///
						72 "Molo" ///
						73 "Naivasha" ///
						74 "Nakuru" ///
						75 "Kapsabet" ///
						76 "Narok" ///
						77 "Nyamira" ///
						78 "Nyansiongo" ///
						79 "Ol Kalou" ///
						80 "Nyeri" ///
						81 "Maralal" ///
						82 "Bondo" ///
						83 "Siaya" ///
						84 "Ugunja" ///
						85 "Ukwala" ///
						86 "Yala" ///
						87 "Taveta" ///
						88 "Voi" ///
						89 "Wundanyi" ///
						90 "Chuka" ///
						91 "Kitale" ///
						92 "Nandi Hills" ///
						93 "Kakuma" ///
						94 "Lodwar" ///
						95 "Burnt Forest" ///
						96 "Eldoret" ///
						97 "Luanda" ///
						98 "Vihiga" ///
						99 "Wajir" ///
						100 "Kapenguria"
	lab values h10h_ h10h_1

	** Gen dummy variables for staff type question	
	gen h5_1 = 1 if strpos(h5_, "clinicalofficer")
	gen h5_2 = 1 if strpos(h5_, "chw")
	gen h5_3 = 1 if strpos(h5_, "dentist")
	gen h5_4 = 1 if strpos(h5_, "doctormo")
	gen h5_5 = 1 if strpos(h5_, "hospitaladmin")
	gen h5_6 = 1 if strpos(h5_, "intern")
	gen h5_7 = 1 if strpos(h5_, "labtech")
	gen h5_8 = 1 if strpos(h5_, "labsci")
	gen h5_9 = 1 if strpos(h5_, "midwife")
	gen h5_10 = 1 if strpos(h5_, "nurse_bsc")
	gen h5_11 = 1 if strpos(h5_, "nurse_r")
	gen h5_12 = 1 if strpos(h5_, "nurse_e")
	gen h5_13 = 1 if strpos(h5_, "nurseaide")
	gen h5_14 = 1 if strpos(h5_, "nutritionist")
	gen h5_15 = 1 if strpos(h5_, "pharm")
	gen h5_16 = 1 if strpos(h5_, "pho")
	gen h5_17 = 1 if strpos(h5_, "specialist")
	gen h5_18 = 1 if strpos(h5_, "therapist")
	gen h5_19 = 1 if strpos(h5_, "otherclinical")
	gen h5_20 = 1 if strpos(h5_, "otheradmin")
	gen h5_21 = 1 if strpos(h5_, "othersupport")

	replace h5_1 = 0 if h5_1 ==. & h5_ != ""
	replace h5_2 = 0 if h5_2 ==. & h5_ != ""
	replace h5_3 = 0 if h5_3 ==. & h5_ != ""
	replace h5_4 = 0 if h5_4 ==. & h5_ != ""
	replace h5_5 = 0 if h5_5 ==. & h5_ != ""
	replace h5_6 = 0 if h5_6 ==. & h5_ != ""
	replace h5_7 = 0 if h5_7 ==. & h5_ != ""
	replace h5_8 = 0 if h5_8 ==. & h5_ != ""
	replace h5_9 = 0 if h5_9 ==. & h5_ != ""
	replace h5_10 = 0 if h5_10 ==. & h5_ != ""
	replace h5_11 = 0 if h5_11 ==. & h5_ != ""
	replace h5_12 = 0 if h5_12 ==. & h5_ != ""
	replace h5_13 = 0 if h5_13 ==. & h5_ != ""
	replace h5_14 = 0 if h5_14 ==. & h5_ != ""
	replace h5_15 = 0 if h5_15 ==. & h5_ != ""
	replace h5_16 = 0 if h5_16 ==. & h5_ != ""
	replace h5_17 = 0 if h5_17 ==. & h5_ != ""
	replace h5_18 = 0 if h5_18 ==. & h5_ != ""
	replace h5_19 = 0 if h5_19 ==. & h5_ != ""
	replace h5_20 = 0 if h5_20 ==. & h5_ != ""
	replace h5_21 = 0 if h5_21 ==. & h5_ != ""
	
	** Checking
	//br h5_  h5_1 h5_2 h5_3 h5_4 h5_5 h5_6 h5_7 h5_8 h5_9 h5_10 h5_11 h5_12 h5_13 h5_14 h5_15 h5_16 h5_17 h5_18
	drop h5_
	
	label var h5_1 "Staff type includes: Clinical officer"
	label var h5_2 "Staff type includes: Community health worker"
	label var h5_3 "Staff type includes: Dentist"
	label var h5_4 "Staff type includes: Doctor or medical officer"
	label var h5_5 "Staff type includes: Hospital administrator/executive director/superintendent"
	label var h5_6 "Staff type includes: Intern/Student"
	label var h5_7 "Staff type includes: Lab technologist/lab technician"
	label var h5_8 "Staff type includes: Laboratory scientist"
	label var h5_9 "Staff type includes: Midwife"
	label var h5_10 "Staff type includes: Nurse (BSc)"
	label var h5_11 "Staff type includes: Nurse (Registered Community Health Nurses (KRHCN))"
	label var h5_12 "Staff type includes: Nurse (Enrolled Community Health Nurses (EHCN))"
	label var h5_13 "Staff type includes: Nurse Aides"
	label var h5_14 "Staff type includes: Nutritionist"
	label var h5_15 "Staff type includes: Pharmacist/pharmacy technologist/dispenser"
	label var h5_16 "Staff type includes: Public health officer (PHO)"
	label var h5_17 "Staff type includes: Specialists (e.g., haemotologists, radiographers)"
	label var h5_18 "Staff type includes: Therapist/counselor"
	label var h5_19 "Staff type includes: Other clinical staff"
	label var h5_20 "Staff type includes: Other administrative staff"
	label var h5_21 "Staff type includes: Other support staff"
	
	** Job groups I and O do not exist in the official documents 
	replace h14b_ = . if h14b_ == 9 | h14b_ == 15
	
	* Rename variables
	/* SL, 2017-9-4: I constructed "staff ID" variable to give unique ID for each staff within facility. Should I drop it?	*/
	rename	j	staffid
		lab	var	staffid	"Staff ID"
	rename h4_ h4
	rename h6_ h6
	rename h7_ h7
	rename h8_1_ h8_1
	rename h8_2_ h8_2
	rename h8_3_ h8_3
	rename h9_	h9
	rename h10_ h10
	rename h10a_ h10a
	rename h10b_ h10b
	rename h10c_ h10c
	rename h10d_ h10d
	rename h10e_ h10e
	rename h10f_ h10f
	*rename h10g_ h10g
	rename h10h_ h10h
	rename h10i_ h10i
	rename h11_ h11
	rename h12_ h12
	rename h13_v1_ h13
	rename h14a_ h14a
	rename h14b_ h14b
	rename h14c_ h14c
	rename h15_ h15
		
		
	* Order variables
	order	latitude	longitude	date	time	hfid	hfname	county	subcounty	///
			location	sublocation	level	ownership	supervisorid	supervisorname	enumeratorid	enumeratorname	time_start	time_end
	order	key, last
	
	order	staffid,	after(h3b)
	order	h8_?, after(h7)
	order	h5_*, after(h4)
	order	h16, after(h15)
	
	
	* Clean value lables
	
		* Create macros for each type of variables
		qui	ds	*
		global	allvars	`r(varlist)'
		
		global	excludevars	hfid	latitude	longitude	date	time	hfname	location	sublocation	supervisorid	supervisorname	///
							enumeratorid	enumeratorname	time_start	time_end	a2a	a3	a4	a5	staffid	h4	h10b	h10d	h10f	h10g	///
							h10h	h10i	h14c	key


		qui	ds	a2	a2b	h1	h5_? h5_??	h8_1	h8_2	h8_3	h10	h16
		global	dummyvars	`r(varlist)'
		
		global	categoryvars	county	subcounty	level	ownership	a2c	a2d	a6	a7	h6	h9	h10a	h10c	h10e	h11	h13	h14b	h15

		global	coutinuousvars	h2a	h2b	h3a	h3b	h7	h12	h14a
		
		* Assign unique "yesno" label to all dummy vars
		foreach	dummyvar	of	global	dummyvars	{
			cap	lab	drop	`dummyvar'
			lab	val	`dummyvar'	yesno
		}
		*
		
	* Drop profile variables, as they already exist in the main QPS1 data
	drop	a2 a2a a2b a2c a2d a3 a4 a5 a6 a7
	
	* Replace -99 as "I don't know"
	ds	h5_1-h16, has(type numeric)
	loc	numvars	`r(varlist)'
	
	foreach	numvar	of	loc	numvars	{
		replace	`numvar'=.d	if	`numvar'==-99
	}

********************************************************************************

	** Part X: Save & Exit

********************************************************************************
	
	/* Save identified data
	
		* Make dta
		notes	drop _dta
		notes:	qps1_HCWroster_pii / created by `name_do' - `c(username)' - `c(current_date)' ///
				Cleaned dataset of QPS1 HCW roster data

		* Git branch info
		stgit9 
		notes : qps1_HCWroster_pii / Git branch `r(branch)'; commit `r(sha)'.
		replace hfid=500119 if hfid==901138 // recode duplicate ID 

		compress
		
		if		c(stata_version)>=14	{
			saveold	"${qps1_HCWroster_pii}", v(13) replace
		}
		else	{
			save	"${qps1_HCWroster_pii}", replace
		}
		*/
	
	* Save anonymized data

		* Import masked ID from HF inventory
		*use	"${qps1_HCWroster_pii}", clear
	
		/* Merge with the inventory data to have alternate ID.
		preserve
		use "${profile_bl}", clear
		replace hfid=500119 if hfid==901138 // recode duplicate ID 
		tempfile hf_profile
		save `hf_profile'
		restore
		merge	m:1	hfid	using	`hf_profile', keepusing(hfid_m) assert(3) nogen
		order	hfid_m, after(hfid)
		*/
		* List of PII
		loc	PII	latitude longitude hfname location sublocation supervisorid supervisorname enumeratorid enumeratorname h4 h6 h7 // hfid
		drop	`PII'
	
		save	"${qps1_roster_bl}", replace
		
		/* Make dta
		notes	drop _dta
		notes:	qps1_HCWroster_nopii / created by `name_do' - `c(username)' - `c(current_date)' ///
				Cleaned dataset of QPS1 HCW roster data, anonymized to be published.

		* Git branch info
		stgit9 
		notes : qps1_HCWroster_nopii / Git branch `r(branch)'; commit `r(sha)'.
		*/
		/* Generate dictionary
		
		preserve
			descsave, saving("${bl_out}/qps1_HCWroster_nopii_dictionary.dta", replace)
			
			use	"${bl_out}/qps1_HCWroster_nopii_dictionary.dta", clear
			drop order format vallab
			
			export excel using "${qps1_HCWroster_nopii_dic}", firstrow(varlabels) replace
			erase	"${bl_out}/qps1_HCWroster_nopii_dictionary.dta"
		restore
		
		* Save
		if		c(stata_version)>=14	{
			saveold	"${qps1_HCWroster_nopii}", v(13) replace
		}
		else	{
			save	"${qps1_HCWroster_nopii}", replace
		}
		*
	*/
				
	/*
	* Variable tabulation
		
	use	"${qps1_HCWroster_cleaned}", clear
	
	log using	"${bl_do}/Cleaning/logs/variable_tabulation_QPS1", replace
	
	
	foreach var of global allvars	{
		loc	varlab:	variable	label	`var'
		di "Variable: `var', `varlab'"
		loc	in_exclude:			list	posof	"`var'"	in	global(excludevars)
		loc	in_dummy:			list	posof	"`var'"	in	global(dummyvars)
		loc	in_category:		list	posof	"`var'"	in	global(categoryvars)
		loc	in_continuous:		list	posof	"`var'"	in	global(coutinuousvars)

		
		if	`in_exclude'!=0	{
			di	"`var'	is excluded from the tabulation"
		}
		else	if	`in_dummy'!=0	{
			tab1	`var'
		}
		else	if	`in_category'!=0	{
			tab1	`var'
		}
		else	if	`in_continuous'!=0	{
			tabstat `var', s(n mean min max) format(%10.2fc)
		}
		di ""
	}
	*
	*/
	* Dismount
	veracrypt, dismount drive("${mount}") 

