/*******************************************************************************	

Project:  		KePSIE
Created on:  	December 12, 2018
Last udpate on: December 12, 2018

Written by:  	Thomas Escande (tescande@worldbank.org)

Revision: 		

********************************************************************************			

THIS DO FILE: 	This do-file construct the average demand outcomes and deals with outliers 


CONTENT:		Part 0 - Create globals for directories and files and locals to be used throughout the do file
				Part 1 - Looking at 0 and putting them to missing when issues
				Part 2 - Estimation of daily data from other sources 
						2.1 Estimation from weekly data sources
						2.2 Estimation from daily data sources
						2.3 Inputing daily data in weekly data
				Part 3: Set all data from 2017 as missing for facilities which started in 2018
				Part 4: Constructing daily averages variables from monthly source with no missing days
						4.1 Set as untrustful months with days of missing data
						4.2 Get the daily average variables from the non missing months
				Part 5: Inputing when some days are missing, for 5 or 10 missing days
						5.1 Set as untrustful months when at least 5 or 10 days are missing
						5.2 Get the daily average variables from the non missing months
				Part 6: Variables inputing any number of missing days
						6.1 Identifying extrem untrustful observation - no rule for now, just observation 
						6.2 Get the daily average variables from the non missing months
				Part 7: Identifying outliers from the 8 sources of data : 7 months plus weekly 
				Part 8: Inputing with average from other data sources
				Part 9: Taking the averages
				Part 10: Renaming main variables we are going to use later
				Part 11: Save dataset


INPUTS:     	* Cleaned data taken from the fees/ outpatient demand cleaned database
				"${KePSIE_DB}/Baseline/DataSets/Intermediate/Fees_Outpatient_clean_bl.dta"


OUTPUTS:     	
				* Dropbox files: Latest versions created by person in charge (Thomas Escande)
				
					* Database with final outpatient outcomes ready for analysis
					"${KePSIE_DB}/Baseline/DataSets/Intermediate/Averages_Outpatient_bl.dta"
					
				
				* Local files: Produced when running this code and saved in your local GitHub folder
				
					* Database with final outpatient outcomes ready for analysis
					"${bl_dt}/Intermediate/Averages_Outpatient_bl.dta"
					

*******************************************************************************/

********************************************************************************
	** Part 0: Create globals for directories and files 
********************************************************************************

clear all
set more off				

	* Input files
		glo fees_outp_bl 		"${dt_bl_const}/fees_outp_bl.dta"

	
	* Output files: 
		glo outp_av 			"${dt_bl_const}/outp_av_bl.dta"

		
		
		use "${fees_outp_bl}", clear


*Defining locals needed for the do file
*Number of days per month depending on the number of opening days
*November 2014
local days_a 		= 30
local days_a_6dw 	= 25 //assuming not working on sundays
local days_a_5dw 	= 20 //assuming not working on saturdays and sundays
local days_a_4dw 	= 16 //assuming not working on Mondays, saturdays and sundays

*December 2014
local days_b 		= 31
local days_b_6dw 	= 27 //assuming not working on sundays
local days_b_5dw 	= 23 //assuming not working on saturdays and sundays
local days_b_4dw 	= 19 //assuming not working on Mondays, saturdays and sundays

*January 2015
local days_c 		= 31
local days_c_6dw 	= 27 //assuming not working on sundays
local days_c_5dw 	= 22 //assuming not working on saturdays and sundays
local days_c_4dw 	= 17 //assuming not working on Mondays, saturdays and sundays

*February 2015
local days_d 		= 28
local days_d_6dw 	= 24 //assuming not working on sundays
local days_d_5dw 	= 20 //assuming not working on saturdays and sundays
local days_d_4dw 	= 16 //assuming not working on Mondays, saturdays and sundays



*Variable useful to know how many observations were put to missing in each case.
foreach month in a b c d {
	gen id_change_`month'_bl = 0 if !mi(outpatient_`month'_bl)
	}

****************************************************************************************************
*Part 1: Looking at untrustful 0 and put them to missing
****************************************************************************************************
*Creating a variable with all the 0, original variables
foreach month in a b c d {
	gen outpatient_original_`month'_bl = outpatient_`month'_bl
}


global outpatient  outpatient_d_sf_bl outpatient_a_bl outpatient_b_bl outpatient_c_bl outpatient_d_bl 	

*We can look at 0 for outpatient variable. 0 can only happen if the facility is of small size. Put to missing when there is a doubt. 

	egen outpatient_max = rowmax($outpatient)
	egen outpatient_min = rowmin($outpatient)

list hfid $outpatient if outpatient_min == 0


*12380 : 7 for daily, 0 for all months a b c and 225 for d | 18970 : 45 for daily, 0 for all months a b c and 663 for d | 900693 : 50 for daily, 0 for all months a b c and 359 for d | 901526 : 5 for daily, 0 for all months a b c and 137 for d  
foreach month in a b c  {
	replace outpatient_`month'_bl = .q if hfid == 12380 | hfid == 18970 | hfid == 900693 | hfid == 901526
	} 

*17596 : 70 for daily, 0 for b and 1500 for a, 1643 for c, 1409 for d 
	replace outpatient_b_bl = .q if hfid == 17596 

*900009 : 5 for daily, 0 for all months a b c and d 
foreach month in a b c d {
	replace outpatient_`month'_bl = .q if hfid == 900009 
	}


****************************************************************************************************
*Part 3: Set all data from 2014 as missing for facilities which started in 2015
****************************************************************************************************
tab outpatient_a_bl if startyear == 2015 
tab outpatient_b_bl if startyear == 2015 

foreach month in a b {
	replace id_change_`month'_bl  = 1  if startyear == 2018 & outpatient_`month'_bl == 0	 & !mi(id_change_`month'_bl)
	replace outpatient_`month'_bl = .  if startyear == 2018 & outpatient_`month'_bl == 0

	replace id_change_`month'_bl  = 1  if startyear == 2018 & outpatient_`month'_bl >  0 & !mi(outpatient_`month'_bl) & !mi(id_change_`month'_bl)
	replace outpatient_`month'_bl = .q if startyear == 2018 & outpatient_`month'_bl >  0 & !mi(outpatient_`month'_bl)
}

****************************************************************************************************
*Part 4: Constructing daily averages variables from monthly source with no missing days
****************************************************************************************************

	*--------------------------------------------------------*
	* 4.1 Set as untrustful months with days of missing data *
	*--------------------------------------------------------*

foreach month in a b c d {
	gen 	  outpatient_complete_`month'_bl 	= outpatient_`month'_bl 
	label var outpatient_complete_`month'_bl  "$`month':Monthly outpatients without missing data" 
}

	*--------------------------------------------------------------*
	* 4.2 Get the daily average variables from the complete months *
	*--------------------------------------------------------------*

	*Averaging over each month
foreach month in a b c d {
	gen 	outpatient_complete_d_`month'_bl = outpatient_complete_`month'_bl / `days_`month'' 	    if daysopen == 7  
	replace outpatient_complete_d_`month'_bl = outpatient_complete_`month'_bl / `days_`month'_6dw'  if daysopen == 6 | mi(daysopen)  
	replace outpatient_complete_d_`month'_bl = outpatient_complete_`month'_bl / `days_`month'_5dw'  if daysopen == 5  
	replace outpatient_complete_d_`month'_bl = outpatient_complete_`month'_bl / `days_`month'_4dw'  if daysopen <= 4  
}


****************************************************************************************************
*Part 7: Identifying outliers from the 5 sources of data : 4 months plus daily self reported
****************************************************************************************************
//Done it first as after that we input the average so it would be an issue
	foreach type in complete miss5 miss10 missall {

global complete outpatient_d_sf_bl outpatient_complete_d_a_bl outpatient_complete_d_b_bl outpatient_complete_d_c_bl ///
                outpatient_complete_d_d_bl 
	
	}

*Generating all the useful variables: mean, mean without the observation, absolute distance from the min to observation, relative distance from the min to observation
	egen month_data_complete_bl     = rownonmiss($complete) 
	tab month_data_complete_bl		
	egen outpatient_complete_av_bl  = rowmean($complete)

	

		foreach month in a b c d {
			*Variable useful to know how many observations were put to missing in each case.
			gen 	flag_complete_`month'_bl 		  = 0 if !mi(outpatient_complete_d_`month'_bl)

			gen 	av_minus_data_complete_`month'_bl  = (outpatient_complete_av_bl - outpatient_complete_d_`month'_bl/month_data_complete_bl) * (month_data_complete_bl/(month_data_complete_bl-1)) if month_data_complete_bl > 2
			
			gen 	diff_to_av_complete_`month'_bl     = (outpatient_complete_d_`month'_bl - av_minus_data_complete_`month'_bl)  if outpatient_complete_d_`month'_bl > av_minus_data_complete_`month'_bl
			replace diff_to_av_complete_`month'_bl     = -(outpatient_complete_d_`month'_bl - av_minus_data_complete_`month'_bl) if outpatient_complete_d_`month'_bl <= av_minus_data_complete_`month'_bl

			gen	    dist_to_av_complete_`month'_max_bl = diff_to_av_complete_`month'_bl / av_minus_data_complete_`month'_bl if outpatient_complete_d_`month'_bl > av_minus_data_complete_`month'_bl  & month_data_complete_bl > 2 
			gen 	dist_to_av_complete_`month'_min_bl = diff_to_av_complete_`month'_bl/ outpatient_complete_av_bl 		 if outpatient_complete_d_`month'_bl <= av_minus_data_complete_`month'_bl & month_data_complete_bl > 2 

		}


*******Identifying outliers and replacing them with the mean without the observation. 3 main rules: 
*1.Replace at most one observation per facility, the furthest one.
*2.If observation is a max, then outliers when the relative distance to the mean without observation is more than 2
*3.If observation is a min, then outliers when the ratio of ditance to the mean without average to the mean is more than 1

global complete2 diff_to_av_complete_a_bl diff_to_av_complete_b_bl diff_to_av_complete_c_bl diff_to_av_complete_d_bl 
 
		egen outpatient_complete_max_bl = rowmax($complete2)

		foreach month in a b c d {
			count 									if dist_to_av_complete_`month'_max_bl > 2 & !mi(dist_to_av_complete_`month'_max_bl) //
			gen  	outpatient_complete_noo_d_`month'_bl = outpatient_complete_d_`month'_bl
			replace outpatient_complete_noo_d_`month'_bl = av_minus_data_complete_`month'_bl if dist_to_av_complete_`month'_max_bl > 2 & !mi(dist_to_av_complete_`month'_max_bl) & diff_to_av_complete_`month'_bl == outpatient_complete_max_bl
			replace outpatient_complete_noo_d_`month'_bl = av_minus_data_complete_`month'_bl if dist_to_av_complete_`month'_min_bl > 1 & !mi(dist_to_av_complete_`month'_min_bl) & diff_to_av_complete_`month'_bl == outpatient_complete_max_bl

			*Flagging observations which have been changed 
			replace flag_complete_`month'_bl = 1 if dist_to_av_complete_`month'_max_bl > 2 & !mi(dist_to_av_complete_`month'_max_bl) & diff_to_av_complete_`month'_bl == outpatient_complete_max_bl
			replace flag_complete_`month'_bl = 1 if dist_to_av_complete_`month'_min_bl > 1 & !mi(dist_to_av_complete_`month'_min_bl) & diff_to_av_complete_`month'_bl == outpatient_complete_max_bl
		}

		gen flag_complete_bl = 0
		replace flag_complete_bl = 1 if flag_complete_a_bl == 1 | flag_complete_b_bl == 1 | flag_complete_c_bl == 1 | flag_complete_d_bl == 1 
		list hfid $complete if flag_complete_bl == 1


*Generating ratio min max to look for other outliers. The ones which still have high ratio are small facilities or high volatility facilities

global complete_noo outpatient_complete_noo_d_a_bl outpatient_complete_noo_d_b_bl outpatient_complete_noo_d_c_bl outpatient_complete_noo_d_d_bl 


	egen outpatient_complete_noo_max_bl = rowmax($complete_noo)
	egen outpatient_complete_noo_min_bl = rowmin($complete_noo)

	gen ratio_maxmin_complete_noo_bl = outpatient_complete_noo_max_bl / outpatient_complete_noo_min_bl  
	*hist ratio_maxmin_complete_noo_bl, freq




****************************************************************************************************
*Part 8: Inputing with average from other data sources
****************************************************************************************************
global complete outpatient_d_sf_bl outpatient_complete_d_a_bl outpatient_complete_d_b_bl outpatient_complete_d_c_bl outpatient_complete_d_d_bl 
	
	egen  outpatient_complete_d_av_bl   = rowmean($complete)
	egen  obs_missing_complete_w_bl     = rownonmiss($complete)

		foreach month in a b c d {
			gen 	outpatient_complete_input_d_`month'_bl = outpatient_complete_d_`month'_bl
			replace outpatient_complete_input_d_`month'_bl = outpatient_complete_d_av_bl if mi(outpatient_complete_d_`month'_bl)
		}

count if obs_missing_complete_w_bl == 1  & !mi(outpatient_d_sf_bl) //Most of the data come from the weekly anyway, 131 out of 155 or 169 for Januray or February

	
 


****************************************************************************************************
*Part 9: Taking the averages
****************************************************************************************************
global complete_noo  outpatient_complete_noo_d_a_bl outpatient_complete_noo_d_b_bl outpatient_complete_noo_d_c_bl outpatient_complete_noo_d_d_bl 
	
	egen    outpatient_complete_noo_d_av_bl   = rowmean($complete_noo)
	replace outpatient_complete_noo_d_av_bl   = outpatient_d_sf_bl              if mi(outpatient_complete_noo_d_av_bl)




****************************************************************************************************
*Part 10: Renaming main variables we are going to use later
****************************************************************************************************
*Renamed using the standardisation described in KePSIE_DataDictionary excel file

global a nov
global b dec
global c jan 
global d feb 


foreach month in a b c d  {
	rename 		outpatient_complete_d_`month'_bl  			outpatient_c_d_${`month'}_bl 
	rename 		outpatient_complete_input_d_`month'_bl		outpatient_c_input_d_${`month'}_bl
}


global nov November 2014
global dec December 2014
global jan January 	2015 
global feb February 2015 



foreach month in nov dec jan feb {
	rename 		outpatient_c_d_`month'_bl 		outpatients_cmonth_`month'_d_bl
	label var 	outpatients_cmonth_`month'_d_bl "Daily Outpatients - $`month' (Monthly Complete Records)"

	rename 		outpatient_c_input_d_`month'_bl 	outpatients_allsources_`month'_d_bl
	label var 	outpatients_allsources_`month'_d_bl 	"Daily Outpatients - $`month' (All Sources)"
}


rename 			outpatient_complete_noo_d_av_bl				outpatients_allsources_mean_d_bl 
label var 		outpatients_allsources_mean_d_bl 		"Daily Outpatients - Average Available Months (All Sources)"


*Final renaming to reduce length for the final version of the outpatient variable used in the analysis, outpatients_allsources_jan_d or outp_as_jan 
	rename outpatients_allsources_jan_d_bl outp_as_jan_bl 
	lab var outp_as_jan_bl "Daily Outpatients at Baseline"

********************************************************************************
*Part 11: Save dataset
********************************************************************************	

		save "${outp_av}", replace

	

************************************************End of do file****************************************************


