/*******************************************************************************	

Project:  		KePSIE
Created on:  	Oct 30, 2018
Last udpate on: Nov 9, 2018

Written by:  	Thomas Escande (tescande@worldbank.org)

Revision: 		

********************************************************************************			

THIS DO FILE: 	This do-file looks at outliers for price consultation 


CONTENT:		Part 0 - Create globals for directories and files and locals to be used throughout the do file
				Part 1 -

INPUTS:     	* Cleaned data taken from the fees/ outpatient demand cleaned database
				"${KePSIE_DB}/Endline/DataSets/Intermediate/Fees_Outpatient_clean_end.dta"

OUTPUTS:     	
				* Dropbox files: Latest versions created by person in charge (Thomas Escande)
				
					* Database with final outpatient outcomes ready for analysis
					"${KePSIE_DB}/Endline/DataSets/Intermediate/Averages_Outpatient_end.dta"
					
				
				* Local files: Produced when running this code and saved in your local GitHub folder
				
					* Database with final outpatient outcomes ready for analysis
					"${end_dt}/Intermediate/Averages_Outpatient_end.dta"

*******************************************************************************/

********************************************************************************
	** Part 0: Create globals for directories and files 
********************************************************************************

clear all
set more off				

	* Input files
	glo fees_outp_bl 		"${dt_bl_const}/fees_outp_bl.dta"
	
	* Output files 
	glo fees_cons_bl 		"${dt_bl_const}/fees_cons_bl.dta"


		use "${fees_outp_bl}", clear				

keep hfid price_consultation_bl price_date_bl price_month_bl price_year_bl

//To add later once this has been done for baseline too.

/*
*merge with PE to get the variables to compare prices to
merge 1:m hfid using "${PE_clean}", keepusing(g1 g2 g3 g4 g5m i1 i2 i3 i4)
keep if _merge == 3
drop _merge

**************************************Checking for any outliers*************************************
*We are only looking for typing mistakes, either entering one too many figure or one less, so overall differences by a factor of 10
*First estimation is done using i2, the number we are looking for but unlikely to be known
bys hfid: egen examination_price 	= mean(i2)
bys hfid: egen nonmii_i2 			= count(i2)

*Second estimation using total paid minus what was spend for laboratory and medicines
gen 	i2_est = i1 
replace i2_est = i2_est - i3 if !mi(i3)
replace i2_est = i2_est - i4 if !mi(i4)

bys hfid: egen examination_price_i2_est 	= mean(i2_est)
bys hfid: egen nonmii_i2_est 	 			= count(i2_est)

*Third estimation:max cap created by i1
bys hfid: egen max_price 			= mean(i1) 
bys hfid: egen nonmii_i1 			= count(i1)

order hfid price_consultation examination_price examination_price_i2_est max_price nonmii_i2 nonmii_i2_est nonmii_i1

*keeping only one observation per facility
duplicates drop hfid, force

*Comparison variables 
gen 	ratio_price_consult1_max = price_consultation / examination_price if  examination_price > 0
gen 	ratio_price_consult1_min = examination_price / price_consultation if  price_consultation > 0

list hfid price_consultation examination_price examination_price_i2_est max_price nonmii_i2 nonmii_i2_est nonmii_i1 ///
	if (ratio_price_consult1_max > 10 & !mi(ratio_price_consult1_max)) |  (ratio_price_consult1_min > 10 & !mi(ratio_price_consult1_min))
*/

****************************************************************************************************
*Part 10: Renaming main variables we are going to uselater
****************************************************************************************************
*Renamed using the standardisation described in KePSIE_DataDictionary excel file

rename 			price_consultation_bl		consultation_fee_bl
label var 		consultation_fee_bl		"First Time Consultation Fee (KES)"

rename 			price_date_bl 	consultation_fee_date_bl
label var 		consultation_fee_date_bl 	"Date of Collection of Consultation Fee"

rename 			price_month_bl consultation_fee_month_bl
label var 	 	consultation_fee_month_bl	"Month of Collection of Consultation Fee"

rename 			price_year_bl 	consultation_fee_year_bl
label var 		consultation_fee_year_bl 	"Year of Collection of Consultation Fee"

********************************************************************************
*Part 11: Save dataset
********************************************************************************	

	if c(stata_version)>=14 {
		saveold "${fees_cons_bl}", replace v(13)
	}
	else {
		save "${fees_cons_bl}", replace
	}
	

************************************************End of do file**************************************************
