/*******************************************************************************	
*		Project:
*			KePSIE IE
*		Created on:		2018-10-01
*		Last update: 	2018-10-01
********************************************************************************			

** PURPOSE: 	This do-file cleans the  QPS1 endline backchecks done by supervisors	
				
** INPUTS:     	Backcheck_QPS1.dta Dropbox/DataAnalysis/Follow-up/Data/Raw/QPS1


** OUTLINE: 	Part 1: Performs basic cleaning
				Part 4: Anonymize data for general dataset and save

** OUTPUTS:    Backcheck_QPS1_clean_end.dta Github\kepsie\DataWork\Endline\DataSets\Intermediate
				

** Written by: Thomas Escande

*******************************************************************************/
	
********************************************************************************
	** Part 0: Create globals for directories and files 
********************************************************************************

clear all
set more off

	* Input files
	glo backcheck			"${volume}/qps1_bc_end_raw.dta"

	* Output files
	glo qps1_bc_clean 		"${dt_end_clean}/qps1_end_bc.dta"
	 
********************************************************************************

	** Part 1: Basic cleaning 

********************************************************************************		

* Mount veracrypt drive
veracrypt "${encrypt}/Endline Raw Identified Data", mount drive("${mount}")


	use "${backcheck}", clear 

*Manual fix
replace a5 = 16595 if key == "uuid:6d19c1a7-efc6-49fa-8aa1-cf9ac28d2583"

// Dropping non useful variables
drop  speedviolcount speedviollist formdef_version submissiondate starttime endtime c1a_bc c3b_bc c9_bc deviceid subscriberid simid ///
 devicephonenum a2 a2_1 a1_v a1_cal facilitycode f33_1_c f33_4_c f33_s

// Drop variables for the timing of the survey
drop time_end_g time_end_staffroster time_start_staffroster f36_t2_1 f37_t2 f37_t1 f35_t2 f35_t1 f33_t1 time_end_e time_start_e time_end_d ///
time_start_d time_startinteraction time a3 a3_v a3_1 f33_t2 f35_1u_c f35_4u_c f35_u_s f35_1o_c f35_4o_c f35_o_s h2_2 h2_3

// Dropping facility information that will come from the listing 
drop county_preloaded pri pri_string a10


	* Clean date
		gen date_td=date(date,"DMY")
		drop date
		rename date_td date
		format date %td
		lab var date "Survey date"
			assert !mi(date) 


*Multiple choice question in multiple dummies // To add later if needed	
*Done it by hand here to gain some time, in the future use Ben's code 
gen e7_1 		= 0 
replace e7_1	= 1 if key == "uuid:e441048f-030d-4b42-8f68-423a03f2253a" | key == "uuid:ed9688aa-4d1b-4afb-9171-ea927240aa00"
gen e7_2		= 0 
replace e7_2	= 1 if key == "uuid:51edfe6a-f100-4649-8c35-4a69098ff3c8" | key == "uuid:da29a588-1fc5-452d-a09f-8846240fa2ad" | key == "uuid:f2e3a239-0003-406b-96c1-829ef69f51bc" | key == "uuid:b926c529-e9c3-43ac-855e-eeab22dd7384"
gen e7_3 		= 0 
replace e7_3	= 1 if key == "uuid:51edfe6a-f100-4649-8c35-4a69098ff3c8" | key == "uuid:e441048f-030d-4b42-8f68-423a03f2253a" | key == "uuid:da29a588-1fc5-452d-a09f-8846240fa2ad"
gen e7_4 		= 0
gen e7_5 		= 0
gen e7_6 		= 0 
replace e7_6	= 1 if key == "uuid:da29a588-1fc5-452d-a09f-8846240fa2ad" | key == "uuid:f2e3a239-0003-406b-96c1-829ef69f51bc" | key == "uuid:b926c529-e9c3-43ac-855e-eeab22dd7384"
gen e7_7 		= 0 
replace e7_7	= 1 if key == "uuid:da29a588-1fc5-452d-a09f-8846240fa2ad" 
gen e7_8 		= 0 
replace e7_8	= 1 if key == "uuid:da29a588-1fc5-452d-a09f-8846240fa2ad"
gen e7_9  		= 0
gen e7_0 		= 0 
replace e7_0	= 1 if inlist(key,"uuid:6d19c1a7-efc6-49fa-8aa1-cf9ac28d2583","uuid:57765702-ed30-4ce9-b3c1-f5c97534cd6b","uuid:e3d65a01-7d44-4cd3-8fac-29d9c08ad9dc","uuid:85427a18-47a2-4d17-bef8-0578bb8d9c54","uuid:21581421-4af6-4bbc-9b32-507bed9cf2c3","uuid:ad481c72-4ea9-4a7e-adad-8500ba05814d","uuid:4f425811-4dc6-4ca5-b795-e17063484349")

drop e7 


********************************************************************************

	** Part : Renaming and labelling variables - based on QPS1 

********************************************************************************
rename a5  hfid 

	rename 		d3  			c3
	rename 		d7 				c6
	rename 		e1 				d1
	rename 		e5 				d5
	rename 		e6  			d6
	rename 		e7_1 			d7_1
	rename 		e7_2 			d7_2
	rename 		e7_3 			d7_3
	rename 		e7_4 			d7_4
	rename 		e7_5 			d7_5
	rename 		e7_6 			d7_6
	rename 		e7_7 			d7_7
	rename 		e7_8 			d7_8
	rename 		e7_9 			d7_9
	rename 		e7_0 			d7_0

	rename 		e10 			d10
	rename 		e13 			d13
	rename 		e14 			d14
	rename 		e15 			d15
	
	rename 		e30 			d30
	rename 		e31 			d31
	rename 		e48 			d48
	rename 		f16 			f1_JHIC  
	rename 		f17 			f3_JHIC
	rename 		f18  			f4_JHIC
	rename 		f20 			f5_JHIC

	rename 		f34_1 			f8
	rename 		f34_2 			f9
	rename 		f33_1 			f17a
	rename 		f33_4 			f17d
	rename 		f33_miss 		f17_miss
	rename 		f33_miss_1 		f17_miss_a
	rename 		f33_miss_4 		f17_miss_d

	rename 		f35_1u 			f18a
	rename 		f35_4u 			f18d
	rename 		f35_missu 		f18_miss
	rename 		f35_miss_1u 	f18_miss_a
	rename 		f35_miss_4u 	f18_miss_d
	rename 		f35_1o 			f19a
	rename 		f35_4o 			f19d
	rename 		f35_miss 		f19_miss
	rename 		f35_miss_1 		f19_miss_a
	rename 		f35_miss_4 		f19_miss_d

	rename 		f38_1   		f14_1
	rename 		f38_2 			f14_2
	rename 		f38_3 			f14_3
	rename 		f38_4 			f14_4
	rename 		f38_5 			f14_5
	rename 		f38_6 			f14_6



	label var  c3 				"How many consultation rooms are there in this facility?"
	label var  c6 				"Do you offer lab services?"

	label var  d7_1 			"Inspection by regulatory board include:Clinical Officers Council"
	label var  d7_2 			"Inspection by regulatory board include:Kenya Medical Laboratory Technicians and Technologists Board"
	label var  d7_3 			"Inspection by regulatory board include:Medical Practitioners and Dentists Board"
	label var  d7_4 			"Inspection by regulatory board include:Nursing Council of Kenya"
	label var  d7_5 			"Inspection by regulatory board include:Kenya Nutritionists and Dieticians Institute"
	label var  d7_6 			"Inspection by regulatory board include:Pharmacy and Poisons Board"
	label var  d7_7 			"Inspection by regulatory board include:Public Health Technologists Board"
	label var  d7_8 			"Inspection by regulatory board include:Radiation Protection Board"
	label var  d7_9 			"Inspection by regulatory board include:Do not remember which one(s) came"
	label var  d7_0 	"Inspection by regulatory board include:None of the above"

	label var  f8 				"How much do outpatients pay for consultations' fees for first-time visits?"
	label var  f9 				"How much is the registration fee for outpatients?"

	label var  f17a 			"Outpatients:  November 2017"
	label var  f17d 			"Outpatients:  February 2018"
	label var  f18a 			"UNDER 5 Outpatients:  November 2017"
	label var  f18d 			"UNDER 5 Outpatients:  February 2018"
	label var  f19a 			"OVER 5 Outpatients:  November 2017"
	label var  f19d 			"OVER 5 Outpatients:  February 2018"
	label var 	f17_miss 		"Outpatients record incomplete for any month?" 
	label var 	f17_miss_a 		"November 2017:Num of days Outpatients records incomplete" 
	label var 	f17_miss_d  	"February 2018:Num of days Outpatients records incomplete" 
	label var 	f18_miss 		"Outpatients UNDER 5 record incomplete for any month?" 
	label var 	f18_miss_a 		"November 2017:Num of days Outpatients UNDER 5 records incomplete"
	label var 	f18_miss_d  	"February 2018:Num of days Outpatients UNDER 5 records incomplete" 
	label var 	f19_miss 		"Outpatients OVER 5 record incomplete for any month?" 
	label var 	f19_miss_a 		"November 2017:Num of days Outpatients OVER 5 records incomplete"
	label var 	f19_miss_d  	"February 2018:Num of days Outpatients OVER 5 records incomplete"

	label var  f14_1 	"Lab services include: Malaria blood smear"
	label var  f14_2 	"Lab services include: Stool O/C"
	label var  f14_3 	"Lab services include: Tuberculosis (Sputum test for AFB)"
	label var  f14_4 	"Lab services include: Urinalysis"
	label var  f14_5 	"Lab services include: Brucella"
	label var  f14_6 	"Lab services include: Blood type"

	*Renaming all variables with check in the name and label so as not to get confused when merging it with other datasets in the future
	foreach var of varlist * {
		local lbl : variable label `var'
    	label var `var' `"Backchecks: `lbl'"'
		rename `var' bcheck_`var'
	}

********************************************************************************

	** Part : Keeping only surveys that have been completed 

********************************************************************************
keep if bcheck_b_consent == 1
drop bcheck_b_consent bcheck_bc_g1 bcheck_bc_g2 bcheck_bc_g5 bcheck_bc_g6 bcheck_bc_g7 bcheck_bc_g8 //variables used for the consent

********************************************************************************

	** Part : Anonymize data for general dataset and save

********************************************************************************	

* Dropping geo localisation
	drop bcheck_a1latitude bcheck_a1longitude bcheck_a1altitude bcheck_a1accuracy bcheck_h2_1latitude bcheck_h2_1longitude bcheck_h2_1altitude bcheck_h2_1accuracy bcheck_h1_1 bcheck_h1_2

* Dropping HF names
	drop bcheck_facilityname bcheck_backchecker bcheck_backchecker_c bcheck_backchecker_v bcheck_foid_pre bcheck_foname_pre

			* Save
			save	"${qps1_bc_end_clean}", replace
			
			
	* Dismount
	veracrypt, dismount drive("${mount}") 
			

************************************************End of do file****************************************************
