/*******************************************************************************	

Project:  		KePSIE
Created on:  	Nov 9, 2018
Last udpate on: Nov 9, 2018

Written by:  	Thomas Escande (tescande@worldbank.org)

Revision: 		

********************************************************************************			

THIS DO FILE: 	This do-file constructs the intermediary outcomes on the intervention and perception from HF in-charge at health facility level


CONTENT:		Part 0 - Create globals for directories and files 
				Part 1 - Creation of new set of variables, outputting by main categories
				Part 2 -  Save dataset

INPUTS:     	* Cleaned data taken from QPS1
				"${KePSIE_DB}/Endline/DataSets/Intermediate/QPS1_clean_nopii_end.dta"


OUTPUTS:     	Clean dataset of inspection variables 
				* "${KePSIE_DB}/Endline/DataSets/Intermediate/HF_inspection_outcomes_end.dta"

					

*******************************************************************************/

********************************************************************************
	** Part 0: Create globals for directories and files 
********************************************************************************

clear all
set more off				

	* Input files
		glo qps1_clean 		"${dt_end_clean}/qps1_end.dta"

	* Output files: 
		glo inspection_hf	"${dt_end_const}/inspection_hf.dta"

		
		
		
		use "${qps1_clean}", clear

*Reordering data
keep d* hfid
order hfid d*, seq
order hfid



*Renaming to be consistent with usual norms
rename d3_8 d3__99
rename d3_9 d3_8


********************************************************************************
	** Part 1: Creation of new set of variables, outputting by main categories
********************************************************************************


**************New Regulation : d1 - d5 ******************
*Creating new categories for some of the variables
*d1
gen 	regulationaware_hf = d1
label define aware 0 "Not Aware" 1 "Aware"
label values regulationaware_hf aware

*d2 Regulation more strict
gen 	regulation_stricter_hf = 0 if !mi(d2)
replace regulation_stricter_hf = 1 if d2 == 1

*d3 average number of known changes
gen 	know_diff_hf			= 0 if d1 == 1
replace know_diff_hf 			= 1 if d3_1 == 1 | d3_2 == 1 | d3_3 == 1 | d3_4 == 1 | d3_5 == 1 | d3_6  == 1 | d3_7 == 1 

gen 	number_main_diff_hf    	= d3_1 + d3_2 + d3_3 + d3_4 + d3_5 + d3_6 + d3_7 if know_diff_hf == 1


gen 	know_closing_hf		   	= 0 if !mi(d3_6) | !mi(d3_7)
replace know_closing_hf 	   	= 1 if d3_6 == 1 | d3_7 == 1

*d4
gen 	regulationknow_hf  = 0 if !mi(d4) //Only relevant when d1 == 1 (yes)
replace regulationknow_hf  = 1 if inlist(d4,4,5)
label define know 0 "No knowledge" 1 "Know"
label values regulationknow_hf know

*d5 
gen 	copy_received_hf 		= 0 if !mi(d5)
replace copy_received_hf 		= 1 if d5 == 1

label var regulationaware_hf 		"HF In-Charge Familiar with the New Legislation JHIC (Awareness)"
label var regulation_stricter_hf	"HF In-Charge Knows New Regulation Is Stricter (If Aware of Legislation)"
label var know_diff_hf 				"HF In-Charge Knows at Least One Characteristic of New Regulation (If Aware of Legislation)"
label var know_closing_hf 			"HF In-Charge Knows HFs Can Be Closed in New Regulation (If Aware of Legislation)"
label var number_main_diff_hf 		"Number of New Regulation Characteristics In-Charge Knows (If Aware of at Least One Characteristic)"
label var regulationknow_hf  		"HF In-Charge Knows Number of Compliance Categories from Legislation (Knowledge) (If Aware of Legislation)"
label var copy_received_hf 			"HF In-Charge Ever Received a Copy of JHIC Checklist?"

**************Medical supervision team*******************
*d6 
gen 	hmanagement_visit = 0
replace hmanagement_visit = 1 	if  d6 != 0

*Visited by at least one medical Board d7
gen 	med_board_visit = 0
replace med_board_visit = 1 			if 	d7_0 != 1

*d8
gen 	intensity_hmanagement_visit = d8 

*d9
gen 	intensity_med_board 		= 0 if 	d7_0 != 1
forvalues i = 1 / 8 {
	replace intensity_med_board 	= intensity_med_board + d9_`i' if !mi(d9_`i')
}
replace intensity_med_board = .o if intensity_med_board == 48 /*Outlier, more than 5 for each category, 4 times more important than 2 maximum*/
// More than 5 becomes simply 6 in these cases

*d10 
gen 	JHI_visit = 0
replace JHI_visit = 1 if d10 == 1

*d11
gen		intensity_JHI_visit = d11  // More than 5 becomes 6, only for two observations


label var hmanagement_visit 			"HF In-Charge Aware of any Supervision by Health Management Team in 2017 (County/ Subcounty/ Both)"
label var med_board_visit 		 		"HF In-Charge Aware of an Inspection by at Least One of the Medical Boards in 2017 "
label var intensity_hmanagement_visit	"Nb of Health Management's Visits HF In-Charge Is Aware of in 2017 (If Aware of Any)"
label var intensity_med_board 			"Nb of Medical Boards' Visits HF In-Charge Is Aware of in 2017 (If Aware of Any)"
label var JHI_visit 					"HF In-Charge Aware of an Inspection by a Joint Health Inspector in 2017"
label var intensity_JHI_visit 			"Nb of Visits by a JH Inspector HF In-Charge Is Aware of in 2017 (If Aware of Any)"



***************Joint health inspection: only for treated group**********
*d12 

gen		inspection_length = 15 		if d12 == 1
replace inspection_length = 45 		if d12 == 2
replace inspection_length = 90 		if d12 == 3
replace inspection_length = 150 	if d12 == 4
replace inspection_length = 210		if d12 == 5

label var inspection_length "HF In-Charge Estimation of Average Length in min of Joint Health Inspection (If HF Had JHI)"

*d13 
gen 	postJHI_FullyCompliant = 0 if d10 == 1
replace postJHI_FullyCompliant = 1 if d13 == 5
gen 	postJHI_SubstantCompliant = 0 if d10 == 1
replace postJHI_SubstantCompliant = 1 if d13 == 4
gen 	postJHI_PartiallyCompliant = 0 if d10 == 1
replace postJHI_PartiallyCompliant = 1 if d13 == 3
gen 	postJHI_MinimallyCompliant = 0 if d10 == 1
replace postJHI_MinimallyCompliant = 1 if d13 == 2
gen 	postJHI_NotCompliant 	= 0 	if d10 == 1
replace postJHI_NotCompliant 	= 1 	if d13 == 1
gen 	postJHI_noremember 		= 0 	if d10 == 1
replace postJHI_noremember 		= 1 	if d13 == -99

label var postJHI_FullyCompliant 		"HF Scoring Fully Compliant at Last JHI as Remembered by HF In-Charge (If HF Had JHI)"
label var postJHI_SubstantCompliant  	"HF Scoring Substantially Compliant at Last JHI as Remembered by HF In-Charge (If HF Had JHI)"
label var postJHI_PartiallyCompliant 	"HF Scoring Partially Compliant at Last JHI as Remembered by HF In-Charge (If HF Had JHI)"
label var postJHI_MinimallyCompliant	"HF Scoring Minimally Compliant at Last JHI as Remembered by HF In-Charge (If HF Had JHI)"
label var postJHI_NotCompliant 			"HF Scoring Not Compliant at Last JHI as Remembered by HF In-Charge (If HF Had JHI)"


*d14
gen 	inspection_summary = 0 		if d10 == 1
replace inspection_summary = 1 		if d14 == 1
label var inspection_summary "HF In-Charge Aware of Receiving Inspection Summary After Last Inspection (If HF Had JHI)"

*d15 
gen 	receive_copy_report = 0 if d10 == 1
replace receive_copy_report = 1 if d15 == 1
label var receive_copy_report "HF In-Charge Aware of Receiving Inspection Report After Last Inspection (If HF Had JHI)"

*d15_1
gen 	receive_printed_copy = 0 if d15 == 1 
replace receive_printed_copy = 1 if d15_1 == 1
label var receive_printed_copy "HF In-Charge Received a Printed Copy Report After Last Inspection (If Received Report)"

*d15_2
gen 	receive_email_copy = 0 if d15 == 1 
replace receive_email_copy = 1 if d15_2 == 1
label var receive_email_copy "HF In-Charge Received an Email Copy Report After Last Inspection (If Received Report)"

*d16 
gen 	subcounty_request = 0 if d15 == 0
replace subcounty_request = 1 if d16 == 1
label var subcounty_request "HF In-Charge Went to Sub-County Office to Get Report (If Did Not Received Report)"

*d17
gen 	nb_visit_office = d17
replace nb_visit_office = . if d17 == -99
label var nb_visit_office "Nb of Times HF In-Charge Went to Sub-County Office to Get Report (If Did Not Received Report)"

*d19
gen 	implement_changes = 0 if d1  == 1
replace implement_changes = 1 if d19 == 1
label var implement_changes "HF In-Charge Implementing Any Change to Comply with JHIC (If Aware of Regulation)"

******************Changes******************************************
*d20 
gen 	changes_1 = 0 if d19 == 1
replace changes_1 = 1 if d20_1 == 1
label var changes_1 "HF In-Charge Made Changes in: Renewing/Obtaining Licenses (If Implemented Changes)"

gen 	changes_2 = 0 if d19 == 1
replace changes_2 = 1 if d20_2 == 1
label var changes_2 "HF In-Charge Made Changes in: Help From County Office (If Implemented Changes)"

gen 	changes_3 = 0 if d19 == 1
replace changes_3 = 1 if d20_3 == 1
label var changes_3 "HF In-Charge Made Changes in: New SOPs (If Implemented Changes)"

gen 	changes_4 = 0 if d19 == 1
replace changes_4 = 1 if d20_4 == 1
label var changes_4 "HF In-Charge Made Changes in: Minor Equipment (If Implemented Changes)"

gen 	changes_5 = 0 if d19 == 1
replace changes_5 = 1 if d20_5 == 1
label var changes_5 "HF In-Charge Made Changes in: Upgrade of Infrastructure (If Implemented Changes)"

gen 	changes_6_1 = 0 if d19 == 1
replace changes_6_1 = 1 if d20_6_1 == 1
label var changes_6_1 "HF In-Charge Made Changes in: Additional Temporary Staff (If Implemented Changes)"

gen 	changes_6_2 = 0 if d19 == 1
replace changes_6_2 = 1 if d20_6_2 == 1
label var changes_6_2 "HF In-Charge Made Changes in: Additional Permanent Staff (If Implemented Changes)"

gen 	changes_7 = 0 if d19 == 1
replace changes_7 = 1 if d20_7 == 1
label var changes_7 "HF In-Charge Made Changes in: Management Structure (If Implemented Changes)"

gen 	changes_8 = 0 if d19 == 1
replace changes_8 = 1 if d20_8 == 1
label var changes_8 "HF In-Charge Made Changes in: Reporting Tools (If Implemented Changes)"

gen 	changes_9 = 0 if d19 == 1
replace changes_9 = 1 if d20_9 == 1
label var changes_9 "HF In-Charge Made Changes in: Plan with Goals (If Implemented Changes)"

*d21
gen 	price_changes_1 = d21_1 / 1000
replace price_changes_1 = .d if d21_1 == -99
replace price_changes_1 = .r if d21_1 == -98
label var price_changes_1 "HF In-Charge Estimate Cost of Changes (k KSH): Renewing/Obtaining Licenses (If Implemented the Changes)"

gen 	price_changes_2 = d21_2 / 1000
replace price_changes_2 = .d if d21_2 == -99
replace price_changes_2 = .r if d21_2 == -98
label var price_changes_2 "HF In-Charge Estimate Cost of Changes (k KSH): Help From County Office (If Implemented the Changes)"

gen 	price_changes_3 = d21_3 / 1000
replace price_changes_3 = .d if d21_3 == -99
replace price_changes_3 = .r if d21_3 == -98
label var price_changes_3 "HF In-Charge Estimate Cost of Changes (k KSH): New SOPs (If Implemented the Changes)"

gen 	price_changes_4 = d21_4 / 1000
replace price_changes_4 = .d if d21_4 == -99
replace price_changes_4 = .r if d21_4 == -98
label var price_changes_4 "HF In-Charge Estimate Cost of Changes (k KSH): Minor Equipment (If Implemented the Changes)"

gen 	price_changes_5 = d21_5 / 1000
replace price_changes_5 = .d if d21_5 == -99
replace price_changes_5 = .r if d21_5 == -98
label var price_changes_5 "HF In-Charge Estimate Cost of Changes (k KSH): Upgrade of Infrastructure (If Implemented the Changes)"

gen 	price_changes_6_1 = d21_6_1 / 1000 
replace price_changes_6_1 = .d if d21_6_1 == -99
replace price_changes_6_1 = .r if d21_6_1 == -98
label var price_changes_6_1 "HF In-Charge Estimate Cost of Changes (k KSH): Additional Temporary Staff (If Implemented the Changes)"

gen 	price_changes_6_2 = d21_6_2 / 1000
replace price_changes_6_2 = .d if d21_6_2 == -99
replace price_changes_6_2 = .r if d21_6_2 == -98
label var price_changes_6_2 "HF In-Charge Estimate Cost of Changes (k KSH): Additional Permanent Staff (If Implemented the Changes)"

gen 	price_changes_7 = d21_7 / 1000
replace price_changes_7 = .d if d21_7 == -99
replace price_changes_7 = .r if d21_7 == -98
label var price_changes_7 "HF In-Charge Estimate Cost of Changes (k KSH): Management Structure (If Implemented the Changes)"

gen 	price_changes_8 = d21_8 / 1000
replace price_changes_8 = .d if d21_8 == -99
replace price_changes_8 = .r if d21_8 == -98
label var price_changes_8 "HF In-Charge Estimate Cost of Changes (k KSH): Reporting Tools (If Implemented the Changes)"

gen 	price_changes_9 = d21_9 / 1000
replace price_changes_9 = .d if d21_9 == -99
replace price_changes_9 = .r if d21_9 == -98
label var price_changes_9 "HF In-Charge Estimate Cost of Changes (k KSH): Plan with Goals (If Implemented the Changes)"

*d22 Disabled

*d23: 
gen 	obstacle_1 = 0 if d1 == 1 
replace obstacle_1 = 1 if d23 == 1
label var obstacle_1 "HF In-Charge Thinks Greatest Obstacle to Complying with Regulation Is: Don't Know How (If Aware of Regulation)" 

gen 	obstacle_2 = 0 if d1 == 1 
replace obstacle_2 = 1 if d23 == 2
label var obstacle_2 "HF In-Charge Thinks Greatest Obstacle to Complying with Regulation Is: Too Expensive (If Aware of Regulation)" 

gen 	obstacle_3 = 0 if d1 == 1 
replace obstacle_3 = 1 if d23 == 3
label var obstacle_3 "HF In-Charge Thinks Greatest Obstacle to Complying with Regulation Is: Can't Find Right Inputs (If Aware of Regulation)" 

gen 	obstacle_4 = 0 if d1 == 1 
replace obstacle_4 = 1 if d23 == 4
label var obstacle_4 "HF In-Charge Thinks Greatest Obstacle to Complying with Regulation Is: Standards Not Appropriate (If Aware of Regulation)" 

*d24: Breakdown in percentages
*Distribution of percentage
*hist d24_1 if d24_1 > -99 , freq
*hist d24_2 if d24_2 > -99 , freq
*hist d24_3 if d24_3 > -99 , freq


gen 	change_lowcost = 1 if d24_1 >= 0  & d24_1 < 25
replace change_lowcost = 2 if d24_1 >= 25 & d24_1 < 50
replace change_lowcost = 3 if d24_1 >= 50 & d24_1 < 75
replace change_lowcost = 4 if d24_1 >= 75 & d24_1 < 100

gen 	change_modcost = 1 if d24_2 >= 0  & d24_2 < 25
replace change_modcost = 2 if d24_2 >= 25 & d24_2 < 50
replace change_modcost = 3 if d24_2 >= 50 & d24_2 < 75
replace change_modcost = 4 if d24_2 >= 75 & d24_2 < 100

gen 	change_highcost = 1 if d24_3 >= 0  & d24_3 < 25
replace change_highcost = 2 if d24_3 >= 25 & d24_3 < 50
replace change_highcost = 3 if d24_3 >= 50 & d24_3 < 75
replace change_highcost = 4 if d24_3 >= 75 & d24_3 < 100

label define quantiles 1 "Between 0 and 25%" 2 "Between 25 and 50%" 3 "Between 50 and 75%" 4 "Between 75 and 100%"
label values change_lowcost quantiles
label values change_modcost quantiles
label values change_highcost quantiles

label var change_lowcost "% of changes needed which are low cost"
label var change_modcost "% of changes needed which are moderate cost"
label var change_highcost "% of changes needed which are high cost"

gen 	exact_perchange_low  = d24_1 if d24_1 != -99
gen 	exact_perchange_mod  = d24_2 if d24_2 != -99
gen 	exact_perchange_high = d24_3 if d24_3 != -99

label var exact_perchange_low 	"HF In-Charge Perception of percentage Low Cost Changes Needed to Comply with Regulation (If Aware of Regulation)"
label var exact_perchange_mod 	"HF In-Charge Perception of percentage Moderate Cost Changes Needed to Comply with Regulation (If Aware of Regulation)"
label var exact_perchange_high 	"HF In-Charge Perception of percentage High Cost Changes Needed to Comply with Regulation (If Aware of Regulation)"


label var d25 "HF In-Charge Requested Support from County Office (If Implemented Changes)"
label var d26 "HF In-Charge Received Support from County Office (If Asked for Support)"

*d27/28
gen 	beneficial_inspect_hf = 0 if d1 == 1
replace beneficial_inspect_hf = 1 if d27 == 4 | d27 == 5

gen 	beneficial_inspect_p  = 0 if d1 == 1 
replace beneficial_inspect_p  = 1 if d28 == 4 | d28 == 5

label var beneficial_inspect_hf "HF In-Charge Thinks Inspection Is Beneficial/ Very Beneficial for HF (If Aware of Legislation)"
label var beneficial_inspect_p  "HF In-Charge Thinks Inspection Is Beneficial/ Very Beneficial for Patients (If Aware of Legislation)"

*d29 
label var d29a "HF In-Charge Rating Inspection On: Overall Expericence with JHI (If Had JHI)"
label var d29b "HF In-Charge Rating Inspection On: Clarity of the content"
label var d29c "HF In-Charge Rating Inspection On: Fairness of scoring system"
label var d29d "HF In-Charge Rating Inspection On: Clarity of recommendations"
label var d29e "HF In-Charge Rating Inspection On: Professionalism of inspectors"
label var d29f "HF In-Charge Rating Inspection On: Possibilities to report issues"
label var d29g "HF In-Charge Rating Inspection On: Fairness of closing facilities when needed"
label var d29h "HF In-Charge Rating Inspection On: Fairness of closing facilities when not improving"

global d29 d29a d29b d29c d29d d29e d29f d29g d29h

*d30
gen 	scorecardaware_hf  = d30

gen 	scorecardaware_hf2 = d30
replace scorecardaware_hf2 = 1   if d30 != 1 & d31 == 1
label values scorecardaware_hf aware
label var scorecardaware_hf "HF In-Charge Ever Noticed a Scorecard (Awareness)"

*d31
gen 	scorecard_posted_inspection = 0 if d10 == 1 
replace scorecard_posted_inspection = 1 if d31 == 1
label var scorecard_posted_inspection "HF In-Charge Aware of Inspector Posting Scorecard After Last Inspection (If HF Had JHI)"

*d33 
gen 	scorecard_helpful = 0 if !mi(d33)
replace scorecard_helpful = 1 if d33 == 5 | d33 == 4
label var scorecard_helpful "HF In-Charge Thinks Scorecard Has Been (Very) Helpful (If Scorecard Posted)"

gen 	scorecard_neutral = 0 if !mi(d33)
replace scorecard_neutral = 1 if d33 == 3
label var scorecard_neutral "HF In-Charge Thinks Scorecard Has Been Neutral (If Scorecard Posted)"

gen 	scorecard_unhelpful = 0 if !mi(d33)
replace scorecard_unhelpful = 1 if d33 == 1 | d33 == 2
label var scorecard_unhelpful "HF In-Charge Thinks Scorecard Has Been (Very) Unhelpful (If Scorecard Posted)"

gen 	scorecard_dknow = 0 if !mi(d33)
replace scorecard_dknow = 1 if d33 == -99
label var scorecard_dknow "HF In-Charge Don't Know If Scorecard Has Been Helpful (If Scorecard Posted)"

*d34 
gen 	helpful_1 = 0 if scorecard_helpful == 1
replace helpful_1 = 1 if d34_1 == 1 
label var helpful_1 "HF In-Charge Thinks Scorecard Helpful to: Show Improvement to Patients (If Scorecard Helpful)"

gen 	helpful_2 = 0 if scorecard_helpful == 1
replace helpful_2 = 1 if d34_2 == 1 
label var helpful_2 "HF In-Charge Thinks Scorecard Helpful as: Visible Goal  (If Scorecard Helpful)"

gen 	helpful_3 = 0 if scorecard_helpful == 1
replace helpful_3 = 1 if d34_3 == 1 
label var helpful_3 "HF In-Charge Thinks Scorecard Helpful to: Know Where HF Stands (If Scorecard Helpful)"

gen 	helpful_4 = 0 if scorecard_helpful == 1
replace helpful_4 = 1 if d34_4 == 1 
label var helpful_4 "HF In-Charge Thinks Scorecard Helpful to: Compare to Other HFs (If Scorecard Helpful)"

*d35 
gen 	regulationknow2_hf  = 0 if !mi(d35) 
replace regulationknow2_hf  = 1 if inlist(d35,4,5)
label var regulationknow2_hf "HF In-Charge Knows Number of Scorecard Letters (Knowledge) (If Noticed or Received Scorecard)"

*d36
gen 	scorecardknow_hf   = 0 if !mi(d36)  // Relevant when d30 = yes or d31 = yes 
replace scorecardknow_hf   = 1 if d36 == 2
label values scorecardknow_hf know
label var scorecardknow_hf "HF In-Charge Know Scorecards' Letter Ranking (If Noticed or Received Scorecard)"

*d37 disable

*d38
gen 	scorecard_improve_quality = 0 
replace scorecard_improve_quality = 1 if inlist(d38, 4, 5)
label var scorecard_improve_quality "HF In-Charge Thinks Scorecard System Would Be (Very) Helpful to Improve Quality of Services"

gen 	scorecard_neutral_quality = 0 
replace scorecard_neutral_quality = 1 if d38 == 3
label var scorecard_neutral_quality "HF In-Charge Thinks Scorecard System Would Be Neutral to Improve Quality of Services"

gen 	scorecard_unhelpful_quality = 0 
replace scorecard_unhelpful_quality = 1 if inlist(d38, 1, 2)
label var scorecard_unhelpful_quality "HF In-Charge Thinks Scorecard System Would Be (Very) Unhelpful to Improve Quality of Services"

 *d39
gen 	  nearby_facility = d39
label var nearby_facility "HF In-Charge Aware of HF Closed Because of Inspections Within 4 Km"

*d40
replace   d40 = .d if d40 == -99
gen 	  nb_nearby_facility = d40 
label var nb_nearby_facility "Number of Nearby HFs Closed Because of Inspections as Heard of by HF In-Charge (If Aware of Closed HF)"

*d41 text

*d42
gen 	  belong_franchise = 1
replace   belong_franchise = 0 if d42_7 == 1 
label var belong_franchise "HF Is an Active Member of at Least One of the Social Franchises"

*d43
replace d43 = .d if d43 == -99
gen 	  intensity_franchise_supervision = d43 //More than 5 becomes 6 for now
label var intensity_franchise_supervision "Nb of Social Franchises' Supervision HF In-Charge Is Aware of in 2017 (If Active Member of Social Franchise)"

*d44
gen 	  accred_hf = 1
replace   accred_hf = 0 if d44_4 == 1
label var accred_hf "HF Accredited by at Least One of the Accreditation Agency"

*d45
replace d45 = .d if d45 == -99
gen 	  intensity_accreditation = d45 // More than 5 becomes 6
label var intensity_accreditation "Nb of Accreditation Agencies' Supervision HF In-Charge Is Aware of in 2017 (If Accredited)"

*d46
gen 	  accred_lab = 0 if d46_3 == 1
replace   accred_lab = 1 if d46_1 == 1 | !mi(d46_2)
label var accred_lab "HF's Laboratory Accredited by at Least One of the Accreditation Agency (If HF Has Laboratory)"

*d47
replace d47 = .d if d47 == -99
gen 	  intensity_accreditation_lab = d47 // More than 5 becomes 6
label var intensity_accreditation_lab "Nb of Accreditation Agencies' Supervision for Laboratory HF In-Charge Is Aware of in 2017 (If Accredited)"

*d48
gen 	  other_supervision_visit = d48
replace   other_supervision_visit = 0 if d48 == - 99
label var other_supervision_visit "HF In-Charge Aware of Supervision from Another Institution"

*d49 text

*d50
replace d50 = .d if d50 == -99
gen 	  intensity_other_supervision = d50 // More than 5 becomes 6
label var intensity_other_supervision "Nb of Supervision from Any Other Institution HF In-Charge Is Aware of in 2017 (If Aware of Other Supervision)"

********************************************************************************
*Part 2: Save dataset
********************************************************************************

		save "${inspection_hf}", replace



**************End of do file*****************************************************************************************************
