/*******************************************************************************	

Project:  		KePSIE - Kenya
Created on:  	September 11, 2019

Written by:  	Thomas Escande (tescande@worldbank.org)

Revision: 		

********************************************************************************			

THIS DO FILE: 	 *This do file use the prediction dataset created on R, cleans it, constructs the number of closure-type facilities per markets and then save the dataset for the final merge to inputadata.
CONTENT:		Part 0 - Create globals for directories and files
				Part 1: Construct variables exploring patients' perception of government inspections 
				Part 2: Construct variables related to scorecard awareness 
				Part 3: Construct variables related to the impact of scorecards on patients' behaviors 
				Part 4: Save dataset at patient level
				Part 5: Save dataset at the HF level
INPUTS:     	*

OUTPUTS:		*  

*******************************************************************************/

********************************************************************************
	** Part 0: Create globals for directories and files 
********************************************************************************
clear all
set more off				

	* Input files
	glo pe_clean 			"${dt_end_clean}/pe_end.dta"
	
	* Output files: 
	glo pe_insp_p_end		"${dt_end_const}/inspection_pe_p.dta"
	glo pe_insp_hf_end		"${dt_end_const}/inspection_pe_hf.dta"

*******************************************************************************************
	** Part 1: Construct variables exploring patients' perception of government inspections 
*******************************************************************************************	

		use "${pe_clean}", clear

	*Keep variables as needed
keep hfid a3 a4 l* m*


*Creation of new set of variables, dummies to compare accross groups
*l1 
gen 	improvedq_p = 1 if l1 == 1 
replace improvedq_p = 0 if l1 == 2 | l1 == 3 | l1 == .d | l1 == .r 
label define improved 0 "No improvement" 1 "Improvement"
label values improvedq_p improved

label var improvedq_p "Patients Perceive Improvement in 2017 in HF's Quality (If opened before 2018)"

*l2
gen		inspectedhf_p 	= 0
replace inspectedhf_p 	= 1 if l2 == 1
label var inspectedhf_p	"Patients Perceive Recent Government Inspection"

*l3
gen 	inspected_gov_MOH_p = 0 if !mi(l3__99)
replace inspected_gov_MOH_p = 1 if l3_1 == 1 
label var inspected_gov_MOH_p "Patients Perceive Inspection by Central Gov/MOH (If Perceive Inspection)" 	

gen 	inspected_county_p = 0 if !mi(l3__99)
replace inspected_county_p = 1 if l3_2 == 1 
label var inspected_county_p "Patients Perceive Inspection by County (If Perceive Inspection)" 

gen 	inspected_other_p = 0 if !mi(l3__99)
replace inspected_other_p = 1 if l3__97 == 1 
label var inspected_other_p "Patients Perceive Inspection by Other Government Institution (If Perceive Inspection)" 

gen 	inspected_dknow_p = 0 if !mi(l3__99)
replace inspected_dknow_p = 1 if l3__99 == 1 
label var inspected_dknow_p "Patients Perceive Inspection by Unknown Government Institution (If Perceive Inspection)" 

*l4
gen 	bad_experience_p = 0
replace bad_experience_p = 1 if l4 == 1
label var bad_experience_p "Patients Ever Had Bad Experience with HF"

*l5 
gen 	report_bad_experience_p = l5
label var report_bad_experience_p "Patients Ever Reported Bad Experience (If Had Bad Experience)"

*l6 
gen 	reported_incharge_p = l6_1
label var reported_incharge_p "Patients Reported Bad Experience to In-charge (If Reported)"

gen 	reported_owner_p = l6_2
label var reported_owner_p "Patients Reported Bad Experience to Owner (If Reported)"

gen 	reported_moh_p = l6_3
label var reported_moh_p "Patients Reported Bad Experience to MOH (If Reported)"

gen 	reported_county_p = l6_4
label var reported_county_p "Patients Reported Bad Experience to County Government (If Reported)"

gen 	reported_boards_p = l6_5
label var reported_boards_p "Patients Reported Bad Experience to Boards and Councils (If Reported)"

gen 	reported_other_p = l6__97
label var reported_other_p "Patients Reported Bad Experience to Other Institution (If Reported)"


*******************************************************************************************
	** Part 2: Construct variables related to scorecard awareness 
*******************************************************************************************	

*l7
gen scorecardaware_p = l7
label define aware 0 "Not Aware" 1 "Aware"
label values scorecardaware_p aware

label var scorecardaware_p "Patients Ever Noticed a Scorecard (Awareness)"

*l8
gen 	decision_scorecard_p = 0
replace decision_scorecard_p = 1 if l8 == 1 | l8 == 2
label var decision_scorecard_p "Patients Ever Made Decision Based on Scorecards"

*l8a
gen 	letter_decided_go_A = 0 if !mi(l8a) 
replace letter_decided_go_A = 1 if l8a == 1 

gen 	letter_decided_go_B = 0 if !mi(l8a) 
replace letter_decided_go_B = 1 if l8a == 2 

gen 	letter_decided_go_C = 0 if !mi(l8a) 
replace letter_decided_go_C = 1 if l8a == 3

gen 	letter_decided_go_D = 0 if !mi(l8a) 
replace letter_decided_go_D = 1 if l8a == 4

gen 	letter_decided_go_E = 0 if !mi(l8a) 
replace letter_decided_go_E = 1 if l8a == 5

label var letter_decided_go_A "Patients Went to HF Because of Its A (If Went Because of Scorecard)"   
label var letter_decided_go_B "Patients Went to HF Because of Its B (If Went Because of Scorecard)"   
label var letter_decided_go_C "Patients Went to HF Because of Its C (If Went Because of Scorecard)"   
label var letter_decided_go_D "Patients Went to HF Because of Its D (If Went Because of Scorecard)"   
label var letter_decided_go_E "Patients Went to HF Because of Its Closure Status (If Went Because of Scorecard)"   

*l8b
gen 	letter_decided_notgo_A = 0 if !mi(l8b) 
replace letter_decided_notgo_A = 1 if l8b == 1 

gen 	letter_decided_notgo_B = 0 if !mi(l8b) 
replace letter_decided_notgo_B = 1 if l8b == 2 

gen 	letter_decided_notgo_C = 0 if !mi(l8b) 
replace letter_decided_notgo_C = 1 if l8b == 3

gen 	letter_decided_notgo_D = 0 if !mi(l8b) 
replace letter_decided_notgo_D = 1 if l8b == 4

gen 	letter_decided_notgo_E = 0 if !mi(l8b) 
replace letter_decided_notgo_E = 1 if l8b == 5

label var letter_decided_notgo_A "Patients Didn't Go to HF Because of Its A (If Didn't Go Because of Scorecard)"   
label var letter_decided_notgo_B "Patients Didn't Go to HF Because of Its B (If Didn't Go Because of Scorecard)"   
label var letter_decided_notgo_C "Patients Didn't Go to HF Because of Its C (If Didn't Go Because of Scorecard)"   
label var letter_decided_notgo_D "Patients Didn't Go to HF Because of Its D (If Didn't Go Because of Scorecard)"   
label var letter_decided_notgo_E "Patients Didn't Go to HF Because of Its Closure Status (If Didn't Go Because of Scorecard)"   

*l9
gen 	scorecard_purpose_p = 0 if l9__99 == 1 // Should check that the "others" actually make sense 
replace scorecard_purpose_p = 1 if l9_2 == 1 | l9_3 == 1 
label  var scorecard_purpose_p "Patients Associate Scorecards with Quality or Inspection (If Scorecard Noticed)"

*l10 
gen 	scorecardknow_p = 1 if l10 == 1 
replace scorecardknow_p = 0 if l10 == 2 | l10 == 3 | l10 == .d | l10 == .r 
label define know 0 "No knowledge" 1 "Know"
label values scorecardknow_p know
label var scorecardknow_p "Patients Know Scorecards' Letter Ranking (A vs C)"


*******************************************************************************************
	** Part 3: Construct variables related to the impact of scorecards on patients' behaviors  
*******************************************************************************************	

*l11
gen 	  notice_closed_scorecards_p = l11
label var notice_closed_scorecards_p "Patients Ever Noticed Closure Scorecard"

*l12
gen 	  aware_closedhf_p = l12
label var aware_closedhf_p "Patients Aware of Nearby HF Closed by Government"

*l13
gen 	  nb_closed_hf = l13 // More than 10 becomes 10
label var nb_closed_hf "Number of Closed HFs Patients Are Aware of Nearby (If Aware of Closed HFs)"

*l14
gen 	  affected_closed_p = 0 if l14 == .r | l14 == 0
replace   affected_closed_p = 1 if l14 == 1
label var affected_closed_p "Patients Affected by Closure of Nearby HF (If Aware of Closed HFs)"

*l15 
gen 	  affected_close_lessoption_p = l15_1
label var affected_close_lessoption_p "Patients Have Less Option (If Affected)"

gen 	  affected_close_farther_p = l15_2
label var affected_close_farther_p "Patients Need to Go Farther (If Affected)"

gen 	  affected_close_closedfacility_p = l15_3
label var affected_close_closedfacility_p "Patients Had Their Facility Closed (If Affected)"

gen 	  affected_close_paymore_p = l15_4
label var affected_close_paymore_p "Patients Have to Pay More (If Affected)"

gen 	  affected_close_crowded_p = l15_5
label var affected_close_crowded_p "Patients' HFs Are More Crowded (If Affected)"

gen 	  affected_close_betteroption_p = l15_6
label var affected_close_betteroption_p "Patients Have Better Options (If Affected)"

*m1
gen 	  scorecardknow2_p 	= 0
replace   scorecardknow2_p  = 1 if m1 == 2
label var scorecardknow2_p  "Patients Know Scorecards' Letter Ranking (Vignette: A vs C vs D)"

*****Aggregating variables in globals
global facility_quality  improvedq_p inspectedhf_p  inspected_gov_MOH_p inspected_county_p inspected_other_p ///
					 inspected_dknow_p  bad_experience_p report_bad_experience_p  reported_incharge_p reported_owner_p /// 
                 		reported_moh_p reported_county_p reported_boards_p reported_other_p

global scorecard  scorecardaware_p  scorecard_purpose_p scorecardknow_p ///
				 scorecardknow2_p  decision_scorecard_p  letter_decided_go_A ///
				 letter_decided_go_B letter_decided_go_C letter_decided_go_D letter_decided_go_E  ///
					letter_decided_notgo_A letter_decided_notgo_B letter_decided_notgo_C letter_decided_notgo_D letter_decided_notgo_E ///


global scorecard_impact notice_closed_scorecards_p aware_closedhf_p nb_closed_hf affected_closed_p  affected_close_lessoption_p ///
						affected_close_farther_p affected_close_closedfacility_p affected_close_paymore_p affected_close_crowded_p ///
						affected_close_betteroption_p

preserve 
********************************************************************************
*Part 4: Save dataset at patient level
********************************************************************************

		save "${pe_insp_p_end}", replace

****Collapse at the health facility level**************************************
foreach var of varlist $facility_quality $scorecard $scorecard_impact {
rename `var' `var'_
bys hfid : egen `var' = mean(`var'_) 
	}

keep hfid $facility_quality $scorecard $scorecard_impact //keep only variables that make sense
duplicates drop hfid, force

********************************************************************************
*Part 5: Save dataset at the HF level
********************************************************************************

		save "${pe_insp_hf_end}", replace

restore 


**************End of do file*****************************************************************************************************
