/*******************************************************************************	

Project:  		KePSIE
Created on:  	July 23, 2019

Written by:  	Thomas Escande			

Revision: 		

********************************************************************************			

THIS DO FILE: 	Following Chandra & Finkelstein (2016), it constructs the dataset to perform the decomposition analysis. This do file is not run directly but will be run by decomposition_construction_scenarios which first prepare the dataset before this final step of constructing the variables and saving the dataset. 

CONTENT:		Part 0 - Create globals for directories and files 
				Part 1: Creating necessary variables and setting up dataset
				Part 2: Computing the total variation in quality (JHIC score)
				Part 3: Computing each factor of the decomposition
				Part 4: Save Dataset

INPUTS:     	"${KePSIE_DB}/IE_Main_Paper/DataSets/Final/Data_for_analysis.dta"
					
OUTPUTS:     	

*******************************************************************************/


********************************************************************************
** Part 1: Creating necessary variables and setting up dataset
********************************************************************************


*Do it for treatment only and for control only 
forvalues i = 0/1 {
preserve 
keep if t == `i'

*Computing weights within each market and for each market. 
bys market_all_expanded  : egen outp_as_jan_m_t 	= sum(outp_as_jan) //Use egen so that missing (because facilities do not exist) are not taking into account
bys market_all_expanded  : egen outp_as_jan_bl_m_t  = sum(outp_as_jan_bl)

gen w_mkt 		= outp_as_jan 	 / outp_as_jan_m_t
gen w_mkt_bl	= outp_as_jan_bl / outp_as_jan_bl_m_t

egen total_outp_t  		= sum(outp_as_jan)  
egen total_outp_bl_t  	= sum(outp_as_jan_bl) 

gen tot_w_t 		= outp_as_jan_m_t 	/ total_outp_t    		
gen tot_w_bl_t 		= outp_as_jan_bl_m_t / total_outp_bl_t    

*Creating market-share-weighted average quality at baseline
	bys market_all_expanded  : egen jhic_all_bl_av = sum(jhic_all_bl*w_mkt_bl) 


********************************************************************************
** Part 2: Computing the total variation in quality (JHIC score)
********************************************************************************
 
	gen 	q_change_h = jhic_all*w_mkt  - jhic_all_bl*w_mkt_bl                 if continuing 	== 1 
	replace q_change_h = jhic_all*w_mkt  										if entering		== 1 
	replace q_change_h = - jhic_all_bl*w_mkt_bl  								if exiting 		== 1 
		
	bys market_all_expanded  : egen q_change_m_test = sum(q_change_h)	
	
********************************************************************************
** Part 3: Computing each factor of the decomposition
********************************************************************************

*Within
	gen tsum_within = (jhic_all - jhic_all_bl)*w_mkt_bl 					if continuing 	== 1 
	
*Between
	gen tsum_between = (jhic_all_bl - jhic_all_bl_av)*(w_mkt - w_mkt_bl) 	if continuing 	== 1 
	
*Cross
	gen tsum_cross = (jhic_all - jhic_all_bl)*(w_mkt - w_mkt_bl)  			if continuing 	== 1 
	
*Entry
	gen tsum_entry = (jhic_all - jhic_all_bl_av)*(w_mkt) 	 				if entering		== 1 
	
*Exit
	gen tsum_exit = -(jhic_all_bl - jhic_all_bl_av)*(w_mkt_bl) 				if exiting 		== 1 
	
tempfile decomposition_`i'
save `decomposition_`i'', replace 

	restore
	}

*Combining the two temporary datasets
use `decomposition_0', clear
append using `decomposition_1'


********************************************************************************
** Part 4: Save Dataset
********************************************************************************

		save "${decomposition_data}", replace

******************************End of do file***********************************
