/*******************************************************************************	
Project:  	KePSIE
********************************************************************************			

PURPOSE: 	Combine intermediate analyses into final analysis databases

CONTENT:	Part 0: Create globals for directories and files 
			Part 1: Combine databases
			Part 2: Export	 		
					 
*******************************************************************************/
********************************************************************************
** Part 0: Create globals for directories and files 
********************************************************************************
clear all
set more off

	* Input
	* --------
	* Profile
	glo pro				"${dt_mast}/profile_end.dta"
	glo pro_add			"${dt_end_fin}/profile_add.dta"
	* JHIC
	glo jhic			"${dt_end_fin}/jhic_for_analysis.dta"
	* Outpatients
	glo outp 			"${dt_end_fin}/outpatients_for_analysis.dta"
	* Prices
	glo price			"${dt_end_const}/fees_cons_end.dta"
	glo price_bl        "${dt_bl_const}/fees_cons_bl.dta"  
	glo oop				"${dt_end_fin}/oop_for_analysis.dta"
	glo oophf			"${dt_end_fin}/oop_hf_for_analysis.dta"
	glo rev 			"${dt_end_fin}/profits_rev_for_analysis.dta"
	glo nhif			"${dt_end_fin}/nhif_claims.dta"
	* Patients
	glo patients		"${dt_end_const}/patient_quality.dta"
	glo wi				"${dt_bl_const}/wealth_index_bl.dta"
	glo wi_bl			"${dt_end_const}/wealth_index_end.dta"
	* Markets
	glo dens 			"${dt_end_fin}/markets_density.dta"
	glo sat				"${dt_end_fin}/markets_saturation.dta"
	* Intervention
	glo inspection 		"${dt_end_const}/inspection_hf.dta"
	glo inspection_p    "${dt_end_const}/inspection_pe_hf.dta"
	glo insp 			"${dt_end_fin}/inspections_fadeout.dta"
	* Licenses and closures
	glo licenses 		"${dt_end_fin}/new_licenses_for_analysis.dta"
	glo closures 		"${dt_end_fin}/closures_for_analysis.dta"
	glo pred 			"${dt_end_fin}/prediction.dta"
	glo controls		"${dt_end_fin}/controls_bl.dta"
		
	* Output  
	* -------- // Outputs are saved in Dropbox
	glo data4analysis 	"${dt_final}/data_for_analysis.dta"
	glo	oop_p			"${dt_final}/oop_p.dta" 

********************************************************************************
** Part 1: Combine databases
********************************************************************************
	foreach x in d4a oop {
		if "`x'"=="d4a"  {
			use "${pro}", clear
			loc y 1
			}
		if "`x'"=="oop"  {
			use "${oop}", clear
			merge 1:1 key using "${patients}", nogen		
			tempfile oop_plus
			save `oop_plus'
			use "${pro}", clear
			merge 1:m hfid using `oop_plus', keep(1 3) nogen
			loc y m
			}		
			
	*---------------------------------------------------------------*
	* JHIC scores 
	*---------------------------------------------------------------*				
		merge `y':1 hfid using "${jhic}", keep(1 3) nogen update	
		
	*---------------------------------------------------------------*
	* Prices 
	*---------------------------------------------------------------*
		* Fees
		* -------
		* Baseline
		glo fee_bl consultation_fee_bl
		glo fee_date_bl consultation_fee_date_bl consultation_fee_month_bl consultation_fee_year_bl
		merge `y':1 hfid using "${price_bl}", keepus($fee_bl) keep(1 3) nogen			
		* Endline
		glo fee consultation_fee
		glo fee_date consultation_fee_date consultation_fee_month consultation_fee_year
		merge `y':1 hfid using "${price}", keepus($fee) keep(1 3) nogen	
		
		* OOP
		* -------------------		
		if "`x'"=="d4a" {
		merge `y':1 hfid using "${oophf}", keep(1 3) nogen	
		}

		* Profits, revenues
		* -------------------		
		merge `y':1 hfid using "${nhif}", keepus(nhif* ) keep(1 3) nogen 
		merge `y':1 hfid using "${rev}", keep(1 3) nogen		
		
	*---------------------------------------------------------------*
	* Outpatients
	*---------------------------------------------------------------*	
		merge `y':1 hfid using "${outp}", keep(1 3) nogen			
		
	*---------------------------------------------------------------*
	* Profile (additional)
	*---------------------------------------------------------------*	
		merge `y':1 hfid using "${pro_add}", keep(1 3) keepus(nhi* sfa* pri* ngo* pat*) nogen	
		
	*---------------------------------------------------------------*
	* Markets
	*---------------------------------------------------------------*	
		* Market vars 
		merge `y':1 hfid using "${dens}", keep(1 3) nogen
		* Saturation
		merge `y':1 hfid using "${sat}", keep(1 3) nogen	
			
	*---------------------------------------------------------------*
	* Intervention
	*---------------------------------------------------------------*	
		* HF intervention vars
		glo regulation regulationaware_hf regulationknow_hf
		glo scorecard  scorecardaware_hf  scorecardknow_hf
		merge `y':1 hfid using "${inspection}", keepusing($regulation $scorecard) keep(1 3) nogen	
				
		* Patient intervention vars (HF averages)
		glo scorecard_p  scorecardaware_p  scorecardknow_p scorecardknow2_p
		glo perceive_p 	improvedq_p inspectedhf_p
		merge `y':1 hfid using "${inspection_p}", keepusing($scorecard_p $perceive_p) keep(1 3) nogen
		
		* Inspections
		merge `y':1 hfid using "${insp}", keep(1 3) nogen
	
	*---------------------------------------------------------------*
	* Licenses and closures
	*---------------------------------------------------------------*	
		* Licenses
		merge `y':1 hfid using "${licenses}", keep(1 3) nogen
		* Closures
		merge `y':1 hfid using "${closures}", keep(1 3) nogen
		* logit prediction
		merge `y':1 hfid using "${pred}", keepus(logit*) keep(1 3) nogen	
		* Controls
		merge `y':1 hfid using "${controls}", keep(1 3) nogen
			
	
********************************************************************************
** Part 2: Export
********************************************************************************
	if "`x'"=="d4a"  {
	save "${data4analysis}", replace
	}
	if "`x'"=="oop"  {
	save "${oop_p}", replace
	}
	}

				

	
	
	
		
					
