/*******************************************************************************	

Project:  		KePSIE - Kenya
Created on:  	September 11, 2019

Written by:  	Thomas Escande (tescande@worldbank.org)

Revision: 		

********************************************************************************			

THIS DO FILE: 	 *This do file use the prediction dataset created on R, cleans it, constructs the number of closure-type facilities per markets and then save the dataset for the final merge to inputadata.
CONTENT:		Part 0 - Create globals for directories and files
				Part 1 - Add missing variables to the dataset
				Part 2: Construct closure-type variable, number of closure-type hfs in the market and a dummy for at least one closure-type hf in the market
				Part 3: Construct different closure-type variable for robustness checks, where the closure-type is replace by the closure status for treatment facilities
				Part 4: Save dataset to be merged with dataset for analysis
INPUTS:     	*

OUTPUTS:		*  

*******************************************************************************/

********************************************************************************
	** Part 0: Create globals for directories and files 
********************************************************************************
	clear all
	set more off
	set maxvar 20000

	*Inputs

	global input			"${dt_end_fin}/ml_cpredict_vf.dta"

	*Inputs to add missing covariates and outcomes 
	global inputdata	 	"${dt_final}/data_for_analysis.dta"
	
	* Outputs
	global pred 			"${dt_end_fin}/prediction.dta"
	
	set  seed 1234

********************************************************************************
	** Part 1: Add missing variables to the dataset
********************************************************************************
	
	use "${input}", clear 
	rename t t_pred 
	 
	*adding needed covariates, keeping the sample to the facilities in the prediction sample, ie the ones that were open at randomization .
	merge 1:1 hfid using "${inputdata}", keep(3) keepusing(market_all_expanded t private) nogen
	

********************************************************************************
	** Part 2: Construct closure-type variable, number of closure-type hfs in the market and a dummy for at least one closure-type hf in the market
********************************************************************************
	

		*Generating logit directly in stata, using naive method and LOO
	
*Naive 
quietly	logit close_enforce  unlicensed_exp  unlicensed_noexp_s0 level_2  level_3  private_type startyear_group_det   county  if t_pred == 1 , vce(cluster market_all_expanded)	
quietly	predict logit_pred_naive	

	*Create the categorical variable
quietly	gen 	logit_group_naive = 1 if logit_pred_naive<=0.4 
quietly	replace logit_group_naive = 2 if logit_pred_naive>0.4 & logit_pred_naive<0.6
quietly	replace logit_group_naive = 3 if logit_pred_naive>=0.6 
quietly	replace logit_group_naive = . if private==0 | logit_pred_naive==.	

quietly gen 	logit_group_naive_2   = 1 if logit_group_naive == 2
quietly replace logit_group_naive_2   = 0 if logit_group_naive == 1 | logit_group_naive == 3
quietly gen 	logit_group_naive_2_t = logit_group_naive_2 * t

quietly gen 	logit_group_naive_3   = 1 if logit_group_naive == 3
quietly replace logit_group_naive_3   = 0 if logit_group_naive == 1 | logit_group_naive == 2
quietly gen 	logit_group_naive_3_t = logit_group_naive_3 * t


*******
*LOO
*******

quietly	logit close_enforce  unlicensed_exp  unlicensed_noexp_s0 level_2  level_3  private_type startyear_group_det   county   if t_pred == 1 , vce(cluster market_all_expanded)		
quietly	predict logit_pred	if t_pred == 0 // for control facilities, LOO is the same as the endogenous stratification estimation as they are not used for training, so no risk of overfitting 

	*Run the prediction for each facility excluding that facility
		gsort -t_pred hfid 
quietly	gen count_treat = _n if t_pred == 1
quietly	sum count_treat
		local max_fac = r(N)
	
forvalues facility = 1/`max_fac' {
quietly	logit close_enforce  unlicensed_exp  unlicensed_noexp_s0 level_2  level_3  private_type startyear_group_det   county  if t_pred == 1 & count_treat != `facility' , vce(cluster market_all_expanded)		
quietly	predict logit_pred_`facility'						if t_pred == 1 & count_treat == `facility'
quietly	replace logit_pred	= logit_pred_`facility'			if t_pred == 1 & count_treat == `facility'	
}	

	
	*Create the categorical variable
quietly	gen 	logit_group = 1 if logit_pred <= 0.4 
quietly	replace logit_group = 2 if logit_pred > 0.4 & logit_pred < 0.6
quietly	replace logit_group = 3 if logit_pred >= 0.6 
quietly	replace logit_group = . if private == 0 | logit_pred == .	
quietly	replace logit_group = . if logit_pred == .

quietly gen 	logit_group_2   = 1 if logit_group == 2
quietly replace logit_group_2   = 0 if logit_group == 1 | logit_group == 3
quietly gen 	logit_group_2_t = logit_group_2 * t

quietly gen 	logit_group_3   = 1 if logit_group == 3
quietly replace logit_group_3   = 0 if logit_group == 1 | logit_group == 2
quietly gen 	logit_group_3_t = logit_group_3 * t
	 

drop t //


********************************************************************************
	** Part 4: Save dataset to be merged with dataset for analysis
********************************************************************************	
	
	save "$pred", replace


******************************************End of do file********************************************
