/*******************************************************************************
*					KENYA PATIENT SAFETY IMPACT EVALUATION  				   *
*   					  		MASTER DO-FILE						   	   	   *
********************************************************************************
********************************************************************************
*						   SELECT PARTS TO RUN   							   *
********************************************************************************/
	
* Select which parts of this do-file to run	   
loc clean				0	// De-identify and clean raw data (requires access to encrypted files)
loc	construct			1	// Construct indicators for baseline, endline and analysis
loc	mainresults			1	// Run main results
loc	appendix			1	// Run appendix files
loc	supplemental		1	// Run supplemental material files

********************************************************************************
* PART 1:  Prepare globals and define paths					  			       *
********************************************************************************

* Add your directory below
 display c(username)  	// 1. copy username below in XX 
						// 2. add path to GitHub folder
						// 3. add path to DataWork folder
						// 4. add volume for encrypted data (only if accessing encrypted files)

* Set directories 
* ---------------
* Amy
if "`c(username)'" == "amy" {
	glo	github		 	"/Users/amy/Documents/GitKraken/kepsie/Reproducibility Package"
	glo	datawork		"/Users/amy/+ Dropbox/Amy Dolinger/Kepsie/DataWork"
	glo volume 			"/Users/amy/${mount}colon"
	}   
* Add user
if "`c(username)'" == "wb532468" {
	glo github 	 "C:/Users/wb532468/OneDrive - WBG/Rep-checks/FY23/Lupe - Minimum quality standards on health markets v2/kepsie/Reproducibility Package" // GitHub directory
	glo datawork "C:/Users/wb532468/OneDrive - WBG/Rep-checks/FY23/Lupe - Minimum quality standards on health markets v2/DataWork" // DataWork directory
	glo volume 	 "" // Encryption volume (only if accessing encrypted files) 
	}	
* Add user
if "`c(username)'" == "XX" {
	glo github 	 "" // GitHub directory
	glo datawork "" // DataWork directory
	glo volume 	 "" // Encryption volume (only if accessing encrypted files) 
	}			
	
* Project folders 
* ---------------------
glo encrypt 				"${datawork}/data/raw_encrypted" // Confidential folder
glo adopath					"${github}/dofiles/ado"
glo program					"${adopath}/programs"
glo ado						"${adopath}/ado"

* Dofiles
glo	do						"${github}/dofiles"
glo	do_main					"${do}/analysis/main"
glo	do_appendix				"${do}/analysis/appendix"
glo	do_supp					"${do}/analysis/supplemental_material"
glo	do_mast					"${do}/masterdata"
glo	do_bl					"${do}/baseline"
glo	do_bl_clean				"${do_bl}/clean"
glo	do_bl_const				"${do_bl}/construct"
glo	do_end					"${do}/endline"
glo	do_end_clean			"${do_end}/clean"
glo	do_end_const			"${do_end}/construct"
glo	do_end_fin				"${do_end_const}/prep4analysis"

* Datasets
glo	data					"${datawork}/data"
glo	dt_final				"${data}/final"
glo dt_mast					"${data}/masterdata"
glo dt_adm					"${dt_mast}/admindata"
glo	dt_int					"${data}/intermediate"
glo	dt_bl_int				"${dt_int}/baseline"
glo	dt_bl_clean				"${dt_bl_int}/clean"
glo	dt_bl_const				"${dt_bl_int}/constructed"
glo	dt_end_int				"${dt_int}/endline"
glo	dt_end_clean			"${dt_end_int}/clean"
glo	dt_end_const			"${dt_end_int}/constructed"
glo	dt_end_fin				"${dt_end_const}/prep4analysis"
glo dt_raw					"${data}/raw_encrypted"	

* Documentation
glo	doc						"${github}/documentation"
glo doc_bl					"${doc}/baseline"
glo doc_end					"${doc}/endline"

* Outputs
glo	out						"${github}/output"
glo	out_main				"${out}/main"
glo	out_appendix			"${out}/appendix"
glo	out_supp				"${out}/supplemental_material"		

* Set project globals
* ---------------------
glo mount			"M"			// Encryption drive

* Install packages
* ----------------	
foreach package in ietoolkit {
	capture which `package'
	if _rc == 111 ssc install `package'
	}	
ieboilstart, v(15.0) matsize(10000) adopath("${ado}", strict)
`r(version)'	

********************************************************************************
* PART 2:  Run cleaning files							       				   *
********************************************************************************
*
* 	REQUIRES:	* Baseline encrypted files
*					${encrypt}/pe_bl_raw
*					${encrypt}/qps1_bl_raw
*					${encrypt}/qps1_helper_bl_raw
*					${encrypt}/qps1_roster_bl_raw
*					${encrypt}/qps2_bl_raw
*					${encrypt}/pps_do_bl_raw
*					${encrypt}/pps_hcw_bl_raw
*					${encrypt}/pps_so_bl_raw
*				* Endline encrypted files
*					${encrypt}/pe_end_raw
*					${encrypt}/qps1_end_raw
*					${encrypt}/qps1_helper_end_raw
*					${encrypt}/qps2_end_raw
*					${encrypt}/pps_do_end_raw
*					${encrypt}/pps_hcw_end_raw
*					${encrypt}/pps_so_end_raw
*				* MasterData encrypted files
*					${encrypt}/profile_bl_raw
*					${encrypt}/listing_bl_raw
* 	CREATES:	* Baseline clean files
* 					${dt_bl_clean}/pe_bl
*					${dt_bl_clean}/qps1_bl
*					${dt_bl_clean}/qps1_helper_bl
*					${dt_bl_clean}/qps1_roster_bl
*					${dt_bl_clean}/qps2_bl
*					${dt_bl_clean}/jhic_bl_clean
*					${dt_bl_clean}/pps_do_bl
*					${dt_bl_clean}/pps_hcw_bl
*					${dt_bl_clean}/pps_so_bl
*				* Endline clean files
* 					${dt_end_clean}/pe_end
*					${dt_end_clean}/qps1_end
*					${dt_end_clean}/qps1_roster_end
*					${dt_end_clean}/qps1_fees_outp_end
*					${dt_end_clean}/qps2_bl
*					${dt_end_clean}/jhic_end_clean
*					${dt_bl_clean}/pps_do_end
*					${dt_bl_clean}/pps_hcw_end
*					${dt_bl_clean}/pps_so_end
*				* MasterData clean files
*					${dt_mast}/profile_bl
*					${dt_mast}/listing_bl
*
* ------------------------------------------------------------------------------
	
if `clean' {
	do "${do_bl_clean}/pe_bl_clean.do"
	do "${do_bl_clean}/qps1_bc_bl_clean.do"
	do "${do_bl_clean}/qps1_bl_clean.do"
	do "${do_bl_clean}/qps1_helper_bl_clean.do"
	do "${do_bl_clean}/qps1_roster_bl_clean.do"
	do "${do_bl_clean}/qps1_fees_outpatient_bl_clean.do"
	do "${do_bl_clean}/qps2_bl_clean.do"
	do "${do_bl_clean}/jhic_bl_clean.do"
	do "${do_bl_clean}/pps_do_bl_clean.do"
	do "${do_bl_clean}/pps_hcw_bl_clean.do"
	do "${do_bl_clean}/pps_so_bl_clean.do"
	do "${do_end_clean}/pe_end_clean.do"
	do "${do_end_clean}/qps1_bc_end_clean.do"
	do "${do_end_clean}/qps1_end_clean.do"
	do "${do_end_clean}/qps1_roster_end_clean.do"
	do "${do_end_clean}/qps2_end_clean.do"
	do "${do_end_clean}/jhic_end_clean.do"
	do "${do_end_clean}/pps_do_end_clean.do"
	do "${do_end_clean}/pps_hcw_end_clean.do"
	do "${do_end_clean}/pps_so_end_clean.do"
	}
	
********************************************************************************
* PART 3:  Run construction files						   	   				   *
********************************************************************************		
*
*	REQUIRES:	* Baseline clean files
** 					${dt_bl_clean}/pe_bl
*					${dt_bl_clean}/qps1_bl
*					${dt_bl_clean}/qps1_helper_bl
*					${dt_bl_clean}/qps1_roster_bl
*					${dt_bl_clean}/qps2_bl
*					${dt_bl_clean}/jhic_bl_clean
*					${dt_bl_clean}/pps_do_bl
*					${dt_bl_clean}/pps_hcw_bl
*					${dt_bl_clean}/pps_so_bl
*				* Endline clean files
* 					${dt_end_clean}/pe_end
*					${dt_end_clean}/qps1_end
*					${dt_end_clean}/qps1_roster_end
*					${dt_end_clean}/qps1_fees_outp_end
*					${dt_end_clean}/qps2_bl
*					${dt_end_clean}/jhic_end_clean
*					${dt_bl_clean}/pps_do_end
*					${dt_bl_clean}/pps_hcw_end
*					${dt_bl_clean}/pps_so_end
*	CREATES:	* Baseline constructed files
*					${dt_bl_const}/jhic_bl_scores.dta
*					${dt_bl_const}/fees_outp_bl.dta
*					${dt_bl_const}/fees_cons_bl.dta
*					${dt_bl_const}/outp_av_bl.dta
*					${dt_bl_const}/wealth_index_bl.dta
*				* Endline constructed files
*					${dt_end_const}/jhic_end_scores.dta
*					${dt_end_const}/jhic_compliance_items.dta
*					${dt_end_const}/outp_av_end.dta
*					${dt_end_const}/outp_av_robust_end.dta
*					${dt_end_const}/inspection_hf.dta
*					${dt_end_const}/inspection_pe.dta
*					${dt_end_const}/patient_quality.dta
*					${dt_end_const}/staff_roster_end.dta
*					${dt_end_const}/wealth_index_end.dta
*					${dt_end_fin}/outpatients_for_analysis.dta
*					${dt_end_fin}/jhic_for_analysis.dta
*					${dt_end_fin}/new_licenses_for_analysis.dta
*					${dt_end_fin}/oop_for_analysis.dta
*					${dt_end_fin}/nhif_claims.dta
*					${dt_end_fin}/profits_staff_for_analysis.dta
*					${dt_end_fin}/inspections_fadeout.dta
*					${dt_end_fin}/ipc_for_analysis.dta
*					${dt_end_fin}/markets_density.dta
*					${dt_end_fin}/markets_saturation.dta
*					${dt_end_fin}/rf_closure_input_end.dta
*					${dt_end_fin}/rf_closure_output_end.dta
*					${dt_end_fin}/mediation_construction.dta
*					${dt_end_fin}/mediation_construction.dta
*					${dt_final}/data_for_analysis.dta
*					${dt_final}/oop_p.dta
*
* ------------------------------------------------------------------------------

if `construct' {
	do "${do_bl_const}/jhic_bl_scores.do"
	do "${do_bl_const}/outp_av_bl.do"
	do "${do_bl_const}/fees_outp_bl.do"
	do "${do_bl_const}/price_outliers_bl.do"
	do "${do_bl_const}/wealth_index_bl.do"
	do "${do_end_const}/jhic_end_scores.do"
	do "${do_end_const}/jhic_compliance_items.do"
	do "${do_end_const}/outp_av_end.do"
	do "${do_end_const}/outp_av_robust_end.do"	
	do "${do_end_const}/inspection_hf.do"
	do "${do_end_const}/inspection_pe.do"
	do "${do_end_const}/patient_quality.do"
	do "${do_end_const}/staff_roster_end.do"
	do "${do_end_const}/wealth_index_end.do"
	do "${do_end_fin}/outpatients_for_analysis.do"
	do "${do_end_fin}/jhic_for_analysis.do"
	do "${do_end_fin}/new_licenses_for_analysis.do"
	do "${do_end_fin}/oop_for_analysis.do"
	do "${do_end_fin}/nhif_claims.do"
	do "${do_end_fin}/profits_staff_for_analysis.do"
	do "${do_end_fin}/inspections_fadeout.do"	
	do "${do_end_fin}/ipc_for_analysis.do"	
	do "${do_end_fin}/markets_density.do"	
	do "${do_end_fin}/markets_saturation.do"
	do "${do_end_fin}/merge_for_analysis.do"
	do "${do_end_fin}/rf_closure_input_end.do"	
	do "${do_end_fin}/rf_closure_output_end.do"	
	do "${do_end_fin}/mediation_construction.do"
	do "${do_end_fin}/decomposition_construction_scenarios.do"
	}	
	
********************************************************************************
* PART 4:  Run main results							   					       *
********************************************************************************
*
*	Note: ^ indicates tables and figures not generated by code
*
*	OUTLINE:	* Tables
*					Table 1: Summary Statistics at Baseline
*					Table 2: Baseline Quality Association
*					Table 3: Impacts on Main Outcomes
*					Table 4: Impacts by Functional Categories
*					Table 5: Impacts on Outpatients and Inactivity
*					Table 6: Decomposition
* 					Table 7: Impacts by Treatment Arms
*				* Figures
*					Figure 1: Study Timeline^
*					Figure 2: Wealth Index
*					Figure 3: Conditional QTE
*					Figure 4: Closure Probability Groups
* 	REQUIRES:	* Analysis files
*					${dt_final}/data_for_analysis.dta
*					${dt_final}/oop_p.dta
*				* Texdoc files
*					${do_main}/tex (for corresponding table)
* 	CREATES:	* Tables 
*					${out_main}/table_1.tex
*					${out_main}/table_2.tex
*					${out_main}/table_3.tex
*					${out_main}/table_4.tex
*					${out_main}/table_5.tex
*					${out_main}/table_6.tex
*					${out_main}/table_7.tex
*				* Figures
*					${out_main}/figure_2.pdf
*					${out_main}/figure_3.pdf
*					${out_main}/figure_4.pdf
*
* ------------------------------------------------------------------------------

if `mainresults' {
	do "${do_main}/table_1.do"
	do "${do_main}/table_2.do"
	do "${do_main}/table_3.do"
	do "${do_main}/table_4.do"
	do "${do_main}/table_5.do"
	do "${do_main}/table_6.do"
	do "${do_main}/table_7.do"
	do "${do_main}/figure_2.do"
	do "${do_main}/figure_3.do"
	do "${do_main}/figure_4.do"
	}	
	
********************************************************************************
* PART 5:  Run appendix files
********************************************************************************
*
*	Note: ^ indicates tables and figures not generated by code
*
*	OUTLINE:	* Tables
*					Table A1: JHIC Compliance Categories^
*					Table A2: Balance Checks
*					Table A3: Baseline Quality Associations
*					Table A4: Government Closures and Inactivity
*					Table A5: Impacts at Randomization
*					Table A6: Wealth Index
* 					Table A7: Quality Indicators: IPC
* 					Table A8: Quality Indicators: Patients
* 					Table A9: Quality Indicators: Staff
* 					Table A10: Cost Categories
* 					Table A11: Public Facilities in Market
* 					Table A12: Intermediate Outcomes
*				* Figures
*					Figure A1: Scorecards^
*					Figure A2: Dissemination Materials^
*					Figure A3: Intervention Compliance^
*					Figure A4: Inspection Visits^
*					Figure A5: Robustness Checks
*					Figure A6: Decomposition Scenarios
*					Figure A7: McCrary Test
*					Figure A8: JHIC Distribution
*					Figure A9: Unconditional QTE
* 	REQUIRES:	* Analysis files
*					${dt_final}/data_for_analysis.dta
*					${dt_final}/oop_p.dta
*				* Texdoc files
*					${do_appendix}/tex (for corresponding table)
* 	CREATES:	* Tables 
*					${out_appendix}/table_A2.tex
*					${out_appendix}/table_A3.tex
*					${out_appendix}/table_A4.tex
*					${out_appendix}/table_A5.tex
*					${out_appendix}/table_A6.tex
*					${out_appendix}/table_A7.tex
*					${out_appendix}/table_A8.tex
*					${out_appendix}/table_A9.tex
*					${out_appendix}/table_A10.tex
*					${out_appendix}/table_A11.tex
*					${out_appendix}/table_A12.tex
*				* Figures
*					${out_appendix}/figure_A5.pdf
*					${out_appendix}/figure_A6.pdf
*					${out_appendix}/figure_A7.pdf
*					${out_appendix}/figure_A8.pdf
*					${out_appendix}/figure_A9.pdf
*
* ------------------------------------------------------------------------------

if `appendix' {
	do "${do_appendix}/table_A2.do"
	do "${do_appendix}/table_A3.do"
	do "${do_appendix}/table_A4.do"
	do "${do_appendix}/table_A5.do"
	do "${do_appendix}/table_A6.do"
	do "${do_appendix}/table_A7.do"
	do "${do_appendix}/table_A8.do"
	do "${do_appendix}/table_A9.do"
	do "${do_appendix}/table_A10.do"
	do "${do_appendix}/table_A11.do"
	do "${do_appendix}/table_A12.do"
	do "${do_appendix}/figure_A5.do"
	do "${do_appendix}/figure_A6.do"
	do "${do_appendix}/figure_A7.do"
	do "${do_appendix}/figure_A8.do"
	do "${do_appendix}/figure_A9.do"
	}		
	
********************************************************************************
* PART 6:  Run supplemental material files
********************************************************************************
*
*	Notes: 	^ indicates tables and figures not generated by code.
*			Table S16 is currently an unformatted tex output that requires
*			manual revisions to labels and formatting, but will be 
*			updated to an automated formatted version for the next round of 
*			review.
*
*	OUTLINE:	* Tables
*					Table S1: Market Characteristics
*					Table S2: JHIC Sections^
*					Table S3: Surveys
*					Table S4: Census
*					Table S5: Randomized Markets
*					Table S6: Differential Response
* 					Table S7: Contamination
* 					Table S8: Market Size Correlations
* 					Table S9: Exit and Entry
* 					Table S10: Robustness: Baseline Controls
* 					Table S11: Robustness: Strata Only
* 					Table S12: Spillovers
* 					Table S13: Spillovers Balance
* 					Table S14: Fadeout
* 					Table S15: Fadeout Balance
* 					Table S16: Unconditional QTE
* 					Table S17: Closure Probability Group
* 					Table S18a: JHIC Score >40
* 					Table S18b: JHIC Score >50
*				* Figures
*					Figure S1: Facilities by Level^
*					Figure S2: Market Illustration^
*					Figure S3: JHIC Score in Control Facilities
*					Figure S4: Fadeout
* 	REQUIRES:	* Analysis files
*					${dt_final}/data_for_analysis.dta
*					${dt_final}/oop_p.dta
*				* Texdoc files
*					${do_supp}/tex (for corresponding table)
* 	CREATES:	* Tables 
*					${out_supp}/table_S1.tex
*					${out_supp}/table_S3.tex
*					${out_supp}/table_S4.tex
*					${out_supp}/table_S5.tex
*					${out_supp}/table_S6.tex
*					${out_supp}/table_S7.tex
*					${out_supp}/table_S8.tex
*					${out_supp}/table_S9.tex
*					${out_supp}/table_S10.tex
*					${out_supp}/table_S11.tex
*					${out_supp}/table_S12.tex
*					${out_supp}/table_S13.tex
*					${out_supp}/table_S14.tex
*					${out_supp}/table_S15.tex
*					${out_supp}/table_S16.xls
*					${out_supp}/table_S17.tex
*					${out_supp}/table_S18.tex
*					${out_supp}/table_S18b.tex
*				* Figures
*					${out_supp}/figure_S3.pdf
*					${out_supp}/figure_S4.pdf
*
* ------------------------------------------------------------------------------

if `supplemental' {
	do "${do_supp}/table_S1.do"
	do "${do_supp}/table_S3.do"
	do "${do_supp}/table_S4.do"
	do "${do_supp}/table_S5.do"
	do "${do_supp}/table_S6.do"
	do "${do_supp}/table_S7.do"
	do "${do_supp}/table_S8.do"
	do "${do_supp}/table_S9.do"
	do "${do_supp}/table_S10.do"
	do "${do_supp}/table_S11.do"
	do "${do_supp}/table_S12.do"
	do "${do_supp}/table_S13.do"
	do "${do_supp}/table_S14.do"
	do "${do_supp}/table_S15.do"
	do "${do_supp}/table_S16.do"
	do "${do_supp}/table_S17.do"
	do "${do_supp}/table_S18a.do"
	do "${do_supp}/table_S18b.do"
	do "${do_supp}/figure_S3.do"
	do "${do_supp}/figure_S4.do"
	}			
	