/*******************************************************************************	
*		Project:
*		KePSIE
* 		Last update: 19 May 2016

********************************************************************************			


** PURPOSE:    	This do file creates Checklist's scores
				
** INPUTS:   	Checklist_adherence_nodeliveries.dta

** OUTPUTS:    	Checklist_scores_nodeliveries.dta
				Checklist_scores_s1_nodeliveries.dta
				Checklist_scores_s2_nodeliveries.dta
				Checklist_scores_s3_nodeliveries.dta
				Checklist_scores_s4_nodeliveries.dta
				
** Written by: 	Tatiana Zarate

*******************************************************************************/

********************************************************************************	
	
* Part 0: Directories

********************************************************************************

	* Globals for input files
	glo jhic_bl 		"${dt_bl_clean}/jhic_bl"
	glo jhic_bl_scores	"${dt_bl_const}/jhic_bl_scores"	
		
********************************************************************************	
	
* Part 1: Simuations

********************************************************************************
		
	cls
	clear all
	set maxvar 10000
	use "${jhic_bl}", clear
	
*^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
	** Groups based on low to high cost items in Checklist
*^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^

	* Group 1 (no cost)
	local sops s2c_3b	s4a_1a	s4a_1b	s4a_2a	s4b_1b	s5a_1c	s5a_1d	s5a_4b	s5b_1a s5b_1b	s5b_3c	s6a_1i	s6a_2c	s6a_3b	s6a_3c	s6a_4a	s6a_7d	s6a_8d	s6b_1a s6b_1b	s6b_3c	s7b_1a s7b_1b	s7b_3c	s8b_1a s8b_1b	s8b_3c	s9b_1c	s9c_1b	s9e_1a s9e_1b	s9e_3c	s10a_2b	s10a_3a	s10a_3b	s10a_4a	s10a_4b	s10a_5a	s10d_2b	s10e_1a	s10e_1b s10e_3c	s11a_4a	s11b_1a	s11d_1a s11d_1b	s12b_1a	s12b_1b	s12b_1c	s12b_1d	s12b_1e	s12b_1f	s12b_1g	s12b_1h	s12d_1c	s12f_1a	s12f_1b s12f_3c
	local cleaning s4a_3a	s4a_3d	s4a_4a	s4a_4b	s4a_4c
	local documentation s3a_2g s3a_2h s2b_3b	s3a_1b	s3a_1c	s3a_1d	s3a_3a	s3b_1b	s3b_2b	s3b_3c	s3d_1a	s3d_1b	s3d_2a	s3d_2b	s3d_2c	s6a_5a	s6a_6a	s6a_6b	s6a_6c	s6a_6d	s6a_6e	s6a_6f	s6a_6g	s7a_1a	s7a_1c	s7a_1d	s9c_1d	s9c_1e	s9c_1f	s10b_2a	s10b_2b	s10b_3a	s10b_4a	s10b_4b	s10d_1a	s10d_1b	s10d_1c	s10d_1d	s11a_2a	s11a_5a	s11b_3a	s11b_4d	s12c_1d	s12d_1f	s11c_2b
	local management s5a_1a	s3b_1a	s3b_3b	s4b_1d	s5a_1b	s8a_4a	s8a_4b	s9b_1b	s9c_1a	s9c_1c	s9d_1b	s10a_2a	s10b_1a	s10b_1b	s10d_1e	s10d_1f	s11b_1b	s11b_1c	s11b_2a	s11b_4a	s11b_4b	s11b_4c	s12c_1b	s12d_1a	s12d_1b	s12d_1d	s12d_1e	s12d_1g	s12d_2a	s12d_2b	s12e_3a	s11c_1b	s11c_2a	s11c_3a

	* Group 2 (low cost)
	local supplies_low s5a_3a	s5a_3b	s5a_3c	s5a_3d	s5a_3e	s5a_3f	s5a_3g	s5a_3h	s5a_3i	s5a_4a	s5a_4c	s5a_4d	s5a_4e	s5a_4f	s5a_4g	s5a_4h	s5a_4l	s5b_2b	s5b_3a	s5b_3b	s5b_4a	s5b_4b	s5b_5a	s5b_5b	s5b_5c	s5b_5d	s6a_1f	s6a_1g	s6a_8c	s6b_2b	s6b_3a	s6b_3b	s6b_4a	s6b_4b	s6b_5a	s6b_5b	s6b_5c	s6b_5d	s7a_1b	s7a_3b	s7a_3c	s7a_3d	s7b_2b	s7b_3a	s7b_3b	s7b_4a	s7b_4b	s7b_5a	s7b_5b	s7b_5c	s7b_5d	s8a_1b	s8a_1c	s8a_2b	s8a_2c	s8a_2d	s8a_2e	s8a_3d	s8a_3g	s8a_3i	s8a_3j	s8b_2b	s8b_3a	s8b_3b	s8b_4a	s8b_4b	s8b_5a	s8b_5b	s8b_5c	s8b_5d	s9d_1a	s9e_2b	s9e_3a	s9e_3b	s9e_4a	s9e_4b	s9e_5a	s9e_5b	s9e_5c	s9e_5d	s10e_2b	s10e_3a	s10e_3b	s10e_4a	s10e_4b	s10e_5a	s10e_5b	s10e_5c	s10e_5d	s11d_2b	s11d_3a	s11d_3b	s11d_4a	s11d_4b	s11d_4c	s11d_4d	s12a_1a	s12a_1b	s12a_1c	s12a_1d	s12a_1e	s12a_1f	s12a_1g	s12a_2b	s12a_2c	s12a_2d	s12a_2e	s12a_2f	s12a_2g	s12a_2h	s12a_2i	s12a_2j	s12e_1a	s12e_1b	s12e_1d	s12e_1f	s12f_2b	s12f_3a	s12f_3b	s12f_4a	s12f_4b	s12f_5a	s12f_5b	s12f_5c	s12f_5d
	local records s3b_2a	s3b_2b	s3b_2c	s3b_2d s3b_2e	s3c_1a	s3c_1b	s3c_1c	s3c_2a	s3c_2b	s3c_2c	s3c_2d	s3c_5a	s7a_2a	s10c_1a	s12c_1a

	* Group 3 (medium cost)
	local equipment s2c_2a	s2c_2b	s5a_2a	s5a_2b	s5a_2c	s5a_4i	s5a_4j	s5a_4k	s6a_1b	s6a_1e	s6a_3a	s6a_4b	s6a_7a	s6a_7b	s6a_7c	s7a_3a	s8a_3f	s8a_3h	s8a_3k	s8a_3l	s8a_5b	s4a_2b
	local supplies_med s3b_3a	s6a_1c	s6a_1d	s8a_3e	s8a_5c	s10d_2a	s11a_1a	s11a_3a	s12e_1c	s12e_1e

	* Group 4 (high cost)
	local infrastructure s2a_1b	s2a_1c	s2a_1d	s3a_1a	s3a_2a	s3a_2b	s3a_2c	s3a_2d	s3a_2e	s3a_2f	s2a_1a	s2a_1e	s2a_2a	s2a_3a	s2b_1a	s2b_1b	s2b_2a	s2b_3a	s2c_1a	s2c_1b	s2c_3a	s2c_3c	s2c_3d	s2c_4a	s3c_3a	s3c_3b	s3c_3c	s3c_4a	s3c_4b	s4a_2c	s4a_3b	s4a_3c	s4b_1a	s4b_1c	s5b_2a	s6a_1a	s6a_1h	s6a_2a	s6a_2b	s6a_5b	s6a_7e	s6a_8a	s6a_8b	s6b_2a	s7a_2b	s7a_3e	s7b_2a	s8a_1a	s8a_1d	s8a_2a	s8a_2f	s8a_2g	s8a_2h	s8a_3a	s8a_3b	s8a_3c	s8a_5a	s8b_2a	s9a_1a	s9a_2a	s9a_2b	s9b_1a	s9e_2a	s10e_2a	s11d_2a	s12a_2a	s12c_1c	s12e_2a	s12e_2b	s12e_2c	s12e_2d	s12e_2e	s12f_2a s12e_3b

********************************************************************************

** Part 2: Scores

********************************************************************************

*^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
	* 2.1. Creates globals for adherence variables 
*^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
	
	* S2: HF Infrastructure 

	* A. Building
	local s2a_1_a	s2a_1a_a s2a_1b_a s2a_1c_a s2a_1d_a s2a_1e_a
	local s2a_2_a	s2a_2a_a
	local s2a_3_a	s2a_3a_a
	
	* B. Utilities
	local s2b_1_a	s2b_1a_a s2b_1b_a
	local s2b_2_a	s2b_2a_a	
	local s2b_3_a	s2b_3a_a s2b_3b_a
		
	* C. Security
	local s2c_1_a s2c_1a_a s2c_1b_a		
	local s2c_2_a s2c_2a_a s2c_2b_a		
	local s2c_3_a s2c_3a_a s2c_3b_a s2c_3c_a s2c_3d_a
	local s2c_4_a s2c_4a_a			
		
	local s2_a `s2a_1_a' `s2a_2_a' `s2a_3_a' `s2b_1_a' `s2b_2_a' `s2b_3_a' `s2c_1_a' `s2c_2_a' `s2c_3_a' `s2c_4_a'
	
	
    * S3: General Management and Recording of Information

	* A. General Management 
	local s3a_1_a s3a_1a_a s3a_1b_a s3a_1c_a s3a_1d_a			
	local s3a_2_a s3a_2a_a s3a_2b_a s3a_2c_a s3a_2d_a s3a_2e_a s3a_2f_a s3a_2g_a s3a_2h_a 
	local s3a_3_a s3a_3a_a //  s3a_3b_a	is not included because in QPS1/2 we didn't ask for certifications
	
	* B. Quality management
	local s3b_1_a s3b_1a s3b_1b_a	// Not scored questions
	local s3b_2_a s3b_2a_a	s3b_2b_a s3b_2c_a	s3b_2d_a s3b_2e_a
	local s3b_3_a s3b_3a_a s3b_3b_a s3b_3c_a		
	
	* C. Medical records and information systems
	local s3c_1_a s3c_1a_a s3c_1b_a	s3c_1c_a	
	local s3c_2_a s3c_2a_a s3c_2b_a	s3c_2c_a s3c_2d_a
	local s3c_3_a s3c_3a_a s3c_3b_a	s3c_3c_a	
	local s3c_4_a s3c_4a_a s3c_4b_a	// Not scored questions
						
	local s3c_5_a s3c_5a_a 			
	
	* D. Equipment management
	local s3d_1_a s3d_1a_a s3d_1b_a	
	local s3d_2_a s3d_2a_a s3d_2b_a	s3d_2c_a
	
	local s3_a `s3a_1_a' `s3a_2_a' `s3a_3_a' `s3b_1_a' `s3b_2_a' `s3b_3_a' `s3c_1_a' `s3c_2_a' `s3c_3_a' `s3c_4_a' `s3c_5_a' `s3d_1_a' `s3d_2_a'

					
	* S4: (Infection Prevention and Control)
		
	* A. General
	local s4a_1_a s4a_1a_a s4a_1b_a					
	local s4a_2_a s4a_2a_a s4a_2b_a	s4a_2c_a				
	local s4a_3_a s4a_3a_a s4a_3b_a s4a_3c_a s4a_3d_a
	local s4a_4_a s4a_4a_a s4a_4b_a	s4a_4c_a				
	
	* B. Sterilization Services
	local s4b_1_a s4b_1a_a s4b_1b_a	s4b_1c_a s4b_1d_a
	
	local s4_a `s4a_1_a' `s4a_2_a' `s4a_3_a' `s4a_4_a' `s4b_1_a'
	
	* S5: Medical and Dental Consultation Services 

	* A. General
	local s5a_1_a s5a_1a_a	s5a_1b_a s5a_1c_a s5a_1d_a								
	local s5a_2_a s5a_2a_a	s5a_2b_a s5a_2c_a									
	local s5a_3_a s5a_3a_a	s5a_3b_a s5a_3c_a s5a_3d_a s5a_3e_a	s5a_3f_a s5a_3g_a s5a_3h_a s5a_3i_a			
	local s5a_4_a s5a_4a_a	s5a_4b_a s5a_4c_a s5a_4d_a s5a_4e_a s5a_4f_a s5a_4g_a	s5a_4h_a s5a_4i_a	s5a_4j_a s5a_4k_a	s5a_4l_a

	* B. IPC
	local s5b_1_a s5b_1a_a s5b_1b_a
	local s5b_2_a s5b_2a_a s5b_2b_a		
	local s5b_3_a s5b_3a_a s5b_3b_a s5b_3c_a	
	local s5b_4_a s5b_4a_a s5b_4b_a		
	local s5b_5_a s5b_5a_a s5b_5b_a s5b_5c_a s5b_5d_a
	
	local s5_a `s5a_1_a' `s5a_2_a' `s5a_3_a' `s5a_4_a' `s5b_1_a' `s5b_2_a' `s5b_3_a' `s5b_4_a' `s5b_5_a'

	* S6: Labour Ward 

	local s6a_1_a s6a_1a_a	s6a_1b_a s6a_1c_a s6a_1d_a s6a_1e_a s6a_1f_a s6a_1g_a s6a_1h_a s6a_1i_a
	local s6a_2_a s6a_2a_a	s6a_2b_a s6a_2c_a						
	local s6a_3_a s6a_3a_a	s6a_3b_a s6a_3c_a						
	local s6a_4_a s6a_4a_a	s6a_4b_a							
	local s6a_5_a s6a_5a_a	s6a_5b_a							
	local s6a_6_a s6a_6a_a	s6a_6b_a s6a_6c_a	s6a_6d_a s6a_6e_a	s6a_6f_a s6a_6g_a 		
	local s6a_7_a s6a_7a_a	s6a_7b_a s6a_7c_a s6a_7d_a s6a_7e_a				
	local s6a_8_a s6a_8a_a	s6a_8b_a s6a_8c_a s6a_8d_a		
	
	* B. IPC	
	local s6b_1_a s6b_1a_a s6b_1b_a			
	local s6b_2_a s6b_2a_a	s6b_2b_a		
	local s6b_3_a s6b_3a_a	s6b_3b_a s6b_3c_a	
	local s6b_4_a s6b_4a_a	s6b_4b_a		
	local s6b_5_a s6b_5a_a	s6b_5b_a s6b_5c_a s6b_5d_a
	
	local s6_a `s6a_1_a' `s6a_2_a' `s6a_3_a' `s6a_4_a' `s6a_5_a' `s6a_6_a' `s6a_7_a' `s6a_8_a' `s6b_1_a' `s6b_2_a' `s6b_3_a' `s6b_4_a' `s6b_5_a'

	* S7: Medical and Pediatric Wards 
	
	* A. General
	local s7a_1_a s7a_1a_a	s7a_1b_a s7a_1c_a s7a_1d_a		
	local s7a_2_a s7a_2a_a	s7a_2b_a				
	local s7a_3_a s7a_3a_a	s7a_3b_a s7a_3c_a s7a_3d_a	s7a_3e_a
	
	* B. IPC	
	local s7b_1_a s7b_1a_a	s7b_1b_a		
	local s7b_2_a s7b_2a_a	s7b_2b_a		
	local s7b_3_a s7b_3a_a	s7b_3b_a s7b_3c_a	
	local s7b_4_a s7b_4a_a	s7b_4b_a		
	local s7b_5_a s7b_5a_a	s7b_5b_a s7b_5c_a s7b_5d_a
	
	local s7_a `s7a_1_a' `s7a_2_a' `s7a_3_a' `s7b_1_a' `s7b_2_a' `s7b_3_a' `s7b_4_a' `s7b_5_a'

	* S8: Theatre 
	
	* A. General
	local	s8a_1_a	s8a_1a_a	s8a_1b_a	s8a_1c_a	s8a_1d_a								
	local	s8a_2_a	s8a_2a_a	s8a_2b_a	s8a_2c_a	s8a_2d_a	s8a_2e_a	s8a_2f_a	s8a_2g_a	s8a_2h_a				
	local	s8a_3_a	s8a_3a_a	s8a_3b_a	s8a_3c_a	s8a_3d_a	s8a_3e_a	s8a_3f_a	s8a_3g_a	s8a_3h_a	s8a_3i_a	s8a_3j_a	s8a_3k_a	s8a_3l_a
	local	s8a_4_a	s8a_4a_a	s8a_4b_a										
	local	s8a_5_a	s8a_5a_a	s8a_5b_a	s8a_5c_a											
	
	* B. IPC	
	local	s8b_1_a	s8b_1a_a 	s8b_1b_a			
	local	s8b_2_a	s8b_2a_a	s8b_2b_a		
	local	s8b_3_a	s8b_3a_a	s8b_3b_a	s8b_3c_a	
	local	s8b_4_a	s8b_4a_a	s8b_4b_a		
	local	s8b_5_a	s8b_5a_a	s8b_5b_a	s8b_5c_a	s8b_5d_a					
 
	local s8_a `s8a_1_a' `s8a_2_a' `s8a_3_a' `s8a_4_a' `s8a_5_a' `s8b_1_a' `s8b_2_a' `s8b_3_a' `s8b_4_a' `s8b_5_a'
	
	* S9: Pharmacy 

	* A. General condition of permises	
	local	s9a_1_a	s9a_1a_a	
	local	s9a_2_a	s9a_2a_a	s9a_2b_a

	* B. Storage and display of commodities
	local	s9b_1_a	s9b_1a_a s9b_1b_a s9b_1c_a
	
	
	* C. Record keeping and documentation
	local	s9c_1_a	s9c_1a_a s9c_1b_a s9c_1c_a s9c_1d_a s9c_1e_a s9c_1f_a
	
	* D. Reference and materials and policies
	local	s9d_1_a	s9d_1a_a s9d_1b_a
	
	* E. IPC
	local	s9e_1_a	s9e_1a_a    s9e_1b_a			
	local	s9e_2_a	s9e_2a_a	s9e_2b_a		
	local	s9e_3_a	s9e_3a_a	s9e_3b_a	s9e_3c_a	
	local	s9e_4_a	s9e_4a_a	s9e_4b_a		
	local	s9e_5_a	s9e_5a_a	s9e_5b_a	s9e_5c_a	s9e_5d_a

	local s9_a `s9a_1_a' `s9a_2_a' `s9b_1_a'  `s9c_1_a' `s9d_1_a'  `s9e_1_a' `s9e_2_a' `s9e_3_a' `s9e_4_a' `s9e_5_a'
	
	* S10: Laboratory 

	* A. Policies, guidelines, and SOPs
	** S10a_1 is not included because QPS1/2 didn't ask for licenses. 
	local	s10a_2_a	s10a_2a_a	s10a_2b_a
	local	s10a_3_a	s10a_3a_a	s10a_3b_a
	local	s10a_4_a	s10a_4a_a	s10a_4b_a
	local	s10a_5_a	s10a_5a_a	
		
	* B. Equipment management program
	local	s10b_1_a	s10b_1a_a	s10b_1b_a	
	local	s10b_2_a	s10b_2a_a	s10b_2b_a	
	local	s10b_3_a	s10b_3a_a		
	local	s10b_4_a	s10b_4a_a	s10b_4b_a	
		
	* C. Record keeping and documentation
	local 	s10c_1_a s10c_1a_a
		
	* D. Quality control of tests
	local	s10d_1_a	s10d_1a_a	s10d_1b_a	s10d_1c_a	s10d_1d_a	s10d_1e_a	s10d_1f_a
	local	s10d_2_a	s10d_2a_a	s10d_2b_a				
		
	* E. IPC
	local	s10e_1_a	s10e_1a_a s10e_1b_a			
	local	s10e_2_a	s10e_2a_a	s10e_2b_a		
	local	s10e_3_a	s10e_3a_a	s10e_3b_a	s10e_3c_a	
	local	s10e_4_a	s10e_4a_a	s10e_4b_a		
	local	s10e_5_a	s10e_5a_a	s10e_5b_a	s10e_5c_a	s10e_5d_a	

	local s10_a `s10a_1_a' `s10a_2_a' `s10a_3_a' `s10a_4_a' `s10a_5_a' `s10b_1_a' `s10b_2_a' `s10b_3_a' `s10b_4_a' `s10c_1_a' `s10d_1_a' `s10d_2_a' `s10e_1_a' `s10e_2_a' `s10e_3_a' `s10e_4_a' `s10e_5_a'
	
	* S11: Radiology 

	* A. Radiation protection
	local	s11a_1_a	s11a_1a_a
	local	s11a_2_a	s11a_2a_a
	local	s11a_3_a	s11a_3a_a
	local	s11a_4_a	s11a_4a_a
	local	s11a_5_a	s11a_5a_a
	
	* B. Policies, SOPs, and registers
	local	s11b_1_a	s11b_1a_a	s11b_1b_a	s11b_1c_a	
	local	s11b_2_a	s11b_2a_a			
	local	s11b_3_a	s11b_3a_a			
	local	s11b_4_a	s11b_4a_a	s11b_4b_a	s11b_4c_a	s11b_4d_a
	
	* C. Radioactive waste management
	local	s11c_1_a	s11c_1a_a	s11c_1b_a
	local	s11c_2_a	s11c_2a_a	s11c_2b_a
	local	s11c_3_a	s11c_3a_a			
	
	* D. IPC	
	local	s11d_1_a	s11d_1a_a 	s11d_1b_a			
	local	s11d_2_a	s11d_2a_a	s11d_2b_a		
	local	s11d_3_a	s11d_3a_a	s11d_3b_a		
	local	s11d_4_a	s11d_4a_a	s11d_4b_a	s11d_4c_a	s11d_4d_a
	
	local s11_a `s11a_1_a' `s11a_2_a' `s11a_3_a' `s11a_4_a' `s11a_5_a' `s11b_1_a' `s11b_2_a' `s11b_3_a' `s11b_4_a' `s11c_1_a' `s11c_2_a' `s11c_3_a' `s11d_1_a' `s11d_2_a' `s11d_3_a' `s11d_4_a'
	
	* S12: Nutrition 

	* A. Nutrition equipment, tools and supplies
	local	s12a_1_a	s12a_1a_a	s12a_1b_a	s12a_1c_a	s12a_1d_a	s12a_1e_a	s12a_1f_a	s12a_1g_a			
	local	s12a_2_a	s12a_2a_a	s12a_2b_a	s12a_2c_a	s12a_2d_a	s12a_2e_a	s12a_2f_a	s12a_2g_a	s12a_2h_a	s12a_2i_a	s12a_2j_a
	
	* B. SOPs for nutrition care processes and other services	
	local	s12b_1_a	s12b_1a_a	s12b_1b_a	s12b_1c_a	s12b_1d_a	s12b_1e_a	s12b_1f_a	s12b_1g_a	s12b_1h_a		

	* C. Record keeping and documentation
	local	s12c_1_a	s12c_1a_a	s12c_1b_a	s12c_1c_a	s12c_1d_a					
	
	* D. Patient feeding
	local	s12d_1_a	s12d_1a_a	s12d_1b_a	s12d_1c_a	s12d_1d_a	s12d_1e_a	s12d_1f_a	s12d_1g_a
	local	s12d_2_a	s12d_2a_a	s12d_2b_a										

	* E. Food preparation unit
	local	s12e_1_a	s12e_1a_a	s12e_1b_a	s12e_1c_a	s12e_1d_a	s12e_1e_a	s12e_1f_a
	local	s12e_2_a	s12e_2a_a	s12e_2b_a	s12e_2c_a	s12e_2d_a	s12e_2e_a	
	local	s12e_3_a	s12e_3a_a	s12e_3b_a									
	
	* F. IPC	
	local	s12f_1_a	s12f_1a_a   s12f_1b_a			
	local	s12f_2_a	s12f_2a_a	s12f_2b_a		
	local	s12f_3_a	s12f_3a_a	s12f_3b_a	s12f_3c_a	
	local	s12f_4_a	s12f_4a_a	s12f_4b_a		
	local	s12f_5_a	s12f_5a_a	s12f_5b_a	s12f_5c_a	s12f_5d_a

	local s12_a `s12a_1_a' `s12a_2_a' `s12b_1_a' `s12c_1_a' `s12d_1_a' `s12d_2_a' `s12e_1_a' `s12e_2_a' `s12e_3_a' `s12f_1_a' `s12f_2_a' `s12f_3_a' `s12f_4_a' `s12f_5_a'

	
*^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
	** 2.2. Counting non missing 
*^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^

* To move at some point - these adherence variables need to have zeros in denominator (not missing)
foreach x in s5a_4b_a s5a_4c_a s5a_4d_a s5a_4e_a s5a_4f_a s5a_4g_a s5a_1b_a {
	replace `x'=0 if mi(`x')	
	}	

	* Section 2: count 
	forvalues i = 1(1)3 {
		foreach var in a b c {		
			egen  s2`var'_`i'_a_count = rownonmiss(`s2`var'_`i'_a')		
		}
	}
	
	egen s2c_4_a_count = rownonmiss(`s2c_4_a')
	
	* Section 3: count 
	forvalues i = 1(1)3 {
		foreach var in a b c {		
			egen  s3`var'_`i'_a_count = rownonmiss(`s3`var'_`i'_a')
		}
	}
	
		* Checking
		//br s3a_1a_a s3a_1b_a s3a_1c_a s3a_1d_a s3a_1_a
	
	egen s3c_4_a_count = rownonmiss(`s3c_4_a')
	egen  s3c_5_a_count = rownonmiss(`s3c_5_a')
	egen  s3d_1_a_count = rownonmiss(`s3d_1_a')
	egen  s3d_2_a_count = rownonmiss(`s3d_2_a')

	* Section 4: count 
	forvalues i = 1(1)4 {		
		egen  s4a_`i'_a_count = rownonmiss(`s4a_`i'_a')
	}

	egen  s4b_1_a_count = rownonmiss(`s4b_1_a')
	

	* Section 5: count 
	forvalues i = 1(1)4 {
		foreach var in a b {
			egen  s5`var'_`i'_a_count = rownonmiss(`s5`var'_`i'_a')
		}
	}
	
	egen  s5b_5_a_count = rownonmiss(`s5b_5_a')
	
	* Section 6: count 
	forvalues i = 1(1)5 {
		foreach var in a b {
			egen  s6`var'_`i'_a_count = rownonmiss(`s6`var'_`i'_a')
		}
	}
	egen  s6a_6_a_count = rownonmiss(`s6a_6_a')
	egen  s6a_7_a_count = rownonmiss(`s6a_7_a')
	egen  s6a_8_a_count = rownonmiss(`s6a_8_a')
	
		* Check
		//br s6a_4a_a s6a_4b_a s6a_4_a_count
	
	* Section 7: count 
	forvalues i = 1(1)3 {
		foreach var in a b {
			egen  s7`var'_`i'_a_count = rownonmiss(`s7`var'_`i'_a')
		}
	}
	egen  s7b_4_a_count = rownonmiss(`s7b_4_a')
	egen  s7b_5_a_count = rownonmiss(`s7b_5_a')
	
		* Checking
		//br s7b_5a_a s7b_5b_a  s7b_5c_a s7b_5d_a s7b_5_a_count	
	
	* Section 8: count 
	forvalues i = 1(1)5 {
		foreach var in a b {
			egen  s8`var'_`i'_a_count = rownonmiss(`s8`var'_`i'_a')
		}
	}
		
	* Section 9: count
	
	forvalues i = 1(1)6 {
		foreach var in a b c d e {
			capture egen  s9`var'_`i'_a_count = rownonmiss(`s9`var'_`i'_a')
			if _rc!=0 {
				display "`var'_`i'_a_count not found"			  
			} 
			
		}
	}
		* Checking
		//br s9c_1e_a s9c_1_a_count 
		
	* Section 10: count 
	forvalues i = 2(1)5 {
		foreach var in a e {
			egen  s10`var'_`i'_a_count = rownonmiss(`s10`var'_`i'_a')
		}
	}

	forvalues i = 1(1)2 {
		foreach var in b d {
			egen  s10`var'_`i'_a_count = rownonmiss(`s10`var'_`i'_a')
		}
	}

	egen  s10c_1_a_count = rownonmiss(`s10c_1_a')
	egen  s10b_3_a_count = rownonmiss(`s10b_3_a')
	egen  s10b_4_a_count = rownonmiss(`s10b_4_a')
	egen  s10e_1_a_count = rownonmiss(`s10e_1_a')

	
	* Section 11: count 
	forvalues i = 1(1)3 {
		foreach var in a b c d {
			egen  s11`var'_`i'_a_count = rownonmiss(`s11`var'_`i'_a')
		}
	}

	egen  s11a_4_a_count = rownonmiss(`s11a_4_a')
	egen  s11a_5_a_count = rownonmiss(`s11a_5_a')
	egen  s11b_4_a_count = rownonmiss(`s11b_4_a')
	egen  s11d_4_a_count = rownonmiss(`s11d_4_a')
	
		* Checking
		//br s11d_4a_a s11d_4b_a s11d_4c_a s11d_4d_a s11d_4_a_count 
	
	* Section 12: count 
	forvalues i = 1(1)2 {
		foreach var in a d e f {
			egen  s12`var'_`i'_a_count = rownonmiss(`s12`var'_`i'_a')
		}
	}

	egen  s12b_1_a_count = rownonmiss(`s12b_1_a')
	egen  s12c_1_a_count = rownonmiss(`s12c_1_a')
	egen  s12e_3_a_count = rownonmiss(`s12e_3_a')
	egen  s12f_3_a_count = rownonmiss(`s12f_3_a')
	egen  s12f_4_a_count = rownonmiss(`s12f_4_a')
	egen  s12f_5_a_count = rownonmiss(`s12f_5_a')

	* Checking
	//br s12f_5a_a s12f_5b_a s12f_5c_a s12f_5d_a s12f_5_a_count 
	

*^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
	** Maxscores 
*^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^

	** gen maxscores (level 3)
	
	gen s2a_1_a_ms = 15
	gen s2a_2_a_ms = 10
	gen s2a_3_a_ms = 10	
	local s2a_a_ms s2a_1_a_ms s2a_2_a_ms s2a_3_a_ms
	
	gen s2b_1_a_ms = 15
	gen s2b_2_a_ms = 10
	gen s2b_3_a_ms = 10
	local s2b_a_ms s2b_1_a_ms s2b_2_a_ms s2b_3_a_ms

	gen s2c_1_a_ms = 10
	gen s2c_2_a_ms = 10
	gen s2c_3_a_ms = 5
	gen s2c_4_a_ms = 5
	local s2c_a_ms s2c_1_a_ms s2c_2_a_ms s2c_3_a_ms s2c_4_a_ms
	
	gen s3a_1_a_ms = 10
	gen s3a_2_a_ms = 15
	gen s3a_3_a_ms = 15
	local s3a_a_ms s3a_1_a_ms s3a_2_a_ms s3a_3_a_ms

	gen s3b_2_a_ms = 10
	gen s3b_3_a_ms = 10
	local s3b_a_ms s3b_2_a_ms s3b_3_a_ms 

	gen s3c_1_a_ms = 10
	gen s3c_2_a_ms = 5
	gen s3c_3_a_ms = 10
	gen s3c_5_a_ms = 5
	local s3c_a_ms s3c_1_a_ms s3c_2_a_ms s3c_3_a_ms s3c_5_a_ms

	gen s3d_1_a_ms = 5
	gen s3d_2_a_ms = 5
	local s3d_a_ms s3d_1_a_ms s3d_2_a_ms 

	gen s4a_1_a_ms = 20
	gen s4a_2_a_ms = 30
	gen s4a_3_a_ms = 20
	gen s4a_4_a_ms = 10
	local s4a_a_ms s4a_1_a_ms s4a_2_a_ms s4a_3_a_ms s4a_4_a_ms

	gen s4b_1_a_ms = 20
	local s4b_a_ms  s4b_1_a_ms
	
	gen s5a_1_a_ms = 20
	gen s5a_2_a_ms = 20
	gen s5a_3_a_ms = 20
	gen s5a_4_a_ms = 20
	local s5a_a_ms s5a_1_a_ms s5a_2_a_ms s5a_3_a_ms s5a_4_a_ms

	gen s5b_1_a_ms = 4
	gen s5b_2_a_ms = 4
	gen s5b_3_a_ms = 4
	gen s5b_4_a_ms = 4
	gen s5b_5_a_ms = 4
	local s5b_a_ms s5b_1_a_ms s5b_2_a_ms  s5b_3_a_ms s5b_4_a_ms s5b_5_a_ms

	gen s6a_1_a_ms = 10
	gen s6a_2_a_ms = 10
	gen s6a_3_a_ms = 10
	gen s6a_4_a_ms = 10
	gen s6a_5_a_ms = 10
	gen s6a_6_a_ms = 10
	gen s6a_7_a_ms = 10
	gen s6a_8_a_ms = 10
	local s6a_a_ms s6a_1_a_ms s6a_2_a_ms  s6a_3_a_ms s6a_4_a_ms s6a_5_a_ms s6a_6_a_ms s6a_7_a_ms s6a_8_a_ms

	gen s6b_1_a_ms = 4
	gen s6b_2_a_ms = 4
	gen s6b_3_a_ms = 4
	gen s6b_4_a_ms = 4
	gen s6b_5_a_ms = 4
	local s6b_a_ms s6b_1_a_ms s6b_2_a_ms  s6b_3_a_ms s6b_4_a_ms s6b_5_a_ms 

	gen s7a_1_a_ms = 30
	gen s7a_2_a_ms = 20
	gen s7a_3_a_ms = 30
	local s7a_a_ms s7a_1_a_ms s7a_2_a_ms  s7a_3_a_ms 

	gen s7b_1_a_ms = 4
	gen s7b_2_a_ms = 4
	gen s7b_3_a_ms = 4
	gen s7b_4_a_ms = 4
	gen s7b_5_a_ms = 4
	local s7b_a_ms s7b_1_a_ms s7b_2_a_ms  s7b_3_a_ms s7b_4_a_ms s7b_5_a_ms 

	gen s8a_1_a_ms = 10
	gen s8a_2_a_ms = 20
	gen s8a_3_a_ms = 30
	gen s8a_4_a_ms = 10
	gen s8a_5_a_ms = 10
	local s8a_a_ms s8a_1_a_ms s8a_2_a_ms  s8a_3_a_ms s8a_4_a_ms s8a_5_a_ms 

	gen s8b_1_a_ms = 4
	gen s8b_2_a_ms = 4
	gen s8b_3_a_ms = 4
	gen s8b_4_a_ms = 4
	gen s8b_5_a_ms = 4
	local s8b_a_ms s8b_1_a_ms s8b_2_a_ms  s8b_3_a_ms s8b_4_a_ms s8b_5_a_ms 

	gen s9a_1_a_ms = 10
	gen s9a_2_a_ms = 10
	local s9a_a_ms s9a_1_a_ms s9a_2_a_ms

	gen s9b_1_a_ms = 20
	local s9b_a_ms s9b_1_a_ms 

	gen s9c_1_a_ms = 30
	local s9c_a_ms s9c_1_a_ms 

	gen s9d_1_a_ms = 10
	local s9d_a_ms s9d_1_a_ms 

	gen s9e_1_a_ms = 4
	gen s9e_2_a_ms = 4
	gen s9e_3_a_ms = 4
	gen s9e_4_a_ms = 4
	gen s9e_5_a_ms = 4
	local s9e_a_ms s9e_1_a_ms s9e_2_a_ms s9e_3_a_ms s9e_4_a_ms s9e_5_a_ms

	gen s10a_2_a_ms = 5
	gen s10a_3_a_ms = 5
	gen s10a_4_a_ms = 5
	gen s10a_5_a_ms = 5
	local s10a_a_ms s10a_2_a_ms s10a_3_a_ms s10a_4_a_ms s10a_5_a_ms 

	gen s10b_1_a_ms = 10
	gen s10b_2_a_ms = 10
	gen s10b_3_a_ms = 5
	gen s10b_4_a_ms = 5
	local s10b_a_ms s10b_1_a_ms s10b_2_a_ms  s10b_3_a_ms s10b_4_a_ms 
	gen s10c_1_a_ms = 10
	local s10c_a_ms s10c_1_a_ms 
	
	gen s10d_1_a_ms = 10
	gen s10d_2_a_ms = 10
	local s10d_a_ms s10d_1_a_ms s10d_2_a_ms   

	gen s10e_1_a_ms = 4
	gen s10e_2_a_ms = 4
	gen s10e_3_a_ms = 4
	gen s10e_4_a_ms = 4
	gen s10e_5_a_ms = 4
	local s10e_a_ms s10e_1_a_ms s10e_2_a_ms s10e_3_a_ms s10e_4_a_ms s10e_5_a_ms

	gen s11a_1_a_ms = 10
	gen s11a_2_a_ms = 5
	gen s11a_3_a_ms = 5
	gen s11a_4_a_ms = 5
	gen s11a_5_a_ms = 10
	local s11a_a_ms s11a_1_a_ms s11a_2_a_ms s11a_3_a_ms s11a_4_a_ms s11a_5_a_ms 

	gen s11b_1_a_ms = 5
	gen s11b_2_a_ms = 5
	gen s11b_3_a_ms = 5
	gen s11b_4_a_ms = 10
	local s11b_a_ms s11b_1_a_ms s11b_2_a_ms  s11b_3_a_ms s11b_4_a_ms 
	
	gen s11c_1_a_ms = 10
	gen s11c_2_a_ms = 5
	gen s11c_3_a_ms = 5
	local s11c_a_ms s11c_1_a_ms s11c_2_a_ms s11c_3_a_ms

	gen s11d_1_a_ms = 5
	gen s11d_2_a_ms = 5
	gen s11d_3_a_ms = 5
	gen s11d_4_a_ms = 5
	local s11d_a_ms s11d_1_a_ms s11d_2_a_ms s11d_3_a_ms s11d_4_a_ms

	gen s12a_1_a_ms = 7
	gen s12a_2_a_ms = 10
	local s12a_a_ms s12a_1_a_ms s12a_2_a_ms 

	gen s12b_1_a_ms = 16
	local s12b_a_ms s12b_1_a_ms
	
	gen s12c_1_a_ms = 10
	local s12c_a_ms s12c_1_a_ms

	gen s12d_1_a_ms = 16
	gen s12d_2_a_ms = 4
	local s12d_a_ms s12d_1_a_ms s12d_2_a_ms 
	
	gen s12e_1_a_ms = 6
	gen s12e_2_a_ms = 5
	gen s12e_3_a_ms = 6
	local s12e_a_ms s12e_1_a_ms s12e_2_a_ms s12e_3_a_ms 
	
	gen s12f_1_a_ms = 4
	gen s12f_2_a_ms = 4
	gen s12f_3_a_ms = 4
	gen s12f_4_a_ms = 4
	gen s12f_5_a_ms = 4  
	local s12f_a_ms s12f_1_a_ms s12f_2_a_ms s12f_3_a_ms  s12f_4_a_ms s12f_5_a_ms

	local L3_ms `s2a_a_ms'	`s2b_a_ms'	`s2c_a_ms'	`s3a_a_ms'	`s3b_a_ms'	`s3c_a_ms'	`s3d_a_ms'	`s4a_a_ms'	`s4b_a_ms'	`s5a_a_ms'	`s5b_a_ms'	`s6a_a_ms'	`s6b_a_ms'	`s7a_a_ms'	`s7b_a_ms'	`s8a_a_ms'	`s8b_a_ms'	`s9a_a_ms'	`s9b_a_ms'	`s9c_a_ms'	`s9d_a_ms'	`s9e_a_ms'	`s10a_a_ms'	`s10b_a_ms'	`s10c_a_ms'	`s10d_a_ms'	`s10e_a_ms'	`s11a_a_ms'	`s11b_a_ms'	`s11c_a_ms'	`s11d_a_ms'	`s12a_a_ms'	`s12b_a_ms'	`s12c_a_ms'	`s12d_a_ms'	`s12e_a_ms'	`s12f_a_ms'

	** If one section is not applicable the max score should be missing **
	
		** Section 6: Labour
		forvalues i=1(1)8 {	
			foreach x in a b {
				capture replace s6`x'_`i'_a_ms =. if labour == .			
				if _rc!=0 {
					display "s6`x'_`i'_a_ms not found"			  
				} 		
			}	
		}
		
		** Section 7: Ward
		forvalues i=1(1)5 {	
			foreach x in a b {
				capture replace s7`x'_`i'_a_ms =. if wards == .			
				if _rc!=0 {
					display "s7`x'_`i'_a_ms not found"			  
				} 		
			}	
		}	
		
		** Section 8: Theatre 
		forvalues i=1(1)5 {	
			foreach x in a b {
				capture replace s8`x'_`i'_a_ms =. if theatre == .			
				if _rc!=0 {
					display "s8`x'_`i'_a_ms not found"			  
				} 		
			}	
		}	
		
		** Section 9: Pharmacy
		forvalues i=1(1)6 {	
			foreach x in a b c d e {
				capture replace s9`x'_`i'_a_ms =. if pharmacy == .			
				if _rc!=0 {
					display "s9`x'_`i'_a_ms not found"			  
				} 		
			}	
		}
		
		** Section 10: Lab
		forvalues i=1(1)6 {	
			foreach x in a b c d e {
				capture replace s10`x'_`i'_a_ms =. if lab == .			
				if _rc!=0 {
					display "s10`x'_`i'_a_ms not found"			  
				} 		
			}	
		}
		
		** Section 11: radiology
		forvalues i=1(1)5 {	
			foreach x in a b c d {
				capture replace s11`x'_`i'_a_ms =. if radiology == .			
				if _rc!=0 {
					display "s11`x'_`i'_a_ms not found"			  
				} 		
			}	
		}
		
		** Section 12: nutrition
		forvalues i=1(1)5 {	
			foreach x in a b c d e f{
				capture replace s12`x'_`i'_a_ms =. if nutrition == .			
				if _rc!=0 {
					display "s12`x'_`i'_a_ms not found"			  
				} 		
			}	
		}
		
		** Radiology section: No points if the HF does not produce radioactive waste
		replace s11c_1_a_ms = . if s11c_1a_a == 0
		replace s11c_2_a_ms = . if s11c_1a_a == 0
		replace s11c_3_a_ms = . if s11c_1a_a == 0
		
		* Checking L3 max score
		//sum a5 s2a_1_a_ms s2a_2_a_ms s2a_3_a_ms s2b_1_a_ms s2b_2_a_ms s2b_3_a_ms s2c_1_a_ms s2c_2_a_ms s2c_3_a_ms s2c_4_a_ms s3a_1_a_ms s3a_2_a_ms s3a_3_a_ms s3b_2_a_ms s3b_3_a_ms s3c_1_a_ms s3c_2_a_ms s3c_3_a_ms s3c_5_a_ms s3d_1_a_ms s3d_2_a_ms s4a_1_a_ms s4a_2_a_ms s4a_3_a_ms s4a_4_a_ms	s4b_1_a_ms	s5a_1_a_ms	s5a_2_a_ms	s5a_3_a_ms	s5a_4_a_ms	s5b_1_a_ms	s5b_2_a_ms	s5b_3_a_ms	s5b_4_a_ms	s5b_5_a_ms	s6a_1_a_ms	s6a_2_a_ms	s6a_3_a_ms	s6a_4_a_ms	s6a_5_a_ms	s6a_6_a_ms	s6a_7_a_ms	s6a_8_a_ms	s6b_1_a_ms	s6b_2_a_ms	s6b_3_a_ms	s6b_4_a_ms	s6b_5_a_ms	s7a_1_a_ms	s7a_2_a_ms	s7a_3_a_ms	s7b_1_a_ms	s7b_2_a_ms	s7b_3_a_ms	s7b_4_a_ms	s7b_5_a_ms	s8a_1_a_ms	s8a_2_a_ms	s8a_3_a_ms	s8a_4_a_ms	s8a_5_a_ms	s8b_1_a_ms	s8b_2_a_ms	s8b_3_a_ms	s8b_4_a_ms	s8b_5_a_ms	s9a_1_a_ms	s9a_2_a_ms	s9b_1_a_ms s9c_1_a_ms s9d_1_a_ms s9e_1_a_ms	s9e_2_a_ms	s9e_3_a_ms	s9e_4_a_ms	s9e_5_a_ms	s10a_2_a_ms	s10a_3_a_ms	s10a_4_a_ms	s10a_5_a_ms	s10b_1_a_ms	s10b_2_a_ms	s10b_3_a_ms	s10b_4_a_ms	s10c_1_a_ms s10d_1_a_ms	s10d_2_a_ms	s10e_1_a_ms	s10e_2_a_ms	s10e_3_a_ms	s10e_4_a_ms	s10e_5_a_ms	s11a_1_a_ms	s11a_2_a_ms	s11a_3_a_ms	s11a_4_a_ms	s11a_5_a_ms	s11b_1_a_ms	s11b_2_a_ms	s11b_3_a_ms	s11b_4_a_ms	s11c_1_a_ms	s11c_2_a_ms	s11c_3_a_ms	s11d_1_a_ms	s11d_2_a_ms	s11d_3_a_ms	s11d_4_a_ms	s12a_1_a_ms	s12a_2_a_ms s12b_1_a_ms s12c_1_a_ms	s12d_1_a_ms	s12d_2_a_ms	s12e_1_a_ms	s12e_2_a_ms	s12e_3_a_ms	s12f_1_a_ms	s12f_2_a_ms	s12f_3_a_ms	s12f_4_a_ms	s12f_5_a_ms
	
	* Gen maxscores (level 4)
	
	local nocombinations s2a_1f_a_ms s2a_1g_a_ms s2a_1h_a_ms s2a_1i_a_ms s2a_1j_a_ms s2a_1k_a_ms s2a_1l_a_ms s2a_2b_a_ms s2a_2c_a_ms s2a_2d_a_ms s2a_2e_a_ms s2a_2f_a_ms s2a_2g_a_ms s2a_2h_a_ms s2a_2i_a_ms s2a_2j_a_ms s2a_2k_a_ms s2a_2l_a_ms s2a_3b_a_ms s2a_3c_a_ms s2a_3d_a_ms s2a_3e_a_ms s2a_3f_a_ms	s2a_3g_a_ms	s2a_3h_a_ms	s2a_3i_a_ms	s2a_3j_a_ms	s2a_3k_a_ms	s2a_3l_a_ms s2b_1c_a_ms	s2b_1d_a_ms	s2b_1e_a_ms	s2b_1f_a_ms	s2b_1g_a_ms	s2b_1h_a_ms	s2b_1i_a_ms	s2b_1j_a_ms	s2b_1k_a_ms	s2b_1l_a_ms s2b_2b_a_ms	s2b_2c_a_ms	s2b_2d_a_ms	s2b_2e_a_ms	s2b_2f_a_ms	s2b_2g_a_ms	s2b_2h_a_ms	s2b_2i_a_ms	s2b_2j_a_ms	s2b_2k_a_ms	s2b_2l_a_ms s2b_3c_a_ms	s2b_3d_a_ms	s2b_3e_a_ms	s2b_3f_a_ms	s2b_3g_a_ms	s2b_3h_a_ms	s2b_3i_a_ms	s2b_3j_a_ms	s2b_3k_a_ms	s2b_3l_a_ms s2c_1c_a_ms	s2c_1d_a_ms	s2c_1e_a_ms	s2c_1f_a_ms	s2c_1g_a_ms	s2c_1h_a_ms	s2c_1i_a_ms	s2c_1j_a_ms	s2c_1k_a_ms	s2c_1l_a_ms s2c_2c_a_ms	s2c_2d_a_ms	s2c_2e_a_ms	s2c_2f_a_ms	s2c_2g_a_ms	s2c_2h_a_ms	s2c_2i_a_ms	s2c_2j_a_ms	s2c_2k_a_ms	s2c_2l_a_ms s2c_3e_a_ms	s2c_3f_a_ms	s2c_3g_a_ms	s2c_3h_a_ms	s2c_3i_a_ms	s2c_3j_a_ms	s2c_3k_a_ms	s2c_3l_a_ms s2c_4b_a_ms	s2c_4c_a_ms	s2c_4d_a_ms	s2c_4e_a_ms	s2c_4f_a_ms	s2c_4g_a_ms	s2c_4h_a_ms	s2c_4i_a_ms	s2c_4j_a_ms	s2c_4k_a_ms	s2c_4l_a_ms s3a_1e_a_ms	s3a_1f_a_ms	s3a_1g_a_ms	s3a_1h_a_ms	s3a_1i_a_ms	s3a_1j_a_ms	s3a_1k_a_ms	s3a_1l_a_ms s3a_2i_a_ms	s3a_2j_a_ms	s3a_2k_a_ms	s3a_2l_a_ms  s3a_3c_a_ms	s3a_3d_a_ms	s3a_3e_a_ms	s3a_3f_a_ms	s3a_3g_a_ms	s3a_3h_a_ms	s3a_3i_a_ms	s3a_3j_a_ms	s3a_3k_a_ms	s3a_3l_a_ms s3b_2f_a_ms	s3b_2g_a_ms	s3b_2h_a_ms	s3b_2i_a_ms	s3b_2j_a_ms	s3b_2k_a_ms	s3b_2l_a_ms s3b_3d_a_ms	s3b_3e_a_ms	s3b_3f_a_ms	s3b_3g_a_ms	s3b_3h_a_ms	s3b_3i_a_ms	s3b_3j_a_ms	s3b_3k_a_ms	s3b_3l_a_ms s3c_1d_a_ms	s3c_1e_a_ms	s3c_1f_a_ms	s3c_1g_a_ms	s3c_1h_a_ms	s3c_1i_a_ms	s3c_1j_a_ms	s3c_1k_a_ms	s3c_1l_a_ms s3c_2e_a_ms	s3c_2f_a_ms	s3c_2g_a_ms	s3c_2h_a_ms	s3c_2i_a_ms	s3c_2j_a_ms	s3c_2k_a_ms	s3c_2l_a_ms s3c_3d_a_ms	s3c_3e_a_ms	s3c_3f_a_ms	s3c_3g_a_ms	s3c_3h_a_ms	s3c_3i_a_ms	s3c_3j_a_ms	s3c_3k_a_ms	s3c_3l_a_ms s3c_5b_a_ms	s3c_5c_a_ms	s3c_5d_a_ms	s3c_5e_a_ms	s3c_5f_a_ms	s3c_5g_a_ms	s3c_5h_a_ms	s3c_5i_a_ms	s3c_5j_a_ms	s3c_5k_a_ms	s3c_5l_a_ms s3d_1c_a_ms	s3d_1d_a_ms	s3d_1e_a_ms	s3d_1f_a_ms	s3d_1g_a_ms	s3d_1h_a_ms	s3d_1i_a_ms	s3d_1j_a_ms s3d_1k_a_ms	s3d_1l_a_ms s3d_2d_a_ms	s3d_2e_a_ms	s3d_2f_a_ms	s3d_2g_a_ms	s3d_2h_a_ms	s3d_2i_a_ms	s3d_2j_a_ms	s3d_2k_a_ms	s3d_2l_a_ms s4a_1c_a_ms	s4a_1d_a_ms	s4a_1e_a_ms	s4a_1f_a_ms	s4a_1g_a_ms	s4a_1h_a_ms	s4a_1i_a_ms	s4a_1j_a_ms	s4a_1k_a_ms	s4a_1l_a_ms s4a_2d_a_ms	s4a_2e_a_ms	s4a_2f_a_ms	s4a_2g_a_ms	s4a_2h_a_ms	s4a_2i_a_ms	s4a_2j_a_ms	s4a_2k_a_ms	s4a_2l_a_ms s4a_3e_a_ms	s4a_3f_a_ms	s4a_3g_a_ms	s4a_3h_a_ms	s4a_3i_a_ms	s4a_3j_a_ms	s4a_3k_a_ms	s4a_3l_a_ms s4a_4d_a_ms	s4a_4e_a_ms	s4a_4f_a_ms	s4a_4g_a_ms	s4a_4h_a_ms	s4a_4i_a_ms	s4a_4j_a_ms	s4a_4k_a_ms	s4a_4l_a_ms s4b_1e_a_ms	s4b_1f_a_ms	s4b_1g_a_ms	s4b_1h_a_ms	s4b_1i_a_ms	s4b_1j_a_ms	s4b_1k_a_ms	s4b_1l_a_ms s5a_1e_a_ms	s5a_1f_a_ms	s5a_1g_a_ms	s5a_1h_a_ms	s5a_1i_a_ms	s5a_1j_a_ms	s5a_1k_a_ms	s5a_1l_a_ms s5a_2d_a_ms	s5a_2e_a_ms	s5a_2f_a_ms	s5a_2g_a_ms	s5a_2h_a_ms	s5a_2i_a_ms	s5a_2j_a_ms	s5a_2k_a_ms	s5a_2l_a_ms s5a_3j_a_ms	s5a_3k_a_ms	s5a_3l_a_ms s5b_1c_a_ms	s5b_1d_a_ms	s5b_1e_a_ms	s5b_1f_a_ms	s5b_1g_a_ms	s5b_1h_a_ms	s5b_1i_a_ms	s5b_1j_a_ms	s5b_1k_a_ms	s5b_1l_a_ms s5b_2c_a_ms	s5b_2d_a_ms	s5b_2e_a_ms	s5b_2f_a_ms	s5b_2g_a_ms	s5b_2h_a_ms	s5b_2i_a_ms	s5b_2j_a_ms	s5b_2k_a_ms	s5b_2l_a_ms s5b_3d_a_ms	s5b_3e_a_ms	s5b_3f_a_ms	s5b_3g_a_ms	s5b_3h_a_ms	s5b_3i_a_ms	s5b_3j_a_ms	s5b_3k_a_ms	s5b_3l_a_ms s5b_4c_a_ms	s5b_4d_a_ms	s5b_4e_a_ms	s5b_4f_a_ms	s5b_4g_a_ms	s5b_4h_a_ms	s5b_4i_a_ms	s5b_4j_a_ms	s5b_4k_a_ms	s5b_4l_a_ms s5b_5e_a_ms	s5b_5f_a_ms	s5b_5g_a_ms	s5b_5h_a_ms	s5b_5i_a_ms	s5b_5j_a_ms	s5b_5k_a_ms	s5b_5l_a_ms s6a_1j_a_ms	s6a_1k_a_ms	s6a_1l_a_ms s6a_2d_a_ms	s6a_2e_a_ms	s6a_2f_a_ms	s6a_2g_a_ms	s6a_2h_a_ms	s6a_2i_a_ms	s6a_2j_a_ms	s6a_2k_a_ms	s6a_2l_a_ms s6a_3d_a_ms	s6a_3e_a_ms	s6a_3f_a_ms	s6a_3g_a_ms	s6a_3h_a_ms	s6a_3i_a_ms	s6a_3j_a_ms	s6a_3k_a_ms	s6a_3l_a_ms s6a_4c_a_ms	s6a_4d_a_ms	s6a_4e_a_ms	s6a_4f_a_ms	s6a_4g_a_ms	s6a_4h_a_ms	s6a_4i_a_ms	s6a_4j_a_ms	s6a_4k_a_ms	s6a_4l_a_ms s6a_5c_a_ms	s6a_5d_a_ms	s6a_5e_a_ms	s6a_5f_a_ms	s6a_5g_a_ms	s6a_5h_a_ms	s6a_5i_a_ms	s6a_5j_a_ms	s6a_5k_a_ms	s6a_5l_a_ms s6a_6h_a_ms	s6a_6i_a_ms	s6a_6j_a_ms	s6a_6k_a_ms	s6a_6l_a_ms s6a_7h_a_ms	s6a_7i_a_ms	s6a_7j_a_ms	s6a_7k_a_ms	s6a_7l_a_ms s6a_8e_a_ms	s6a_8f_a_ms	s6a_8g_a_ms	s6a_8h_a_ms	s6a_8i_a_ms	s6a_8j_a_ms	s6a_8k_a_ms	s6a_8l_a_ms s6b_1c_a_ms	s6b_1d_a_ms	s6b_1e_a_ms	s6b_1f_a_ms	s6b_1g_a_ms	s6b_1h_a_ms	s6b_1i_a_ms	s6b_1j_a_ms	s6b_1k_a_ms	s6b_1l_a_ms s6b_2c_a_ms	s6b_2d_a_ms	s6b_2e_a_ms	s6b_2f_a_ms	s6b_2g_a_ms	s6b_2h_a_ms	s6b_2i_a_ms	s6b_2j_a_ms	s6b_2k_a_ms	s6b_2l_a_ms s6b_3d_a_ms	s6b_3e_a_ms	s6b_3f_a_ms	s6b_3g_a_ms	s6b_3h_a_ms	s6b_3i_a_ms	s6b_3j_a_ms	s6b_3k_a_ms	s6b_3l_a_ms s6b_4c_a_ms	s6b_4d_a_ms	s6b_4e_a_ms	s6b_4f_a_ms	s6b_4g_a_ms	s6b_4h_a_ms	s6b_4i_a_ms	s6b_4j_a_ms	s6b_4k_a_ms	s6b_4l_a_ms s6b_5e_a_ms	s6b_5f_a_ms	s6b_5g_a_ms	s6b_5h_a_ms	s6b_5i_a_ms	s6b_5j_a_ms	s6b_5k_a_ms	s6b_5l_a_ms s7a_1e_a_ms	s7a_1f_a_ms	s7a_1g_a_ms	s7a_1h_a_ms	s7a_1i_a_ms	s7a_1j_a_ms	s7a_1k_a_ms	s7a_1l_a_ms s7a_2c_a_ms	s7a_2d_a_ms	s7a_2e_a_ms	s7a_2f_a_ms	s7a_2g_a_ms	s7a_2h_a_ms	s7a_2i_a_ms	s7a_2j_a_ms	s7a_2k_a_ms	s7a_2l_a_ms s7a_3f_a_ms	s7a_3g_a_ms	s7a_3h_a_ms	s7a_3i_a_ms	s7a_3j_a_ms	s7a_3k_a_ms	s7a_3l_a_ms s7b_1c_a_ms	s7b_1d_a_ms	s7b_1e_a_ms	s7b_1f_a_ms	s7b_1g_a_ms	s7b_1h_a_ms	s7b_1i_a_ms	s7b_1j_a_ms	s7b_1k_a_ms	s7b_1l_a_ms	s7b_2c_a_ms	s7b_2d_a_ms	s7b_2e_a_ms	s7b_2f_a_ms	s7b_2g_a_ms	s7b_2h_a_ms	s7b_2i_a_ms	s7b_2j_a_ms	s7b_2k_a_ms	s7b_2l_a_ms s7b_3d_a_ms	s7b_3e_a_ms	s7b_3f_a_ms	s7b_3g_a_ms	s7b_3h_a_ms	s7b_3i_a_ms	s7b_3j_a_ms	s7b_3k_a_ms	s7b_3l_a_ms s7b_4c_a_ms	s7b_4d_a_ms	s7b_4e_a_ms	s7b_4f_a_ms	s7b_4g_a_ms	s7b_4h_a_ms	s7b_4i_a_ms	s7b_4j_a_ms	s7b_4k_a_ms	s7b_4l_a_ms s7b_5e_a_ms	s7b_5f_a_ms	s7b_5g_a_ms	s7b_5h_a_ms	s7b_5i_a_ms	s7b_5j_a_ms	s7b_5k_a_ms	s7b_5l_a_ms s8a_1e_a_ms	s8a_1f_a_ms	s8a_1g_a_ms	s8a_1h_a_ms	s8a_1i_a_ms	s8a_1j_a_ms	s8a_1k_a_ms	s8a_1l_a_ms s8a_2i_a_ms	s8a_2j_a_ms	s8a_2k_a_ms	s8a_2l_a_ms s8a_4c_a_ms	s8a_4d_a_ms	s8a_4e_a_ms	s8a_4f_a_ms	s8a_4g_a_ms	s8a_4h_a_ms	s8a_4i_a_ms	s8a_4j_a_ms	s8a_4k_a_ms	s8a_4l_a_ms s8a_5d_a_ms	s8a_5e_a_ms	s8a_5f_a_ms	s8a_5g_a_ms	s8a_5h_a_ms	s8a_5i_a_ms	s8a_5j_a_ms	s8a_5k_a_ms	s8a_5l_a_ms s8b_1c_a_ms	s8b_1d_a_ms	s8b_1e_a_ms	s8b_1f_a_ms	s8b_1g_a_ms	s8b_1h_a_ms	s8b_1i_a_ms	s8b_1j_a_ms	s8b_1k_a_ms	s8b_1l_a_ms s8b_2c_a_ms	s8b_2d_a_ms	s8b_2e_a_ms	s8b_2f_a_ms	s8b_2g_a_ms	s8b_2h_a_ms	s8b_2i_a_ms	s8b_2j_a_ms	s8b_2k_a_ms	s8b_2l_a_ms s8b_3d_a_ms	s8b_3e_a_ms	s8b_3f_a_ms	s8b_3g_a_ms	s8b_3h_a_ms	s8b_3i_a_ms	s8b_3j_a_ms	s8b_3k_a_ms	s8b_3l_a_ms s8b_4c_a_ms	s8b_4d_a_ms	s8b_4e_a_ms	s8b_4f_a_ms	s8b_4g_a_ms	s8b_4h_a_ms	s8b_4i_a_ms	s8b_4j_a_ms	s8b_4k_a_ms	s8b_4l_a_ms s8b_5e_a_ms	s8b_5f_a_ms	s8b_5g_a_ms	s8b_5h_a_ms	s8b_5i_a_ms	s8b_5j_a_ms	s8b_5k_a_ms	s8b_5l_a_ms s9a_1b_a_ms	s9a_1c_a_ms	s9a_1d_a_ms	s9a_1e_a_ms	s9a_1f_a_ms	s9a_1g_a_ms	s9a_1h_a_ms	s9a_1i_a_ms	s9a_1j_a_ms	s9a_1k_a_ms	s9a_1l_a_ms s9a_2c_a_ms	s9a_2d_a_ms	s9a_2e_a_ms	s9a_2f_a_ms	s9a_2g_a_ms	s9a_2h_a_ms	s9a_2i_a_ms	s9a_2j_a_ms	s9a_2k_a_ms	s9a_2l_a_ms s9b_1d_a_ms	s9b_1e_a_ms	s9b_1f_a_ms	s9b_1g_a_ms	s9b_1h_a_ms	s9b_1i_a_ms	s9b_1j_a_ms	s9b_1k_a_ms	s9b_1l_a_ms s9c_1g_a_ms	s9c_1h_a_ms	s9c_1i_a_ms	s9c_1j_a_ms	s9c_1k_a_ms	s9c_1l_a_ms s9d_1c_a_ms	s9d_1d_a_ms	s9d_1e_a_ms	s9d_1f_a_ms	s9d_1g_a_ms	s9d_1h_a_ms	s9d_1i_a_ms	s9d_1j_a_ms	s9d_1k_a_ms	s9d_1l_a_ms s9e_1c_a_ms	s9e_1d_a_ms	s9e_1e_a_ms	s9e_1f_a_ms	s9e_1g_a_ms	s9e_1h_a_ms	s9e_1i_a_ms	s9e_1j_a_ms	s9e_1k_a_ms	s9e_1l_a_ms s9e_2c_a_ms	s9e_2d_a_ms	s9e_2e_a_ms	s9e_2f_a_ms	s9e_2g_a_ms	s9e_2h_a_ms	s9e_2i_a_ms	s9e_2j_a_ms	s9e_2k_a_ms	s9e_2l_a_ms s9e_3d_a_ms	s9e_3e_a_ms	s9e_3f_a_ms	s9e_3g_a_ms	s9e_3h_a_ms	s9e_3i_a_ms	s9e_3j_a_ms	s9e_3k_a_ms	s9e_3l_a_ms s9e_4c_a_ms	s9e_4d_a_ms	s9e_4e_a_ms	s9e_4f_a_ms	s9e_4g_a_ms	s9e_4h_a_ms	s9e_4i_a_ms	s9e_4j_a_ms	s9e_4k_a_ms	s9e_4l_a_ms s9e_5e_a_ms	s9e_5f_a_ms	s9e_5g_a_ms	s9e_5h_a_ms	s9e_5i_a_ms	s9e_5j_a_ms	s9e_5k_a_ms	s9e_5l_a_ms s10a_2c_a_ms	s10a_2d_a_ms	s10a_2e_a_ms	s10a_2f_a_ms	s10a_2g_a_ms	s10a_2h_a_ms	s10a_2i_a_ms	s10a_2j_a_ms	s10a_2k_a_ms	s10a_2l_a_ms s10a_3c_a_ms	s10a_3d_a_ms	s10a_3e_a_ms	s10a_3f_a_ms	s10a_3g_a_ms	s10a_3h_a_ms	s10a_3i_a_ms	s10a_3j_a_ms	s10a_3k_a_ms	s10a_3l_a_ms s10a_4c_a_ms	s10a_4d_a_ms	s10a_4e_a_ms	s10a_4f_a_ms	s10a_4g_a_ms	s10a_4h_a_ms	s10a_4i_a_ms	s10a_4j_a_ms	s10a_4k_a_ms	s10a_4l_a_ms s10a_5b_a_ms	s10a_5c_a_ms	s10a_5d_a_ms	s10a_5e_a_ms	s10a_5f_a_ms	s10a_5g_a_ms	s10a_5h_a_ms	s10a_5i_a_ms	s10a_5j_a_ms	s10a_5k_a_ms	s10a_5l_a_ms s10b_1c_a_ms	s10b_1d_a_ms	s10b_1e_a_ms	s10b_1f_a_ms	s10b_1g_a_ms	s10b_1h_a_ms	s10b_1i_a_ms	s10b_1j_a_ms	s10b_1k_a_ms	s10b_1l_a_ms s10b_2c_a_ms	s10b_2d_a_ms	s10b_2e_a_ms	s10b_2f_a_ms	s10b_2g_a_ms	s10b_2h_a_ms	s10b_2i_a_ms	s10b_2j_a_ms	s10b_2k_a_ms	s10b_2l_a_ms s10b_3b_a_ms	s10b_3c_a_ms	s10b_3d_a_ms	s10b_3e_a_ms	s10b_3f_a_ms	s10b_3g_a_ms	s10b_3h_a_ms	s10b_3i_a_ms	s10b_3j_a_ms	s10b_3k_a_ms	s10b_3l_a_ms s10b_4c_a_ms	s10b_4d_a_ms	s10b_4e_a_ms	s10b_4f_a_ms	s10b_4g_a_ms	s10b_4h_a_ms	s10b_4i_a_ms	s10b_4j_a_ms	s10b_4k_a_ms	s10b_4l_a_ms s10c_1b_a_ms	s10c_1c_a_ms	s10c_1d_a_ms	s10c_1e_a_ms	s10c_1f_a_ms	s10c_1g_a_ms	s10c_1h_a_ms	s10c_1i_a_ms	s10c_1j_a_ms	s10c_1k_a_ms	s10c_1l_a_ms s10d_1g_a_ms	s10d_1h_a_ms	s10d_1i_a_ms	s10d_1j_a_ms	s10d_1k_a_ms	s10d_1l_a_ms s10d_2c_a_ms	s10d_2d_a_ms	s10d_2e_a_ms	s10d_2f_a_ms	s10d_2g_a_ms	s10d_2h_a_ms	s10d_2i_a_ms	s10d_2j_a_ms	s10d_2k_a_ms	s10d_2l_a_ms s10e_1c_a_ms	s10e_1d_a_ms	s10e_1e_a_ms	s10e_1f_a_ms	s10e_1g_a_ms	s10e_1h_a_ms	s10e_1i_a_ms	s10e_1j_a_ms	s10e_1k_a_ms	s10e_1l_a_ms s10e_2c_a_ms	s10e_2d_a_ms	s10e_2e_a_ms	s10e_2f_a_ms	s10e_2g_a_ms	s10e_2h_a_ms	s10e_2i_a_ms	s10e_2j_a_ms	s10e_2k_a_ms	s10e_2l_a_ms s10e_3d_a_ms	s10e_3e_a_ms	s10e_3f_a_ms	s10e_3g_a_ms	s10e_3h_a_ms	s10e_3i_a_ms	s10e_3j_a_ms	s10e_3k_a_ms	s10e_3l_a_ms s10e_4c_a_ms	s10e_4d_a_ms	s10e_4e_a_ms	s10e_4f_a_ms	s10e_4g_a_ms	s10e_4h_a_ms	s10e_4i_a_ms	s10e_4j_a_ms	s10e_4k_a_ms	s10e_4l_a_ms s10e_5e_a_ms	s10e_5f_a_ms	s10e_5g_a_ms	s10e_5h_a_ms	s10e_5i_a_ms	s10e_5j_a_ms	s10e_5k_a_ms	s10e_5l_a_ms s11a_1b_a_ms	s11a_1c_a_ms	s11a_1d_a_ms	s11a_1e_a_ms	s11a_1f_a_ms	s11a_1g_a_ms	s11a_1h_a_ms	s11a_1i_a_ms	s11a_1j_a_ms	s11a_1k_a_ms	s11a_1l_a_ms s11a_2b_a_ms	s11a_2c_a_ms	s11a_2d_a_ms	s11a_2e_a_ms	s11a_2f_a_ms	s11a_2g_a_ms	s11a_2h_a_ms	s11a_2i_a_ms	s11a_2j_a_ms	s11a_2k_a_ms	s11a_2l_a_ms s11a_3b_a_ms	s11a_3c_a_ms	s11a_3d_a_ms	s11a_3e_a_ms	s11a_3f_a_ms	s11a_3g_a_ms	s11a_3h_a_ms	s11a_3i_a_ms	s11a_3j_a_ms	s11a_3k_a_ms	s11a_3l_a_ms s11a_4b_a_ms	s11a_4c_a_ms	s11a_4d_a_ms	s11a_4e_a_ms	s11a_4f_a_ms	s11a_4g_a_ms	s11a_4h_a_ms	s11a_4i_a_ms	s11a_4j_a_ms	s11a_4k_a_ms	s11a_4l_a_ms s11a_5b_a_ms	s11a_5c_a_ms	s11a_5d_a_ms	s11a_5e_a_ms	s11a_5f_a_ms	s11a_5g_a_ms	s11a_5h_a_ms	s11a_5i_a_ms	s11a_5j_a_ms	s11a_5k_a_ms	s11a_5l_a_ms s11b_1d_a_ms	s11b_1e_a_ms	s11b_1f_a_ms	s11b_1g_a_ms	s11b_1h_a_ms	s11b_1i_a_ms	s11b_1j_a_ms	s11b_1k_a_ms	s11b_1l_a_ms s11b_2b_a_ms	s11b_2c_a_ms	s11b_2d_a_ms	s11b_2e_a_ms	s11b_2f_a_ms	s11b_2g_a_ms	s11b_2h_a_ms	s11b_2i_a_ms	s11b_2j_a_ms	s11b_2k_a_ms	s11b_2l_a_ms s11b_3b_a_ms	s11b_3c_a_ms	s11b_3d_a_ms	s11b_3e_a_ms	s11b_3f_a_ms	s11b_3g_a_ms	s11b_3h_a_ms	s11b_3i_a_ms	s11b_3j_a_ms	s11b_3k_a_ms	s11b_3l_a_ms s11b_4e_a_ms	s11b_4f_a_ms	s11b_4g_a_ms	s11b_4h_a_ms	s11b_4i_a_ms	s11b_4j_a_ms	s11b_4k_a_ms	s11b_4l_a_ms s11c_1c_a_ms	s11c_1d_a_ms	s11c_1e_a_ms	s11c_1f_a_ms	s11c_1g_a_ms	s11c_1h_a_ms	s11c_1i_a_ms	s11c_1j_a_ms	s11c_1k_a_ms	s11c_1l_a_ms s11c_2c_a_ms	s11c_2d_a_ms	s11c_2e_a_ms	s11c_2f_a_ms	s11c_2g_a_ms	s11c_2h_a_ms	s11c_2i_a_ms	s11c_2j_a_ms	s11c_2k_a_ms	s11c_2l_a_ms s11c_3b_a_ms	s11c_3c_a_ms	s11c_3d_a_ms	s11c_3e_a_ms	s11c_3f_a_ms	s11c_3g_a_ms	s11c_3h_a_ms	s11c_3i_a_ms	s11c_3j_a_ms	s11c_3k_a_ms	s11c_3l_a_ms s11d_1c_a_ms	s11d_1d_a_ms	s11d_1e_a_ms	s11d_1f_a_ms	s11d_1g_a_ms	s11d_1h_a_ms	s11d_1i_a_ms	s11d_1j_a_ms	s11d_1k_a_ms    s11d_1l_a_ms s11d_2c_a_ms	s11d_2d_a_ms	s11d_2e_a_ms	s11d_2f_a_ms	s11d_2g_a_ms	s11d_2h_a_ms	s11d_2i_a_ms	s11d_2j_a_ms	s11d_2k_a_ms	s11d_2l_a_ms s11d_3c_a_ms	s11d_3d_a_ms	s11d_3e_a_ms	s11d_3f_a_ms	s11d_3g_a_ms	s11d_3h_a_ms	s11d_3i_a_ms	s11d_3j_a_ms	s11d_3k_a_ms	s11d_3l_a_ms s11d_4e_a_ms	s11d_4f_a_ms	s11d_4g_a_ms	s11d_4h_a_ms	s11d_4i_a_ms	s11d_4j_a_ms	s11d_4k_a_ms	s11d_4l_a_ms s12a_1h_a_ms	s12a_1i_a_ms	s12a_1j_a_ms	s12a_1k_a_ms	s12a_1l_a_ms s12a_2k_a_ms	s12a_2l_a_ms s12b_1i_a_ms	s12b_1j_a_ms	s12b_1k_a_ms	s12b_1l_a_ms s12c_1e_a_ms	s12c_1f_a_ms	s12c_1g_a_ms	s12c_1h_a_ms	s12c_1i_a_ms	s12c_1j_a_ms	s12c_1k_a_ms	s12c_1l_a_ms s12d_1h_a_ms	s12d_1i_a_ms	s12d_1j_a_ms	s12d_1k_a_ms	s12d_1l_a_ms s12d_2c_a_ms	s12d_2d_a_ms	s12d_2e_a_ms	s12d_2f_a_ms	s12d_2g_a_ms	s12d_2h_a_ms	s12d_2i_a_ms	s12d_2j_a_ms	s12d_2k_a_ms	s12d_2l_a_ms s12e_1g_a_ms	s12e_1h_a_ms	s12e_1i_a_ms	s12e_1j_a_ms	s12e_1k_a_ms	s12e_1l_a_ms s12e_2f_a_ms	s12e_2g_a_ms	s12e_2h_a_ms	s12e_2i_a_ms	s12e_2j_a_ms	s12e_2k_a_ms	s12e_2l_a_ms s12e_3c_a_ms	s12e_3d_a_ms	s12e_3e_a_ms	s12e_3f_a_ms	s12e_3g_a_ms	s12e_3h_a_ms	s12e_3i_a_ms	s12e_3j_a_ms	s12e_3k_a_ms	s12e_3l_a_ms s12f_1c_a_ms	s12f_1d_a_ms	s12f_1e_a_ms	s12f_1f_a_ms	s12f_1g_a_ms	s12f_1h_a_ms	s12f_1i_a_ms	s12f_1j_a_ms	s12f_1k_a_ms	s12f_1l_a_ms s12f_2c_a_ms	s12f_2d_a_ms	s12f_2e_a_ms	s12f_2f_a_ms	s12f_2g_a_ms	s12f_2h_a_ms	s12f_2i_a_ms	s12f_2j_a_ms	s12f_2k_a_ms	s12f_2l_a_ms s12f_3d_a_ms	s12f_3e_a_ms	s12f_3f_a_ms	s12f_3g_a_ms	s12f_3h_a_ms	s12f_3i_a_ms	s12f_3j_a_ms	s12f_3k_a_ms	s12f_3l_a_ms s12f_4c_a_ms	s12f_4d_a_ms	s12f_4e_a_ms	s12f_4f_a_ms	s12f_4g_a_ms	s12f_4h_a_ms	s12f_4i_a_ms	s12f_4j_a_ms	s12f_4k_a_ms	s12f_4l_a_ms s12f_5e_a_ms	s12f_5f_a_ms	s12f_5g_a_ms	s12f_5h_a_ms	s12f_5i_a_ms	s12f_5j_a_ms	s12f_5k_a_ms	s12f_5l_a_ms s6a_7f_a_ms s6a_7g_a_ms 
	
	forvalues i = 2(1)12 {	
		foreach x in a b c d e f {			
			forvalues j = 1(1)8 {			
				foreach y in a b c d e f g h i j k l {	
				
					capture gen s`i'`x'_`j'`y'_a_ms = s`i'`x'_`j'_a_ms/ s`i'`x'_`j'_a_count
					if _rc!=0 {		
						display "s`i'`x'_`j'`y'_a_ms not found"		
					} 					
				}
			}		
		}	
	}
	
	drop `nocombinations'

	** Special questions: Manually 
	
	** If one section is not applicable the max score should be missing
	replace s9a_1a_a_ms =. if pharmacy == .
	replace s9a_2a_a_ms =. if pharmacy == .
	
	** Level restricted questions
	replace s2c_2a_a_ms = 10 if level < 4
	replace s2c_2b_a_ms = . if level < 4 
	
	* When we implemented QPS1 and QPS2 there were no information about the level of this HF. For that reason, question s2c_2b has missing values, but we can't assign 0 in the
	* adherence variable s2c_2b_a. So, max score will be missing in this case, but it won't affect the observed score and percentage score.
	replace s2c_2b_a_ms = . if a5 == 11976
		
	replace s2c_3a_a_ms = (5/3) if level < 4 
	replace s2c_3b_a_ms = (5/3) if level < 4
	replace s2c_3c_a_ms = (5/3) if level < 4
	replace s2c_3d_a_ms = . if level <4
	
	* s2c_3a: 16 observations missing because HFs didn't answer both questions in QPS2: s1c_5 & s1c_6. We can't say anything about the missings. So, for HF a5 11976, which is level 4, we need to assign manually the max scores. 
	replace s2c_3a_a_ms = 1.25 if s2c_3a_a == . & level >= 4 
	replace s2c_3b_a_ms = 1.25 if s2c_3a_a == . & level >= 4 
	replace s2c_3c_a_ms = 1.25 if s2c_3a_a == . & level >= 4 
	replace s2c_3d_a_ms = 1.25 if s2c_3a_a == . & level >= 4 

	//br s2c_3a_a_ms s2c_3b_a_ms s2c_3c_a_ms s2c_3d_a_ms level
	** Inpatient restricted question
	replace s3c_2a_a_ms = 2.5 if nutrition !=1 
	replace s3c_2d_a_ms = 2.5 if nutrition !=1
	replace s3c_2b_a_ms = . if nutrition !=1
	replace s3c_2c_a_ms = . if nutrition !=1

	** General compound cleanliness special question
	replace s4a_4c_a_ms = 10 if s4a_4a_a == . & s4a_4b_a == .
	replace s4a_4c_a_ms = 5 if (s4a_4a_a == . & s4a_4b_a == 1) | (s4a_4a_a == 1 & s4a_4b_a == .)
	replace s4a_4a_a_ms = 5 if (s4a_4a_a == 1 & s4a_4b_a == .)	
	replace s4a_4b_a_ms = 5 if (s4a_4a_a == . & s4a_4b_a == 1)
	replace s4a_4a_a_ms = . if s4a_4a_a == .
	replace s4a_4b_a_ms = . if s4a_4b_a == .	
	
	** 
	* HFs 11696, 11293, 11563, 11894 have missing values for s5b_1a, so we have to assign manually the max scores
	replace s5b_1a_a_ms = 2 if s5b_1a_a == .
	replace s5b_1b_a_ms = 2 if s5b_1a_a == .
	
	** Radiology section: No points if the HF does not produce radioactive waste
	replace s11c_1a_a_ms = . if s11c_1a_a == 0
	replace s11c_1b_a_ms = . if s11c_1a_a == 0
	replace s11c_2a_a_ms = . if s11c_1a_a == 0
	replace s11c_2b_a_ms = . if s11c_1a_a == 0
	replace s11c_3a_a_ms = . if s11c_1a_a == 0

		* Checking
		//sum s2a_1a_a_ms	s2a_1b_a_ms	s2a_1c_a_ms	s2a_1d_a_ms	s2a_1e_a_ms	s2a_2a_a_ms	s2a_3a_a_ms s2b_1a_a_ms	s2b_1b_a_ms	s2b_2a_a_ms	s2b_3a_a_ms	s2b_3b_a_ms	s2c_1a_a_ms	s2c_1b_a_ms	s2c_2a_a_ms	s2c_2b_a_ms	s2c_3a_a_ms	s2c_3b_a_ms	s2c_3c_a_ms	s2c_3d_a_ms	s2c_4a_a_ms	s3a_1a_a_ms	s3a_1b_a_ms	s3a_1c_a_ms	s3a_1d_a_ms	s3a_2a_a_ms	s3a_2b_a_ms	s3a_2c_a_ms	s3a_2d_a_ms	s3a_2e_a_ms	s3a_2f_a_ms	s3a_2g_a_ms	s3a_2h_a_ms	s3a_3a_a_ms	s3b_2a_a_ms	s3b_2b_a_ms	s3b_2c_a_ms	s3b_2d_a_ms	s3b_2e_a_ms	s3b_3a_a_ms	s3b_3b_a_ms	s3b_3c_a_ms	s3c_1a_a_ms	s3c_1b_a_ms	s3c_1c_a_ms	s3c_2a_a_ms	s3c_2b_a_ms	s3c_2c_a_ms	s3c_2d_a_ms	s3c_3a_a_ms	s3c_3b_a_ms	s3c_3c_a_ms	s3c_5a_a_ms	s3d_1a_a_ms	s3d_1b_a_ms	s3d_2a_a_ms	s3d_2b_a_ms	s3d_2c_a_ms	s4a_1a_a_ms	s4a_1b_a_ms	s4a_2a_a_ms	s4a_2b_a_ms	s4a_2c_a_ms	s4a_3a_a_ms s4a_3b_a_ms	s4a_3c_a_ms	s4a_3d_a_ms	s4a_4a_a_ms	s4a_4b_a_ms	s4a_4c_a_ms	s4b_1a_a_ms	s4b_1b_a_ms	s4b_1c_a_ms	s4b_1d_a_ms	s5a_1a_a_ms	s5a_1b_a_ms	s5a_1c_a_ms	s5a_1d_a_ms	s5a_2a_a_ms	s5a_2b_a_ms	s5a_2c_a_ms	s5a_3a_a_ms	s5a_3b_a_ms	s5a_3c_a_ms	s5a_3d_a_ms	s5a_3e_a_ms	s5a_3f_a_ms	s5a_3g_a_ms	s5a_3h_a_ms	s5a_3i_a_ms	s5a_4a_a_ms	s5a_4b_a_ms	s5a_4c_a_ms	s5a_4d_a_ms	s5a_4e_a_ms	s5a_4f_a_ms	s5a_4g_a_ms	s5a_4h_a_ms	s5a_4i_a_ms	s5a_4j_a_ms	s5a_4k_a_ms	s5a_4l_a_ms	s5b_1a_a_ms	s5b_1b_a_ms	s5b_2a_a_ms	s5b_2b_a_ms	s5b_3a_a_ms	s5b_3b_a_ms	s5b_3c_a_ms	s5b_4a_a_ms	s5b_4b_a_ms	s5b_5a_a_ms	s5b_5b_a_ms	s5b_5c_a_ms	s5b_5d_a_ms	s6a_1a_a_ms	s6a_1b_a_ms	s6a_1c_a_ms	s6a_1d_a_ms	s6a_1e_a_ms	s6a_1f_a_ms	s6a_1g_a_ms	s6a_1h_a_ms	s6a_1i_a_ms	s6a_2a_a_ms	s6a_2b_a_ms	s6a_2c_a_ms	s6a_3a_a_ms	s6a_3b_a_ms	s6a_3c_a_ms	s6a_4a_a_ms	s6a_4b_a_ms	s6a_5a_a_ms	s6a_5b_a_ms	s6a_6a_a_ms	s6a_6b_a_ms	s6a_6c_a_ms	s6a_6d_a_ms	s6a_6e_a_ms	s6a_6f_a_ms	s6a_6g_a_ms	s6a_7a_a_ms	s6a_7b_a_ms	s6a_7c_a_ms	s6a_7d_a_ms	s6a_7e_a_ms	s6a_8a_a_ms	s6a_8b_a_ms	s6a_8c_a_ms	s6a_8d_a_ms	s6b_1a_a_ms	s6b_1b_a_ms	s6b_2a_a_ms	s6b_2b_a_ms	s6b_3a_a_ms	s6b_3b_a_ms	s6b_3c_a_ms	s6b_4a_a_ms	s6b_4b_a_ms	s6b_5a_a_ms	s6b_5b_a_ms	s6b_5c_a_ms	s6b_5d_a_ms	
		//sum s7a_1a_a_ms	s7a_1b_a_ms	s7a_1c_a_ms	s7a_1d_a_ms	s7a_2a_a_ms	s7a_2b_a_ms	s7a_3a_a_ms	s7a_3b_a_ms	s7a_3c_a_ms	s7a_3d_a_ms	s7a_3e_a_ms	s7b_1a_a_ms	s7b_1b_a_ms	s7b_2a_a_ms	s7b_2b_a_ms	s7b_3a_a_ms	s7b_3b_a_ms	s7b_3c_a_ms	s7b_4a_a_ms	s7b_4b_a_ms	s7b_5a_a_ms	s7b_5b_a_ms	s7b_5c_a_ms	s7b_5d_a_ms	s8a_1a_a_ms	s8a_1b_a_ms	s8a_1c_a_ms	s8a_1d_a_ms	s8a_2a_a_ms	s8a_2b_a_ms	s8a_2c_a_ms	s8a_2d_a_ms	s8a_2e_a_ms	s8a_2f_a_ms	s8a_2g_a_ms	s8a_2h_a_ms	s8a_3a_a_ms	s8a_3b_a_ms	s8a_3c_a_ms	s8a_3d_a_ms	s8a_3e_a_ms	s8a_3f_a_ms	s8a_3g_a_ms	s8a_3h_a_ms	s8a_3i_a_ms	s8a_3j_a_ms	s8a_3k_a_ms	s8a_3l_a_ms	s8a_4a_a_ms	s8a_4b_a_ms	s8a_5a_a_ms	s8a_5b_a_ms	s8a_5c_a_ms	s8b_1a_a_ms	s8b_1b_a_ms	s8b_2a_a_ms	s8b_2b_a_ms	s8b_3a_a_ms	s8b_3b_a_ms	s8b_3c_a_ms	s8b_4a_a_ms	s8b_4b_a_ms	s8b_5a_a_ms	s8b_5b_a_ms	s8b_5c_a_ms	s8b_5d_a_ms	s9a_1a_a_ms s9a_2a_a_ms s9a_2b_a_ms	s9b_1a_a_ms	s9b_1b_a_ms	s9b_1c_a_ms	s9c_1a_a_ms	s9c_1b_a_ms	s9c_1c_a_ms	s9c_1d_a_ms	s9c_1e_a_ms	s9c_1f_a_ms	s9d_1a_a_ms	s9d_1b_a_ms	s9e_1a_a_ms	s9e_1b_a_ms	s9e_2a_a_ms	s9e_2b_a_ms	s9e_3a_a_ms	s9e_3b_a_ms	s9e_3c_a_ms	s9e_4a_a_ms	s9e_4b_a_ms	s9e_5a_a_ms	s9e_5b_a_ms	s9e_5c_a_ms	s9e_5d_a_ms	s10a_2a_a_ms	s10a_2b_a_ms	s10a_3a_a_ms	s10a_3b_a_ms	s10a_4a_a_ms	s10a_4b_a_ms	s10a_5a_a_ms	s10b_1a_a_ms	s10b_1b_a_ms	s10b_2a_a_ms	s10b_2b_a_ms	s10b_3a_a_ms	s10b_4a_a_ms	s10b_4b_a_ms	s10c_1a_a_ms	s10d_1a_a_ms	s10d_1b_a_ms	s10d_1c_a_ms	s10d_1d_a_ms	s10d_1e_a_ms	s10d_1f_a_ms	s10d_2a_a_ms	s10d_2b_a_ms	s10e_1a_a_ms	s10e_1b_a_ms	s10e_2a_a_ms	s10e_2b_a_ms	s10e_3a_a_ms	s10e_3b_a_ms	s10e_3c_a_ms	s10e_4a_a_ms	s10e_4b_a_ms	s10e_5a_a_ms	s10e_5b_a_ms	s10e_5c_a_ms	s10e_5d_a_ms	s11a_1a_a_ms	s11a_2a_a_ms	s11a_3a_a_ms	s11a_4a_a_ms	s11a_5a_a_ms	s11b_1a_a_ms	s11b_1b_a_ms	s11b_1c_a_ms	s11b_2a_a_ms	s11b_3a_a_ms	s11b_4a_a_ms	s11b_4b_a_ms	s11b_4c_a_ms	s11b_4d_a_ms	s11c_1a_a_ms	s11c_1b_a_ms	s11c_2a_a_ms	s11c_2b_a_ms	s11c_3a_a_ms	s11d_1a_a_ms	s11d_1b_a_ms	s11d_2a_a_ms	s11d_2b_a_ms	s11d_3a_a_ms	s11d_3b_a_ms	s11d_4a_a_ms	s11d_4b_a_ms	s11d_4c_a_ms	s11d_4d_a_ms	s12a_1a_a_ms	s12a_1b_a_ms	s12a_1c_a_ms	s12a_1d_a_ms	s12a_1e_a_ms	s12a_1f_a_ms	s12a_1g_a_ms	s12a_2a_a_ms	s12a_2b_a_ms	s12a_2c_a_ms	s12a_2d_a_ms	s12a_2e_a_ms	s12a_2f_a_ms	s12a_2g_a_ms	s12a_2h_a_ms	s12a_2i_a_ms	s12a_2j_a_ms	s12b_1a_a_ms	s12b_1b_a_ms	s12b_1c_a_ms	s12b_1d_a_ms	s12b_1e_a_ms	s12b_1f_a_ms	s12b_1g_a_ms	s12b_1h_a_ms	s12c_1a_a_ms	s12c_1b_a_ms	s12c_1c_a_ms	s12c_1d_a_ms	s12d_1a_a_ms	s12d_1b_a_ms	s12d_1c_a_ms	s12d_1d_a_ms	s12d_1e_a_ms	s12d_1f_a_ms	s12d_1g_a_ms	s12d_2a_a_ms	s12d_2b_a_ms	s12e_1a_a_ms	s12e_1b_a_ms	s12e_1c_a_ms	s12e_1d_a_ms	s12e_1e_a_ms	s12e_1f_a_ms	s12e_2a_a_ms	s12e_2b_a_ms	s12e_2c_a_ms	s12e_2d_a_ms	s12e_2e_a_ms	s12e_3a_a_ms	s12e_3b_a_ms	s12f_1a_a_ms	s12f_1b_a_ms	s12f_2a_a_ms	s12f_2b_a_ms	s12f_3a_a_ms	s12f_3b_a_ms	s12f_3c_a_ms	s12f_4a_a_ms	s12f_4b_a_ms	s12f_5a_a_ms	s12f_5b_a_ms	s12f_5c_a_ms	s12f_5d_a_ms
		
	** gen maxscore (level 2)

	forvalues j=2(1)12 {	
	 foreach x in a b c d e f {
		gen s`j'`x'_a_ms = 0		
		 foreach col in `s`j'`x'_a_ms' {
				capture replace s`j'`x'_a_ms = s`j'`x'_a_ms + `col'
					
					if _rc!=0 {
							display "`col' problem"			  
					} 
			}
		}					
	}

	** If one section is not applicable the max score should be missing
	** Section 6: Labour
	foreach x in a b {
		replace s6`x'_a_ms =. if labour == .			
	}	
	
	** Section 7: Ward
	foreach x in a b {
		replace s7`x'_a_ms =. if wards == .			
					
	}		
	
	** Section 8: Theatre 
	foreach x in a b {
		replace s8`x'_a_ms =. if theatre == .			
 	}	
	
	** Section 9: Pharmacy
	foreach x in a b c d e {
		replace s9`x'_a_ms =. if pharmacy == .			
	}
	
	** Section 10: Lab
	foreach x in a b c d e {
		replace s10`x'_a_ms =. if lab == .			

	}
	
	** Section 11: radiology
	foreach x in a b c d {
		replace s11`x'_a_ms =. if radiology == .					
	}	
		
	** Section 12: nutrition
	foreach x in a b c d e f{
		replace s12`x'_a_ms =. if nutrition == .		
	}
	
	** Radiology section: No points in section C if the HF does not produce radioactive waste
	replace s11c_a_ms = . if s11c_1a == 0
	
		* Checking
		//br s2a_a_ms s2b_a_ms s2c_a_ms
		//br s5a_a_ms s5b_a_ms 
		//br s3a_a_ms s3b_a_ms s3c_a_ms s3d_a_ms
		//br s11a_a_ms s11b_a_ms s11c_a_ms s11d_a_ms	
		//sum s2a_a_ms s2b_a_ms s2c_a_ms s3a_a_ms s3b_a_ms s3c_a_ms s3d_a_ms s4a_a_ms s4b_a_ms s5a_a_ms s5b_a_ms s6a_a_ms s6b_a_ms s7a_a_ms s7b_a_ms s8a_a_ms s8b_a_ms s9a_a_ms s9b_a_ms s9c_a_ms s9d_a_ms s9e_a_ms s10a_a_ms s10b_a_ms s10c_a_ms s10d_a_ms s10e_a_ms s11a_a_ms s11b_a_ms s11c_a_ms s11d_a_ms s12a_a_ms s12b_a_ms s12c_a_ms s12d_a_ms s12e_a_ms s12f_a_ms

	*+ gen max score (level 1)
	
	//local L1 s2 s3 s4 s5 s6 s7 s8 s9 s10 s11 s12
	
	local s2_a_ms s2a_a_ms s2b_a_ms s2c_a_ms
	local s3_a_ms s3a_a_ms s3b_a_ms s3c_a_ms s3d_a_ms
	local s4_a_ms s4a_a_ms s4b_a_ms
	local s5_a_ms s5a_a_ms s5b_a_ms
	local s6_a_ms s6a_a_ms s6b_a_ms
	local s7_a_ms s7a_a_ms s7b_a_ms
	local s8_a_ms s8a_a_ms s8b_a_ms
	local s9_a_ms s9a_a_ms s9b_a_ms s9c_a_ms s9d_a_ms s9e_a_ms
	local s10_a_ms s10a_a_ms s10b_a_ms s10c_a_ms s10d_a_ms s10e_a_ms
	local s11_a_ms s11a_a_ms s11b_a_ms s11c_a_ms s11d_a_ms
	local s12_a_ms s12a_a_ms s12b_a_ms s12c_a_ms s12d_a_ms s12e_a_ms s12f_a_ms
	
	//local L2_ms `s2a_a_ms'	`s3_a_ms'	`s4_a_ms'	`s5_a_ms'	`s6_a_ms'	`s7_a_ms'	`s8_a_ms'	`s9_a_ms'	`s10_a_ms'	`s11_a_ms'	`s12_a_ms'
	
		forvalues j=2(1)12 {
			gen s`j'_a_ms = 0		
			foreach col in `s`j'_a_ms' {
					capture replace s`j'_a_ms = s`j'_a_ms + `col'
					
					if _rc!=0 {
							display "`col' problem"			  
					} 
			}
					
		}
		
	** Radiology section: 80 points if the HF does not produce radioactive waste
	replace s11_a_ms = 80 if s11c_1a == 0

	** If one section is not applicable the max score should be missing
	replace s6_a_ms = . if labour == .
	replace s7_a_ms = . if wards == .
	replace s8_a_ms = . if theatre == . 
	replace s9_a_ms = . if pharmacy == .
	replace s10_a_ms = . if lab == .
	replace s11_a_ms = . if radiology == .
	replace s12_a_ms = . if nutrition == .
	
		** Checking
		//br s3_a_ms s3a_a_ms s3b_a_ms s3c_a_ms s3d_a_ms
		//br s9_a_ms s9a_a_ms s9b_a_ms s9c_a_ms s9d_a_ms s9e_a_ms
		//br s2_a_ms s3_a_ms s4_a_ms s5_a_ms s6_a_ms s7_a_ms s8_a_ms s9_a_ms s10_a_ms s11_a_ms s12_a_ms
		//br s2_a_ms s3_a_ms s4_a_ms s5_a_ms s6_a_ms s7_a_ms s8_a_ms s9_a_ms s10_a_ms s11_a_ms s12_a_ms
		//sum s2_a_ms s3_a_ms s4_a_ms	s5_a_ms s6_a_ms s7_a_ms s8_a_ms s9_a_ms s10_a_ms s11_a_ms s12_a_ms
		
	* gen global for level 4 names 
	//local L4_a $s2_a $s3_a $s4_a $s5_a $s6_a $s7_a $s8_a $s9_a $s10_a $s11_a $s12_a
		
	* gen global for level 3 names
	//local L3_a s2a_1_a s2a_2_a s2a_3_a s2b_1_a s2b_2_a s2b_3_a s2c_1_a s2c_2_a s2c_3_a s2c_4_a s3a_1_a s3a_2_a s3a_3_a s3b_1_a s3b_2_a s3b_3_a s3c_1_a s3c_2_a s3c_3_a s3c_4_a s3c_5_a s3d_1_a s3d_2_a s4a_1_a s4a_2_a s4a_3_a s4a_4_a	s4b_1_a	s5a_1_a	s5a_2_a	s5a_3_a	s5a_4_a	s5b_1_a	s5b_2_a	s5b_3_a	s5b_4_a	s5b_5_a	s6a_1_a	s6a_2_a	s6a_3_a	s6a_4_a	s6a_5_a	s6a_6_a	s6a_7_a	s6a_8_a	s6b_1_a	s6b_2_a	s6b_3_a	s6b_4_a	s6b_5_a	s7a_1_a	s7a_2_a	s7a_3_a	s7b_1_a	s7b_2_a	s7b_3_a	s7b_4_a	s7b_5_a	s8a_1_a	s8a_2_a	s8a_3_a	s8a_4_a	s8a_5_a	s8b_1_a	s8b_2_a	s8b_3_a	s8b_4_a	s8b_5_a	s9a_1_a	s9a_2_a	s9e_1_a	s9e_2_a	s9e_3_a	s9e_4_a	s9e_5_a	s10a_1_a	s10a_2_a	s10a_3_a	s10a_4_a	s10a_5_a	s10b_1_a	s10b_2_a	s10b_3_a	s10b_4_a	s10d_1_a	s10d_2_a	s10e_1_a	s10e_2_a	s10e_3_a	s10e_4_a	s10e_5_a	s11a_1_a	s11a_2_a	s11a_3_a	s11a_4_a	s11a_5_a	s11b_1_a	s11b_2_a	s11b_3_a	s11b_4_a	s11c_1_a	s11c_2_a	s11c_3_a	s11d_1_a	s11d_2_a	s11d_3_a	s11d_4_a	s12a_1_a	s12a_2_a	s12d_1_a	s12d_2_a	s12e_1_a	s12e_2_a	s12e_3_a	s12f_1_a	s12f_2_a	s12f_3_a	s12f_4_a	s12f_5_a

	* gen global for level 2 names 
	//local L2_a s2a_a	s2b_a	s2c_a	s3a_a	s3b_a	s3c_a	s3d_a	s4a_a	s4b_a	s5a_a	s5b_a	s6a_a	s6b_a	s7a_a	s7b_a	s8a_a	s8b_a	s9a_a	s9b_a	s9c_a	s9d_a	s9e_a	s10a_a	s10b_a	s10c_a	s10d_a	s10e_a	s11a_a	s11b_a	s11c_a	s11d_a	s12a_a	s12b_a	s12c_a	s12d_a	s12e_a	s12f_a

	* gen global for level 1 names
	//local L1_a s2_a s3_a s4_a	s5_a s6_a s7_a s8_a s9_a s10_a s11_a s12_a
	
	** Labeling Maxscores: Level 4
	lab var s2a_1a_a_ms "Does the facility display legible signage?"
	lab var s2a_1b_a_ms "Does HF display signage that is accurate outside the facility? if signage"
	lab var s2a_1c_a_ms "Does the signage outside include HF name? if signage"
	lab var s2a_1d_a_ms "Does the signage inside the facility include department names and direction? if signage"
	lab var s2a_1e_a_ms "Does the facility have an accessibility ramp for disabled/wheelchair patients?"
	lab var s2a_2a_a_ms "Adequate ventilation"	
	lab var s2a_3a_a_ms "Adequate lighting"	
	lab var s2b_1a_a_ms "Is safe, clean water available from a tap or container?"
	lab var s2b_1b_a_ms "Is there sufficient storage for the water?"
	lab var s2b_2a_a_ms "Is there a stable source of power?"
	lab var s2b_3a_a_ms "Are clean toilets available for both male and female clients?"
	lab var s2b_3b_a_ms "Is there a cleaning roster displayed?"
	lab var s2c_1a_a_ms "Does the facility have a lockable door?"
	lab var s2c_1b_a_ms "Is the door secured with grills or another security mechanism?"
	lab var s2c_2a_a_ms "Does HF have a fire control mechanism such?"
	lab var s2c_2b_a_ms "Is the equipment available in the reception area as well as specific departments? if L4/L5"
	lab var s2c_3a_a_ms "Does the facility have a fire assembly point or fire assembly protocol? if L4/L5"
	lab var s2c_3b_a_ms "Is there a documented firefighting protocol?"
	lab var s2c_3c_a_ms "Does the facility display emergency exit?"
	lab var s2c_3d_a_ms "Does the facility display fire assembly point signage? if L4/L5 & assembly point"
	lab var s2c_4a_a_ms "Is there a security system present (e.g. security guard, alarm system)?"
	lab var s3a_1a_a_ms "Does the facility have a strategic plan with its vision, values, and objectives?"
	lab var s3a_1b_a_ms "Is the plan displayed and shared to all staff? if strategic plan" 
	lab var s3a_1c_a_ms "Does the facility have an annual work plan or a business plan?"
	lab var s3a_1d_a_ms "Is there an organizational chart available and approved by management?"
	lab var s3a_2a_a_ms "Is a client service charter displayed?"
	lab var s3a_2b_a_ms "Is it displayed in all key departments/areas? if charter"
	lab var s3a_2c_a_ms "Mention common services offered? if charter"
	lab var s3a_2d_a_ms "Mention obligations to clients? if charter"
	lab var s3a_2e_a_ms "Mention waiting times for clients? if charter"
	lab var s3a_2f_a_ms "Mention ways to communicate with management regarding problems? if charter"
	lab var s3a_2g_a_ms "Mention services offered for free if charter"
	lab var s3a_2h_a_ms "Does the facility have a regular performance review for the charter targets?if charter"
	lab var s3a_3a_a_ms "Does the facility have a list of all staff with qualifications/job description"
	lab var s3a_3b_a_ms "Are copies of professional certificates for all staff available at the facility"
	lab var s3b_2a_a_ms "Infant mortality"
	lab var s3b_2b_a_ms "Maternal mortality"
	lab var s3b_2c_a_ms "Immunization"
	lab var s3b_2d_a_ms "Notifiable diseases"
	lab var s3b_2e_a_ms "Are performance indicators shared with staff and published regularly?"
	lab var s3b_3a_a_ms "Is there a functional feedback mechanism, such as a suggestion box, hotline numb"
	lab var s3b_3b_a_ms "Is client feedback reviewed at least biweekly? if feedbacl"
	lab var s3b_3c_a_ms "Are client suggestions documented in a report? if feedback"
	lab var s3c_1a_a_ms "Are medical records kept for each patient?"
	lab var s3c_1b_a_ms "Do the records include names and unique patient numbers? if records"
	lab var s3c_1c_a_ms "Are all the records legible and signed? if records"
	lab var s3c_2a_a_ms "Are outpatients registers kept?"
	lab var s3c_2b_a_ms "Are inpatients registers kept?"
	lab var s3c_2c_a_ms "Are inpatient and outpatient records kept separately?"
	lab var s3c_2d_a_ms "Are the registers up to date?"
	lab var s3c_3a_a_ms "Is there a system in place for storing medical records? if records"
	lab var s3c_3b_a_ms "Is there a filing and numbering system for easy retrieval? if records & system"
	lab var s3c_3c_a_ms "Are the records protected in cabinets (if paper) or by password (if digital)?"
	lab var s3c_5a_a_ms "Does the facility contribute to the DHIS?"
	lab var s3d_1a_a_ms "Is there a service contract for maintenance?"
	lab var s3d_1b_a_ms "Is there a written schedule for maintaining equipment?"
	lab var s3d_2a_a_ms "Is there a written calibration schedule available at the area where equipment is?"
	lab var s3d_2b_a_ms "Is there a document showing regular calibration?"
	lab var s3d_2c_a_ms "Are contracts available at the facility administration?"
	lab var s4a_1a_a_ms "Does the facility have a hygiene protocol?"
	lab var s4a_1b_a_ms "Does the facility have a dedicated staff roster for cleaning?"
	lab var s4a_2a_a_ms "Is there a standard operating procedure for waste management?"
	lab var s4a_2b_a_ms "Is there an incinerator or contracted waste management company?"
	lab var s4a_2c_a_ms "Does the facility have a waste holding area?"
	lab var s4a_3a_a_ms "HF Cleanliness" 	
	lab var s4a_3b_a_ms "Is the paint work acceptable?"
	lab var s4a_3c_a_ms "Is the floor smooth?"
	lab var s4a_3d_a_ms "Is the ceiling free of cobwebs and dust?"
	lab var s4a_4a_a_ms "Is the grass well maintained?"
	lab var s4a_4b_a_ms "Are the bushes neatly kept?"
	lab var s4a_4c_a_ms "Is the site free of odor?"
	lab var s4b_1a_a_ms "Is there a separate area for cleaning with decontamination and sterilization processes?"
	lab var s4b_1b_a_ms "Are standard operating procedures available for sterilization?"
	lab var s4b_1c_a_ms "Is there storage available for sterile supplies?"
	lab var s4b_1d_a_ms "Are sterile supplies labeled and stored in a designated area?"
	lab var s5a_1a_a_ms "Does the facility have a triage area with a qualified nurse(s)?"
	lab var s5a_1b_a_ms "Is it located at the first point of contact with patients? if triage"
	lab var s5a_1c_a_ms "Is there a standard operating procedure for triage? if triage"
	lab var s5a_1d_a_ms "Is there a system for coding patients?"
	lab var s5a_2a_a_ms "Does the examination room have a coach and a mackintosh?"
	lab var s5a_2b_a_ms "Does the room have a consultation table with at least two chairs?"
	lab var s5a_2c_a_ms "Does the room have a pedal bin and stepper?"
	lab var s5a_3a_a_ms "Is a thermometer available?"
	lab var s5a_3b_a_ms "Is a stethoscope available?"
	lab var s5a_3c_a_ms "Is a tongue depressor available?"
	lab var s5a_3d_a_ms "Is a weighing scale available/accessible?"
	lab var s5a_3e_a_ms "Is a blood pressure (BP) machine available/accessible?"
	lab var s5a_3f_a_ms "Is a torch available?"
	lab var s5a_3g_a_ms "Is a privacy screen available?"
	lab var s5a_3h_a_ms "Is a diagnostic set available?"
	lab var s5a_3i_a_ms "Is a lamp available?"
	lab var s5a_4a_a_ms "Does the facility have an emergency tray available at designated sites?"
	lab var s5a_4b_a_ms "Is there a checklist for regular review emergency tray? if emerg tray"
	lab var s5a_4c_a_ms "Glucose if emerg tray"
	lab var s5a_4d_a_ms "Adrenaline if emerg tray"
	lab var s5a_4e_a_ms "Sodium bicarbonate if emerg tray"
	lab var s5a_4f_a_ms "Diazepam if emerg tray"
	lab var s5a_4g_a_ms "Phenobarbitone if emerg tray"
	lab var s5a_4h_a_ms "Ambu bag and mask available in pediatric and adult sizes"
	lab var s5a_4i_a_ms "Adjustable bed  "
	lab var s5a_4j_a_ms "Functional suction machine"
	lab var s5a_4k_a_ms "Oxygen cylinder and flowmeter, or piped oxygen"
	lab var s5a_4l_a_ms "Endotracheal tubes"
	lab var s5b_1a_a_ms "Is there a hygiene protocol?"
	lab var s5b_1b_a_ms "Does the hygiene protocol have a dedicated staff roster available?"
	lab var s5b_2a_a_ms "Is a sink present with running water from a tap or modified storage container?"
	lab var s5b_2b_a_ms "Is soap available at the hand washing area?"
	lab var s5b_3a_a_ms "Are there at least two color-coded bins (red, black and/or yellow)?"
	lab var s5b_3b_a_ms "Are there coded lining bags that match the color of the bins?"
	lab var s5b_3c_a_ms "Are there standard operating procedures for waste management?"
	lab var s5b_4a_a_ms "Is there disinfectant readily available in the consultation room?"
	lab var s5b_4b_a_ms "Are you able to observe disinfectant containers used for cleaning?"
	lab var s5b_5a_a_ms "Are gloves available?"
	lab var s5b_5b_a_ms "Are gowns or dust coats available?"
	lab var s5b_5c_a_ms "Are face masks available?"
	lab var s5b_5d_a_ms "Are safety boots available?"
	lab var s6a_1a_a_ms "Is there privacy in the ward (privacy during delivery)?"
	lab var s6a_1b_a_ms "Is a delivery bed available?"
	lab var s6a_1c_a_ms "Is a sterile delivery set available?"
	lab var s6a_1d_a_ms "Is a vacuum extractor available?"
	lab var s6a_1e_a_ms "Is a suction machine available?"
	lab var s6a_1f_a_ms "Is an ambu bag and mask available?"
	lab var s6a_1g_a_ms "Is a cord ligature available?"
	lab var s6a_1h_a_ms "Is there sufficient lighting?"
	lab var s6a_1i_a_ms "Are maintenance plans available for all equipment?"
	lab var s6a_2a_a_ms "Is the floor appropriately covered (e.g. ceramic tiles or terrazzo)?"
	lab var s6a_2b_a_ms "Is there a drainage system?"
	lab var s6a_2c_a_ms "Is there a cleaning chart?"
	lab var s6a_3a_a_ms "Does the labour ward have oxygen cylinder or piped oxygen connection?"
	lab var s6a_3b_a_ms "Are there standard operating procedures for oxygen?"
	lab var s6a_3c_a_ms "Is there a maintenance plan for oxygen?"
	lab var s6a_4a_a_ms "Are there procedures available for handling obstructed labour, foetal distress, eclampsia and APH/PPH/HELLP?"
	lab var s6a_4b_a_ms "Is a functional resusitaire available with oxygen, suction machine and ambu bags?"
	lab var s6a_5a_a_ms "Is an ambulance (or contact details) available?"
	lab var s6a_5b_a_ms "Is a fully equipped theatre near the labour ward?"
	lab var s6a_6a_a_ms "Is a partograph available?"
	lab var s6a_6b_a_ms "Is contraction properly charted?"
	lab var s6a_6c_a_ms "Is cervical dilation recorded?"
	lab var s6a_6d_a_ms "Is color coding done?"
	lab var s6a_6e_a_ms "Is TPR/BP recorded?"
	lab var s6a_6f_a_ms "Is urine output/input charted?"
	lab var s6a_6g_a_ms "Are drugs coded?"
	lab var s6a_7a_a_ms "Is a functional incubator available?"
	lab var s6a_7b_a_ms "Does the incubator have a temperature regulator? if incubator"
	lab var s6a_7c_a_ms "Does the incubator have an oxygen connection? if incubator"
	lab var s6a_7d_a_ms "Are maintenance plans available for the incubator? if incubator"
	lab var s6a_7e_a_ms "Is there a sitting area for nursing mothers?"
	lab var s6a_8a_a_ms "Is a sluice room with a sluicing sink available?"
	lab var s6a_8b_a_ms "Does the sluice room have running water? if sluice room"
	lab var s6a_8c_a_ms "Does it have a decontamination bucket? if sluice room"
	lab var s6a_8d_a_ms "Are standard operating procedures available? if sluice room"
	lab var s6b_1a_a_ms "Is there a hygiene protocol?"
	lab var s6b_1b_a_ms "Does the hygiene protocol have a dedicated staff roster available?"
	lab var s6b_2a_a_ms "Is a sink present with running water from a tap or modified storage container?"
	lab var s6b_2b_a_ms "Is soap available at the handwashing area?"
	lab var s6b_3a_a_ms "Are there at least two color-coded bins (red, black and/or yellow)?"
	lab var s6b_3b_a_ms "Are there coded lining bags that match the color of the bins?"
	lab var s6b_3c_a_ms "Are there standard operating procedures for waste management?"
	lab var s6b_4a_a_ms "Is there evidence of disinfectant use?"
	lab var s6b_4b_a_ms "Are you able to observe disinfectant containers used for cleaning?"
	lab var s6b_5a_a_ms "Are gloves available?"
	lab var s6b_5b_a_ms "Are gowns or dust coats available?"
	lab var s6b_5c_a_ms "Are face masks available?"
	lab var s6b_5d_a_ms "Are safety boots available?"
	lab var s7a_1a_a_ms "Are admissions procedures standardized with patient categorizations?"
	lab var s7a_1b_a_ms "Are patients in hospital uniform?"
	lab var s7a_1c_a_ms "Are there regular ward rounds?"
	lab var s7a_1d_a_ms "Are there handover and discharge reports on a standard form?"
	lab var s7a_2a_a_ms "Are patient records kept with unique reference numbers?"
	lab var s7a_2b_a_ms "Is the filing system secure?"
	lab var s7a_3a_a_ms "Does each ward have a BP machine?"
	lab var s7a_3b_a_ms "Does each ward have a thermometer?"
	lab var s7a_3c_a_ms "Does each ward have a pulse oxymeter?"
	lab var s7a_3d_a_ms "Does each ward have a suction machine?"
	lab var s7a_3e_a_ms "Does each ward have an emergency room?"
	lab var s7b_1a_a_ms "Is there a hygiene protocol?"	
	lab var s7b_1b_a_ms "Does the hygiene protocol have a dedicated staff roster available?"
	lab var s7b_2a_a_ms "Is a sink present with running water from a tap or modified storage container?"
	lab var s7b_2b_a_ms "Is soap available at the handwashing area?"
	lab var s7b_3a_a_ms "Are there at least two color-coded bins (red, black and/or yellow)?"
	lab var s7b_3b_a_ms "Are there coded lining bags that match the color of the bins?"
	lab var s7b_3c_a_ms "Are there standard operating procedures for waste management?"
	lab var s7b_4a_a_ms "Is there evidence of disinfectant use?"
	lab var s7b_4b_a_ms "Are you able to observe disinfectant containers used for cleaning?"
	lab var s7b_5a_a_ms "Are gloves available?"
	lab var s7b_5b_a_ms "Are gowns or dust coats available?"
	lab var s7b_5c_a_ms "Are face masks available?"
	lab var s7b_5d_a_ms "Are safety boots available?"
	lab var s8a_1a_a_ms "Does the receiving area have a barrier?"
	lab var s8a_1b_a_ms "Does the receiving area have a shoe rack?"
	lab var s8a_1c_a_ms "Does the receiving area have a coach?"
	lab var s8a_1d_a_ms "Does the receiving area have adequate lighting?"
	lab var s8a_2a_a_ms "Does the theatre have male and female changing rooms with barrier?"
	lab var s8a_2b_a_ms "Do changing rooms have clean clothing?"
	lab var s8a_2c_a_ms "Do changing rooms have masks?"
	lab var s8a_2d_a_ms "Do changing rooms have caps?"
	lab var s8a_2e_a_ms "Do changing rooms have theatre shoes?"
	lab var s8a_2f_a_ms "Is there a scrubbing area present?"
	lab var s8a_2g_a_ms "Is there a hands-free tap?"
	lab var s8a_2h_a_ms "Are there swinging theatre doors?"
	lab var s8a_3a_a_ms "Does the operating area have adequate space?"
	lab var s8a_3b_a_ms "Does the operating area have adequate lighting?"
	lab var s8a_3c_a_ms "Does the operating area have adequate cabinets for non-pharms?"
	lab var s8a_3d_a_ms "Does the operating area have adequate sterile gloves?"
	lab var s8a_3e_a_ms "Does the operating area have a standard operating table?"
	lab var s8a_3f_a_ms "Does the operating area have an adequate functional anaesthetic machine?"
	lab var s8a_3g_a_ms "Does the operating area have adequate ambu-bags, both adult and paediatric?"
	lab var s8a_3h_a_ms "Does the operating area have adequate monitors?"
	lab var s8a_3i_a_ms "Does the operating area have adequate laryngoscopes?"
	lab var s8a_3j_a_ms "Does the operating area have adequate endotracheal tubes?"
	lab var s8a_3k_a_ms "Does the operating room have a functioning suction machine?"
	lab var s8a_3l_a_ms "Does the operating room have adequate back-up oxygen, separate from anaesthetic "
	lab var s8a_4a_a_ms "Are there at least three nurses (scrub, runner and anaesthetic nurse)?"
	lab var s8a_4b_a_ms "Are nurses skilled with peri-operative training?"
	lab var s8a_5a_a_ms "Does the recovery room have adequate lighting?"
	lab var s8a_5b_a_ms "Does the recovery room have a monitor?"
	lab var s8a_5c_a_ms "Does the recovery room have a drip stand?"
	lab var s8b_1a_a_ms "Is there a hygiene protocol?"	
	lab var s8b_1b_a_ms "Does the hygiene protocol have a dedicated staff roster available?"
	lab var s8b_2a_a_ms "Is a sink present with running water from a tap or modified storage container?"
	lab var s8b_2b_a_ms "Is soap available at the hand washing area?"
	lab var s8b_3a_a_ms "Are there at least two color-coded bins (red, black and/or yellow)?"
	lab var s8b_3b_a_ms "Are there coded lining bags that match the color of the bins?"
	lab var s8b_3c_a_ms "Are there standard operating procedures for waste management?"
	lab var s8b_4a_a_ms "Is there evidence of disinfectant use?"
	lab var s8b_4b_a_ms "Are you able to observe disinfectant containers used for cleaning?"
	lab var s8b_5a_a_ms "Are gloves available?"
	lab var s8b_5b_a_ms "Are gowns or dust coats available?"
	lab var s8b_5c_a_ms "Are face masks available?"
	lab var s8b_5d_a_ms "Are safety boots available?"
	lab var s9a_1a_a_ms "Adequate ventilation in pharm"
	lab var s9a_2a_a_ms "Adequate lighting in pharm"	
	lab var s9a_2b_a_ms "Does the pharmacy have adequate space for staff movement in the dispensing area?"
	lab var s9b_1a_a_ms "Does the pharmacy have secure, lockable cupboards for restricted drugs only acce"
	lab var s9b_1b_a_ms "Are drugs stored and displayed to good standards?"
	lab var s9b_1c_a_ms "Are there standard operating procedures for the storage of medicines?"
	lab var s9c_1a_a_ms "Does the pharmacy have a well-explained system for recording prescriptions?"
	lab var s9c_1b_a_ms "Does the pharmacy have standard operating procedures for disposal of expired dru"
	lab var s9c_1c_a_ms "Is there a daily updated inventory system showing which commodities are availabl"
	lab var s9c_1d_a_ms "Is there documentation showing where medicines are procured?"
	lab var s9c_1e_a_ms "Are there systems for documenting and feeding back medication errors?"
	lab var s9c_1f_a_ms "Are there separate records for narcotic and psychotropic medicines?"
	lab var s9d_1a_a_ms "Does the pharmacy have reference materials for medicines (e.g. drug index)?"
	lab var s9d_1b_a_ms "Is the staff familiar with these reference materials? if materials"
	lab var s9e_1a_a_ms "Is there a hygiene protocol?"
	lab var s9e_1b_a_ms "Does the hygiene protocol have a dedicated staff roster available?"
	lab var s9e_2a_a_ms "Is a sink present with running water from a tap or modified storage container?"
	lab var s9e_2b_a_ms "Is soap available at the handwashing area?"
	lab var s9e_3a_a_ms "Are there at least two color-coded bins (red, black and/or yellow)?"
	lab var s9e_3b_a_ms "Are there coded lining bags that match the color of the bins?"
	lab var s9e_3c_a_ms "Are there standard operating procedures for waste management?"
	lab var s9e_4a_a_ms "Is there evidence of disinfectant use?"
	lab var s9e_4b_a_ms "Are you able to observe disinfectant containers used for cleaning?"
	lab var s9e_5a_a_ms "Are gloves available?"
	lab var s9e_5b_a_ms "Are gowns or dust coats available?"
	lab var s9e_5c_a_ms "Are face masks available?"
	lab var s9e_5d_a_ms "Are safety boots available?"
	lab var s10a_2a_a_ms "Does the laboratory have SOPs and guidelines for reporting lab procedures?"
	lab var s10a_2b_a_ms "Are the SOPs and guidelines for reporting lab procedures displayed? if SOPS"
	lab var s10a_3a_a_ms "Does the laboratory have SOPs and guidelines for handling, labeling and storage "
	lab var s10a_3b_a_ms "Are the SOPs and guidelines for specimens dispousal if SOPS"
	lab var s10a_4a_a_ms "Does the laboratory have SOPs and guidelines for disposal of specimens?"
	lab var s10a_4b_a_ms "Are the SOPs and guidelines for disposal of specimens displayed? if SOPS"
	lab var s10a_5a_a_ms "Does the laboratory have standard quality operational manual (SOP of SOPs) avail"
	lab var s10b_1a_a_ms "Does the lab have a system for regular calibration/validation of equipment avail"
	lab var s10b_1b_a_ms "Is the system for calibration of equipment placed close to respective if system"
	lab var s10b_2a_a_ms "Does the labo have a systematic equipment maintenance schedule?"
	lab var s10b_2b_a_ms "Are service contracts available for all lab equipment?"
	lab var s10b_3a_a_ms "Does lab have a system for equipment procurement that is known by staff?"
	lab var s10b_4a_a_ms "Does the laboratory have a list of all equipment in use?"
	lab var s10b_4b_a_ms "Does the laboratory have a functional inventory management system?"
	lab var s10c_1a_a_ms "Does lab have a records system integrated in the facility record system?"
	lab var s10d_1a_a_ms "Are equipment registered, validated and calibrated?"
	lab var s10d_1b_a_ms "Is there documentation of quality control of tests?"
	lab var s10d_1c_a_ms "Is there a documented system for regular review and improvement of lab?"
	lab var s10d_1d_a_ms "Is there documentation of sample archiving, retrieval and disposal?"
	lab var s10d_1e_a_ms "Is Internal Quality Control (IQC) done regularly?"
	lab var s10d_1f_a_ms "Is the laboratory enrolled in External Quality Assurance?"
	lab var s10d_2a_a_ms "Does the laboratory have a functional temperature recording system in place?"
	lab var s10d_2b_a_ms "Are standards for procurement and safe storage of reagents in place?"
	lab var s10e_1a_a_ms "Is there a hygiene protocol?"	
	lab var s10e_1b_a_ms "Does the hygiene protocol have a dedicated staff roster available?"
	lab var s10e_2a_a_ms "Is a sink present with running water from a tap or modified storage container?"
	lab var s10e_2b_a_ms "Is soap available at the handwashing area?"
	lab var s10e_3a_a_ms "Are there at least two color-coded bins (red, black and/or yellow)?"
	lab var s10e_3b_a_ms "Are there coded lining bags that match the color of the bins?"
	lab var s10e_3c_a_ms "Are there standard operating procedures for waste management?"
	lab var s10e_4a_a_ms "Is there evidence of disinfectant use?"
	lab var s10e_4b_a_ms "Are you able to observe disinfectant containers used for cleaning?"
	lab var s10e_5a_a_ms "Are gloves available?"
	lab var s10e_5b_a_ms "Are gowns or dust coats available?"
	lab var s10e_5c_a_ms "Are face masks available?"
	lab var s10e_5d_a_ms "Are safety boots available?"
	lab var s11a_1a_a_ms "Are personal radiation dose monitoring badges worn daily and evaluated monthly?"
	lab var s11a_2a_a_ms "Does the facility have records confirming that there is a radiation safety servi"
	lab var s11a_3a_a_ms "Is there an adequate number of lead aprons, i.e. a minimum of three: one each fo"
	lab var s11a_4a_a_ms "Is a code of practice for pregnant women available and producible?"
	lab var s11a_5a_a_ms "Is there evidence of quality assurance of the image processing system"
	lab var s11b_1a_a_ms "Are standard operating procedures available for radiology and imaging services?"
	lab var s11b_1b_a_ms "Is there evidence that they've been reviewed in the past year... if stand oper proc"
	lab var s11b_1c_a_ms "Is a code of practice displayed next to the respective device?"
	lab var s11b_2a_a_ms "Is reporting, testing and calibrating up to date and displayed?"
	lab var s11b_3a_a_ms "Is there a register of eradiating activities and a monthly dose report for worke"
	lab var s11b_4a_a_ms "Is there a quality assurance program?"
	lab var s11b_4b_a_ms "Does the quality/assurance/progr include safety patient... if quality assurance"
	lab var s11b_4c_a_ms "Is there a designated or appointed quality assurance staff member in the facilit"
	lab var s11b_4d_a_ms "Is there updated annual documentation for quality assurance procedures?"
	lab var s11c_1a_a_ms "Does the facility produce radioactive waste?"
	lab var s11c_1b_a_ms "Are patient and staff safety measures implemented alongside routine waste manage"
	lab var s11c_2a_a_ms "Is there designated staff in charge of rad. waste management? if radioactive waste"
	lab var s11c_2b_a_ms "Are there records showing that rad. waste manag. syst. are in place if radioactive waste"
	lab var s11c_3a_a_ms "Does the facility have designated personnel to oversee rad. waste managem. if radioactive waste"
	lab var s11d_1a_a_ms "Is there a hygiene protocol?"	
	lab var s11d_1b_a_ms "Does the hygiene protocol have a dedicated staff roster available?"
	lab var s11d_2a_a_ms "Is a sink present with running water from a tap or modified storage container?"
	lab var s11d_2b_a_ms "Is soap available at the handwashing area?"
	lab var s11d_3a_a_ms "Is there evidence of disinfectant use?"
	lab var s11d_3b_a_ms "Are you able to observe disinfectant containers used for cleaning?"
	lab var s11d_4a_a_ms "Are gloves available?"
	lab var s11d_4b_a_ms "Are gowns or dust coats available?"
	lab var s11d_4c_a_ms "Are face masks available?"
	lab var s11d_4d_a_ms "Are safety boots available?"
	lab var s12a_1a_a_ms "Is a functional calibrated weighing scale available?"
	lab var s12a_1b_a_ms "Is a stadiometer available?"
	lab var s12a_1c_a_ms "Are Mid-Upper Arm Circumference (MUAC) tapes available?"
	lab var s12a_1d_a_ms "Is a waist circumference tape available?"
	lab var s12a_1e_a_ms "Is a functional blood pressure machine available?"
	lab var s12a_1f_a_ms "Is a functional glucometer available?"
	lab var s12a_1g_a_ms "Are reference charts available?"
	lab var s12a_2a_a_ms "Is food store available with evidence of regular stock replenishment?"
	lab var s12a_2b_a_ms "Are ‘Ready to Use Therapeutic Foods’ (RUTF) available and accessible?"
	lab var s12a_2c_a_ms "Are ‘Ready to Use Supplementary Foods’ (RUSF) available and accessible?"
	lab var s12a_2d_a_ms "Are the F75 and F100 diet milks available and adequate for clients?"
	lab var s12a_2e_a_ms "Are food fortifiers available and acceptable?"
	lab var s12a_2f_a_ms "Are nutrition formulations for specialized nutrition support available and acces"
	lab var s12a_2g_a_ms "Are Vitamin A Supplements available for children and expectant mothers?"
	lab var s12a_2h_a_ms "Are iron supplements available in the acceptable form?"
	lab var s12a_2i_a_ms "Are folate supplements available in the acceptable form?"
	lab var s12a_2j_a_ms "Is zinc supplement available?"
	lab var s12b_1a_a_ms "Are there SOPs for comprehensive nutritional assessment?"
	lab var s12b_1b_a_ms "Are there adequate guidelines for nutritional diagnosis?"
	lab var s12b_1c_a_ms "Are there guidelines for choice of appropriate nutrition care intervention?"
	lab var s12b_1d_a_ms "Are there adequate guidelines for monitoring patient care?"
	lab var s12b_1e_a_ms "Are there adequate SOPs for food formulations?"
	lab var s12b_1f_a_ms "Are there adequate SOPs for food supplementation?"
	lab var s12b_1g_a_ms "Are SOPs reviewed and regularly updated (within a 5-year framework)?"
	lab var s12b_1h_a_ms "Are staff familiar with the SOPs and guidelines?"
	lab var s12c_1a_a_ms "Is the system for record keeping linked to the facility information management s"
	lab var s12c_1b_a_ms "Is there a designated person aware of the documentation processes?"
	lab var s12c_1c_a_ms "Is there security for the information in the system?"
	lab var s12c_1d_a_ms "Is there a documented plan for regular updating?"
	lab var s12d_1a_a_ms "Is there an inpatient feeding committee?"
	lab var s12d_1b_a_ms "Does the composition of the committee include qualified nutritionist and dietici"
	lab var s12d_1c_a_ms "Is there a comprehensive protocol for inpatient feeding?"
	lab var s12d_1d_a_ms "Is there a food inspection committee with at least one licensed nutritionist?"
	lab var s12d_1e_a_ms "Is there a communication link between patients in the ward and the food preparat"
	lab var s12d_1f_a_ms "Are there food modification schemes for groups with special needs?"
	lab var s12d_1g_a_ms "Is there an option for patients to choose from available sources of foods?"
	lab var s12d_2a_a_ms "Are postpartum mothers fed on an appropriately tailored diet?"
	lab var s12d_2b_a_ms "Is breastfeeding initiated within one hour after delivery?"
	lab var s12e_1a_a_ms "Is a functional blender available?"
	lab var s12e_1b_a_ms "Is a functional mincer available?"
	lab var s12e_1c_a_ms "Is a functional food weighing scale available and regularly calibrated?"
	lab var s12e_1d_a_ms "Are measuring jars available?"
	lab var s12e_1e_a_ms "Are food trolleys available?"
	lab var s12e_1f_a_ms "Are reliable sources of fuel available?"
	lab var s12e_2a_a_ms "Is the layout and physical structure of the kitchen adequate?"
	lab var s12e_2b_a_ms "Is a diet therapy kitchen available and separated from normal food kitchen?"
	lab var s12e_2c_a_ms "Is a mini store available in the kitchen for food from the main store?"
	lab var s12e_2d_a_ms "Does the paediatric ward have room to prepare special food?"
	lab var s12e_2e_a_ms "Is there adequate space for storage of food commodities?"
	lab var s12e_3a_a_ms "Are kitchen personnel qualified caterers and trained cooks?"
	lab var s12e_3b_a_ms "Is the supervisor qualified and licensed by the Nutritionist and Dieticians Inst"
	lab var s12f_1a_a_ms "Is there a hygiene protocol?"	
	lab var s12f_1b_a_ms "Does the hygiene protocol have a dedicated staff roster available?"
	lab var s12f_2a_a_ms "Is a sink present with running water from a tap or modified storage container?"
	lab var s12f_2b_a_ms "Is soap available at the hand washing area?"
	lab var s12f_3a_a_ms "Are there at least two color-coded bins (red, black and/or yellow)?"
	lab var s12f_3b_a_ms "Are there coded lining bags that match the color of the bins?"
	lab var s12f_3c_a_ms "Are there standard operating procedures for waste management?"
	lab var s12f_4a_a_ms "Is there evidence of disinfectant use?"
	lab var s12f_4b_a_ms "Are you able to observe disinfectant containers used for cleaning?"
	lab var s12f_5a_a_ms "Are gloves available and accessible?"
	lab var s12f_5b_a_ms "Are gowns or dust coats available and accessible?"
	lab var s12f_5c_a_ms "Are face masks available and accessible?"
	lab var s12f_5d_a_ms "Are safety boots available and accessible?"
	
	* Labeling Maxscores: level 1		
	lab var s2_a_ms "Section 2: Health Facility Infrastructure"
	lab var s3_a_ms "Section 3: General Management and Recording of Information"
	lab var s4_a_ms "Section 4: Infection Prevention and Control"
	lab var s5_a_ms "Section 5: Medical and Dental Consultation Services"
	lab var s6_a_ms "Section 6: Labour Ward"
	lab var s7_a_ms "Section 7: Medical and Pediatric Wards"
	lab var s8_a_ms "Section 8: Theatre"
	lab var s9_a_ms "Section 9: Pharmacy"
	lab var s10_a_ms "Section 10. Laboratory"
	lab var s11_a_ms "Section 11: Radiology"
	lab var s12_a_ms "Section 12: Nutrition and Dietetics Service Unit"

	* Labeling Maxscores: level 2		
	lab var s2a_a_ms "A. Building"
	lab var s2b_a_ms "B. Utilities"
	lab var s2c_a_ms "C. Security"
	lab var s3a_a_ms "A. General Management"
	lab var s3b_a_ms "B. Quality Management"
	lab var s3c_a_ms "C. Medical Records and Information Systems"
	lab var s3d_a_ms "D. Equipment Management"
	lab var s4a_a_ms "A. General"
	lab var s4b_a_ms "B. Sterilization Services"
	lab var s5a_a_ms "A. General"
	lab var s5b_a_ms "B. Infection prevention and control"
	lab var s6a_a_ms "A. General"
	lab var s6b_a_ms "B. Infection prevention and control"
	lab var s7a_a_ms "A. General"
	lab var s7b_a_ms "B. Infection prevention and control"
	lab var s8a_a_ms "A. General"
	lab var s8b_a_ms "B. Infection prevention and control"
	lab var s9a_a_ms "A. General condition of premises"
	lab var s9b_a_ms "B.  Storage and display of commodities "
	lab var s9c_a_ms "C.  Record keeping and documentation "
	lab var s9d_a_ms "D. Reference materials and policies"
	lab var s9e_a_ms "E. Infection prevention and control"
	lab var s10a_a_ms "A. Policies, guidelines and SOPs "
	lab var s10b_a_ms "B. Equipment management program "
	lab var s10c_a_ms "C. Record keeping and documentation "
	lab var s10d_a_ms "D. Quality control of tests "
	lab var s10e_a_ms "E. Infection prevention and control"
	lab var s11a_a_ms "A. Radiation protection"
	lab var s11b_a_ms "B. Policies, SOPs and registers "
	lab var s11c_a_ms "C. Radioactive waste management "
	lab var s11d_a_ms "D. Infection prevention and control"
	lab var s12a_a_ms "A. Nutrition equipment, Tools and Supplies "
	lab var s12b_a_ms "B. SOPs for nutrition care processes and other services  "
	lab var s12c_a_ms "C. Record keeping and documentation"
	lab var s12d_a_ms "D. Patient feeding "
	lab var s12e_a_ms "E. Food Preparation Unit"
	lab var s12f_a_ms "F. Infection prevention and control"

	* Labeling Maxscores: level 3
	lab var s2a_1_a_ms "1. Signage and accessibility"
	lab var s2a_2_a_ms "2. Ventilation"
	lab var s2a_3_a_ms "3. Lighting "
	lab var s2b_1_a_ms "1. Water"
	lab var s2b_2_a_ms "2. Electricity"
	lab var s2b_3_a_ms "3. Toilet facilities"
	lab var s2c_1_a_ms "1. Lockable door"
	lab var s2c_2_a_ms "2. Fire control mechanism"
	lab var s2c_3_a_ms "3. Fire assembly point"
	lab var s2c_4_a_ms "4. Security"
	lab var s3a_1_a_ms "1. Strategic Plan"
	lab var s3a_2_a_ms "2. Client Service Charter"
	lab var s3a_3_a_ms "3. List of staff"
	lab var s3b_2_a_ms "2. Monitoring performance indicators"
	lab var s3b_3_a_ms "3. Client feedback mechanism"
	lab var s3c_1_a_ms "1. Medical records for each patient"
	lab var s3c_2_a_ms "2. Approved register for all patients"
	lab var s3c_3_a_ms "3. System for storing medical records"
	lab var s3c_5_a_ms "5. Contribution to external databases and reports"
	lab var s3d_1_a_ms "1. Preventative maintenance plan for equipment"
	lab var s3d_2_a_ms "2. Calibration and validation"
	lab var s4a_1_a_ms "1. Hygiene protocol"
	lab var s4a_2_a_ms "2. Solid waste management"
	lab var s4a_3_a_ms "3. General facility cleanliness"
	lab var s4a_4_a_ms "4. General compound cleanliness"
	lab var s4b_1_a_ms "1. Central Supply Unit"
	lab var s5a_1_a_ms "1. Triage"
	lab var s5a_2_a_ms "2. Examination room"
	lab var s5a_3_a_ms "3. Examination equipment"
	lab var s5a_4_a_ms "4. Emergency tray and equipment"
	lab var s5b_1_a_ms "1. Hygiene protocol"
	lab var s5b_2_a_ms "2. Hand washing"
	lab var s5b_3_a_ms "3. Solid waste management"
	lab var s5b_4_a_ms "4. Use of disinfectants"
	lab var s5b_5_a_ms "5. Protective equipment"
	lab var s6a_1_a_ms "1. Labour ward"
	lab var s6a_2_a_ms "2. Labour room floor"
	lab var s6a_3_a_ms "3. Oxygen source"
	lab var s6a_4_a_ms "4. Procedures for obstetrics emergency"
	lab var s6a_5_a_ms "5. Access to theatre"
	lab var s6a_6_a_ms "6. Procedure for monitoring labour"
	lab var s6a_7_a_ms "7. New born unit"
	lab var s6a_8_a_ms "8. Sluice room"
	lab var s6b_1_a_ms "1. Hygiene protocol"
	lab var s6b_2_a_ms "2. Hand washing"
	lab var s6b_3_a_ms "3. Solid waste management"
	lab var s6b_4_a_ms "4. Use of disinfectants"
	lab var s6b_5_a_ms "5. Protective equipment"
	lab var s7a_1_a_ms "1. Patient oversight "
	lab var s7a_2_a_ms "2. Patient records"
	lab var s7a_3_a_ms "3. Monitoring equipment "
	lab var s7b_1_a_ms "1. Hygiene protocol"
	lab var s7b_2_a_ms "2. Hand washing"
	lab var s7b_3_a_ms "3. Solid waste management"
	lab var s7b_4_a_ms "4. Use of disinfectants"
	lab var s7b_5_a_ms "5. Protective equipment"
	lab var s8a_1_a_ms "1. Receiving area "
	lab var s8a_2_a_ms "2. Changing rooms and scrubbing area "
	lab var s8a_3_a_ms "3. Operating area "
	lab var s8a_4_a_ms "4. Staff requirements "
	lab var s8a_5_a_ms "5. Recovery room"
	lab var s8b_1_a_ms "1. Hygiene protocol"
	lab var s8b_2_a_ms "2. Hand washing"
	lab var s8b_3_a_ms "3. Solid waste management"
	lab var s8b_4_a_ms "4. Use of disinfectants"
	lab var s8b_5_a_ms "5. Protective equipment"
	lab var s9a_1_a_ms "1. Ventilation"
	lab var s9a_2_a_ms "2. Lighting "
	lab var s9b_1_a_ms "1. Storage and display of commodities"
	lab var s9c_1_a_ms "1 Record keeping and documentation"	
	lab var s9d_1_a_ms "1 Reference materials and policies"
	lab var s9e_1_a_ms "1. Hygiene protocol"
	lab var s9e_2_a_ms "2. Hand washing"
	lab var s9e_3_a_ms "3. Solid waste management"
	lab var s9e_4_a_ms "4. Use of disinfectants"
	lab var s9e_5_a_ms "5. Protective equipment"
	lab var s10a_2_a_ms "2. Reporting procedures"
	lab var s10a_3_a_ms "3. Handling, labeling and storage of specimen"
	lab var s10a_4_a_ms "4. Disposal of specimens"
	lab var s10a_5_a_ms "5. Standard quality operational manual "
	lab var s10b_1_a_ms "1. Calibration and validation of equipment"
	lab var s10b_2_a_ms "2. Equipment maintenance documentation"
	lab var s10b_3_a_ms "3. System for procurement of equipment"
	lab var s10b_4_a_ms "4. Inventory of equipment"
	lab var s10c_1_a_ms "1 Record keeping and documentation"
	lab var s10d_1_a_ms "1. Quality control practices"
	lab var s10d_2_a_ms "2. Procurement and storage of reagents"
	lab var s10e_1_a_ms "1. Hygiene protocol"
	lab var s10e_2_a_ms "2. Hand washing"
	lab var s10e_3_a_ms "3. Solid waste management"
	lab var s10e_4_a_ms "4. Use of disinfectants"
	lab var s10e_5_a_ms "5. Protective equipment"
	lab var s11a_1_a_ms "1. Personal radiation dose monitoring"
	lab var s11a_2_a_ms "2. Radiation safety service provider "
	lab var s11a_3_a_ms "3. Adequate number of lead aprons "
	lab var s11a_4_a_ms "4. Radiological examination in pregnancy "
	lab var s11a_5_a_ms "5. Quality assurance of image processing"
	lab var s11b_1_a_ms "1. Policies, SOPs and code of practice"
	lab var s11b_2_a_ms "2. Reporting, testing and calibration "
	lab var s11b_3_a_ms "3. Register of eradiating activities "
	lab var s11b_4_a_ms "4. Quality assurance program"
	lab var s11c_1_a_ms "1. Personal safety measures "
	lab var s11c_2_a_ms "2. Radioactive waste management programs in place "
	lab var s11c_3_a_ms "3. Designated staff for radioactive waste management programs "
	lab var s11d_1_a_ms "1. Hygiene protocol"
	lab var s11d_2_a_ms "2. Hand washing"
	lab var s11d_3_a_ms "3. Use of disinfectants"
	lab var s11d_4_a_ms "4. Protective equipment"
	lab var s12a_1_a_ms "1. Nutrition equipment and tools "
	lab var s12a_2_a_ms "2. Food supplies, formulations and Nutrition supplements "
	lab var s12b_1_a_ms "1 SOPs for nutrition car processes and other services"
	lab var s12c_1_a_ms "2 Record keeping and documentation"
	lab var s12d_1_a_ms "1. Inpatient feeding"
	lab var s12d_2_a_ms "2. Maternity feeding "
	lab var s12e_1_a_ms "1. Kitchen equipment and fuel"
	lab var s12e_2_a_ms "2. Food Preparation Unit layout"
	lab var s12e_3_a_ms "3. Kitchen personnel"
	lab var s12f_1_a_ms "1 Hygiene protocol"
	lab var s12f_2_a_ms "2. Hand washing"
	lab var s12f_3_a_ms "3. Solid waste management"
	lab var s12f_4_a_ms "4. Use of disinfectants"
	lab var s12f_5_a_ms "5. Protective equipment"
	
*^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
	** Scores: Level 4 
*^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
	foreach x in a b c d e f {	
		forvalues r = 1(1)8 {
			forvalues i=1(1)8 {
				forvalues j=1(1)12 {			
					foreach var in `s`j'`x'_`i'_a' {
						if `i' == `r' {
							capture gen `var'_os = (s`j'`x'_`r'_a_ms/s`j'`x'_`r'_a_count)*(`var')
							capture replace s`j'`x'_`r'_a_count = . if s`j'`x'_`r'_a_ms == .

								if _rc!=0 {
									display "`var'_score problem"			  
								} 
						}	
					}
					else {
					}
					
				}
			}
		}	
	}
	
	** Scores for especial questions
	replace s2a_2a_a_os = 0 if s2a_2a1_a == 0
	replace s2a_2a_a_os = 10/3 if s2a_2a2_a == 1/3
	replace s2a_2a_a_os = 20/3 if s2a_2a3_a == 2/3
	replace s2a_2a_a_os = 10 if s2a_2a4_a == 1

	replace s2a_3a_a_os = 0 if s2a_3a1_a == 0
	replace s2a_3a_a_os = 10/3 if s2a_3a2_a == 1/3
	replace s2a_3a_a_os = 20/3 if s2a_3a3_a == 2/3
	replace s2a_3a_a_os = 10 if s2a_3a4_a == 1

	replace s9a_1a_a_os = 0 if s9a_1a1_a == 0
	replace s9a_1a_a_os = 10/3 if s9a_1a2_a == 1/3
	replace s9a_1a_a_os = 20/3 if s9a_1a3_a == 2/3
	replace s9a_1a_a_os = 10 if s9a_1a4_a == 1
	
	replace s4a_3a_a_os = 0 if s4a_3a1_a == 0
	replace s4a_3a_a_os = 5/3 if s4a_3a2_a == 5/30
	replace s4a_3a_a_os = 10/3 if s4a_3a3_a == 1/3
	replace s4a_3a_a_os = 5 if s4a_3a4_a == 1
	
	replace s9a_2a_a_os = 0 if s9a_2a1_a == 0
	replace s9a_2a_a_os = 5/3 if s9a_2a2_a == 5/30
	replace s9a_2a_a_os = 10/3 if s9a_2a3_a == 1/3
	replace s9a_2a_a_os = 5 if s9a_2a4_a == 1

	/*replace s2a_2a_a_os = s2a_2a_a* s2a_2a_a_ms // We can also think about this score as the sum of: s2a_2a1_a_os + s2a_2a2_a_os + s2a_2a3_a_os s2a_2a4_a_os+
	replace s2a_3a_a_os = s2a_3a_a* s2a_3a_a_ms
	replace s9a_1a_a_os = s9a_1a_a* s9a_1a_a_ms
	replace s4a_3a_a_os = s4a_3a_a* s4a_3a_a_ms
	replace s9a_2a_a_os = s9a_2a_a* s9a_2a_a_ms */

	** General compound cleanliness special question	
	replace s4a_4c_a_os = s4a_4c_a_ms if s4a_4a_a == . & s4a_4b_a == .
	replace s4a_4c_a_os = s4a_4c_a_ms if (s4a_4a_a == . & s4a_4b_a == 1) | (s4a_4a_a == 1 & s4a_4b_a == .)
	replace s4a_4a_a_os = s4a_4a_a_ms if s4a_4a_a == 1 
	replace s4a_4b_a_os = s4a_4b_a_ms if s4a_4b_a == 1 
	
	* s2c_3a: 16 observations missing because HFs didn't answer both questions in QPS2: s1c_5 & s1c_6. We can't say anything about the missings.
	replace s2c_3a_a_os = . if s2c_3a_a == . & level >= 4 
	replace s2c_3b_a_os = 1.25 if s2c_3a_a == . & level >= 4 & s2c_3b_a == 1
	replace s2c_3c_a_os = 1.25 if s2c_3a_a == . & level >= 4 & s2c_3c_a == 1
	replace s2c_3d_a_os = 1.25 if s2c_3a_a == . & level >= 4 & s2c_3d_a == 1
	
	replace s2c_3a_a_os = . if s2c_3a_a == . & level < 4 
	replace s2c_3b_a_os = 5/3 if s2c_3a_a == . & level < 4 & s2c_3b_a == 1
	replace s2c_3c_a_os = 5/3 if s2c_3a_a == . & level < 4 & s2c_3c_a == 1
	
	** Radiology section: No points if the HF does not produce radioactive waste
	replace s11c_1b_a_os = . if s11c_1a_a == 0
	replace s11c_2a_a_os = . if s11c_1a_a == 0
	replace s11c_2b_a_os = . if s11c_1a_a == 0
	replace s11c_3a_a_os = . if s11c_1a_a == 0
		
	** Checking :)
	//br s4a_4a_a s4a_4a_a_ms s4a_4a_a_os s4a_4b_a s4a_4b_a_ms s4a_4b_a_os s4a_4c_a s4a_4c_a_ms s4a_4c_a_os
	//br s4a_4a_a s4a_4a_a_ms s4a_4a_a_os s4a_4b_a s4a_4b_a_ms s4a_4b_a_os s4a_4c_a s4a_4c_a_ms s4a_4c_a_os	
	//br s2a_1a_a s2a_1b_a s2a_1c_a s2a_1d_a s2a_1e_a s2a_1_a_ms s2a_1_a_count  s2a_1a_a_os s2a_1b_a_os s2a_1c_a_os s2a_1d_a_os s2a_1e_a_os
	//br s2a_1a_a s2a_1b_a s2a_1c_a s2a_1d_a s2a_1e_a s2a_1_a_ms s2a_1_a_count  s2a_1a_a_os s2a_1b_a_os s2a_1c_a_os s2a_1d_a_os s2a_1e_a_os
	
*^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
	** Scores: Level 3
*^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^

	** Creating locals and globals for the scores

	* S2: HF Infrastructure 

	* A. Building
	local s2a_1_a_os	s2a_1a_a_os s2a_1b_a_os s2a_1c_a_os s2a_1d_a_os s2a_1e_a_os
	local s2a_2_a_os	s2a_2a_a_os	
	local s2a_3_a_os	s2a_3a_a_os
	
	* B. Utilities
	local s2b_1_a_os	s2b_1a_a_os s2b_1b_a_os
	local s2b_2_a_os	s2b_2a_a_os	
	local s2b_3_a_os	s2b_3a_a_os s2b_3b_a_os
		
	* C. Security
	local s2c_1_a_os s2c_1a_a_os s2c_1b_a_os		
	local s2c_2_a_os s2c_2a_a_os s2c_2b_a_os		
	local s2c_3_a_os s2c_3a_a_os s2c_3b_a_os s2c_3c_a_os s2c_3d_a_os
	local s2c_4_a_os s2c_4a_a_os			
		
	local s2_a_os `s2a_1_a_os' `s2a_2_a_os' `s2a_3_a_os' `s2b_1_a_os' `s2b_2_a_os' `s2b_3_a_os' `s2c_1_a_os' `s2c_2_a_os' `s2c_3_a_os' `s2c_4_a_os'
		
* S3: General Management and Recording of Information

	* A. General Management 
	local s3a_1_a_os s3a_1a_a_os s3a_1b_a_os s3a_1c_a_os s3a_1d_a_os			
	local s3a_2_a_os s3a_2a_a_os s3a_2b_a_os s3a_2c_a_os s3a_2d_a_os s3a_2e_a_os s3a_2f_a_os s3a_2g_a_os s3a_2h_a_os 
	local s3a_3_a_os s3a_3a_a_os //  s3a_3b_a_os	is not included because in QPS1/2 we didn't ask for certifications
	
	* B. Quality management
	//local s3b_1_a_os s3b_1a s3b_1b_a_os	// Not scored questions
	local s3b_2_a_os s3b_2a_a_os	s3b_2b_a_os s3b_2c_a_os	s3b_2d_a_os s3b_2e_a_os
	local s3b_3_a_os s3b_3a_a_os s3b_3b_a_os s3b_3c_a_os		
	
	* C. Medical records and information systems
	local s3c_1_a_os s3c_1a_a_os s3c_1b_a_os	s3c_1c_a_os	
	local s3c_2_a_os s3c_2a_a_os s3c_2b_a_os	s3c_2c_a_os s3c_2d_a_os
	local s3c_3_a_os s3c_3a_a_os s3c_3b_a_os	s3c_3c_a_os	
	//local s3c_4_a_os s3c_4a_a_os s3c_4b_a_os	// Not scored questions
						
	local s3c_5_a_os s3c_5a_a_os 			
	
	* D. Equipment management
	local s3d_1_a_os s3d_1a_a_os s3d_1b_a_os	
	local s3d_2_a_os s3d_2a_a_os s3d_2b_a_os	s3d_2c_a_os
	
	local s3_a_os `s3a_1_a_os' `s3a_2_a_os' `s3a_3_a_os' `s3b_1_a_os' `s3b_2_a_os' `s3b_3_a_os' `s3c_1_a_os' `s3c_2_a_os' `s3c_3_a_os' `s3c_4_a_os' `s3c_5_a_os' `s3d_1_a_os' `s3d_2_a_os'
					
* S4: (Infection Prevention and Control)
		
	* A. General
	local s4a_1_a_os s4a_1a_a_os s4a_1b_a_os					
	local s4a_2_a_os s4a_2a_a_os s4a_2b_a_os	s4a_2c_a_os				
	local s4a_3_a_os s4a_3a_a_os s4a_3b_a_os s4a_3c_a_os s4a_3d_a_os
	local s4a_4_a_os s4a_4a_a_os s4a_4b_a_os	s4a_4c_a_os				
	
	* B. Sterilization Services
	local s4b_1_a_os s4b_1a_a_os s4b_1b_a_os	s4b_1c_a_os s4b_1d_a_os	
	local s4_a_os `s4a_1_a_os' `s4a_2_a_os' `s4a_3_a_os' `s4a_4_a_os' `s4b_1_a_os'
	
* S5: Medical and Dental Consultation Services 

	* A. General
	local s5a_1_a_os s5a_1a_a_os	s5a_1b_a_os s5a_1c_a_os s5a_1d_a_os								
	local s5a_2_a_os s5a_2a_a_os	s5a_2b_a_os s5a_2c_a_os									
	local s5a_3_a_os s5a_3a_a_os	s5a_3b_a_os s5a_3c_a_os s5a_3d_a_os s5a_3e_a_os	s5a_3f_a_os s5a_3g_a_os s5a_3h_a_os s5a_3i_a_os			
	local s5a_4_a_os s5a_4a_a_os	s5a_4b_a_os s5a_4c_a_os s5a_4d_a_os s5a_4e_a_os s5a_4f_a_os s5a_4g_a_os	s5a_4h_a_os s5a_4i_a_os	s5a_4j_a_os s5a_4k_a_os	s5a_4l_a_os

	* B. IPC
	local s5b_1_a_os s5b_1a_a_os s5b_1b_a_os
	local s5b_2_a_os s5b_2a_a_os s5b_2b_a_os		
	local s5b_3_a_os s5b_3a_a_os s5b_3b_a_os s5b_3c_a_os	
	local s5b_4_a_os s5b_4a_a_os s5b_4b_a_os		
	local s5b_5_a_os s5b_5a_a_os s5b_5b_a_os s5b_5c_a_os s5b_5d_a_os
	
	local s5_a_os `s5a_1_a_os' `s5a_2_a_os' `s5a_3_a_os' `s5a_4_a_os' `s5b_1_a_os' `s5b_2_a_os' `s5b_3_a_os' `s5b_4_a_os' `s5b_5_a_os'

* S6: Labour Ward 

	local s6a_1_a_os s6a_1a_a_os	s6a_1b_a_os s6a_1c_a_os s6a_1d_a_os s6a_1e_a_os s6a_1f_a_os s6a_1g_a_os s6a_1h_a_os s6a_1i_a_os
	local s6a_2_a_os s6a_2a_a_os	s6a_2b_a_os s6a_2c_a_os						
	local s6a_3_a_os s6a_3a_a_os	s6a_3b_a_os s6a_3c_a_os						
	local s6a_4_a_os s6a_4a_a_os	s6a_4b_a_os							
	local s6a_5_a_os s6a_5a_a_os	s6a_5b_a_os							
	local s6a_6_a_os s6a_6a_a_os	s6a_6b_a_os s6a_6c_a_os	s6a_6d_a_os s6a_6e_a_os	s6a_6f_a_os s6a_6g_a_os 		
	local s6a_7_a_os s6a_7a_a_os	s6a_7b_a_os s6a_7c_a_os s6a_7d_a_os s6a_7e_a_os				
	local s6a_8_a_os s6a_8a_a_os	s6a_8b_a_os s6a_8c_a_os s6a_8d_a_os		
	
	* B. IPC	
	local s6b_1_a_os s6b_1a_a_os    s6b_1b_a_os			
	local s6b_2_a_os s6b_2a_a_os	s6b_2b_a_os		
	local s6b_3_a_os s6b_3a_a_os	s6b_3b_a_os s6b_3c_a_os	
	local s6b_4_a_os s6b_4a_a_os	s6b_4b_a_os		
	local s6b_5_a_os s6b_5a_a_os	s6b_5b_a_os s6b_5c_a_os s6b_5d_a_os
	
	local s6_a_os `s6a_1_a_os' `s6a_2_a_os' `s6a_3_a_os' `s6a_4_a_os' `s6a_5_a_os' `s6a_6_a_os' `s6a_7_a_os' `s6a_8_a_os' `s6b_1_a_os' `s6b_2_a_os' `s6b_3_a_os' `s6b_4_a_os' `s6b_5_a_os'

* S7: Medical and Pediatric Wards 
	
	* A. General
	local s7a_1_a_os s7a_1a_a_os	s7a_1b_a_os s7a_1c_a_os s7a_1d_a_os		
	local s7a_2_a_os s7a_2a_a_os	s7a_2b_a_os				
	local s7a_3_a_os s7a_3a_a_os	s7a_3b_a_os s7a_3c_a_os s7a_3d_a_os	s7a_3e_a_os
	
	* B. IPC	
	local s7b_1_a_os s7b_1a_a_os	s7b_1b_a_os		
	local s7b_2_a_os s7b_2a_a_os	s7b_2b_a_os		
	local s7b_3_a_os s7b_3a_a_os	s7b_3b_a_os s7b_3c_a_os	
	local s7b_4_a_os s7b_4a_a_os	s7b_4b_a_os		
	local s7b_5_a_os s7b_5a_a_os	s7b_5b_a_os s7b_5c_a_os s7b_5d_a_os
	
	local s7_a_os `s7a_1_a_os' `s7a_2_a_os' `s7a_3_a_os' `s7b_1_a_os' `s7b_2_a_os' `s7b_3_a_os' `s7b_4_a_os' `s7b_5_a_os'

* S8: Theatre 
	
	* A. General
	local	s8a_1_a_os	s8a_1a_a_os	s8a_1b_a_os	s8a_1c_a_os	s8a_1d_a_os								
	local	s8a_2_a_os	s8a_2a_a_os	s8a_2b_a_os	s8a_2c_a_os	s8a_2d_a_os	s8a_2e_a_os	s8a_2f_a_os	s8a_2g_a_os	s8a_2h_a_os				
	local	s8a_3_a_os	s8a_3a_a_os	s8a_3b_a_os	s8a_3c_a_os	s8a_3d_a_os	s8a_3e_a_os	s8a_3f_a_os	s8a_3g_a_os	s8a_3h_a_os	s8a_3i_a_os	s8a_3j_a_os	s8a_3k_a_os	s8a_3l_a_os
	local	s8a_4_a_os	s8a_4a_a_os	s8a_4b_a_os										
	local	s8a_5_a_os	s8a_5a_a_os	s8a_5b_a_os	s8a_5c_a_os											
	
	* B. IPC	
	local	s8b_1_a_os	s8b_1a_a_os 	s8b_1b_a_os			
	local	s8b_2_a_os	s8b_2a_a_os	s8b_2b_a_os		
	local	s8b_3_a_os	s8b_3a_a_os	s8b_3b_a_os	s8b_3c_a_os	
	local	s8b_4_a_os	s8b_4a_a_os	s8b_4b_a_os		
	local	s8b_5_a_os	s8b_5a_a_os	s8b_5b_a_os	s8b_5c_a_os	s8b_5d_a_os					
 
	local s8_a_os `s8a_1_a_os' `s8a_2_a_os' `s8a_3_a_os' `s8a_4_a_os' `s8a_5_a_os' `s8b_1_a_os' `s8b_2_a_os' `s8b_3_a_os' `s8b_4_a_os' `s8b_5_a_os'
	
* S9: Pharmacy 

	* A. General condition of permises	
	local	s9a_1_a_os	s9a_1a_a_os	
	local	s9a_2_a_os	s9a_2a_a_os	s9a_2b_a_os

	* B. Storage and display of commodities
	local	s9b_1_a_os	s9b_1a_a_os s9b_1b_a_os s9b_1c_a_os
	
	* C. Record keeping and documentation
	local	s9c_1_a_os	s9c_1a_a_os s9c_1b_a_os s9c_1c_a_os s9c_1d_a_os s9c_1e_a_os s9c_1f_a_os 
	
	* D. Reference and materials and policies
	local	s9d_1_a_os	s9d_1a_a_os s9d_1b_a_os
	
	* E. IPC
	local	s9e_1_a_os	s9e_1a_a_os s9e_1b_a_os			
	local	s9e_2_a_os	s9e_2a_a_os	s9e_2b_a_os		
	local	s9e_3_a_os	s9e_3a_a_os	s9e_3b_a_os	s9e_3c_a_os	
	local	s9e_4_a_os	s9e_4a_a_os	s9e_4b_a_os		
	local	s9e_5_a_os	s9e_5a_a_os	s9e_5b_a_os	s9e_5c_a_os	s9e_5d_a_os

	local s9_a_os `s9a_1_a_os' `s9a_2_a_os' `s9b_1_a_os' `s9c_1_a_os'  `s9d_1_a_os'  `s9e_1_a_os' `s9e_2_a_os' `s9e_3_a_os' `s9e_4_a_os' `s9e_5_a_os'
	
* S10: Laboratory 

	* A. Policies, guidelines, and SOPs
	** S10a_1 is not included because QPS1/2 didn't ask for licenses. 
	local	s10a_2_a_os	s10a_2a_a_os	s10a_2b_a_os
	local	s10a_3_a_os	s10a_3a_a_os	s10a_3b_a_os
	local	s10a_4_a_os	s10a_4a_a_os	s10a_4b_a_os
	local	s10a_5_a_os	s10a_5a_a_os	
		
	* B. Equipment management program
	local	s10b_1_a_os	s10b_1a_a_os	s10b_1b_a_os	
	local	s10b_2_a_os	s10b_2a_a_os	s10b_2b_a_os	
	local	s10b_3_a_os	s10b_3a_a_os		
	local	s10b_4_a_os	s10b_4a_a_os	s10b_4b_a_os	
		
	* C. Record keeping and documentation
	local 	s10c_1_a_os s10c_1a_a_os
		
	* D. Quality control of tests
	local	s10d_1_a_os	s10d_1a_a_os	s10d_1b_a_os	s10d_1c_a_os	s10d_1d_a_os	s10d_1e_a_os	s10d_1f_a_os
	local	s10d_2_a_os	s10d_2a_a_os	s10d_2b_a_os				
		
	* E. IPC
	local	s10e_1_a_os	s10e_1a_a_os s10e_1b_a_os			
	local	s10e_2_a_os	s10e_2a_a_os	s10e_2b_a_os		
	local	s10e_3_a_os	s10e_3a_a_os	s10e_3b_a_os	s10e_3c_a_os	
	local	s10e_4_a_os	s10e_4a_a_os	s10e_4b_a_os		
	local	s10e_5_a_os	s10e_5a_a_os	s10e_5b_a_os	s10e_5c_a_os	s10e_5d_a_os	

	local s10_a_os `s10a_1_a_os' `s10a_2_a_os' `s10a_3_a_os' `s10a_4_a_os' `s10a_5_a_os' `s10b_1_a_os' `s10b_2_a_os' `s10b_3_a_os' `s10b_4_a_os' `s10c_1_a_os' `s10d_1_a_os' `s10d_2_a_os' `s10e_1_a_os' `s10e_2_a_os' `s10e_3_a_os' `s10e_4_a_os' `s10e_5_a_os'
	
* S11: Radiology 

	* A. Radiation protection
	local	s11a_1_a_os	s11a_1a_a_os
	local	s11a_2_a_os	s11a_2a_a_os
	local	s11a_3_a_os	s11a_3a_a_os
	local	s11a_4_a_os	s11a_4a_a_os
	local	s11a_5_a_os	s11a_5a_a_os
	
	* B. Policies, SOPs, and registers
	local	s11b_1_a_os	s11b_1a_a_os	s11b_1b_a_os	s11b_1c_a_os	
	local	s11b_2_a_os	s11b_2a_a_os			
	local	s11b_3_a_os	s11b_3a_a_os			
	local	s11b_4_a_os	s11b_4a_a_os	s11b_4b_a_os	s11b_4c_a_os	s11b_4d_a_os
	
	* C. Radioactive waste management
	local	s11c_1_a_os	s11c_1a_a_os	s11c_1b_a_os
	local	s11c_2_a_os	s11c_2a_a_os	s11c_2b_a_os
	local	s11c_3_a_os	s11c_3a_a_os			
	
	* D. IPC	
	local	s11d_1_a_os	s11d_1a_a_os 	s11d_1b_a_os			
	local	s11d_2_a_os	s11d_2a_a_os	s11d_2b_a_os		
	local	s11d_3_a_os	s11d_3a_a_os	s11d_3b_a_os		
	local	s11d_4_a_os	s11d_4a_a_os	s11d_4b_a_os	s11d_4c_a_os	s11d_4d_a_os
	
	local s11_a_os `s11a_1_a_os' `s11a_2_a_os' `s11a_3_a_os' `s11a_4_a_os' `s11a_5_a_os' `s11b_1_a_os' `s11b_2_a_os' `s11b_3_a_os' `s11b_4_a_os' `s11c_1_a_os' `s11c_2_a_os' `s11c_3_a_os' `s11d_1_a_os' `s11d_2_a_os' `s11d_3_a_os' `s11d_4_a_os'
	
* S12: Nutrition 

	* A. Nutrition equipment, tools and supplies
	local	s12a_1_a_os	s12a_1a_a_os	s12a_1b_a_os	s12a_1c_a_os	s12a_1d_a_os	s12a_1e_a_os	s12a_1f_a_os	s12a_1g_a_os			
	local	s12a_2_a_os	s12a_2a_a_os	s12a_2b_a_os	s12a_2c_a_os	s12a_2d_a_os	s12a_2e_a_os	s12a_2f_a_os	s12a_2g_a_os	s12a_2h_a_os	s12a_2i_a_os	s12a_2j_a_os
	
	* B. SOPs for nutrition care processes and other services	
	local	s12b_1_a_os	s12b_1a_a_os	s12b_1b_a_os	s12b_1c_a_os	s12b_1d_a_os	s12b_1e_a_os	s12b_1f_a_os	s12b_1g_a_os	s12b_1h_a_os		

	* C. Record keeping and documentation
	local	s12c_1_a_os	s12c_1a_a_os	s12c_1b_a_os	s12c_1c_a_os	s12c_1d_a_os					
	
	* D. Patient feeding
	local	s12d_1_a_os	s12d_1a_a_os	s12d_1b_a_os	s12d_1c_a_os	s12d_1d_a_os	s12d_1e_a_os	s12d_1f_a_os	s12d_1g_a_os
	local	s12d_2_a_os	s12d_2a_a_os	s12d_2b_a_os										

	* E. Food preparation unit
	local	s12e_1_a_os	s12e_1a_a_os	s12e_1b_a_os	s12e_1c_a_os	s12e_1d_a_os	s12e_1e_a_os	s12e_1f_a_os
	local	s12e_2_a_os	s12e_2a_a_os	s12e_2b_a_os	s12e_2c_a_os	s12e_2d_a_os	s12e_2e_a_os	
	local	s12e_3_a_os	s12e_3a_a_os	s12e_3b_a_os									
	
	* F. IPC	
	local	s12f_1_a_os	s12f_1a_a_os   s12f_1b_a_os			
	local	s12f_2_a_os	s12f_2a_a_os	s12f_2b_a_os		
	local	s12f_3_a_os	s12f_3a_a_os	s12f_3b_a_os	s12f_3c_a_os	
	local	s12f_4_a_os	s12f_4a_a_os	s12f_4b_a_os		
	local	s12f_5_a_os	s12f_5a_a_os	s12f_5b_a_os	s12f_5c_a_os	s12f_5d_a_os

	local s12_a_os `s12a_1_a_os' `s12a_2_a_os' `s12b_1_a_os' `s12c_1_a_os' `s12d_1_a_os' `s12d_2_a_os' `s12e_1_a_os' `s12e_2_a_os' `s12e_3_a_os' `s12f_1_a_os' `s12f_2_a_os' `s12f_3_a_os' `s12f_4_a_os' `s12f_5_a_os'
	
	local	L3	s2a_1	s2a_2	s2a_3	s2b_1	s2b_2	s2b_3	s2c_1	s2c_2	s2c_3	s2c_4	s3a_1	s3a_2	s3a_3	s3b_1	s3b_2	s3b_3	s3c_1	s3c_2	s3c_3	s3c_4	s3c_5	s3d_1	s3d_2	s4a_1	s4a_2	s4a_3	s4a_4	s4b_1	s5a_1	s5a_2	s5a_3	s5a_4	s5b_1	s5b_2	s5b_3	s5b_4	s5b_5	s6a_1	s6a_2	s6a_3	s6a_4	s6a_5	s6a_6	s6a_7	s6a_8	s6b_1	s6b_2	s6b_3	s6b_4	s6b_5	s7a_1	s7a_2	s7a_3	s7b_1	s7b_2	s7b_3	s7b_4	s7b_5	s8a_1	s8a_2	s8a_3	s8a_4	s8a_5	s8b_1	s8b_2	s8b_3	s8b_4	s8b_5	s9a_1	s9a_2	s9b_1 s9c_1 s9d_1 s9e_1	s9e_2	s9e_3	s9e_4	s9e_5	s10a_1	s10a_2	s10a_3	s10a_4	s10a_5	s10b_1	s10b_2	s10b_3	s10b_4	s10c_1 s10d_1	s10d_2	s10e_1	s10e_2	s10e_3	s10e_4	s10e_5	s11a_1	s11a_2	s11a_3	s11a_4	s11a_5	s11b_1	s11b_2	s11b_3	s11b_4	s11c_1	s11c_2	s11c_3	s11d_1	s11d_2	s11d_3	s11d_4	s12a_1	s12a_2	s12b_1 s12c_1 s12d_1 s12d_2	s12e_1	s12e_2	s12e_3	s12f_1	s12f_2	s12f_3	s12f_4	s12f_5
	
	//global L4_a_os 	$s2_a_os $s3_a_os $s4_a_os $s5_a_os $s6_a_os $s7_a_os $s8_a_os $s9_a_os $s10_a_os $s11_a_os $s12_a_os


	foreach var in `L3' {
		capture egen `var'_a_os = rowtotal(`var'*_a_os)
		capture replace `var'_a_os =. if `var'_a_ms == .
		if _rc!=0 {
				display "`var'_score problem"	
			
		} 		
	}
		
	* Checking :)
	//br s2a_1a_a_os s2a_1b_a_os s2a_1c_a_os s2a_1d_a_os s2a_1e_a_os s2a_1_a_os
	//br s7a_1a_a_os	s7a_1b_a_os	s7a_1c_a_os	s7a_1d_a_os	s7a_1_a_os	
	//br s12a_2a_a_os	s12a_2b_a_os	s12a_2c_a_os	s12a_2d_a_os	s12a_2e_a_os	s12a_2f_a_os	s12a_2g_a_os	s12a_2h_a_os	s12a_2i_a_os	s12a_2j_a_os s12a_2_a_os	
	
*^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
	** Scores: Level 2
*^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^

	local	s2a_a_os	s2a_1_a_os	s2a_2_a_os	s2a_3_a_os
	local	s2b_a_os	s2b_1_a_os	s2b_2_a_os	s2b_3_a_os
	local	s2c_a_os	s2c_1_a_os	s2c_2_a_os	s2c_3_a_os	s2c_4_a_os
	local	s3a_a_os	s3a_1_a_os	s3a_2_a_os	s3a_3_a_os
	local	s3b_a_os	s3b_2_a_os	s3b_3_a_os
	local	s3c_a_os	s3c_1_a_os	s3c_2_a_os	s3c_3_a_os	s3c_5_a_os
	local	s3d_a_os	s3d_1_a_os	s3d_2_a_os
	local	s4a_a_os	s4a_1_a_os	s4a_2_a_os	s4a_3_a_os	s4a_4_a_os
	local   s4b_a_os	s4b_1_a_os
	local	s5a_a_os	s5a_1_a_os	s5a_2_a_os	s5a_3_a_os	s5a_4_a_os
	local	s5b_a_os	s5b_1_a_os	s5b_2_a_os	s5b_3_a_os	s5b_4_a_os	s5b_5_a_os
	local	s6a_a_os	s6a_1_a_os	s6a_2_a_os	s6a_3_a_os	s6a_4_a_os	s6a_5_a_os	s6a_6_a_os	s6a_7_a_os	s6a_8_a_os
	local	s6b_a_os	s6b_1_a_os	s6b_2_a_os	s6b_3_a_os	s6b_4_a_os	s6b_5_a_os
	local	s7a_a_os	s7a_1_a_os	s7a_2_a_os	s7a_3_a_os
	local	s7b_a_os	s7b_1_a_os	s7b_2_a_os	s7b_3_a_os	s7b_4_a_os	s7b_5_a_os
	local	s8a_a_os	s8a_1_a_os	s8a_2_a_os	s8a_3_a_os	s8a_4_a_os	s8a_5_a_os
	local	s8b_a_os	s8b_1_a_os	s8b_2_a_os	s8b_3_a_os	s8b_4_a_os	s8b_5_a_os	s8_a_os
	local	s9a_a_os	s9a_1_a_os	s9a_2_a_os
	local	s9b_a_os	s9b_1_a_os	
	local	s9c_a_os	s9c_1_a_os	
	local	s9d_a_os	s9d_1_a_os	
	local	s9e_a_os	s9e_1_a_os	s9e_2_a_os	s9e_3_a_os	s9e_4_a_os	s9e_5_a_os
	local	s10a_a_os	s10a_2_a_os	s10a_3_a_os	s10a_4_a_os	s10a_5_a_os
	local	s10b_a_os	s10b_1_a_os	s10b_2_a_os	s10b_3_a_os	s10b_4_a_os
	local	s10c_a_os	s10c_1_a_os
	local	s10d_a_os	s10d_1_a_os	s10d_2_a_os
	local	s10e_a_os	s10e_1_a_os	s10e_2_a_os	s10e_3_a_os	s10e_4_a_os	s10e_5_a_os
	local	s11a_a_os	s11a_1_a_os	s11a_2_a_os	s11a_3_a_os	s11a_4_a_os	s11a_5_a_os
	local	s11b_a_os	s11b_1_a_os	s11b_2_a_os	s11b_3_a_os	s11b_4_a_os
	local	s11c_a_os	s11c_1_a_os	s11c_2_a_os	s11c_3_a_os
	local	s11d_a_os	s11d_1_a_os	s11d_2_a_os	s11d_3_a_os	s11d_4_a_os
	local	s12a_a_os	s12a_1_a_os	s12a_2_a_os	
	local 	s12b_a_os	s12b_1_a_os	
	local 	s12c_a_os	s12c_1_a_os	
	local	s12d_a_os	s12d_1_a_os	s12d_2_a_os
	local	s12e_a_os	s12e_1_a_os	s12e_2_a_os	s12e_3_a_os
	local	s12f_a_os	s12f_1_a_os	s12f_2_a_os	s12f_3_a_os	s12f_4_a_os	s12f_5_a_os

	local nocomb_L2 s2d_a_os s2e_a_os s2f_a_os s3e_a_os s3f_a_os s4c_a_os s4d_a_os s4e_a_os s4f_a_os s5c_a_os s5d_a_os s5e_a_os s5f_a_os s6c_a_os s6d_a_os s6e_a_os s6f_a_os s7c_a_os s7d_a_os s7e_a_os s7f_a_os s8c_a_os s8d_a_os s8e_a_os s8f_a_os s9f_a_os s10f_a_os s11e_a_os	s11f_a_os	

	foreach x in a b c d e f {	
		forvalues j=2(1)12 {
			gen s`j'`x'_a_os = 0		
			foreach col in `s`j'`x'_a_os' {
					capture replace s`j'`x'_a_os = s`j'`x'_a_os + `col'
					
					if _rc!=0 {
							display "`col' problem"			  
					} 
			}
					
		}
	}
	
	drop `nocomb_L2'
	
	* Checking :)

	//br s2a_1_a_os s2a_2_a_os s2a_3_a_os s2a_a_os 
	//br s2b_1_a_os s2b_2_a_os s2b_3_a_os s2b_a_os 
	//br s12f_1_a_os s12f_2_a_os s12f_3_a_os s12f_4_a_os s12f_5_a_os s12f_a_os 

	
*^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
	** Scores: Level 1
*^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^

	local s2_a_os s2a_a_os s2b_a_os s2c_a_os
	local s3_a_os s3a_a_os s3b_a_os s3c_a_os s3d_a_os
	local s4_a_os s4a_a_os s4b_a_os
	local s5_a_os s5a_a_os s5b_a_os
	local s6_a_os s6a_a_os s6b_a_os
	local s7_a_os s7a_a_os s7b_a_os
	local s8_a_os s8a_a_os s8b_a_os
	local s9_a_os s9a_a_os s9b_a_os s9c_a_os s9d_a_os s9e_a_os
	local s10_a_os s10a_a_os s10b_a_os s10c_a_os s10d_a_os s10e_a_os
	local s11_a_os s11a_a_os s11b_a_os s11c_a_os s11d_a_os
	local s12_a_os s12a_a_os s12b_a_os s12c_a_os s12d_a_os s12e_a_os s12f_a_os

	forvalues j=2(1)12 {
		gen s`j'_a_os = 0		
			foreach col in `s`j'_a_os' {
					capture replace s`j'_a_os = s`j'_a_os + `col' 
					if _rc!=0 {
							display "`col' problem"			  
					} 
			}
					
	}
	
	* S11 is an special case because s11c can be missing, and sum formula does not add the rows if there is a missing value
	replace s11_a_os = s11a_a_os + s11b_a_os + s11c_a_os + s11d_a_os
	replace s11_a_os = s11a_a_os + s11b_a_os + s11d_a_os if s11c_a_os == .
	
	* Checking :)
	//br s2a_a_os s2b_a_os s2c_a_os s2_a_os
	//br s5a_a_os s5b_a_os s2_a_os
	//br s3a_a_os s3b_a_os s3c_a_os s3d_a_os s3_a_os

*^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
	** Scores: Level 0
*^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^

	local total_s s2_a_os s3_a_os s4_a_os s5_a_os s6_a_os s7_a_os s8_a_os s9_a_os s10_a_os s11_a_os s12_a_os
	egen total_s = rowtotal(`total_s') 
		
	** Checking
	//br s2_a_os s3_a_os s4_a_os s5_a_os s6_a_os s7_a_os s8_a_os s9_a_os s10_a_os s11_a_os s12_a_os total_s
	
*^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
	** Labeling scores 
*^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
	
	** Labeling scores: Level 4
	lab var s2a_1a_a_os "Does the facility display legible signage?"
	lab var s2a_1b_a_os "Does HF display signage that is accurate outside the facility? if signage"
	lab var s2a_1c_a_os "Does the signage outside include HF name? if signage"
	lab var s2a_1d_a_os "Does the signage inside the facility include department names and direction? if signage"
	lab var s2a_1e_a_os "Does the facility have an accessibility ramp for disabled/wheelchair patients?"

	lab var s2a_2a_a_os "Adequate ventilation"	
	lab var s2a_3a_a_os "Adequate lighting"
	
	lab var s2b_1a_a_os "Is safe, clean water available from a tap or container?"
	lab var s2b_1b_a_os "Is there sufficient storage for the water?"
	lab var s2b_2a_a_os "Is there a stable source of power?"
	lab var s2b_3a_a_os "Are clean toilets available for both male and female clients?"
	lab var s2b_3b_a_os "Is there a cleaning roster displayed?"
	lab var s2c_1a_a_os "Does the facility have a lockable door?"
	lab var s2c_1b_a_os "Is the door secured with grills or another security mechanism?"
	lab var s2c_2a_a_os "Does HF have a fire control mechanism such?"
	lab var s2c_2b_a_os "Is the equipment available in the reception area as well as specific departments? if L4/L5"
	lab var s2c_3a_a_os "Does the facility have a fire assembly point or fire assembly protocol? if L4/L5"
	lab var s2c_3b_a_os "Is there a documented firefighting protocol?"
	lab var s2c_3c_a_os "Does the facility display emergency exit?"
	lab var s2c_3d_a_os "Does the facility display fire assembly point signage? if L4/L5 & assembly point"
	lab var s2c_4a_a_os "Is there a security system present (e.g. security guard, alarm system)?"
	lab var s3a_1a_a_os "Does the facility have a strategic plan with its vision, values, and objectives?"
	lab var s3a_1b_a_os "Is the plan displayed and shared to all staff? if strategic plan" 
	lab var s3a_1c_a_os "Does the facility have an annual work plan or a business plan?"
	lab var s3a_1d_a_os "Is there an organizational chart available and approved by management?"
	lab var s3a_2a_a_os "Is a client service charter displayed?"
	lab var s3a_2b_a_os "Is it displayed in all key departments/areas? if charter"
	lab var s3a_2c_a_os "Mention common services offered? if charter"
	lab var s3a_2d_a_os "Mention obligations to clients? if charter"
	lab var s3a_2e_a_os "Mention waiting times for clients? if charter"
	lab var s3a_2f_a_os "Mention ways to communicate with management regarding problems? if charter"
	lab var s3a_2g_a_os "Mention services offered for free if charter"
	lab var s3a_2h_a_os "Does the facility have a regular performance review for the charter targets?if charter"
	lab var s3a_3a_a_os "Does the facility have a list of all staff with qualifications/job description"
	//lab var s3a_3b_a_os "Are copies of professional certificates for all staff available at the facility?" Not included
	lab var s3b_2a_a_os "Infant mortality"
	lab var s3b_2b_a_os "Maternal mortality"
	lab var s3b_2c_a_os "Immunization"
	lab var s3b_2d_a_os "Notifiable diseases"
	lab var s3b_2e_a_os "Are performance indicators shared with staff and published regularly?"
	lab var s3b_3a_a_os "Is there a functional feedback mechanism, such as a suggestion box, hotline numb"
	lab var s3b_3b_a_os "Is client feedback reviewed at least biweekly? if feedbacl"
	lab var s3b_3c_a_os "Are client suggestions documented in a report? if feedback"
	lab var s3c_1a_a_os "Are medical records kept for each patient?"
	lab var s3c_1b_a_os "Do the records include names and unique patient numbers? if records"
	lab var s3c_1c_a_os "Are all the records legible and signed? if records"
	lab var s3c_2a_a_os "Are outpatients registers kept?"
	lab var s3c_2b_a_os "Are inpatients registers kept?"
	lab var s3c_2c_a_os "Are inpatient and outpatient records kept separately?"
	lab var s3c_2d_a_os "Are the registers up to date?"
	lab var s3c_3a_a_os "Is there a system in place for storing medical records? if records"
	lab var s3c_3b_a_os "Is there a filing and numbering system for easy retrieval? if records & system"
	lab var s3c_3c_a_os "Are the records protected in cabinets (if paper) or by password (if digital)?"
	lab var s3c_5a_a_os "Does the facility contribute to the DHIS?"
	lab var s3d_1a_a_os "Is there a service contract for maintenance?"
	lab var s3d_1b_a_os "Is there a written schedule for maintaining equipment?"
	lab var s3d_2a_a_os "Is there a written calibration schedule available at the area where equipment is?"
	lab var s3d_2b_a_os "Is there a document showing regular calibration?"
	lab var s3d_2c_a_os "Are contracts available at the facility administration?"
	lab var s4a_1a_a_os "Does the facility have a hygiene protocol?"
	lab var s4a_1b_a_os "Does the facility have a dedicated staff roster for cleaning?"
	lab var s4a_2a_a_os "Is there a standard operating procedure for waste management?"
	lab var s4a_2b_a_os "Is there an incinerator or contracted waste management company?"
	lab var s4a_2c_a_os "Does the facility have a waste holding area?"
	lab var s4a_3a_a_os "HF Cleanliness"	
	lab var s4a_3b_a_os "Is the paint work acceptable?"
	lab var s4a_3c_a_os "Is the floor smooth?"
	lab var s4a_3d_a_os "Is the ceiling free of cobwebs and dust?"
	lab var s4a_4a_a_os "Is the grass well maintained?"
	lab var s4a_4b_a_os "Are the bushes neatly kept?"
	lab var s4a_4c_a_os "Is the site free of odor?"
	lab var s4b_1a_a_os "Is there a separate area for cleaning with decontamination and sterilization processes?"
	lab var s4b_1b_a_os "Are standard operating procedures available for sterilization?"
	lab var s4b_1c_a_os "Is there storage available for sterile supplies?"
	lab var s4b_1d_a_os "Are sterile supplies labeled and stored in a designated area?"
	lab var s5a_1a_a_os "Does the facility have a triage area with a qualified nurse(s)?"
	lab var s5a_1b_a_os "Is it located at the first point of contact with patients? if triage"
	lab var s5a_1c_a_os "Is there a standard operating procedure for triage? if triage"
	lab var s5a_1d_a_os "Is there a system for coding patients?"
	lab var s5a_2a_a_os "Does the examination room have a coach and a mackintosh?"
	lab var s5a_2b_a_os "Does the room have a consultation table with at least two chairs?"
	lab var s5a_2c_a_os "Does the room have a pedal bin and stepper?"
	lab var s5a_3a_a_os "Is a thermometer available?"
	lab var s5a_3b_a_os "Is a stethoscope available?"
	lab var s5a_3c_a_os "Is a tongue depressor available?"
	lab var s5a_3d_a_os "Is a weighing scale available/accessible?"
	lab var s5a_3e_a_os "Is a blood pressure (BP) machine available/accessible?"
	lab var s5a_3f_a_os "Is a torch available?"
	lab var s5a_3g_a_os "Is a privacy screen available?"
	lab var s5a_3h_a_os "Is a diagnostic set available?"
	lab var s5a_3i_a_os "Is a lamp available?"
	lab var s5a_4a_a_os "Does the facility have an emergency tray available at designated sites?"
	lab var s5a_4b_a_os "Is there a checklist for regular review emergency tray? if emerg tray"
	lab var s5a_4c_a_os "Glucose if emerg tray"
	lab var s5a_4d_a_os "Adrenaline if emerg tray"
	lab var s5a_4e_a_os "Sodium bicarbonate if emerg tray"
	lab var s5a_4f_a_os "Diazepam if emerg tray"
	lab var s5a_4g_a_os "Phenobarbitone if emerg tray"
	lab var s5a_4h_a_os "Ambu bag and mask available in pediatric and adult sizes"
	lab var s5a_4i_a_os "Adjustable bed  "
	lab var s5a_4j_a_os "Functional suction machine"
	lab var s5a_4k_a_os "Oxygen cylinder and flowmeter, or piped oxygen"
	lab var s5a_4l_a_os "Endotracheal tubes"
	lab var s5b_1a_a_os "Is there a hygiene protocol?"
	lab var s5b_1b_a_os "Does the hygiene protocol have a dedicated staff roster available?"
	lab var s5b_2a_a_os "Is a sink present with running water from a tap or modified storage container?"
	lab var s5b_2b_a_os "Is soap available at the hand washing area?"
	lab var s5b_3a_a_os "Are there at least two color-coded bins (red, black and/or yellow)?"
	lab var s5b_3b_a_os "Are there coded lining bags that match the color of the bins?"
	lab var s5b_3c_a_os "Are there standard operating procedures for waste management?"
	lab var s5b_4a_a_os "Is there disinfectant readily available in the consultation room?"
	lab var s5b_4b_a_os "Are you able to observe disinfectant containers used for cleaning?"
	lab var s5b_5a_a_os "Are gloves available?"
	lab var s5b_5b_a_os "Are gowns or dust coats available?"
	lab var s5b_5c_a_os "Are face masks available?"
	lab var s5b_5d_a_os "Are safety boots available?"
	lab var s6a_1a_a_os "Is there privacy in the ward (privacy during delivery)?"
	lab var s6a_1b_a_os "Is a delivery bed available?"
	lab var s6a_1c_a_os "Is a sterile delivery set available?"
	lab var s6a_1d_a_os "Is a vacuum extractor available?"
	lab var s6a_1e_a_os "Is a suction machine available?"
	lab var s6a_1f_a_os "Is an ambu bag and mask available?"
	lab var s6a_1g_a_os "Is a cord ligature available?"
	lab var s6a_1h_a_os "Is there sufficient lighting?"
	lab var s6a_1i_a_os "Are maintenance plans available for all equipment?"
	lab var s6a_2a_a_os "Is the floor appropriately covered (e.g. ceramic tiles or terrazzo)?"
	lab var s6a_2b_a_os "Is there a drainage system?"
	lab var s6a_2c_a_os "Is there a cleaning chart?"
	lab var s6a_3a_a_os "Does the labour ward have oxygen cylinder or piped oxygen connection?"
	lab var s6a_3b_a_os "Are there standard operating procedures for oxygen?"
	lab var s6a_3c_a_os "Is there a maintenance plan for oxygen?"
	lab var s6a_4a_a_os "Are there procedures available for handling obstructed labour, foetal distress, eclampsia and APH/PPH/HELLP?"
	lab var s6a_4b_a_os "Is a functional resusitaire available with oxygen, suction machine and ambu bags?"
	lab var s6a_5a_a_os "Is an ambulance (or contact details) available?"
	lab var s6a_5b_a_os "Is a fully equipped theatre near the labour ward?"
	lab var s6a_6a_a_os "Is a partograph available?"
	lab var s6a_6b_a_os "Is contraction properly charted?"
	lab var s6a_6c_a_os "Is cervical dilation recorded?"
	lab var s6a_6d_a_os "Is color coding done?"
	lab var s6a_6e_a_os "Is TPR/BP recorded?"
	lab var s6a_6f_a_os "Is urine output/input charted?"
	lab var s6a_6g_a_os "Are drugs coded?"
	lab var s6a_7a_a_os "Is a functional incubator available?"
	lab var s6a_7b_a_os "Does the incubator have a temperature regulator? if incubator"
	lab var s6a_7c_a_os "Does the incubator have an oxygen connection? if incubator"
	lab var s6a_7d_a_os "Are maintenance plans available for the incubator? if incubator"
	lab var s6a_7e_a_os "Is there a sitting area for nursing mothers?"
	lab var s6a_8a_a_os "Is a sluice room with a sluicing sink available?"
	lab var s6a_8b_a_os "Does the sluice room have running water? if sluice room"
	lab var s6a_8c_a_os "Does it have a decontamination bucket? if sluice room"
	lab var s6a_8d_a_os "Are standard operating procedures available? if sluice room"
	lab var s6b_1a_a_os "Is there a hygiene protocol?"
	lab var s6b_1b_a_os "Does the hygiene protocol have a dedicated staff roster available?"
	lab var s6b_2a_a_os "Is a sink present with running water from a tap or modified storage container?"
	lab var s6b_2b_a_os "Is soap available at the handwashing area?"
	lab var s6b_3a_a_os "Are there at least two color-coded bins (red, black and/or yellow)?"
	lab var s6b_3b_a_os "Are there coded lining bags that match the color of the bins?"
	lab var s6b_3c_a_os "Are there standard operating procedures for waste management?"
	lab var s6b_4a_a_os "Is there evidence of disinfectant use?"
	lab var s6b_4b_a_os "Are you able to observe disinfectant containers used for cleaning?"
	lab var s6b_5a_a_os "Are gloves available?"
	lab var s6b_5b_a_os "Are gowns or dust coats available?"
	lab var s6b_5c_a_os "Are face masks available?"
	lab var s6b_5d_a_os "Are safety boots available?"
	lab var s7a_1a_a_os "Are admissions procedures standardized with patient categorizations?"
	lab var s7a_1b_a_os "Are patients in hospital uniform?"
	lab var s7a_1c_a_os "Are there regular ward rounds?"
	lab var s7a_1d_a_os "Are there handover and discharge reports on a standard form?"
	lab var s7a_2a_a_os "Are patient records kept with unique reference numbers?"
	lab var s7a_2b_a_os "Is the filing system secure?"
	lab var s7a_3a_a_os "Does each ward have a BP machine?"
	lab var s7a_3b_a_os "Does each ward have a thermometer?"
	lab var s7a_3c_a_os "Does each ward have a pulse oxymeter?"
	lab var s7a_3d_a_os "Does each ward have a suction machine?"
	lab var s7a_3e_a_os "Does each ward have an emergency room?"
	lab var s7b_1a_a_os "Is there a hygiene protocol?"
	lab var s7b_1b_a_os "Does the hygiene protocol have a dedicated staff roster available?"
	lab var s7b_2a_a_os "Is a sink present with running water from a tap or modified storage container?"
	lab var s7b_2b_a_os "Is soap available at the handwashing area?"
	lab var s7b_3a_a_os "Are there at least two color-coded bins (red, black and/or yellow)?"
	lab var s7b_3b_a_os "Are there coded lining bags that match the color of the bins?"
	lab var s7b_3c_a_os "Are there standard operating procedures for waste management?"
	lab var s7b_4a_a_os "Is there evidence of disinfectant use?"
	lab var s7b_4b_a_os "Are you able to observe disinfectant containers used for cleaning?"
	lab var s7b_5a_a_os "Are gloves available?"
	lab var s7b_5b_a_os "Are gowns or dust coats available?"
	lab var s7b_5c_a_os "Are face masks available?"
	lab var s7b_5d_a_os "Are safety boots available?"
	lab var s8a_1a_a_os "Does the receiving area have a barrier?"
	lab var s8a_1b_a_os "Does the receiving area have a shoe rack?"
	lab var s8a_1c_a_os "Does the receiving area have a coach?"
	lab var s8a_1d_a_os "Does the receiving area have adequate lighting?"
	lab var s8a_2a_a_os "Does the theatre have male and female changing rooms with barrier?"
	lab var s8a_2b_a_os "Do changing rooms have clean clothing?"
	lab var s8a_2c_a_os "Do changing rooms have masks?"
	lab var s8a_2d_a_os "Do changing rooms have caps?"
	lab var s8a_2e_a_os "Do changing rooms have theatre shoes?"
	lab var s8a_2f_a_os "Is there a scrubbing area present?"
	lab var s8a_2g_a_os "Is there a hands-free tap?"
	lab var s8a_2h_a_os "Are there swinging theatre doors?"
	lab var s8a_3a_a_os "Does the operating area have adequate space?"
	lab var s8a_3b_a_os "Does the operating area have adequate lighting?"
	lab var s8a_3c_a_os "Does the operating area have adequate cabinets for non-pharms?"
	lab var s8a_3d_a_os "Does the operating area have adequate sterile gloves?"
	lab var s8a_3e_a_os "Does the operating area have a standard operating table?"
	lab var s8a_3f_a_os "Does the operating area have an adequate functional anaesthetic machine?"
	lab var s8a_3g_a_os "Does the operating area have adequate ambu-bags, both adult and paediatric?"
	lab var s8a_3h_a_os "Does the operating area have adequate monitors?"
	lab var s8a_3i_a_os "Does the operating area have adequate laryngoscopes?"
	lab var s8a_3j_a_os "Does the operating area have adequate endotracheal tubes?"
	lab var s8a_3k_a_os "Does the operating room have a functioning suction machine?"
	lab var s8a_3l_a_os "Does the operating room have adequate back-up oxygen, separate from anaesthetic "
	lab var s8a_4a_a_os "Are there at least three nurses (scrub, runner and anaesthetic nurse)?"
	lab var s8a_4b_a_os "Are nurses skilled with peri-operative training?"
	lab var s8a_5a_a_os "Does the recovery room have adequate lighting?"
	lab var s8a_5b_a_os "Does the recovery room have a monitor?"
	lab var s8a_5c_a_os "Does the recovery room have a drip stand?"
	lab var s8b_1a_a_os "Is there a hygiene protocol?"
	lab var s8b_1b_a_os "Does the hygiene protocol have a dedicated staff roster available?"
	lab var s8b_2a_a_os "Is a sink present with running water from a tap or modified storage container?"
	lab var s8b_2b_a_os "Is soap available at the hand washing area?"
	lab var s8b_3a_a_os "Are there at least two color-coded bins (red, black and/or yellow)?"
	lab var s8b_3b_a_os "Are there coded lining bags that match the color of the bins?"
	lab var s8b_3c_a_os "Are there standard operating procedures for waste management?"
	lab var s8b_4a_a_os "Is there evidence of disinfectant use?"
	lab var s8b_4b_a_os "Are you able to observe disinfectant containers used for cleaning?"
	lab var s8b_5a_a_os "Are gloves available?"
	lab var s8b_5b_a_os "Are gowns or dust coats available?"
	lab var s8b_5c_a_os "Are face masks available?"
	lab var s8b_5d_a_os "Are safety boots available?"
	lab var s9a_1a_a_os "Adequate ventilation in pharm"
	lab var s9a_2a_a_os "Adequate lighting in pharm"	
	lab var s9a_2b_a_os "Does the pharmacy have adequate space for staff movement in the dispensing area?"
	lab var s9b_1a_a_os "Does the pharmacy have secure, lockable cupboards for restricted drugs only acce"
	lab var s9b_1b_a_os "Are drugs stored and displayed to good standards?"
	lab var s9b_1c_a_os "Are there standard operating procedures for the storage of medicines?"
	lab var s9c_1a_a_os "Does the pharmacy have a well-explained system for recording prescriptions?"
	lab var s9c_1b_a_os "Does the pharmacy have standard operating procedures for disposal of expired dru"
	lab var s9c_1c_a_os "Is there a daily updated inventory system showing which commodities are availabl"
	lab var s9c_1d_a_os "Is there documentation showing where medicines are procured?"
	lab var s9c_1e_a_os "Are there systems for documenting and feeding back medication errors?"
	lab var s9c_1f_a_os "Are there separate records for narcotic and psychotropic medicines?"
	lab var s9d_1a_a_os "Does the pharmacy have reference materials for medicines (e.g. drug index)?"
	lab var s9d_1b_a_os "Is the staff familiar with these reference materials? if materials"
	lab var s9e_1a_a_os "Is there a hygiene protocol?"
	lab var s9e_1b_a_os "Does the hygiene protocol have a dedicated staff roster available?"	
	lab var s9e_2a_a_os "Is a sink present with running water from a tap or modified storage container?"
	lab var s9e_2b_a_os "Is soap available at the handwashing area?"
	lab var s9e_3a_a_os "Are there at least two color-coded bins (red, black and/or yellow)?"
	lab var s9e_3b_a_os "Are there coded lining bags that match the color of the bins?"
	lab var s9e_3c_a_os "Are there standard operating procedures for waste management?"
	lab var s9e_4a_a_os "Is there evidence of disinfectant use?"
	lab var s9e_4b_a_os "Are you able to observe disinfectant containers used for cleaning?"
	lab var s9e_5a_a_os "Are gloves available?"
	lab var s9e_5b_a_os "Are gowns or dust coats available?"
	lab var s9e_5c_a_os "Are face masks available?"
	lab var s9e_5d_a_os "Are safety boots available?"
	lab var s10a_2a_a_os "Does the laboratory have SOPs and guidelines for reporting lab procedures?"
	lab var s10a_2b_a_os "Are the SOPs and guidelines for reporting lab procedures displayed? if SOPS"
	lab var s10a_3a_a_os "Does the laboratory have SOPs and guidelines for handling, labeling and storage "
	lab var s10a_3b_a_os "Are the SOPs and guidelines for specimens dispousal if SOPS"
	lab var s10a_4a_a_os "Does the laboratory have SOPs and guidelines for disposal of specimens?"
	lab var s10a_4b_a_os "Are the SOPs and guidelines for disposal of specimens displayed? if SOPS"
	lab var s10a_5a_a_os "Does the laboratory have standard quality operational manual (SOP of SOPs) avail"
	lab var s10b_1a_a_os "Does the lab have a system for regular calibration/validation of equipment avail"
	lab var s10b_1b_a_os "Is the system for calibration of equipment placed close to respective if system"
	lab var s10b_2a_a_os "Does the labo have a systematic equipment maintenance schedule?"
	lab var s10b_2b_a_os "Are service contracts available for all lab equipment?"
	lab var s10b_3a_a_os "Does lab have a system for equipment procurement that is known by staff?"
	lab var s10b_4a_a_os "Does the laboratory have a list of all equipment in use?"
	lab var s10b_4b_a_os "Does the laboratory have a functional inventory management system?"
	lab var s10c_1a_a_os "Does lab have a records system integrated in the facility record system?"
	lab var s10d_1a_a_os "Are equipment registered, validated and calibrated?"
	lab var s10d_1b_a_os "Is there documentation of quality control of tests?"
	lab var s10d_1c_a_os "Is there a documented system for regular review and improvement of lab?"
	lab var s10d_1d_a_os "Is there documentation of sample archiving, retrieval and disposal?"
	lab var s10d_1e_a_os "Is Internal Quality Control (IQC) done regularly?"
	lab var s10d_1f_a_os "Is the laboratory enrolled in External Quality Assurance?"
	lab var s10d_2a_a_os "Does the laboratory have a functional temperature recording system in place?"
	lab var s10d_2b_a_os "Are standards for procurement and safe storage of reagents in place?"
	lab var s10e_1a_a_os "Is there a hygiene protocol?"
	lab var s10e_1b_a_os "Does the hygiene protocol have a dedicated staff roster available?"	
	lab var s10e_2a_a_os "Is a sink present with running water from a tap or modified storage container?"
	lab var s10e_2b_a_os "Is soap available at the handwashing area?"
	lab var s10e_3a_a_os "Are there at least two color-coded bins (red, black and/or yellow)?"
	lab var s10e_3b_a_os "Are there coded lining bags that match the color of the bins?"
	lab var s10e_3c_a_os "Are there standard operating procedures for waste management?"
	lab var s10e_4a_a_os "Is there evidence of disinfectant use?"
	lab var s10e_4b_a_os "Are you able to observe disinfectant containers used for cleaning?"
	lab var s10e_5a_a_os "Are gloves available?"
	lab var s10e_5b_a_os "Are gowns or dust coats available?"
	lab var s10e_5c_a_os "Are face masks available?"
	lab var s10e_5d_a_os "Are safety boots available?"
	lab var s11a_1a_a_os "Are personal radiation dose monitoring badges worn daily and evaluated monthly?"
	lab var s11a_2a_a_os "Does the facility have records confirming that there is a radiation safety servi"
	lab var s11a_3a_a_os "Is there an adequate number of lead aprons, i.e. a minimum of three: one each fo"
	lab var s11a_4a_a_os "Is a code of practice for pregnant women available and producible?"
	lab var s11a_5a_a_os "Is there evidence of quality assurance of the image processing system"
	lab var s11b_1a_a_os "Are standard operating procedures available for radiology and imaging services?"
	lab var s11b_1b_a_os "Is there evidence that they've been reviewed in the past year... if stand oper proc"
	lab var s11b_1c_a_os "Is a code of practice displayed next to the respective device?"
	lab var s11b_2a_a_os "Is reporting, testing and calibrating up to date and displayed?"
	lab var s11b_3a_a_os "Is there a register of eradiating activities and a monthly dose report for worke"
	lab var s11b_4a_a_os "Is there a quality assurance program?"
	lab var s11b_4b_a_os "Does the quality/assurance/progr include safety patient... if quality assurance"
	lab var s11b_4c_a_os "Is there a designated or appointed quality assurance staff member in the facilit"
	lab var s11b_4d_a_os "Is there updated annual documentation for quality assurance procedures?"
	lab var s11c_1a_a_os "Does the facility produce radioactive waste?"
	lab var s11c_1b_a_os "Are patient and staff safety measures implemented alongside routine waste manage"
	lab var s11c_2a_a_os "Is there designated staff in charge of rad. waste management? if radioactive waste"
	lab var s11c_2b_a_os "Are there records showing that rad. waste manag. syst. are in place if radioactive waste"
	lab var s11c_3a_a_os "Does the facility have designated personnel to oversee rad. waste managem. if radioactive waste"
	lab var s11d_1a_a_os "Is there a hygiene protocol?"
	lab var s11d_1b_a_os "Does the hygiene protocol have a dedicated staff roster available?"
	lab var s11d_2a_a_os "Is a sink present with running water from a tap or modified storage container?"
	lab var s11d_2b_a_os "Is soap available at the handwashing area?"
	lab var s11d_3a_a_os "Is there evidence of disinfectant use?"
	lab var s11d_3b_a_os "Are you able to observe disinfectant containers used for cleaning?"
	lab var s11d_4a_a_os "Are gloves available?"
	lab var s11d_4b_a_os "Are gowns or dust coats available?"
	lab var s11d_4c_a_os "Are face masks available?"
	lab var s11d_4d_a_os "Are safety boots available?"
	lab var s12a_1a_a_os "Is a functional calibrated weighing scale available?"
	lab var s12a_1b_a_os "Is a stadiometer available?"
	lab var s12a_1c_a_os "Are Mid-Upper Arm Circumference (MUAC) tapes available?"
	lab var s12a_1d_a_os "Is a waist circumference tape available?"
	lab var s12a_1e_a_os "Is a functional blood pressure machine available?"
	lab var s12a_1f_a_os "Is a functional glucometer available?"
	lab var s12a_1g_a_os "Are reference charts available?"
	lab var s12a_2a_a_os "Is food store available with evidence of regular stock replenishment?"
	lab var s12a_2b_a_os "Are ‘Ready to Use Therapeutic Foods’ (RUTF) available and accessible?"
	lab var s12a_2c_a_os "Are ‘Ready to Use Supplementary Foods’ (RUSF) available and accessible?"
	lab var s12a_2d_a_os "Are the F75 and F100 diet milks available and adequate for clients?"
	lab var s12a_2e_a_os "Are food fortifiers available and acceptable?"
	lab var s12a_2f_a_os "Are nutrition formulations for specialized nutrition support available and acces"
	lab var s12a_2g_a_os "Are Vitamin A Supplements available for children and expectant mothers?"
	lab var s12a_2h_a_os "Are iron supplements available in the acceptable form?"
	lab var s12a_2i_a_os "Are folate supplements available in the acceptable form?"
	lab var s12a_2j_a_os "Is zinc supplement available?"
	lab var s12b_1a_a_os "Are there SOPs for comprehensive nutritional assessment?"
	lab var s12b_1b_a_os "Are there adequate guidelines for nutritional diagnosis?"
	lab var s12b_1c_a_os "Are there guidelines for choice of appropriate nutrition care intervention?"
	lab var s12b_1d_a_os "Are there adequate guidelines for monitoring patient care?"
	lab var s12b_1e_a_os "Are there adequate SOPs for food formulations?"
	lab var s12b_1f_a_os "Are there adequate SOPs for food supplementation?"
	lab var s12b_1g_a_os "Are SOPs reviewed and regularly updated (within a 5-year framework)?"
	lab var s12b_1h_a_os "Are staff familiar with the SOPs and guidelines?"
	lab var s12c_1a_a_os "Is the system for record keeping linked to the facility information management s"
	lab var s12c_1b_a_os "Is there a designated person aware of the documentation processes?"
	lab var s12c_1c_a_os "Is there security for the information in the system?"
	lab var s12c_1d_a_os "Is there a documented plan for regular updating?"
	lab var s12d_1a_a_os "Is there an inpatient feeding committee?"
	lab var s12d_1b_a_os "Does the composition of the committee include qualified nutritionist and dietici"
	lab var s12d_1c_a_os "Is there a comprehensive protocol for inpatient feeding?"
	lab var s12d_1d_a_os "Is there a food inspection committee with at least one licensed nutritionist?"
	lab var s12d_1e_a_os "Is there a communication link between patients in the ward and the food preparat"
	lab var s12d_1f_a_os "Are there food modification schemes for groups with special needs?"
	lab var s12d_1g_a_os "Is there an option for patients to choose from available sources of foods?"
	lab var s12d_2a_a_os "Are postpartum mothers fed on an appropriately tailored diet?"
	lab var s12d_2b_a_os "Is breastfeeding initiated within one hour after delivery?"
	lab var s12e_1a_a_os "Is a functional blender available?"
	lab var s12e_1b_a_os "Is a functional mincer available?"
	lab var s12e_1c_a_os "Is a functional food weighing scale available and regularly calibrated?"
	lab var s12e_1d_a_os "Are measuring jars available?"
	lab var s12e_1e_a_os "Are food trolleys available?"
	lab var s12e_1f_a_os "Are reliable sources of fuel available?"
	lab var s12e_2a_a_os "Is the layout and physical structure of the kitchen adequate?"
	lab var s12e_2b_a_os "Is a diet therapy kitchen available and separated from normal food kitchen?"
	lab var s12e_2c_a_os "Is a mini store available in the kitchen for food from the main store?"
	lab var s12e_2d_a_os "Does the paediatric ward have room to prepare special food?"
	lab var s12e_2e_a_os "Is there adequate space for storage of food commodities?"
	lab var s12e_3a_a_os "Are kitchen personnel qualified caterers and trained cooks?"
	lab var s12e_3b_a_os "Is the supervisor qualified and licensed by the Nutritionist and Dieticians Inst"
	lab var s12f_1a_a_os "Is there a hygiene protocol?"
	lab var s12f_1b_a_os "Does the hygiene protocol have a dedicated staff roster available?"
	lab var s12f_2a_a_os "Is a sink present with running water from a tap or modified storage container?"
	lab var s12f_2b_a_os "Is soap available at the hand washing area?"
	lab var s12f_3a_a_os "Are there at least two color-coded bins (red, black and/or yellow)?"
	lab var s12f_3b_a_os "Are there coded lining bags that match the color of the bins?"
	lab var s12f_3c_a_os "Are there standard operating procedures for waste management?"
	lab var s12f_4a_a_os "Is there evidence of disinfectant use?"
	lab var s12f_4b_a_os "Are you able to observe disinfectant containers used for cleaning?"
	lab var s12f_5a_a_os "Are gloves available and accessible?"
	lab var s12f_5b_a_os "Are gowns or dust coats available and accessible?"
	lab var s12f_5c_a_os "Are face masks available and accessible?"
	lab var s12f_5d_a_os "Are safety boots available and accessible?"
	
	* Labeling scores: level 1		
	lab var s2_a_os "Section 2: Health Facility Infrastructure"
	lab var s3_a_os "Section 3: General Management and Recording of Information"
	lab var s4_a_os "Section 4: Infection Prevention and Control"
	lab var s5_a_os "Section 5: Medical and Dental Consultation Services"
	lab var s6_a_os "Section 6: Labour Ward"
	lab var s7_a_os "Section 7: Medical and Pediatric Wards"
	lab var s8_a_os "Section 8: Theatre"
	lab var s9_a_os "Section 9: Pharmacy"
	lab var s10_a_os "Section 10. Laboratory"
	lab var s11_a_os "Section 11: Radiology"
	lab var s12_a_os "Section 12: Nutrition and Dietetics Service Unit"

	* Labeling scores: level 2		
	lab var s2a_a_os "A. Building"
	lab var s2b_a_os "B. Utilities"
	lab var s2c_a_os "C. Security"
	lab var s3a_a_os "A. General Management"
	lab var s3b_a_os "B. Quality Management"
	lab var s3c_a_os "C. Medical Records and Information Systems"
	lab var s3d_a_os "D. Equipment Management"
	lab var s4a_a_os "A. General"
	lab var s4b_a_os "B. Sterilization Services"
	lab var s5a_a_os "A. General"
	lab var s5b_a_os "B. Infection prevention and control"
	lab var s6a_a_os "A. General"
	lab var s6b_a_os "B. Infection prevention and control"
	lab var s7a_a_os "A. General"
	lab var s7b_a_os "B. Infection prevention and control"
	lab var s8a_a_os "A. General"
	lab var s8b_a_os "B. Infection prevention and control"
	lab var s9a_a_os "A. General condition of premises"
	lab var s9b_a_os "B.  Storage and display of commodities "
	lab var s9c_a_os "C.  Record keeping and documentation "
	lab var s9d_a_os "D. Reference materials and policies"
	lab var s9e_a_os "E. Infection prevention and control"
	lab var s10a_a_os "A. Policies, guidelines and SOPs "
	lab var s10b_a_os "B. Equipment management program "
	lab var s10c_a_os "C. Record keeping and documentation "
	lab var s10d_a_os "D. Quality control of tests "
	lab var s10e_a_os "E. Infection prevention and control"
	lab var s11a_a_os "A. Radiation protection"
	lab var s11b_a_os "B. Policies, SOPs and registers "
	lab var s11c_a_os "C. Radioactive waste management "
	lab var s11d_a_os "D. Infection prevention and control"
	lab var s12a_a_os "A. Nutrition equipment, Tools and Supplies "
	lab var s12b_a_os "B. SOPs for nutrition care processes and other services  "
	lab var s12c_a_os "C. Record keeping and documentation"
	lab var s12d_a_os "D. Patient feeding "
	lab var s12e_a_os "E. Food Preparation Unit"
	lab var s12f_a_os "F. Infection prevention and control"

	* Labeling scores: level 3
	lab var s2a_1_a_os "1. Signage and accessibility"
	lab var s2a_2_a_os "2. Ventilation"
	lab var s2a_3_a_os "3. Lighting "
	lab var s2b_1_a_os "1. Water"
	lab var s2b_2_a_os "2. Electricity"
	lab var s2b_3_a_os "3. Toilet facilities"
	lab var s2c_1_a_os "1. Lockable door"
	lab var s2c_2_a_os "2. Fire control mechanism"
	lab var s2c_3_a_os "3. Fire assembly point"
	lab var s2c_4_a_os "4. Security"
	lab var s3a_1_a_os "1. Strategic Plan"
	lab var s3a_2_a_os "2. Client Service Charter"
	lab var s3a_3_a_os "3. List of staff"
	lab var s3b_2_a_os "2. Monitoring performance indicators"
	lab var s3b_3_a_os "3. Client feedback mechanism"
	lab var s3c_1_a_os "1. Medical records for each patient"
	lab var s3c_2_a_os "2. Approved register for all patients"
	lab var s3c_3_a_os "3. System for storing medical records"
	lab var s3c_5_a_os "5. Contribution to external databases and reports"
	lab var s3d_1_a_os "1. Preventative maintenance plan for equipment"
	lab var s3d_2_a_os "2. Calibration and validation"
	lab var s4a_1_a_os "1. Hygiene protocol"
	lab var s4a_2_a_os "2. Solid waste management"
	lab var s4a_3_a_os "3. General facility cleanliness"
	lab var s4a_4_a_os "4. General compound cleanliness"
	lab var s4b_1_a_os "1. Central Supply Unit"
	lab var s5a_1_a_os "1. Triage"
	lab var s5a_2_a_os "2. Examination room"
	lab var s5a_3_a_os "3. Examination equipment"
	lab var s5a_4_a_os "4. Emergency tray and equipment"
	lab var s5b_1_a_os "1. Hygiene protocol"
	lab var s5b_2_a_os "2. Hand washing"
	lab var s5b_3_a_os "3. Solid waste management"
	lab var s5b_4_a_os "4. Use of disinfectants"
	lab var s5b_5_a_os "5. Protective equipment"
	lab var s6a_1_a_os "1. Labour ward"
	lab var s6a_2_a_os "2. Labour room floor"
	lab var s6a_3_a_os "3. Oxygen source"
	lab var s6a_4_a_os "4. Procedures for obstetrics emergency"
	lab var s6a_5_a_os "5. Access to theatre"
	lab var s6a_6_a_os "6. Procedure for monitoring labour"
	lab var s6a_7_a_os "7. New born unit"
	lab var s6a_8_a_os "8. Sluice room"
	lab var s6b_1_a_os "1. Hygiene protocol"
	lab var s6b_2_a_os "2. Hand washing"
	lab var s6b_3_a_os "3. Solid waste management"
	lab var s6b_4_a_os "4. Use of disinfectants"
	lab var s6b_5_a_os "5. Protective equipment"
	lab var s7a_1_a_os "1. Patient oversight "
	lab var s7a_2_a_os "2. Patient records"
	lab var s7a_3_a_os "3. Monitoring equipment "
	lab var s7b_1_a_os "1. Hygiene protocol"
	lab var s7b_2_a_os "2. Hand washing"
	lab var s7b_3_a_os "3. Solid waste management"
	lab var s7b_4_a_os "4. Use of disinfectants"
	lab var s7b_5_a_os "5. Protective equipment"
	lab var s8a_1_a_os "1. Receiving area "
	lab var s8a_2_a_os "2. Changing rooms and scrubbing area "
	lab var s8a_3_a_os "3. Operating area "
	lab var s8a_4_a_os "4. Staff requirements "
	lab var s8a_5_a_os "5. Recovery room"
	lab var s8b_1_a_os "1. Hygiene protocol"
	lab var s8b_2_a_os "2. Hand washing"
	lab var s8b_3_a_os "3. Solid waste management"
	lab var s8b_4_a_os "4. Use of disinfectants"
	lab var s8b_5_a_os "5. Protective equipment"
	lab var s9a_1_a_os "1. Ventilation"
	lab var s9a_2_a_os "2. Lighting "
	lab var s9b_1_a_os "1. Storage and display of commodities"
	lab var s9c_1_a_os "1 Record keeping and documentation"	
	lab var s9d_1_a_os "1 Reference materials and policies"
	lab var s9e_1_a_os "1. Hygiene protocol"
	lab var s9e_2_a_os "2. Hand washing"
	lab var s9e_3_a_os "3. Solid waste management"
	lab var s9e_4_a_os "4. Use of disinfectants"
	lab var s9e_5_a_os "5. Protective equipment"
	lab var s10a_2_a_os "2. Reporting procedures"
	lab var s10a_3_a_os "3. Handling, labeling and storage of specimen"
	lab var s10a_4_a_os "4. Disposal of specimens"
	lab var s10a_5_a_os "5. Standard quality operational manual "
	lab var s10b_1_a_os "1. Calibration and validation of equipment"
	lab var s10b_2_a_os "2. Equipment maintenance documentation"
	lab var s10b_3_a_os "3. System for procurement of equipment"
	lab var s10b_4_a_os "4. Inventory of equipment"
	lab var s10c_1_a_os "1 Record keeping and documentation"
	lab var s10d_1_a_os "1. Quality control practices"
	lab var s10d_2_a_os "2. Procurement and storage of reagents"
	lab var s10e_1_a_os "1. Hygiene protocol"
	lab var s10e_2_a_os "2. Hand washing"
	lab var s10e_3_a_os "3. Solid waste management"
	lab var s10e_4_a_os "4. Use of disinfectants"
	lab var s10e_5_a_os "5. Protective equipment"
	lab var s11a_1_a_os "1. Personal radiation dose monitoring"
	lab var s11a_2_a_os "2. Radiation safety service provider "
	lab var s11a_3_a_os "3. Adequate number of lead aprons "
	lab var s11a_4_a_os "4. Radiological examination in pregnancy "
	lab var s11a_5_a_os "5. Quality assurance of image processing"
	lab var s11b_1_a_os "1. Policies, SOPs and code of practice"
	lab var s11b_2_a_os "2. Reporting, testing and calibration "
	lab var s11b_3_a_os "3. Register of eradiating activities "
	lab var s11b_4_a_os "4. Quality assurance program"
	lab var s11c_1_a_os "1. Personal safety measures "
	lab var s11c_2_a_os "2. Radioactive waste management programs in place "
	lab var s11c_3_a_os "3. Designated staff for radioactive waste management programs "
	lab var s11d_1_a_os "1. Hygiene protocol"
	lab var s11d_2_a_os "2. Hand washing"
	lab var s11d_3_a_os "3. Use of disinfectants"
	lab var s11d_4_a_os "4. Protective equipment"
	lab var s12a_1_a_os "1. Nutrition equipment and tools "
	lab var s12a_2_a_os "2. Food supplies, formulations and Nutrition supplements "
	lab var s12b_1_a_os "1 SOPs for nutrition car processes and other services"
	lab var s12c_1_a_os "2 Record keeping and documentation"
	lab var s12d_1_a_os "1. Inpatient feeding"
	lab var s12d_2_a_os "2. Maternity feeding "
	lab var s12e_1_a_os "1. Kitchen equipment and fuel"
	lab var s12e_2_a_os "2. Food Preparation Unit layout"
	lab var s12e_3_a_os "3. Kitchen personnel"
	lab var s12f_1_a_os "1 Hygiene protocol"
	lab var s12f_2_a_os "2. Hand washing"
	lab var s12f_3_a_os "3. Solid waste management"
	lab var s12f_4_a_os "4. Use of disinfectants"
	lab var s12f_5_a_os "5. Protective equipment"

********************************************************************************

** Part 3: Percentage Scores

********************************************************************************

*^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
	** Percentage scores: L0
*^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
 	local L1_ms s2_a_ms s3_a_ms s4_a_ms s5_a_ms s6_a_ms s7_a_ms s8_a_ms s9_a_ms s10_a_ms s11_a_ms s12_a_ms
	
	egen total_ms = rowtotal(`L1_ms')		
 	gen total_ps = total_s/total_ms	
	
	* Checking
	//br s2_a_os s3_a_os s4_a_os s5_a_os s6_a_os s7_a_os s8_a_os s9_a_os s10_a_os s11_a_os s12_a_os total_s total_ms total_ps
	
*^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
	** Percentage scores: L1
*^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
	 * Generate percentage scores for all level 1 variables 
	 forvalues i=2(1)12 {
		gen s`i'_a_ps = s`i'_a_os/ s`i'_a_ms
	 }
	 
	 * Checking  
	 //br s2_a_os s2_a_ms s2_a_ps

*^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
	** Percentage scores: L2
*^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
 	 
	 * Generate percentage scores for all level 2 variables 
	 forvalues i=2(1)12 {
		foreach x in a b c d e f {
			capture gen s`i'`x'_a_ps = s`i'`x'_a_os/ s`i'`x'_a_ms

		}		
	 }
	 
	 * Checking 
	 //br s2a_a_os s2a_a_ms s2a_a_ps
	 //br s7b_a_os s7b_a_ms s7b_a_ps

*^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
	** Percentage scores: L3
*^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^

	 * Generate percentage scores for all level 3 variables 
	 forvalues i=2(1)12 {
		foreach x in a b c d e f {
			forvalues j = 1(1)8 {
				capture gen s`i'`x'_`j'_a_ps = s`i'`x'_`j'_a_os/ s`i'`x'_`j'_a_ms
				
				if _rc!=0 {
					display "s`i'`x'_`j'_a_ps problem"			  
				} 				
			}
		}		
	 }

	 * Checking
	 //br s2a_1_a_os s2a_1_a_ms s2a_1_a_ps 
	 //br s8a_1_a_os s8a_1_a_ms s8a_1_a_ps 
	 //br s8b_1_a_os s8b_1_a_ms s8b_1_a_ps 
	 //br s8b_2_a_os s8b_2_a_ms s8b_2_a_ps 
	 
*^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
	** Percentage scores: L4
*^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^

	 * Generate percentage scores for all level 4 variables 
	 
	 forvalues i=2(1)12 {
	 
		foreach x in a b c d e f {
		
			forvalues j=1(1)8 {
				
				foreach y in a b c d e f g h i j k l {
				
					capture gen s`i'`x'_`j'`y'_a_ps = s`i'`x'_`j'`y'_a_os/ s`i'`x'_`j'`y'_a_ms
					
					if _rc!=0 {					
					display "s`i'`x'_`j'_a_ps problem"			  
					} 	
				
				}
			
			}
		
		}
	 
	 } 
	
	* Percentage scores level 4: Special questions (satisfactory disatisfactory)
	replace s2a_2a_a_ps = s2a_2a_a_os/10
	replace s2a_3a_a_ps = s2a_3a_a_os/10	
	replace s4a_3a_a_ps = s4a_3a_a_os/5
	replace s9a_1a_a_ps = s9a_1a_a_os/10
	replace s9a_2a_a_ps = s9a_2a_a_os/5
	 
	* Checking
	//br s3a_1a_a_os s3a_1a_a_ms s3a_1a_a_ps 
	//br s10a_2a_a_os s10a_2a_a_ms s10a_2a_a_ps 

*^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
	** Labeling percentage scores
*^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
	
	** Labeling percentage scores: Level 4
	lab var s2a_1a_a_ps "Does the facility display legible signage?"
	lab var s2a_1b_a_ps "Does HF display signage that is accurate outside the facility? if signage"
	lab var s2a_1c_a_ps "Does the signage outside the facility include the facility name? if signage"
	lab var s2a_1d_a_ps "Does the signage inside the facility include department names and direction? if signage"
	lab var s2a_1e_a_ps "Does the facility have an accessibility ramp for disabled/wheelchair patients?"

	lab var s2a_2a_a_ps "Adequate ventilation"	
	lab var s2a_3a_a_ps "Adequate lighting"
	
	lab var s2b_1a_a_ps "Is safe, clean water available from a tap or container?"
	lab var s2b_1b_a_ps "Is there sufficient storage for the water?"
	lab var s2b_2a_a_ps "Is there a stable source of power?"
	lab var s2b_3a_a_ps "Are clean toilets available for both male and female clients?"
	lab var s2b_3b_a_ps "Is there a cleaning roster displayed?"
	lab var s2c_1a_a_ps "Does the facility have a lockable door?"
	lab var s2c_1b_a_ps "Is the door secured with grills or another security mechanism?"
	lab var s2c_2a_a_ps "Does the facility have a fire control mechanism such as a fire extinguisher, sand buckets?"
	lab var s2c_2b_a_ps "Is the equipment available in the reception area as well as specific departments? if L4/L5"
	lab var s2c_3a_a_ps "Does the facility have a fire assembly point or fire assembly protocol? if L4/L5"
	lab var s2c_3b_a_ps "Is there a documented firefighting protocol?"
	lab var s2c_3c_a_ps "Does the facility display emergency exit?"
	lab var s2c_3d_a_ps "Does the facility display fire assembly point signage? if L4/L5 & assembly point"
	lab var s2c_4a_a_ps "Is there a security system present (e.g. security guard, alarm system)?"
	lab var s3a_1a_a_ps "Does the facility have a strategic plan with its vision, values, and objectives?"
	lab var s3a_1b_a_ps "Is the plan displayed and shared to all staff? if strategic plan" 
	lab var s3a_1c_a_ps "Does the facility have an annual work plan or a business plan?"
	lab var s3a_1d_a_ps "Is there an organizational chart available and approved by management?"
	lab var s3a_2a_a_ps "Is a client service charter displayed?"
	lab var s3a_2b_a_ps "Is it displayed in all key departments/areas? if charter"
	lab var s3a_2c_a_ps "Mention common services offered? if charter"
	lab var s3a_2d_a_ps "Mention obligations to clients? if charter"
	lab var s3a_2e_a_ps "Mention waiting times for clients? if charter"
	lab var s3a_2f_a_ps "Mention ways to communicate with management regarding problems? if charter"
	lab var s3a_2g_a_ps "Mention services offered for free if charter"
	lab var s3a_2h_a_ps "Does the facility have a regular performance review for the charter targets?if charter"
	lab var s3a_3a_a_ps "Does the facility have a list of all staff with qualifications and job descripti"
	// lab var s3a_3b_a_ps "Are copies of professional certificates for all staff available at the facility?"
	lab var s3b_2a_a_ps "Infant mortality"
	lab var s3b_2b_a_ps "Maternal mortality"
	lab var s3b_2c_a_ps "Immunization"
	lab var s3b_2d_a_ps "Notifiable diseases"
	lab var s3b_2e_a_ps "Are performance indicators shared with staff and published regularly?"
	lab var s3b_3a_a_ps "Is there a functional feedback mechanism, such as a suggestion box, hotline numb"
	lab var s3b_3b_a_ps "Is client feedback reviewed at least biweekly? if feedbacl"
	lab var s3b_3c_a_ps "Are client suggestions documented in a report? if feedback"
	lab var s3c_1a_a_ps "Are medical records kept for each patient?"
	lab var s3c_1b_a_ps "Do the records include names and unique patient numbers? if records"
	lab var s3c_1c_a_ps "Are all the records legible and signed? if records"
	lab var s3c_2a_a_ps "Are outpatients registers kept?"
	lab var s3c_2b_a_ps "Are inpatients registers kept?"
	lab var s3c_2c_a_ps "Are inpatient and outpatient records kept separately?"
	lab var s3c_2d_a_ps "Are the registers up to date?"
	lab var s3c_3a_a_ps "Is there a system in place for storing medical records? if records"
	lab var s3c_3b_a_ps "Is there a filing and numbering system for easy retrieval? if records & system"
	lab var s3c_3c_a_ps "Are the records protected in cabinets (if paper) or by password (if digital)?"
	lab var s3c_5a_a_ps "Does the facility contribute to the DHIS?"
	lab var s3d_1a_a_ps "Is there a service contract for maintenance?"
	lab var s3d_1b_a_ps "Is there a written schedule (including next service date) for maintaining equipm"
	lab var s3d_2a_a_ps "Is there a written calibration schedule available at the area where equipment is"
	lab var s3d_2b_a_ps "Is there a document showing regular calibration?"
	lab var s3d_2c_a_ps "Are contracts available at the facility administration?"
	lab var s4a_1a_a_ps "Does the facility have a hygiene protocol?"
	lab var s4a_1b_a_ps "Does the facility have a dedicated staff roster for cleaning?"
	lab var s4a_2a_a_ps "Is there a standard operating procedure for waste management?"
	lab var s4a_2b_a_ps "Is there an incinerator or contracted waste management company?"
	lab var s4a_2c_a_ps "Does the facility have a waste holding area?"
	lab var s4a_3a_a_ps "HF Cleanliness"	
	lab var s4a_3b_a_ps "Is the paint work acceptable?"
	lab var s4a_3c_a_ps "Is the floor smooth?"
	lab var s4a_3d_a_ps "Is the ceiling free of cobwebs and dust?"
	lab var s4a_4a_a_ps "Is the grass well maintained?"
	lab var s4a_4b_a_ps "Are the bushes neatly kept?"
	lab var s4a_4c_a_ps "Is the site free of odor?"
	lab var s4b_1a_a_ps "Is there a separate area for cleaning with decontamination and sterilization processes?"
	lab var s4b_1b_a_ps "Are standard operating procedures available for sterilization?"
	lab var s4b_1c_a_ps "Is there storage available for sterile supplies?"
	lab var s4b_1d_a_ps "Are sterile supplies labeled and stored in a designated area?"
	lab var s5a_1a_a_ps "Does the facility have a triage area with a qualified nurse(s)?"
	lab var s5a_1b_a_ps "Is it located at the first point of contact with patients? if triage"
	lab var s5a_1c_a_ps "Is there a standard operating procedure for triage? if triage"
	lab var s5a_1d_a_ps "Is there a system for coding patients?"
	lab var s5a_2a_a_ps "Does the examination room have a coach and a mackintosh?"
	lab var s5a_2b_a_ps "Does the room have a consultation table with at least two chairs?"
	lab var s5a_2c_a_ps "Does the room have a pedal bin and stepper?"
	lab var s5a_3a_a_ps "Is a thermometer available?"
	lab var s5a_3b_a_ps "Is a stethoscope available?"
	lab var s5a_3c_a_ps "Is a tongue depressor available?"
	lab var s5a_3d_a_ps "Is a weighing scale available/accessible?"
	lab var s5a_3e_a_ps "Is a blood pressure (BP) machine available/accessible?"
	lab var s5a_3f_a_ps "Is a torch available?"
	lab var s5a_3g_a_ps "Is a privacy screen available?"
	lab var s5a_3h_a_ps "Is a diagnostic set available?"
	lab var s5a_3i_a_ps "Is a lamp available?"
	lab var s5a_4a_a_ps "Does the facility have an emergency tray available at designated sites?"
	lab var s5a_4b_a_ps "Is there a checklist for regular review and updates to the emergency tray? if emerg tray"
	lab var s5a_4c_a_ps "Glucose if emerg tray"
	lab var s5a_4d_a_ps "Adrenaline if emerg tray"
	lab var s5a_4e_a_ps "Sodium bicarbonate if emerg tray"
	lab var s5a_4f_a_ps "Diazepam if emerg tray"
	lab var s5a_4g_a_ps "Phenobarbitone if emerg tray"
	lab var s5a_4h_a_ps "Ambu bag and mask available in pediatric and adult sizes"
	lab var s5a_4i_a_ps "Adjustable bed  "
	lab var s5a_4j_a_ps "Functional suction machine"
	lab var s5a_4k_a_ps "Oxygen cylinder and flowmeter, or piped oxygen"
	lab var s5a_4l_a_ps "Endotracheal tubes"
	lab var s5b_1a_a_ps "Is there a hygiene protocol?"
	lab var s5b_1b_a_ps "Does the hygiene protocol have a dedicated staff roster available?"
	lab var s5b_2a_a_ps "Is a sink present with running water from a tap or modified storage container?"
	lab var s5b_2b_a_ps "Is soap available at the hand washing area?"
	lab var s5b_3a_a_ps "Are there at least two color-coded bins (red, black and/or yellow)?"
	lab var s5b_3b_a_ps "Are there coded lining bags that match the color of the bins?"
	lab var s5b_3c_a_ps "Are there standard operating procedures for waste management?"
	lab var s5b_4a_a_ps "Is there disinfectant readily available in the consultation room?"
	lab var s5b_4b_a_ps "Are you able to observe disinfectant containers used for cleaning?"
	lab var s5b_5a_a_ps "Are gloves available?"
	lab var s5b_5b_a_ps "Are gowns or dust coats available?"
	lab var s5b_5c_a_ps "Are face masks available?"
	lab var s5b_5d_a_ps "Are safety boots available?"
	lab var s6a_1a_a_ps "Is there privacy in the ward (privacy during delivery)?"
	lab var s6a_1b_a_ps "Is a delivery bed available?"
	lab var s6a_1c_a_ps "Is a sterile delivery set available?"
	lab var s6a_1d_a_ps "Is a vacuum extractor available?"
	lab var s6a_1e_a_ps "Is a suction machine available?"
	lab var s6a_1f_a_ps "Is an ambu bag and mask available?"
	lab var s6a_1g_a_ps "Is a cord ligature available?"
	lab var s6a_1h_a_ps "Is there sufficient lighting?"
	lab var s6a_1i_a_ps "Are maintenance plans available for all equipment?"
	lab var s6a_2a_a_ps "Is the floor appropriately covered (e.g. ceramic tiles or terrazzo)?"
	lab var s6a_2b_a_ps "Is there a drainage system?"
	lab var s6a_2c_a_ps "Is there a cleaning chart?"
	lab var s6a_3a_a_ps "Does the labour ward have oxygen cylinder or piped oxygen connection?"
	lab var s6a_3b_a_ps "Are there standard operating procedures for oxygen?"
	lab var s6a_3c_a_ps "Is there a maintenance plan for oxygen?"
	lab var s6a_4a_a_ps "Are there procedures available for handling obstructed labour, foetal distress, eclampsia and APH/PPH/HELLP?"
	lab var s6a_4b_a_ps "Is a functional resusitaire available with oxygen, suction machine and ambu bags?"
	lab var s6a_5a_a_ps "Is an ambulance (or contact details) available?"
	lab var s6a_5b_a_ps "Is a fully equipped theatre near the labour ward?"
	lab var s6a_6a_a_ps "Is a partograph available?"
	lab var s6a_6b_a_ps "Is contraction properly charted?"
	lab var s6a_6c_a_ps "Is cervical dilation recorded?"
	lab var s6a_6d_a_ps "Is color coding done?"
	lab var s6a_6e_a_ps "Is TPR/BP recorded?"
	lab var s6a_6f_a_ps "Is urine output/input charted?"
	lab var s6a_6g_a_ps "Are drugs coded?"
	lab var s6a_7a_a_ps "Is a functional incubator available?"
	lab var s6a_7b_a_ps "Does the incubator have a temperature regulator? if incubator"
	lab var s6a_7c_a_ps "Does the incubator have an oxygen connection? if incubator"
	lab var s6a_7d_a_ps "Are maintenance plans available for the incubator? if incubator"
	lab var s6a_7e_a_ps "Is there a sitting area for nursing mothers?"
	lab var s6a_8a_a_ps "Is a sluice room with a sluicing sink available?"
	lab var s6a_8b_a_ps "Does the sluice room have running water? if sluice room"
	lab var s6a_8c_a_ps "Does it have a decontamination bucket? if sluice room"
	lab var s6a_8d_a_ps "Are standard operating procedures available? if sluice room"
	lab var s6b_1a_a_ps "Is there a hygiene protocol?"
	lab var s6b_1b_a_ps "Does the hygiene protocol have a dedicated staff roster available?"
	lab var s6b_2a_a_ps "Is a sink present with running water from a tap or modified storage container?"
	lab var s6b_2b_a_ps "Is soap available at the handwashing area?"
	lab var s6b_3a_a_ps "Are there at least two color-coded bins (red, black and/or yellow)?"
	lab var s6b_3b_a_ps "Are there coded lining bags that match the color of the bins?"
	lab var s6b_3c_a_ps "Are there standard operating procedures for waste management?"
	lab var s6b_4a_a_ps "Is there evidence of disinfectant use?"
	lab var s6b_4b_a_ps "Are you able to observe disinfectant containers used for cleaning?"
	lab var s6b_5a_a_ps "Are gloves available?"
	lab var s6b_5b_a_ps "Are gowns or dust coats available?"
	lab var s6b_5c_a_ps "Are face masks available?"
	lab var s6b_5d_a_ps "Are safety boots available?"
	lab var s7a_1a_a_ps "Are admissions procedures standardized with patient categorizations?"
	lab var s7a_1b_a_ps "Are patients in hospital uniform?"
	lab var s7a_1c_a_ps "Are there regular ward rounds?"
	lab var s7a_1d_a_ps "Are there handover and discharge reports on a standard form?"
	lab var s7a_2a_a_ps "Are patient records kept with unique reference numbers?"
	lab var s7a_2b_a_ps "Is the filing system secure?"
	lab var s7a_3a_a_ps "Does each ward have a BP machine?"
	lab var s7a_3b_a_ps "Does each ward have a thermometer?"
	lab var s7a_3c_a_ps "Does each ward have a pulse oxymeter?"
	lab var s7a_3d_a_ps "Does each ward have a suction machine?"
	lab var s7a_3e_a_ps "Does each ward have an emergency room?"
	lab var s7b_1a_a_ps "Is there a hygiene protocol?"
	lab var s7b_1b_a_ps "Does the hygiene protocol have a dedicated staff roster available?"	
	lab var s7b_2a_a_ps "Is a sink present with running water from a tap or modified storage container?"
	lab var s7b_2b_a_ps "Is soap available at the handwashing area?"
	lab var s7b_3a_a_ps "Are there at least two color-coded bins (red, black and/or yellow)?"
	lab var s7b_3b_a_ps "Are there coded lining bags that match the color of the bins?"
	lab var s7b_3c_a_ps "Are there standard operating procedures for waste management?"
	lab var s7b_4a_a_ps "Is there evidence of disinfectant use?"
	lab var s7b_4b_a_ps "Are you able to observe disinfectant containers used for cleaning?"
	lab var s7b_5a_a_ps "Are gloves available?"
	lab var s7b_5b_a_ps "Are gowns or dust coats available?"
	lab var s7b_5c_a_ps "Are face masks available?"
	lab var s7b_5d_a_ps "Are safety boots available?"
	lab var s8a_1a_a_ps "Does the receiving area have a barrier?"
	lab var s8a_1b_a_ps "Does the receiving area have a shoe rack?"
	lab var s8a_1c_a_ps "Does the receiving area have a coach?"
	lab var s8a_1d_a_ps "Does the receiving area have adequate lighting?"
	lab var s8a_2a_a_ps "Does the theatre have male and female changing rooms with barrier?"
	lab var s8a_2b_a_ps "Do changing rooms have clean clothing?"
	lab var s8a_2c_a_ps "Do changing rooms have masks?"
	lab var s8a_2d_a_ps "Do changing rooms have caps?"
	lab var s8a_2e_a_ps "Do changing rooms have theatre shoes?"
	lab var s8a_2f_a_ps "Is there a scrubbing area present?"
	lab var s8a_2g_a_ps "Is there a hands-free tap?"
	lab var s8a_2h_a_ps "Are there swinging theatre doors?"
	lab var s8a_3a_a_ps "Does the operating area have adequate space?"
	lab var s8a_3b_a_ps "Does the operating area have adequate lighting?"
	lab var s8a_3c_a_ps "Does the operating area have adequate cabinets for non-pharms?"
	lab var s8a_3d_a_ps "Does the operating area have adequate sterile gloves?"
	lab var s8a_3e_a_ps "Does the operating area have a standard operating table?"
	lab var s8a_3f_a_ps "Does the operating area have an adequate functional anaesthetic machine?"
	lab var s8a_3g_a_ps "Does the operating area have adequate ambu-bags, both adult and paediatric?"
	lab var s8a_3h_a_ps "Does the operating area have adequate monitors?"
	lab var s8a_3i_a_ps "Does the operating area have adequate laryngoscopes?"
	lab var s8a_3j_a_ps "Does the operating area have adequate endotracheal tubes?"
	lab var s8a_3k_a_ps "Does the operating room have a functioning suction machine?"
	lab var s8a_3l_a_ps "Does the operating room have adequate back-up oxygen, separate from anaesthetic "
	lab var s8a_4a_a_ps "Are there at least three nurses (scrub, runner and anaesthetic nurse)?"
	lab var s8a_4b_a_ps "Are nurses skilled with peri-operative training?"
	lab var s8a_5a_a_ps "Does the recovery room have adequate lighting?"
	lab var s8a_5b_a_ps "Does the recovery room have a monitor?"
	lab var s8a_5c_a_ps "Does the recovery room have a drip stand?"
	lab var s8b_1a_a_ps "Is there a hygiene protocol?"
	lab var s8b_1b_a_ps "Does the hygiene protocol have a dedicated staff roster available?"
	lab var s8b_2a_a_ps "Is a sink present with running water from a tap or modified storage container?"
	lab var s8b_2b_a_ps "Is soap available at the hand washing area?"
	lab var s8b_3a_a_ps "Are there at least two color-coded bins (red, black and/or yellow)?"
	lab var s8b_3b_a_ps "Are there coded lining bags that match the color of the bins?"
	lab var s8b_3c_a_ps "Are there standard operating procedures for waste management?"
	lab var s8b_4a_a_ps "Is there evidence of disinfectant use?"
	lab var s8b_4b_a_ps "Are you able to observe disinfectant containers used for cleaning?"
	lab var s8b_5a_a_ps "Are gloves available?"
	lab var s8b_5b_a_ps "Are gowns or dust coats available?"
	lab var s8b_5c_a_ps "Are face masks available?"
	lab var s8b_5d_a_ps "Are safety boots available?"
	lab var s9a_1a_a_ps "Adequate ventilation in pharm"
	lab var s9a_2a_a_ps "Adequate lighting in pharm"	
	lab var s9a_2b_a_ps "Does the pharmacy have adequate space for staff movement in the dispensing area?"
	lab var s9b_1a_a_ps "Does the pharmacy have secure, lockable cupboards for restricted drugs only acce"
	lab var s9b_1b_a_ps "Are drugs stored and displayed to good standards?"
	lab var s9b_1c_a_ps "Are there standard operating procedures for the storage of medicines?"
	lab var s9c_1a_a_ps "Does the pharmacy have a well-explained system for recording prescriptions?"
	lab var s9c_1b_a_ps "Does the pharmacy have standard operating procedures for disposal of expired dru"
	lab var s9c_1c_a_ps "Is there a daily updated inventory system showing which commodities are availabl"
	lab var s9c_1d_a_ps "Is there documentation showing where medicines are procured?"
	lab var s9c_1e_a_ps "Are there systems for documenting and feeding back medication errors?"
	lab var s9c_1f_a_ps "Are there separate records for narcotic and psychotropic medicines?"
	lab var s9d_1a_a_ps "Does the pharmacy have reference materials for medicines (e.g. drug index)?"
	lab var s9d_1b_a_ps "Is the staff familiar with these reference materials? if materials"
	lab var s9e_1a_a_ps "Is there a hygiene protocol?"	
	lab var s9e_1b_a_ps "Does the hygiene protocol have a dedicated staff roster available?"
	lab var s9e_2a_a_ps "Is a sink present with running water from a tap or modified storage container?"
	lab var s9e_2b_a_ps "Is soap available at the handwashing area?"
	lab var s9e_3a_a_ps "Are there at least two color-coded bins (red, black and/or yellow)?"
	lab var s9e_3b_a_ps "Are there coded lining bags that match the color of the bins?"
	lab var s9e_3c_a_ps "Are there standard operating procedures for waste management?"
	lab var s9e_4a_a_ps "Is there evidence of disinfectant use?"
	lab var s9e_4b_a_ps "Are you able to observe disinfectant containers used for cleaning?"
	lab var s9e_5a_a_ps "Are gloves available?"
	lab var s9e_5b_a_ps "Are gowns or dust coats available?"
	lab var s9e_5c_a_ps "Are face masks available?"
	lab var s9e_5d_a_ps "Are safety boots available?"
	lab var s10a_2a_a_ps "Does the laboratory have SOPs and guidelines for reporting lab procedures?"
	lab var s10a_2b_a_ps "Are the SOPs and guidelines for reporting lab procedures displayed? if SOPS"
	lab var s10a_3a_a_ps "Does the laboratory have SOPs and guidelines for handling, labeling and storage "
	lab var s10a_3b_a_ps "Are the SOPs and guidelines for handl, label and storage of specimens disp if SOPS"
	lab var s10a_4a_a_ps "Does the laboratory have SOPs and guidelines for disposal of specimens?"
	lab var s10a_4b_a_ps "Are the SOPs and guidelines for disposal of specimens displayed? if SOPS"
	lab var s10a_5a_a_ps "Does the laboratory have standard quality operational manual (SOP of SOPs) avail"
	lab var s10b_1a_a_ps "Does the lab have a system for regular calibration/validation of equipment avail"
	lab var s10b_1b_a_ps "Is the system for calibration of equipment placed close to respective if system"
	lab var s10b_2a_a_ps "Does the laboratory have a systematic, well-documented equipment maintenance sch"
	lab var s10b_2b_a_ps "Are service contracts available for all lab equipment?"
	lab var s10b_3a_a_ps "Does lab have a system for equipment procurement that is known by staff?"
	lab var s10b_4a_a_ps "Does the laboratory have a list of all equipment in use?"
	lab var s10b_4b_a_ps "Does the laboratory have a functional inventory management system?"
	lab var s10c_1a_a_ps "Does lab have a records system integrated in the facility record system, i.e. La"
	lab var s10d_1a_a_ps "Are equipment registered, validated and calibrated?"
	lab var s10d_1b_a_ps "Is there documentation of quality control of tests?"
	lab var s10d_1c_a_ps "Is there a documented system for regular review and improvement of laboratory te"
	lab var s10d_1d_a_ps "Is there documentation of sample archiving, retrieval and disposal?"
	lab var s10d_1e_a_ps "Is Internal Quality Control (IQC) done regularly?"
	lab var s10d_1f_a_ps "Is the laboratory enrolled in External Quality Assurance?"
	lab var s10d_2a_a_ps "Does the laboratory have a functional temperature recording system in place?"
	lab var s10d_2b_a_ps "Are standards for procurement and safe storage of reagents in place, including a"
	lab var s10e_1a_a_ps "Is there a hygiene protocol?"
	lab var s10e_1b_a_ps "Does the hygiene protocol with a dedicated staff roster available?"
	lab var s10e_2a_a_ps "Is a sink present with running water from a tap or modified storage container?"
	lab var s10e_2b_a_ps "Is soap available at the handwashing area?"
	lab var s10e_3a_a_ps "Are there at least two color-coded bins (red, black and/or yellow)?"
	lab var s10e_3b_a_ps "Are there coded lining bags that match the color of the bins?"
	lab var s10e_3c_a_ps "Are there standard operating procedures for waste management?"
	lab var s10e_4a_a_ps "Is there evidence of disinfectant use?"
	lab var s10e_4b_a_ps "Are you able to observe disinfectant containers used for cleaning?"
	lab var s10e_5a_a_ps "Are gloves available?"
	lab var s10e_5b_a_ps "Are gowns or dust coats available?"
	lab var s10e_5c_a_ps "Are face masks available?"
	lab var s10e_5d_a_ps "Are safety boots available?"
	lab var s11a_1a_a_ps "Are personal radiation dose monitoring badges worn daily and evaluated monthly b"
	lab var s11a_2a_a_ps "Does the facility have records confirming that there is a radiation safety servi"
	lab var s11a_3a_a_ps "Is there an adequate number of lead aprons, i.e. a minimum of three: one each fo"
	lab var s11a_4a_a_ps "Is a code of practice for pregnant women available and producible?"
	lab var s11a_5a_a_ps "Is there evidence of quality assurance of the image processing system"
	lab var s11b_1a_a_ps "Are standard operating procedures available for radiology and imaging services?"
	lab var s11b_1b_a_ps "Is there evidence that they've been reviewed in the past year... if stand oper proc"
	lab var s11b_1c_a_ps "Is a code of practice displayed next to the respective device?"
	lab var s11b_2a_a_ps "Is reporting, testing and calibrating up to date and displayed?"
	lab var s11b_3a_a_ps "Is there a register of eradiating activities and a monthly dose report for worke"
	lab var s11b_4a_a_ps "Is there a quality assurance program?"
	lab var s11b_4b_a_ps "Does the quality/assurance/progr include safety patient... if quality assurance"
	lab var s11b_4c_a_ps "Is there a designated or appointed quality assurance staff member in the facilit"
	lab var s11b_4d_a_ps "Is there updated annual documentation for quality assurance procedures?"
	lab var s11c_1a_a_ps "Does the facility produce radioactive waste?"
	lab var s11c_1b_a_ps "Are patient and staff safety measures implemented alongside routine waste manage"
	lab var s11c_2a_a_ps "Is there designated staff in charge of rad. waste management? if radioactive waste"
	lab var s11c_2b_a_ps "Are there records showing that rad. waste manag. syst. are in place if radioactive waste"
	lab var s11c_3a_a_ps "Does the facility have designated personnel to oversee rad. waste managem. if radioactive waste"
	lab var s11d_1a_a_ps "Is there a hygiene protocol?"	
	lab var s11d_1b_a_ps "Does the hygiene protocol have a dedicated staff roster available?"
	lab var s11d_2a_a_ps "Is a sink present with running water from a tap or modified storage container?"
	lab var s11d_2b_a_ps "Is soap available at the handwashing area?"
	lab var s11d_3a_a_ps "Is there evidence of disinfectant use?"
	lab var s11d_3b_a_ps "Are you able to observe disinfectant containers used for cleaning?"
	lab var s11d_4a_a_ps "Are gloves available?"
	lab var s11d_4b_a_ps "Are gowns or dust coats available?"
	lab var s11d_4c_a_ps "Are face masks available?"
	lab var s11d_4d_a_ps "Are safety boots available?"
	lab var s12a_1a_a_ps "Is a functional calibrated weighing scale available?"
	lab var s12a_1b_a_ps "Is a stadiometer available?"
	lab var s12a_1c_a_ps "Are Mid-Upper Arm Circumference (MUAC) tapes available?"
	lab var s12a_1d_a_ps "Is a waist circumference tape available?"
	lab var s12a_1e_a_ps "Is a functional blood pressure machine available?"
	lab var s12a_1f_a_ps "Is a functional glucometer available?"
	lab var s12a_1g_a_ps "Are reference charts available?"
	lab var s12a_2a_a_ps "Is food store available with evidence of regular stock replenishment?"
	lab var s12a_2b_a_ps "Are ‘Ready to Use Therapeutic Foods’ (RUTF) available and accessible?"
	lab var s12a_2c_a_ps "Are ‘Ready to Use Supplementary Foods’ (RUSF) available and accessible?"
	lab var s12a_2d_a_ps "Are the F75 and F100 diet milks available and adequate for clients?"
	lab var s12a_2e_a_ps "Are food fortifiers available and acceptable?"
	lab var s12a_2f_a_ps "Are nutrition formulations for specialized nutrition support available and acces"
	lab var s12a_2g_a_ps "Are Vitamin A Supplements available for children and expectant mothers?"
	lab var s12a_2h_a_ps "Are iron supplements available in the acceptable form?"
	lab var s12a_2i_a_ps "Are folate supplements available in the acceptable form?"
	lab var s12a_2j_a_ps "Is zinc supplement available?"
	lab var s12b_1a_a_ps "Are there SOPs for comprehensive nutritional assessment?"
	lab var s12b_1b_a_ps "Are there adequate guidelines for nutritional diagnosis?"
	lab var s12b_1c_a_ps "Are there guidelines for choice of appropriate nutrition care intervention?"
	lab var s12b_1d_a_ps "Are there adequate guidelines for monitoring patient care?"
	lab var s12b_1e_a_ps "Are there adequate SOPs for food formulations?"
	lab var s12b_1f_a_ps "Are there adequate SOPs for food supplementation?"
	lab var s12b_1g_a_ps "Are SOPs reviewed and regularly updated (within a 5-year framework)?"
	lab var s12b_1h_a_ps "Are staff familiar with the SOPs and guidelines?"
	lab var s12c_1a_a_ps "Is the system for record keeping linked to the facility information management s"
	lab var s12c_1b_a_ps "Is there a designated person aware of the documentation processes?"
	lab var s12c_1c_a_ps "Is there security for the information in the system?"
	lab var s12c_1d_a_ps "Is there a documented plan for regular updating?"
	lab var s12d_1a_a_ps "Is there an inpatient feeding committee?"
	lab var s12d_1b_a_ps "Does the composition of the committee include qualified nutritionist and dietici"
	lab var s12d_1c_a_ps "Is there a comprehensive protocol for inpatient feeding?"
	lab var s12d_1d_a_ps "Is there a food inspection committee with at least one licensed nutritionist?"
	lab var s12d_1e_a_ps "Is there a communication link between patients in the ward and the food preparat"
	lab var s12d_1f_a_ps "Are there food modification schemes for groups with special needs?"
	lab var s12d_1g_a_ps "Is there an option for patients to choose from available sources of foods?"
	lab var s12d_2a_a_ps "Are postpartum mothers fed on an appropriately tailored diet?"
	lab var s12d_2b_a_ps "Is breastfeeding initiated within one hour after delivery?"
	lab var s12e_1a_a_ps "Is a functional blender available?"
	lab var s12e_1b_a_ps "Is a functional mincer available?"
	lab var s12e_1c_a_ps "Is a functional food weighing scale available and regularly calibrated?"
	lab var s12e_1d_a_ps "Are measuring jars available?"
	lab var s12e_1e_a_ps "Are food trolleys available?"
	lab var s12e_1f_a_ps "Are reliable sources of fuel available?"
	lab var s12e_2a_a_ps "Is the layout and physical structure of the kitchen adequate?"
	lab var s12e_2b_a_ps "Is a diet therapy kitchen available and separated from normal food kitchen?"
	lab var s12e_2c_a_ps "Is a mini store available in the kitchen for food from the main store?"
	lab var s12e_2d_a_ps "Does the paediatric ward have room to prepare special food?"
	lab var s12e_2e_a_ps "Is there adequate space for storage of food commodities?"
	lab var s12e_3a_a_ps "Are kitchen personnel qualified caterers and trained cooks?"
	lab var s12e_3b_a_ps "Is the supervisor qualified and licensed by the Nutritionist and Dieticians Inst"
	lab var s12f_1a_a_ps "Is there a hygiene protocol?"
	lab var s12f_1b_a_ps "Does the hygiene protocol have a dedicated staff roster available?"
	lab var s12f_2a_a_ps "Is a sink present with running water from a tap or modified storage container?"
	lab var s12f_2b_a_ps "Is soap available at the hand washing area?"
	lab var s12f_3a_a_ps "Are there at least two color-coded bins (red, black and/or yellow)?"
	lab var s12f_3b_a_ps "Are there coded lining bags that match the color of the bins?"
	lab var s12f_3c_a_ps "Are there standard operating procedures for waste management?"
	lab var s12f_4a_a_ps "Is there evidence of disinfectant use?"
	lab var s12f_4b_a_ps "Are you able to observe disinfectant containers used for cleaning?"
	lab var s12f_5a_a_ps "Are gloves available and accessible?"
	lab var s12f_5b_a_ps "Are gowns or dust coats available and accessible?"
	lab var s12f_5c_a_ps "Are face masks available and accessible?"
	lab var s12f_5d_a_ps "Are safety boots available and accessible?"
	
	** Labeling percentage scores: Level 1
	lab var s2_a_ps "Section 2: Health Facility Infrastructure"
	lab var s3_a_ps "Section 3: General Management and Recording of Information"
	lab var s4_a_ps "Section 4: Infection Prevention and Control"
	lab var s5_a_ps "Section 5: Medical and Dental Consultation Services"
	lab var s6_a_ps "Section 6: Labour Ward"
	lab var s7_a_ps "Section 7: Medical and Pediatric Wards"
	lab var s8_a_ps "Section 8: Theatre"
	lab var s9_a_ps "Section 9: Pharmacy"
	lab var s10_a_ps "Section 10. Laboratory"
	lab var s11_a_ps "Section 11: Radiology"
	lab var s12_a_ps "Section 12: Nutrition and Dietetics Service Unit"

	** Labeling percentage scores: Level 2
	lab var s2a_a_ps "A. Building"
	lab var s2b_a_ps "B. Utilities"
	lab var s2c_a_ps "C. Security"
	lab var s3a_a_ps "A. General Management"
	lab var s3b_a_ps "B. Quality Management"
	lab var s3c_a_ps "C. Medical Records and Information Systems"
	lab var s3d_a_ps "D. Equipment Management"
	lab var s4a_a_ps "A. General"
	lab var s4b_a_ps "B. Sterilization Services"
	lab var s5a_a_ps "A. General"
	lab var s5b_a_ps "B. Infection prevention and control"
	lab var s6a_a_ps "A. General"
	lab var s6b_a_ps "B. Infection prevention and control"
	lab var s7a_a_ps "A. General"
	lab var s7b_a_ps "B. Infection prevention and control"
	lab var s8a_a_ps "A. General"
	lab var s8b_a_ps "B. Infection prevention and control"
	lab var s9a_a_ps "A. General condition of premises"
	lab var s9b_a_ps "B. Storage and display of commodities "
	lab var s9c_a_ps "C. Record keeping and documentation "
	lab var s9d_a_ps "D. Reference materials and policies"
	lab var s9e_a_ps "E. Infection prevention and control"
	lab var s10a_a_ps "A. Policies, guidelines and SOPs "
	lab var s10b_a_ps "B. Equipment management program "
	lab var s10c_a_ps "C. Record keeping and documentation "
	lab var s10d_a_ps "D. Quality control of tests "
	lab var s10e_a_ps "E. Infection prevention and control"
	lab var s11a_a_ps "A. Radiation protection"
	lab var s11b_a_ps "B. Policies, SOPs and registers "
	lab var s11c_a_ps "C. Radioactive waste management "
	lab var s11d_a_ps "D. Infection prevention and control"
	lab var s12a_a_ps "A. Nutrition equipment, Tools and Supplies "
	lab var s12b_a_ps "B. SOPs for nutrition care processes and other services  "
	lab var s12c_a_ps "C. Record keeping and documentation"
	lab var s12d_a_ps "D. Patient feeding "
	lab var s12e_a_ps "E. Food Preparation Unit"
	lab var s12f_a_ps "F. Infection prevention and control"

	** Labeling percentage scores: Level 3
	lab var s2a_1_a_ps "1. Signage and accessibility"
	lab var s2a_2_a_ps "2. Ventilation"
	lab var s2a_3_a_ps "3. Lighting "
	lab var s2b_1_a_ps "1. Water"
	lab var s2b_2_a_ps "2. Electricity"
	lab var s2b_3_a_ps "3. Toilet facilities"
	lab var s2c_1_a_ps "1. Lockable door"
	lab var s2c_2_a_ps "2. Fire control mechanism"
	lab var s2c_3_a_ps "3. Fire assembly point"
	lab var s2c_4_a_ps "4. Security"
	lab var s3a_1_a_ps "1. Strategic Plan"
	lab var s3a_2_a_ps "2. Client Service Charter"
	lab var s3a_3_a_ps "3. List of staff"
	lab var s3b_2_a_ps "2. Monitoring performance indicators"
	lab var s3b_3_a_ps "3. Client feedback mechanism"
	lab var s3c_1_a_ps "1. Medical records for each patient"
	lab var s3c_2_a_ps "2. Approved register for all patients"
	lab var s3c_3_a_ps "3. System for storing medical records"
	lab var s3c_5_a_ps "5. Contribution to external databases and reports"
	lab var s3d_1_a_ps "1. Preventative maintenance plan for equipment"
	lab var s3d_2_a_ps "2. Calibration and validation"
	lab var s4a_1_a_ps "1. Hygiene protocol"
	lab var s4a_2_a_ps "2. Solid waste management"
	lab var s4a_3_a_ps "3. General facility cleanliness"
	lab var s4a_4_a_ps "4. General compound cleanliness"
	lab var s4b_1_a_ps "1. Central Supply Unit"
	lab var s5a_1_a_ps "1. Triage"
	lab var s5a_2_a_ps "2. Examination room"
	lab var s5a_3_a_ps "3. Examination equipment"
	lab var s5a_4_a_ps "4. Emergency tray and equipment"
	lab var s5b_1_a_ps "1. Hygiene protocol"
	lab var s5b_2_a_ps "2. Hand washing"
	lab var s5b_3_a_ps "3. Solid waste management"
	lab var s5b_4_a_ps "4. Use of disinfectants"
	lab var s5b_5_a_ps "5. Protective equipment"
	lab var s6a_1_a_ps "1. Labour ward"
	lab var s6a_2_a_ps "2. Labour room floor"
	lab var s6a_3_a_ps "3. Oxygen source"
	lab var s6a_4_a_ps "4. Procedures for obstetrics emergency"
	lab var s6a_5_a_ps "5. Access to theatre"
	lab var s6a_6_a_ps "6. Procedure for monitoring labour"
	lab var s6a_7_a_ps "7. New born unit"
	lab var s6a_8_a_ps "8. Sluice room"
	lab var s6b_1_a_ps "1. Hygiene protocol"
	lab var s6b_2_a_ps "2. Hand washing"
	lab var s6b_3_a_ps "3. Solid waste management"
	lab var s6b_4_a_ps "4. Use of disinfectants"
	lab var s6b_5_a_ps "5. Protective equipment"
	lab var s7a_1_a_ps "1. Patient oversight "
	lab var s7a_2_a_ps "2. Patient records"
	lab var s7a_3_a_ps "3. Monitoring equipment "
	lab var s7b_1_a_ps "1. Hygiene protocol"
	lab var s7b_2_a_ps "2. Hand washing"
	lab var s7b_3_a_ps "3. Solid waste management"
	lab var s7b_4_a_ps "4. Use of disinfectants"
	lab var s7b_5_a_ps "5. Protective equipment"
	lab var s8a_1_a_ps "1. Receiving area "
	lab var s8a_2_a_ps "2. Changing rooms and scrubbing area "
	lab var s8a_3_a_ps "3. Operating area "
	lab var s8a_4_a_ps "4. Staff requirements "
	lab var s8a_5_a_ps "5. Recovery room"
	lab var s8b_1_a_ps "1. Hygiene protocol"
	lab var s8b_2_a_ps "2. Hand washing"
	lab var s8b_3_a_ps "3. Solid waste management"
	lab var s8b_4_a_ps "4. Use of disinfectants"
	lab var s8b_5_a_ps "5. Protective equipment"
	lab var s9a_1_a_ps "1. Ventilation"
	lab var s9a_2_a_ps "2. Lighting "
	lab var s9b_1_a_ps "1. Storage and display of commodities"
	lab var s9c_1_a_ps "1 Record keeping and documentation"	
	lab var s9d_1_a_ps "1 Reference materials and policies (a)"
	lab var s9e_1_a_ps "1. Hygiene protocol"
	lab var s9e_2_a_ps "2. Hand washing"
	lab var s9e_3_a_ps "3. Solid waste management"
	lab var s9e_4_a_ps "4. Use of disinfectants"
	lab var s9e_5_a_ps "5. Protective equipment"
	lab var s10a_2_a_ps "2. Reporting procedures"
	lab var s10a_3_a_ps "3. Handling, labeling and storage of specimen"
	lab var s10a_4_a_ps "4. Disposal of specimens"
	lab var s10a_5_a_ps "5. Standard quality operational manual "
	lab var s10b_1_a_ps "1. Calibration and validation of equipment"
	lab var s10b_2_a_ps "2. Equipment maintenance documentation"
	lab var s10b_3_a_ps "3. System for procurement of equipment"
	lab var s10b_4_a_ps "4. Inventory of equipment"
	lab var s10c_1_a_ps "1 Record keeping and documentation"
	lab var s10d_1_a_ps "1. Quality control practices"
	lab var s10d_2_a_ps "2. Procurement and storage of reagents"
	lab var s10e_1_a_ps "1. Hygiene protocol"
	lab var s10e_2_a_ps "2. Hand washing"
	lab var s10e_3_a_ps "3. Solid waste management"
	lab var s10e_4_a_ps "4. Use of disinfectants"
	lab var s10e_5_a_ps "5. Protective equipment"
	lab var s11a_1_a_ps "1. Personal radiation dose monitoring"
	lab var s11a_2_a_ps "2. Radiation safety service provider "
	lab var s11a_3_a_ps "3. Adequate number of lead aprons "
	lab var s11a_4_a_ps "4. Radiological examination in pregnancy "
	lab var s11a_5_a_ps "5. Quality assurance of image processing"
	lab var s11b_1_a_ps "1. Policies, SOPs and code of practice"
	lab var s11b_2_a_ps "2. Reporting, testing and calibration "
	lab var s11b_3_a_ps "3. Register of eradiating activities "
	lab var s11b_4_a_ps "4. Quality assurance program"
	lab var s11c_1_a_ps "1. Personal safety measures "
	lab var s11c_2_a_ps "2. Radioactive waste management programs in place "
	lab var s11c_3_a_ps "3. Designated staff for radioactive waste management programs "
	lab var s11d_1_a_ps "1. Hygiene protocol"
	lab var s11d_2_a_ps "2. Hand washing"
	lab var s11d_3_a_ps "3. Use of disinfectants"
	lab var s11d_4_a_ps "4. Protective equipment"
	lab var s12a_1_a_ps "1. Nutrition equipment and tools "
	lab var s12a_2_a_ps "2. Food supplies, formulations and Nutrition supplements "
	lab var s12b_1_a_ps "1 SOPs for nutrition car processes and other services"
	lab var s12c_1_a_ps "2 Record keeping and documentation"
	lab var s12d_1_a_ps "1. Inpatient feeding"
	lab var s12d_2_a_ps "2. Maternity feeding "
	lab var s12e_1_a_ps "1. Kitchen equipment and fuel"
	lab var s12e_2_a_ps "2. Food Preparation Unit layout"
	lab var s12e_3_a_ps "3. Kitchen personnel"
	lab var s12f_1_a_ps "1 Hygiene protocol"
	lab var s12f_2_a_ps "2. Hand washing"
	lab var s12f_3_a_ps "3. Solid waste management"
	lab var s12f_4_a_ps "4. Use of disinfectants"
	lab var s12f_5_a_ps "5. Protective equipment"

	lab var nutrition "Inpatient Services (activates Nutrition)"
	lab var labour "Labour Ward or Delivery Services"
	

	
	drop s2d_a_ms	s2e_a_ms	s2f_a_ms s3e_a_ms	s3f_a_ms s4c_a_ms	s4d_a_ms	s4e_a_ms	s4f_a_ms s5c_a_ms	s5d_a_ms	s5e_a_ms	s5f_a_ms s6c_a_ms	s6d_a_ms	s6e_a_ms	s6f_a_ms s7c_a_ms	s7d_a_ms	s7e_a_ms	s7f_a_ms	s8c_a_ms	s8d_a_ms	s8e_a_ms	s8f_a_ms	s9f_a_ms	s10f_a_ms	s11e_a_ms	s11f_a_ms s8e_10 s2a_1_a_count	s2b_1_a_count	s2c_1_a_count	s2a_2_a_count	s2b_2_a_count	s2c_2_a_count	s2a_3_a_count	s2b_3_a_count	s2c_3_a_count	s2c_4_a_count	s3a_1_a_count	s3b_1_a_count	s3c_1_a_count	s3a_2_a_count	s3b_2_a_count	s3c_2_a_count	s3a_3_a_count	s3b_3_a_count	s3c_3_a_count	s3c_4_a_count	s3c_5_a_count	s3d_1_a_count	s3d_2_a_count	s4a_1_a_count	s4a_2_a_count	s4a_3_a_count	s4a_4_a_count	s4b_1_a_count	s5a_1_a_count	s5b_1_a_count	s5a_2_a_count	s5b_2_a_count	s5a_3_a_count	s5b_3_a_count	s5a_4_a_count	s5b_4_a_count	s5b_5_a_count	s6a_1_a_count	s6b_1_a_count	s6a_2_a_count	s6b_2_a_count	s6a_3_a_count	s6b_3_a_count	s6a_4_a_count	s6b_4_a_count	s6a_5_a_count	s6b_5_a_count	s6a_6_a_count	s6a_7_a_count	s6a_8_a_count	s7a_1_a_count	s7b_1_a_count	s7a_2_a_count	s7b_2_a_count	s7a_3_a_count	s7b_3_a_count	s7b_4_a_count	s7b_5_a_count	s8a_1_a_count	s8b_1_a_count	s8a_2_a_count	s8b_2_a_count	s8a_3_a_count	s8b_3_a_count	s8a_4_a_count	s8b_4_a_count	s8a_5_a_count	s8b_5_a_count	s9a_1_a_count	s9b_1_a_count	s9c_1_a_count	s9d_1_a_count	s9e_1_a_count	s9a_2_a_count	s9e_2_a_count	s9e_3_a_count	s9e_4_a_count	s9e_5_a_count	s10a_2_a_count	s10e_2_a_count	s10a_3_a_count	s10e_3_a_count	s10a_4_a_count	s10e_4_a_count	s10a_5_a_count	s10e_5_a_count	s10b_1_a_count	s10d_1_a_count	s10b_2_a_count	s10d_2_a_count	s10c_1_a_count	s10b_3_a_count	s10b_4_a_count	s10e_1_a_count	s11a_1_a_count	s11b_1_a_count	s11c_1_a_count	s11d_1_a_count	s11a_2_a_count	s11b_2_a_count	s11c_2_a_count	s11d_2_a_count	s11a_3_a_count	s11b_3_a_count	s11c_3_a_count	s11d_3_a_count	s11a_4_a_count	s11a_5_a_count	s11b_4_a_count	s11d_4_a_count	s12a_1_a_count	s12d_1_a_count	s12e_1_a_count	s12f_1_a_count	s12a_2_a_count	s12d_2_a_count	s12e_2_a_count	s12f_2_a_count	s12b_1_a_count	s12c_1_a_count	s12e_3_a_count	s12f_3_a_count	s12f_4_a_count	s12f_5_a_count

********************************************************************************

** Part 4: Risk categories (compliance) 

********************************************************************************

	gen risk_c = 1 if total_ps >= 0 & total_ps <= 0.1
	replace risk_c = 2 if total_ps > 0.1 & total_ps <= 0.4
	replace risk_c = 3 if total_ps > 0.4 &  total_ps <= 0.6
	replace risk_c = 4 if total_ps > 0.6 & total_ps <= 0.75
	replace risk_c = 5 if total_ps > 0.75 
	
	lab define risk_c 1 "Non-compliant" 2 "Minimally compliant" 3 "Partially compliant" 4 "Substantially compliant" 5 "Fully compliant"
	lab value risk_c risk_c
	
	lab var risk_c "Risk Category"
	
	lab var total_s "Total Score"
	lab var total_ms "Total Max Score"
	lab var total_ps "Total Percentage Score"
	
	clonevar hfid=a5
	clonevar jhic_all_bl=total_ps 
	clonevar jhic_infrastructure_bl=s2_a_ps 
	clonevar jhic_management_bl=s3_a_ps 
	clonevar jhic_generalipc_bl=s4_a_ps 
	clonevar jhic_consultation_bl=s5_a_ps 
	lab var jhic_all_bl "JHIC Score at baseline (% of max)"
	lab var jhic_infrastructure_bl "JHIC Score at Baseline - Consultation (% of max)"
	lab var jhic_management_bl "JHIC Score at Baseline - Management (% of max)"
	lab var jhic_generalipc_bl "JHIC Score at Baseline - General IPC (% of max)"
	lab var jhic_consultation_bl "JHIC Score at Baseline - Infrastructure (% of max)"
	foreach x in jhic_all_bl jhic_consultation_bl jhic_generalipc_bl jhic_management_bl jhic_infrastructure_bl {
	replace `x' = `x'*100
	}
	ren risk_c risk_c_bl 
	lab var risk_c_bl "Compliance category, based on JHIC score at baseline"
	lab def risk_c 1 "Non-Compliant (0-10%)" 2 "Minimally Compliant (11-40%)" 3 "Partially Compliant (41-60%)" 4 "Substantially Compliant (61-75%)" 5 "Fully Compliant (>75%)", modify
	lab val	risk_c_bl risk_c
	
	/*
	bys market_all: gen mk_p = _n
		bys market_all: egen mk_tp = max(mk_p)
		lab var mk_p "Patient ID (No.) per market"
		lab var mk_tp "Total No. of Patients per market"
		*/
		
	recode risk_c_bl (2=1) (3 4 5 = 0), gen(minimally_c_bl)
	recode risk_c_bl (3=1) (2 4 5 = 0), gen(partially_c_bl)
	recode risk_c_bl (4=1) (2 3 5 = 0), gen(substantially_c_bl)
	recode risk_c_bl (5=1) (2 3 4 = 0), gen(fully_c_bl)
	
	replace hfid=500119 if hfid==901138 // recode duplicate ID to match with endline
		
********************************************************************************

** Part 5: Save database

********************************************************************************

	 save "${jhic_bl_scores}", replace
